
package io.platform.approvalConfiguration.web.controller.rest;


import io.platform.approvalConfiguration.dto.AuditPathsLevelsDto;
import io.platform.approvalConfiguration.web.remote.AuditPathsLevelsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/auditPathsLevels")
public class AuditPathsLevelsRestController extends AbstractController {

    @Autowired
    private AuditPathsLevelsServiceRemote auditPathsLevelsServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:auditPathsLevels:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", auditPathsLevelsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:auditPathsLevels:page")
    public R page(Page page, AuditPathsLevelsDto auditPathsLevelsDto) {
        return R.ok().put("page", auditPathsLevelsServiceRemote.getPage(page, auditPathsLevelsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:auditPathsLevels:info")
    public R info(@PathVariable("id") Long id) {
        AuditPathsLevelsDto auditPathsLevelsDto = auditPathsLevelsServiceRemote.getOne(id);
        return R.ok().put("auditPathsLevelsDto", auditPathsLevelsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:auditPathsLevels:save")
    public R save(@RequestBody AuditPathsLevelsDto auditPathsLevelsDto) {
        ValidatorUtils.validateEntity(auditPathsLevelsDto);
        ExecuteResult<String> result = auditPathsLevelsServiceRemote.save(auditPathsLevelsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:auditPathsLevels:edit")
    public R update(@RequestBody AuditPathsLevelsDto auditPathsLevelsDto) {
        ValidatorUtils.validateEntity(auditPathsLevelsDto);
        ExecuteResult<String> result = auditPathsLevelsServiceRemote.update(auditPathsLevelsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:auditPathsLevels:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = auditPathsLevelsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
