
package io.platform.approvalConfiguration.web.controller.rest;


import io.platform.approvalConfiguration.dto.AuditPathsActsDto;
import io.platform.approvalConfiguration.dto.AuditPathsDto;
import io.platform.approvalConfiguration.web.remote.AuditPathsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Map;


@RestController
@RequestMapping("/engineering/auditPaths")
public class AuditPathsRestController extends AbstractController {

    @Autowired
    private AuditPathsServiceRemote auditPathsServiceRemote;


    /**
     * 所有列表
     */
    @PostMapping("/selectApprovedEvents")
    public R selectApprovedEvents(@RequestBody Page page) {
        System.out.println(page.toString());
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", auditPathsServiceRemote.selectApprovedEvents(sysUserDto));
    }


    /**
     * 所有列表
     */
    @PostMapping("/list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", auditPathsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/getPage")
    public R page(Page page, AuditPathsDto auditPathsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", auditPathsServiceRemote.getPage(page, auditPathsDto, sysUserDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    public R info(@PathVariable("id") Long id) {
        AuditPathsDto auditPathsDto = auditPathsServiceRemote.getOne(id);
        return R.ok().put("auditPathsDto", auditPathsDto);
    }

    /**
     * 查询审批流信息
     */
    @PostMapping("/queryAuditPath")
    public R queryAuditPath(@RequestBody AuditPathsDto auditPathsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", auditPathsServiceRemote.queryAuditPath(auditPathsDto, sysUserDto));
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    public R save(@RequestParam("auditPaths") String auditPathsDto, @RequestParam("auditPathsLevels") String auditPathsLevelsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = auditPathsServiceRemote.save(auditPathsDto, auditPathsLevelsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    public R update(@RequestBody AuditPathsDto auditPathsDto) {
        ValidatorUtils.validateEntity(auditPathsDto);
        ExecuteResult<String> result = auditPathsServiceRemote.update(auditPathsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    public R delete(@RequestBody Integer ids) {
        ExecuteResult<String> result = auditPathsServiceRemote.deleteAuditPaths(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询审批流配置信息
     */
    @PostMapping("/selectAuditPathAct")
    public Map<String, Object> selectAuditPathAct(Page page, AuditPathsActsDto auditPathsActsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        if (auditPathsActsDto.getBranchId() == null) {
            auditPathsActsDto.setBranchId(sysUserDto.getLoginContractorId());
        }
        return R.ok().put("map", auditPathsServiceRemote.selectAuditPathAct(page,auditPathsActsDto));
    }

    /**
     * 保存审批流配置信息
     */
    @PostMapping("/saveAuditPathAct")
    public R saveAuditPathAct(@RequestBody String auditPathsActsDtoList) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = auditPathsServiceRemote.saveAuditPathAct(auditPathsActsDtoList, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
