package io.platform.base.common.xss;

import org.apache.commons.io.IOUtils;

import javax.servlet.*;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.*;

/**
 * XSS过滤
 *
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2017-04-01 10:20
 */
public class XssFilter implements Filter {

    @Override
    public void init(FilterConfig config) throws ServletException {
    }

    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
            throws IOException, ServletException {
        ContentCachingRequestWrapper requestWrapper = new ContentCachingRequestWrapper((HttpServletRequest) request);
        String body = IOUtils.toString(requestWrapper.getBody(), request.getCharacterEncoding());
        Map<String, String[]> properties = request.getParameterMap();
        if (!body.equals("")) {
            if (SQLFilter.sqlInject(body) == null) {
                return;
            }
        } else if (properties.size() != 0) {
            if (SQLFilter.sqlInject(getMapToString(properties)) == null) {
                return;
            }
        }
        chain.doFilter(requestWrapper, response);
    }
//参数类型是Map<String,String> 因为支付只能用string的参数。如果诸君还需要修改的话，那也可以适当的做调整

    /**
     * map转str
     *
     * @param map
     * @return
     */
    public static String getMapToString(Map<String, String[]> map) {
        Set<String> keySet = map.keySet();
        //将set集合转换为数组
        String[] keyArray = keySet.toArray(new String[keySet.size()]);
        //给数组排序(升序)
        Arrays.sort(keyArray);
        //因为String拼接效率会很低的，所以转用StringBuilder。博主会在这篇博文发后不久，会更新一篇String与StringBuilder开发时的抉择的博文。
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < keyArray.length; i++) {
            // 参数值为空，则不参与签名 这个方法trim()是去空格
            if (String.valueOf(map.get(keyArray[i])).trim().length() > 0) {
                sb.append(keyArray[i]).append("=").append(Arrays.toString(map.get(keyArray[i])).trim());
            }
            if (i != keyArray.length - 1) {
                sb.append(";");
            }
        }
        return sb.toString();
    }

    public static void main(String[] args) {
        Map<String, String[]> objectMap = new HashMap<>(3);
        objectMap.put("id", new String[]{"", ""});
        objectMap.put("name", new String[]{"哆啦A梦", "幻想"});
        System.out.println(XssFilter.getMapToString(objectMap));
    }

    @Override
    public void destroy() {
    }

}