
package io.platform.budget.web.controller.rest;


import io.platform.approvalConfiguration.dto.AuditItemsDto;
import io.platform.budget.dto.BudgetAdjustBillsDto;
import io.platform.budget.web.remote.BudgetAdjustBillsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import io.swagger.models.auth.In;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/budgetAdjustBills")
public class BudgetAdjustBillsRestController extends AbstractController {

    @Autowired
    private BudgetAdjustBillsServiceRemote budgetAdjustBillsServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:budgetAdjustBills:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", budgetAdjustBillsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:budgetAdjustBills:page")
    public R page(Page page, BudgetAdjustBillsDto budgetAdjustBillsDto) {
        return R.ok().put("page", budgetAdjustBillsServiceRemote.getPage(page, budgetAdjustBillsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:budgetAdjustBills:info")
    public R info(@PathVariable("id") Long id) {
        BudgetAdjustBillsDto budgetAdjustBillsDto = budgetAdjustBillsServiceRemote.getOne(id);
        return R.ok().put("budgetAdjustBillsDto", budgetAdjustBillsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:budgetAdjustBills:save")
    public R save(@RequestBody BudgetAdjustBillsDto budgetAdjustBillsDto) {
        ValidatorUtils.validateEntity(budgetAdjustBillsDto);
        ExecuteResult<String> result = budgetAdjustBillsServiceRemote.save(budgetAdjustBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:budgetAdjustBills:edit")
    public R update(@RequestBody BudgetAdjustBillsDto budgetAdjustBillsDto) {
        ValidatorUtils.validateEntity(budgetAdjustBillsDto);
        ExecuteResult<String> result = budgetAdjustBillsServiceRemote.update(budgetAdjustBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:budgetAdjustBills:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = budgetAdjustBillsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectAllAuditItems")
    public Map<String, Object> selectAllAuditItems(@RequestParam("val") String status) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return budgetAdjustBillsServiceRemote.selectAllAuditItems(status, sysUserDto);
    }
}
