
package io.platform.budget.web.controller.rest;


import io.platform.budget.dto.ProjectBillsAdjustsDto;
import io.platform.budget.web.remote.ProjectBillsAdjustsServiceRemote;
import io.platform.project.dto.ProjectBillsStepsAdjustDto;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectBillsAdjusts")
public class ProjectBillsAdjustsRestController extends AbstractController {

    @Autowired
    private ProjectBillsAdjustsServiceRemote projectBillsAdjustsServiceRemote;

    /**
     * 调整预算模糊查询
     *
     * @param projectBillsSubsDto
     * @return
     */
    @PostMapping("/fuzzyQueryProjectAdjust")
    @RequiresPermissions("engineering:projectBillsAdjusts:list")
    public R fuzzyQueryProSubs(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("list", projectBillsAdjustsServiceRemote.fuzzyQueryProjectAdjust(projectBillsSubsDto));
    }

    /**
     * 查询暂存操作信息
     *
     * @param projectBillsAdjustsDto
     * @return
     */
    @PostMapping("/queryTemporaryInformation")
    public R queryTemporaryInformation(@RequestBody ProjectBillsAdjustsDto projectBillsAdjustsDto) {
        return R.ok().put("list", projectBillsAdjustsServiceRemote.queryTemporaryInformation(projectBillsAdjustsDto));
    }

    /**
     * 查询
     */
    @PostMapping("/changeFuzzyQueryProjectAdjust")
    @RequiresPermissions("engineering:projectBillsAdjusts:list")
    public R changeFuzzyQueryProjectAdjust(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("list", projectBillsAdjustsServiceRemote.changeFuzzyQueryProjectAdjust(projectBillsSubsDto));
    }

    /**
     * 查询子工程预算暂存信息
     */
    @PostMapping("/queryProSubBudgetTemporary")
    @RequiresPermissions("engineering:projectBillsAdjusts:list")
    public R queryProSubBudgetTemporary(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("list", projectBillsAdjustsServiceRemote.queryProSubBudgetTemporary(projectBillsSubsDto));
    }

    /**
     * 查询子工程预算信息
     */
    @PostMapping("/queryProSubBudget")
    @RequiresPermissions("engineering:projectBillsAdjusts:list")
    public R queryProSubBudget(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("list", projectBillsAdjustsServiceRemote.queryProSubBudget(projectBillsSubsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:projectBillsAdjusts:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectBillsAdjustsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:projectBillsAdjusts:page")
    public R page(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectBillsAdjustsServiceRemote.getPage(map,sysUserDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectBillsAdjusts:info")
    public R info(@PathVariable("id") Long id) {
        ProjectBillsAdjustsDto projectBillsAdjustsDto = projectBillsAdjustsServiceRemote.getOne(id);
        return R.ok().put("projectBillsAdjustsDto", projectBillsAdjustsDto);
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/projectAdjustsTemporary")
    @RequiresPermissions("engineering:projectBillsAdjusts:save")
    public R projectAdjustsTemporary(@RequestParam(required = false, value = "proSubs") String projectBillsSubs,
                                @RequestParam(required = false, value = "proAdjusts") String projectBillsAdjustsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectBillsAdjustsServiceRemote.projectAdjustsTemporary(projectBillsSubs, projectBillsAdjustsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/saveProjectAdjusts")
    public R saveProjectAdjusts(@RequestParam(required = false, value = "proSubs") String projectBillsSubs,
                                @RequestParam(required = false, value = "proAdjusts") String projectBillsAdjustsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectBillsAdjustsServiceRemote.saveProjectAdjusts(projectBillsSubs, projectBillsAdjustsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectBillsAdjusts:save")
    public R save(@RequestBody ProjectBillsAdjustsDto projectBillsAdjustsDto) {
        ValidatorUtils.validateEntity(projectBillsAdjustsDto);
        ExecuteResult<String> result = projectBillsAdjustsServiceRemote.save(projectBillsAdjustsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectBillsAdjusts:edit")
    public R update(@RequestBody ProjectBillsAdjustsDto projectBillsAdjustsDto) {
        ValidatorUtils.validateEntity(projectBillsAdjustsDto);
        ExecuteResult<String> result = projectBillsAdjustsServiceRemote.update(projectBillsAdjustsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除预算
     */
    @SysLog("删除预算")
    @PostMapping("/deleteProjectAdjusts")
    @RequiresPermissions("engineering:projectBillsAdjusts:delete")
    public R delete(@RequestBody ProjectBillsAdjustsDto projectBillsAdjustsDto) {
        ExecuteResult<String> result = projectBillsAdjustsServiceRemote.deleteProjectAdjusts(projectBillsAdjustsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
