
package io.platform.budget.web.controller.rest;


import io.platform.budget.dto.ProjectBillsBudgetsDto;
import io.platform.budget.web.remote.ProjectBillsBudgetsServiceRemote;
import io.platform.engineering.dto.BpurchasesDto;
import io.platform.project.dto.ProjectBS;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.dto.ProjectbillsDto;
import io.platform.project.dto.SubContractBillsDto;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectBillsBudgets")
public class ProjectBillsBudgetsRestController extends AbstractController {

    @Autowired
    private ProjectBillsBudgetsServiceRemote projectBillsBudgetsServiceRemote;

    /**
     * 根据单号查询
     *
     * @param id
     * @return
     */
    @PostMapping("/budgetsQueryContract")
    public R budgetsQueryContract(@RequestBody Integer id) {
        return R.ok().put("list", projectBillsBudgetsServiceRemote.budgetsQueryContract(id));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:projectBillsBudgets:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectBillsBudgetsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:projectBillsBudgets:page")
    public R page(Page page, ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        return R.ok().put("page", projectBillsBudgetsServiceRemote.getPage(page, projectBillsBudgetsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectBillsBudgets:info")
    public R info(@PathVariable("id") Long id) {
        ProjectBillsBudgetsDto projectBillsBudgetsDto = projectBillsBudgetsServiceRemote.getOne(id);
        return R.ok().put("projectBillsBudgetsDto", projectBillsBudgetsDto);
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/projectBudgetTemporary")
    @RequiresPermissions("engineering:projectBillsBudgets:save")
    public R projectBudgetTemporary(@RequestParam(required = false, value = "proSubs") String projectBillsSubs,
                                    @RequestParam(required = false, value = "proBudGet") String projectBudget) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectBillsBudgetsServiceRemote.projectBudgetTemporary(projectBillsSubs, projectBudget, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/projectBudgetSave")
    public R projectBudgetSave(@RequestParam(required = false, value = "proSubs") String projectBillsSubs,
                               @RequestParam(required = false, value = "proBudGet") String projectBudget) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectBillsBudgetsServiceRemote.projectBudgetSave(projectBillsSubs, projectBudget, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 编辑提交
     */
    @SysLog("编辑提交")
    @PostMapping("/editBudgetSave")
    @RequiresPermissions("engineering:projectBillsBudgets:save")
    public R editBudgetSave(@RequestBody List<ProjectBillsBudgetsDto> projectBillsBudgetsDto) {
        ValidatorUtils.validateEntity(projectBillsBudgetsDto);
        ExecuteResult<String> result = projectBillsBudgetsServiceRemote.editBudgetSave(projectBillsBudgetsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 编辑提交
     */
    @PostMapping("/selectRenewRecordNew")
    public R selectRenewRecordNew(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("page", projectBillsBudgetsServiceRemote.selectRenewRecordNew(projectBillsSubsDto));
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectBillsBudgets:save")
    public R save(@RequestBody ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        ValidatorUtils.validateEntity(projectBillsBudgetsDto);
        ExecuteResult<String> result = projectBillsBudgetsServiceRemote.save(projectBillsBudgetsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectBillsBudgets:edit")
    public R update(@RequestBody ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        ValidatorUtils.validateEntity(projectBillsBudgetsDto);
        ExecuteResult<String> result = projectBillsBudgetsServiceRemote.update(projectBillsBudgetsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除预算编制
     */
    @SysLog("删除预算编制")
    @PostMapping("/deleteProjectBudget")
    @RequiresPermissions("engineering:projectBillsBudgets:delete")
    public R delete(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        ExecuteResult<String> result = projectBillsBudgetsServiceRemote.deleteProjectBudget(projectBillsSubsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     *  付款是存续并且已经开了发票的 查询预算
     */
    @PostMapping("selectBillsBudget")
    public Map<String, Object> selectBillsBudget (@RequestBody ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        return projectBillsBudgetsServiceRemote.selectBillsBudget(projectBillsBudgetsDto);
    }

    /*
        付款存续工程款查询供应商
     */
    @PostMapping("selectProjectPriceBudget")
    public List<BpurchasesDto> selectProjectPriceBudget (@RequestParam("subNo") String subNo) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return projectBillsBudgetsServiceRemote.selectProjectPriceBudget(subNo, sysUserDto.getLoginContractorId());
    }

    /**
     *  查询分包合同
     */
    @PostMapping("selectProjectSubBills")
    public Map<String, Object>  selectProjectSubBills (@RequestBody SubContractBillsDto subContractBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        subContractBillsDto.setBranchId(sysUserDto.getLoginContractorId());
        return projectBillsBudgetsServiceRemote.selectProjectSubBills(subContractBillsDto);
    }
}
