
package io.platform.contract.web.controller;


import io.platform.contract.dto.OtherProjectDto;
import io.platform.contract.web.remote.OtherProjectServiceRemote;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/otherProject")
public class OtherProjectRestController extends AbstractController {

    @Autowired
    private OtherProjectServiceRemote otherProjectServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:otherProject:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", otherProjectServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:otherProject:page")
    public R page(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", otherProjectServiceRemote.getPage(map,sysUserDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:otherProject:info")
    public R info(@PathVariable("id") Long id) {
        OtherProjectDto otherProjectDto = otherProjectServiceRemote.getOne(id);
        return R.ok().put("otherProjectDto", otherProjectDto);
    }

    /**
     * 查询暂存信息
     */
    @PostMapping("/queryOtherProTemporary")
    @RequiresPermissions("engineering:otherProject:save")
    public R queryOtherProTemporary(@RequestBody OtherProjectDto otherProjectDto) {
        ValidatorUtils.validateEntity(otherProjectDto);
        return R.ok().put("list", otherProjectServiceRemote.queryOtherProTemporary(otherProjectDto));
    }

    /**
     * 查询其他合同信息-NC采购单号是否存在
     */
    @PostMapping("/queryOtherProPurchaseNcNo")
    @RequiresPermissions("engineering:otherProject:save")
    public R queryOtherProPurchaseNcNo(@RequestBody OtherProjectDto otherProjectDto) {
        ValidatorUtils.validateEntity(otherProjectDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", otherProjectServiceRemote.queryOtherProPurchaseNcNo(otherProjectDto, sysUserDto));
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/otherProTemporary")
    @RequiresPermissions("engineering:otherProject:save")
    public R otherProTemporary(@RequestBody OtherProjectDto otherProjectDto) {
        ValidatorUtils.validateEntity(otherProjectDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = otherProjectServiceRemote.otherProTemporary(otherProjectDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/otherProSave")
    @RequiresPermissions("engineering:otherProject:save")
    public R otherProSave(@RequestBody OtherProjectDto otherProjectDto) {
        ValidatorUtils.validateEntity(otherProjectDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = otherProjectServiceRemote.otherProSave(otherProjectDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:otherProject:save")
    public R save(@RequestBody OtherProjectDto otherProjectDto) {
        ValidatorUtils.validateEntity(otherProjectDto);
        ExecuteResult<String> result = otherProjectServiceRemote.save(otherProjectDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:otherProject:edit")
    public R update(@RequestBody OtherProjectDto otherProjectDto) {
        ValidatorUtils.validateEntity(otherProjectDto);
        ExecuteResult<String> result = otherProjectServiceRemote.update(otherProjectDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:otherProject:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = otherProjectServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 普通分页
     */
    @PostMapping("purchaseNcPage")
    @RequiresPermissions("engineering:otherProject:page")
    public Map<String, Object> purchaseNcPage(Page page, InvoiceBillsDto invoiceBillsDto){
        return otherProjectServiceRemote.purchaseNcPage(page,invoiceBillsDto, (SysUserDto) SecurityUtils.getSubject().getPrincipal());
    }

}
