
package io.platform.contract.web.controller;


import io.platform.contract.dto.ProjectBillsStlPlansDto;
import io.platform.contract.web.remote.ProjectBillsStlsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectBillsStls")
public class ProjectBillsStlsRestController extends AbstractController {

    @Autowired
    private ProjectBillsStlsServiceRemote projectBillsStlsServiceRemote;

    /**
     * 查询结算明细
     *
     * @param projectBillsStlPlansDto
     * @return
     */
    @PostMapping("/queryProStls")
    @RequiresPermissions("engineering:projectBillsStls:list")
    public R queryProStls(@RequestBody ProjectBillsStlPlansDto projectBillsStlPlansDto) {
        return R.ok().put("list", projectBillsStlsServiceRemote.queryProStls(projectBillsStlPlansDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:projectBillsStls:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectBillsStlsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:projectBillsStls:page")
    public R page(Page page, ProjectBillsStlPlansDto projectBillsStlPlansDto) {
        return R.ok().put("page", projectBillsStlsServiceRemote.getPage(page, projectBillsStlPlansDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectBillsStls:info")
    public R info(@PathVariable("id") Long id) {
        ProjectBillsStlPlansDto projectBillsStlPlansDto = projectBillsStlsServiceRemote.getOne(id);
        return R.ok().put("projectBillsStlsDto", projectBillsStlPlansDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectBillsStls:save")
    public R save(@RequestBody ProjectBillsStlPlansDto projectBillsStlPlansDto) {
        ValidatorUtils.validateEntity(projectBillsStlPlansDto);
        ExecuteResult<String> result = projectBillsStlsServiceRemote.save(projectBillsStlPlansDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectBillsStls:edit")
    public R update(@RequestBody ProjectBillsStlPlansDto projectBillsStlPlansDto) {
        ValidatorUtils.validateEntity(projectBillsStlPlansDto);
        ExecuteResult<String> result = projectBillsStlsServiceRemote.update(projectBillsStlPlansDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:projectBillsStls:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = projectBillsStlsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
