
package io.platform.contract.web.controller;


import io.platform.contract.dto.TasklistsDto;
import io.platform.contract.web.remote.TasklistsServiceRemote;
import io.platform.project.web.remote.ProjectbillsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Calendar;
import java.util.List;
import java.util.Map;
import java.util.Random;


@RestController
@RequestMapping("/engineering/tasklists")
public class TasklistsRestController extends AbstractController {

    @Autowired
    private ProjectbillsServiceRemote projectbillsServiceRemote;
    @Autowired
    private TasklistsServiceRemote tasklistsServiceRemote;

    /**
     * 获取单号
     */
    @PostMapping("/queryBillNo")
    public String queryBillNo(String str) {
        Calendar now = Calendar.getInstance();
//        int i = (int) (Math.random() * 900 + 100);
        String num = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
        Random random1 = new Random();
        //指定字符串长度，拼接字符并toString
        StringBuffer sb = new StringBuffer();
        for (int i = 0; i < 3; i++) {
            //获取指定长度的字符串中任意一个字符的索引值
            int number = random1.nextInt(num.length());
            //根据索引值获取对应的字符
            char charAt = num.charAt(number);
            sb.append(charAt);
        }
        int month = now.get(Calendar.MONTH) + 1;
        if(month>10){
            return str + "-" + now.get(Calendar.YEAR) +""+ month +""+ projectbillsServiceRemote.getSerialNum(str);
        }else{
            return str + "-" + now.get(Calendar.YEAR) +"0"+ month +""+ projectbillsServiceRemote.getSerialNum(str);
        }

    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:tasklists:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", tasklistsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:tasklists:page")
    public R page(Page page, TasklistsDto tasklistsDto) {
        return R.ok().put("page", tasklistsServiceRemote.getPage(page, tasklistsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:tasklists:info")
    public R info(@PathVariable("id") Long id) {
        TasklistsDto tasklistsDto = tasklistsServiceRemote.getOne(id);
        return R.ok().put("tasklistsDto", tasklistsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:tasklists:save")
    public R save(@RequestBody TasklistsDto tasklistsDto) {
        ValidatorUtils.validateEntity(tasklistsDto);
        ExecuteResult<String> result = tasklistsServiceRemote.save(tasklistsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:tasklists:edit")
    public R update(@RequestBody TasklistsDto tasklistsDto) {
        ValidatorUtils.validateEntity(tasklistsDto);
        ExecuteResult<String> result = tasklistsServiceRemote.update(tasklistsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:tasklists:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = tasklistsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
