
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BcorpsDto;
import io.platform.engineering.dto.BprojectNodesDto;
import io.platform.engineering.web.remote.BbranchsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bbranchs")
public class BbranchsRestController extends AbstractController {

    @Autowired
    private BbranchsServiceRemote bbranchsServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectBranchs")
    @RequiresPermissions("engineering:bbranchs:list")
    public R selectbranchs(@RequestBody BbranchsDto bbranchsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", bbranchsServiceRemote.selectbranchs(bbranchsDto, sysUserDto));
    }
    /**
     * 查询所有
     */
    @PostMapping("/selectBranchsTree")
    @RequiresPermissions("engineering:bbranchs:list")
    public R selectBranchsTree() {
//        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", bbranchsServiceRemote.selectbranchsTree());
    }
    /**
     * 模糊查询
     *
     * @param bbranchsDto
     * @return
     */
    @PostMapping("/fuzzyQueryBranch")
    @RequiresPermissions("engineering:bbranchs:list")
    public R fuzzyQuerybranch(Page page, @RequestBody BbranchsDto bbranchsDto) {
        return R.ok().put("list", bbranchsServiceRemote.fuzzyQueryBranch(page, bbranchsDto));
    }

    /**
     * 首页查询承包单位
     *
     */
    @PostMapping("/homeGetBranchs")
    @RequiresPermissions("engineering:bbranchs:list")
    public R homeGetBranchs() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", bbranchsServiceRemote.homeGetBranchs(sysUserDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bbranchs:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bbranchsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @GetMapping("/page")
    @RequiresPermissions("engineering:bbranchs:page")
    public R page(Page page, BbranchsDto bbranchsDto) {
        return R.ok().put("page", bbranchsServiceRemote.getPage(page, bbranchsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bbranchs:info")
    public R info(@PathVariable("id") Long id) {
        BbranchsDto bbranchsDto = bbranchsServiceRemote.getOne(id);
        return R.ok().put("bbranchsDto", bbranchsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/branchSave")
    @RequiresPermissions("engineering:bbranchs:save")
    public R branchSave(@RequestBody BbranchsDto bbranchsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = bbranchsServiceRemote.branchSave(bbranchsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bbranchs:edit")
    public R update(@RequestBody BbranchsDto bbranchsDto) {
        ValidatorUtils.validateEntity(bbranchsDto);
        ExecuteResult<String> result = bbranchsServiceRemote.update(bbranchsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bbranchs:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bbranchsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
