
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BbudgetsDto;
import io.platform.engineering.dto.BprojectTypesDto;
import io.platform.engineering.web.remote.BbudgetsServiceRemote;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bbudgets")
public class BbudgetsRestController extends AbstractController {

    @Autowired
    private BbudgetsServiceRemote bbudgetsServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectBudgets")
    @RequiresPermissions("engineering:bbudgets:list")
    public R selectBudgets(@RequestBody BbudgetsDto bbudgetsDto) {
        return R.ok().put("list", bbudgetsServiceRemote.selectBudgets(bbudgetsDto));
    }

    /*
     * 暂用！！！！！！！！！！！！！！！暂用！！！！！！！！！！
     */
    @PostMapping("/zYQueryBudgetId")
    @RequiresPermissions("engineering:bbudgets:list")
    public R zYQueryBudgetId(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        return R.ok().put("list", bbudgetsServiceRemote.zYQueryBudgetId(invoiceBillsDto));
    }

    /**
     * 模糊查询
     *
     * @param bbudgetsDto
     * @return
     */
    @PostMapping("/fuzzyQueryBudget")
    @RequiresPermissions("engineering:bbudgets:list")
    public R fuzzyQueryBudget(Page page, @RequestBody BbudgetsDto bbudgetsDto) {
        return R.ok().put("list", bbudgetsServiceRemote.fuzzyQueryBudget(page, bbudgetsDto));
    }

    /**
     * 查询其他预算
     *
     * @param bbudgetsDto
     * @return
     */
    @PostMapping("/selectOtherBudgets")
    @RequiresPermissions("engineering:bbudgets:list")
    public R selectOtherBudgets(@RequestBody BbudgetsDto bbudgetsDto) {
        return R.ok().put("list", bbudgetsServiceRemote.selectOtherBudgets(bbudgetsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bbudgets:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bbudgetsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bbudgets:page")
    public R page(Page page, BbudgetsDto bbudgetsDto) {
        return R.ok().put("page", bbudgetsServiceRemote.getPage(page, bbudgetsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bbudgets:info")
    public R info(@PathVariable("id") Long id) {
        BbudgetsDto bbudgetsDto = bbudgetsServiceRemote.getOne(id);
        return R.ok().put("bbudgetsDto", bbudgetsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bbudgets:save")
    public R save(@RequestBody BbudgetsDto bbudgetsDto) {
        ValidatorUtils.validateEntity(bbudgetsDto);
        ExecuteResult<String> result = bbudgetsServiceRemote.save(bbudgetsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bbudgets:edit")
    public R update(@RequestBody BbudgetsDto bbudgetsDto) {
        ValidatorUtils.validateEntity(bbudgetsDto);
        ExecuteResult<String> result = bbudgetsServiceRemote.update(bbudgetsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bbudgets:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bbudgetsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
