
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BcorpTypesDto;
import io.platform.engineering.web.remote.BcorpTypesServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bcorpTypes")
public class BcorpTypesRestController extends AbstractController {

    @Autowired
    private BcorpTypesServiceRemote bcorpTypesServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectCorpType")
    @RequiresPermissions("engineering:bcorpTypes:list")
    public R selectCorpType(@RequestBody BcorpTypesDto bcorpTypesDto) {
        return R.ok().put("list", bcorpTypesServiceRemote.selectCorpType(bcorpTypesDto));
    }

    /**
     * 模糊查询
     *
     * @param bcorpTypesDto
     * @return
     */
    @PostMapping("/fuzzyQueryCorpsType")
    @RequiresPermissions("engineering:bcorpTypes:list")
    public R fuzzyQueryCorpsType(Page page, @RequestBody BcorpTypesDto bcorpTypesDto) {
        return R.ok().put("list", bcorpTypesServiceRemote.fuzzyQueryCorpsType(page, bcorpTypesDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bcorpTypes:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bcorpTypesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bcorpTypes:page")
    public R page(Page page, BcorpTypesDto bcorpTypesDto) {
        return R.ok().put("page", bcorpTypesServiceRemote.getPage(page, bcorpTypesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bcorpTypes:info")
    public R info(@PathVariable("id") Long id) {
        BcorpTypesDto bcorpTypesDto = bcorpTypesServiceRemote.getOne(id);
        return R.ok().put("bcorpTypesDto", bcorpTypesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bcorpTypes:save")
    public R save(@RequestBody BcorpTypesDto bcorpTypesDto) {
        ValidatorUtils.validateEntity(bcorpTypesDto);
        ExecuteResult<String> result = bcorpTypesServiceRemote.save(bcorpTypesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bcorpTypes:edit")
    public R update(@RequestBody BcorpTypesDto bcorpTypesDto) {
        ValidatorUtils.validateEntity(bcorpTypesDto);
        ExecuteResult<String> result = bcorpTypesServiceRemote.update(bcorpTypesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bcorpTypes:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bcorpTypesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
