
package io.platform.engineering.web.controller.rest;


import io.platform.base.common.utils.Excel;
import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BcorpsDto;
import io.platform.engineering.dto.BprojectTypesDto;
import io.platform.engineering.web.remote.BcorpsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.boot.configurationprocessor.json.JSONException;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.text.ParseException;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bcorps")
public class BcorpsRestController extends AbstractController {

    @Autowired
    private BcorpsServiceRemote bcorpsServiceRemote;
    @Autowired
    private Excel excel;

    /**
     * 查询所有
     */
    @PostMapping("/selectCorps")
    @RequiresPermissions("engineering:bcorps:list")
    public R selectCorps(@RequestBody BcorpsDto bcorpsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bcorpsDto.setBranchId(sysUserDto.getLoginContractorId());
        return R.ok().put("list", bcorpsServiceRemote.selectCorps(bcorpsDto));
    }

    /**
     * 模糊查询
     *
     * @param bcorpsDto
     * @return
     */
    @PostMapping("/fuzzyQueryCorps")
    @RequiresPermissions("engineering:bcorps:list")
    public R fuzzyQueryCorps(Page page, @RequestBody BcorpsDto bcorpsDto) {
        return R.ok().put("list", bcorpsServiceRemote.fuzzyQueryCorps(page, bcorpsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bcorps:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bcorpsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bcorps:page")
    public R page(Page page, BcorpsDto bcorpsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", bcorpsServiceRemote.getPage(page, bcorpsDto, sysUserDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bcorps:info")
    public R info(@PathVariable("id") Long id) {
        BcorpsDto bcorpsDto = bcorpsServiceRemote.getOne(id);
        return R.ok().put("bcorpsDto", bcorpsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bcorps:save")
    public R save(@RequestBody BcorpsDto bcorpsDto) {
        ValidatorUtils.validateEntity(bcorpsDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bcorpsDto.setBranchId(sysUserDto.getLoginContractorId());
        ExecuteResult<String> result = bcorpsServiceRemote.save(bcorpsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/saveList")
    @RequiresPermissions("engineering:bcorps:save")
    public R saveList(@RequestBody List<BcorpsDto> bcorpsDtoList) {
        for (BcorpsDto bcorpsDto : bcorpsDtoList) {
            ValidatorUtils.validateEntity(bcorpsDto);
            SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
            bcorpsDto.setBranchId(sysUserDto.getLoginContractorId());
        }
        ExecuteResult<String> result = bcorpsServiceRemote.saveList(bcorpsDtoList);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bcorps:edit")
    public R update(@RequestBody BcorpsDto bcorpsDto) {
        ValidatorUtils.validateEntity(bcorpsDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bcorpsDto.setBranchId(sysUserDto.getLoginContractorId());
        ExecuteResult<String> result = bcorpsServiceRemote.update(bcorpsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bcorps:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bcorpsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 上传
     */
    @PostMapping("/upload")
    public String  upload(@RequestParam("file") MultipartFile file) throws IOException, ParseException, JSONException {

        return excel.excelImportCorp(file);
    }
}
