
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BdeptsDto;
import io.platform.engineering.web.remote.BdeptsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bdepts")
public class BdeptsRestController extends AbstractController {

    @Autowired
    private BdeptsServiceRemote bdeptsServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectDepts")
    @RequiresPermissions("engineering:bdepts:list")
    public R selectDepts(@RequestBody BdeptsDto bdeptsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        if(bdeptsDto.getBranchId()==null){
            bdeptsDto.setBranchId(sysUserDto.getLoginContractorId());
        }
        return R.ok().put("list", bdeptsServiceRemote.selectDepts(bdeptsDto));
    }


    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bdepts:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bdeptsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bdepts:page")
    public R page(Page page, BdeptsDto bdeptsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
//        if (sysUserDto.getLoginContractorId() != 1) {
            bdeptsDto.setBranchId(sysUserDto.getLoginContractorId());
//        }
        return R.ok().put("page", bdeptsServiceRemote.getPage(page, bdeptsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bdepts:info")
    public R info(@PathVariable("id") Long id) {
        BdeptsDto bdeptsDto = bdeptsServiceRemote.getOne(id);
        return R.ok().put("bdeptsDto", bdeptsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bdepts:save")
    public R save(@RequestBody BdeptsDto bdeptsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bdeptsDto.setBranchId(sysUserDto.getLoginContractorId());
        ValidatorUtils.validateEntity(bdeptsDto);
        ExecuteResult<String> result = bdeptsServiceRemote.save(bdeptsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bdepts:edit")
    public R update(@RequestBody BdeptsDto bdeptsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bdeptsDto.setBranchId(sysUserDto.getLoginContractorId());
        ValidatorUtils.validateEntity(bdeptsDto);
        ExecuteResult<String> result = bdeptsServiceRemote.update(bdeptsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bdepts:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bdeptsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
