
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BdeptsDto;
import io.platform.engineering.dto.BemplsDto;
import io.platform.engineering.web.remote.BemplsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bempls")
public class BemplsRestController extends AbstractController {

    @Autowired
    private BemplsServiceRemote bemplsServiceRemote;

    /**
     * 模糊查询
     *
     * @param bemplsDto
     * @return
     */
    @PostMapping("/fuzzyQueryEmpls")
    @RequiresPermissions("engineering:bempls:list")
    public R fuzzyQueryEmpls(Page page, @RequestBody BemplsDto bemplsDto) {
        return R.ok().put("list", bemplsServiceRemote.fuzzyQueryEmpls(page, bemplsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bempls:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bemplsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bempls:page")
    public R page(Page page, BemplsDto bemplsDto) {
        return R.ok().put("page", bemplsServiceRemote.getPage(page, bemplsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bempls:info")
    public R info(@PathVariable("id") Long id) {
        BemplsDto bemplsDto = bemplsServiceRemote.getOne(id);
        return R.ok().put("bemplsDto", bemplsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bempls:save")
    public R save(@RequestBody BemplsDto bemplsDto) {
        ValidatorUtils.validateEntity(bemplsDto);
        ExecuteResult<String> result = bemplsServiceRemote.save(bemplsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bempls:edit")
    public R update(@RequestBody BemplsDto bemplsDto) {
        ValidatorUtils.validateEntity(bemplsDto);
        ExecuteResult<String> result = bemplsServiceRemote.update(bemplsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bempls:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bemplsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
