
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BemplsDto;
import io.platform.engineering.dto.BpayPropertysDto;
import io.platform.engineering.dto.BpriceModesDto;
import io.platform.engineering.web.remote.BpayPropertysServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bpayPropertys")
public class BpayPropertysRestController extends AbstractController {

    @Autowired
    private BpayPropertysServiceRemote bpayPropertysServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectPayPropertys")
    @RequiresPermissions("engineering:bpayPropertys:list")
    public R selectPayPropertys(@RequestBody BpayPropertysDto bpayPropertysDto) {
        return R.ok().put("list", bpayPropertysServiceRemote.selectPayPropertys(bpayPropertysDto));
    }

    /**
     * 模糊查询
     *
     * @param bpayPropertysDto
     * @return
     */
    @PostMapping("/fuzzyQueryPayProperty")
    @RequiresPermissions("engineering:bpayPropertys:list")
    public R fuzzyQueryPayProperty(Page page, @RequestBody BpayPropertysDto bpayPropertysDto) {
        return R.ok().put("list", bpayPropertysServiceRemote.fuzzyQueryPayProperty(page, bpayPropertysDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bpayPropertys:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bpayPropertysServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bpayPropertys:page")
    public R page(Page page, BpayPropertysDto bpayPropertysDto) {
        return R.ok().put("page", bpayPropertysServiceRemote.getPage(page, bpayPropertysDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bpayPropertys:info")
    public R info(@PathVariable("id") Long id) {
        BpayPropertysDto bpayPropertysDto = bpayPropertysServiceRemote.getOne(id);
        return R.ok().put("bpayPropertysDto", bpayPropertysDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bpayPropertys:save")
    public R save(@RequestBody BpayPropertysDto bpayPropertysDto) {
        ValidatorUtils.validateEntity(bpayPropertysDto);
        ExecuteResult<String> result = bpayPropertysServiceRemote.save(bpayPropertysDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bpayPropertys:edit")
    public R update(@RequestBody BpayPropertysDto bpayPropertysDto) {
        ValidatorUtils.validateEntity(bpayPropertysDto);
        ExecuteResult<String> result = bpayPropertysServiceRemote.update(bpayPropertysDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bpayPropertys:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bpayPropertysServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
