
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BpriceModesDto;
import io.platform.engineering.web.remote.BpriceModesServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bpriceModes")
public class BpriceModesRestController extends AbstractController {

    @Autowired
    private BpriceModesServiceRemote bpriceModesServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectProModes")
    @RequiresPermissions("engineering:bpriceModes:list")
    public R selectProModes(@RequestBody BpriceModesDto bpriceModesDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", bpriceModesServiceRemote.selectProModes(bpriceModesDto));
    }

    /**
     * 模糊查询
     *
     * @param bpriceModesDto
     * @return
     */
    @PostMapping("/fuzzyQueryPriceModes")
    @RequiresPermissions("engineering:bpriceModes:list")
    public R fuzzyQueryPriceModes(Page page, @RequestBody BpriceModesDto bpriceModesDto) {
        return R.ok().put("list", bpriceModesServiceRemote.fuzzyQueryPriceModes(page, bpriceModesDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bpriceModes:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bpriceModesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bpriceModes:page")
    public R page(Page page, BpriceModesDto bpriceModesDto) {
        return R.ok().put("page", bpriceModesServiceRemote.getPage(page, bpriceModesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bpriceModes:info")
    public R info(@PathVariable("id") Long id) {
        BpriceModesDto bpriceModesDto = bpriceModesServiceRemote.getOne(id);
        return R.ok().put("bpriceModesDto", bpriceModesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bpriceModes:save")
    public R save(@RequestBody BpriceModesDto bpriceModesDto) {
        ValidatorUtils.validateEntity(bpriceModesDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpriceModesDto.setOpUserName(sysUserDto.getUsername());
        bpriceModesDto.setOpDate(new Date());
        ExecuteResult<String> result = bpriceModesServiceRemote.save(bpriceModesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bpriceModes:edit")
    public R update(@RequestBody BpriceModesDto bpriceModesDto) {
        ValidatorUtils.validateEntity(bpriceModesDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpriceModesDto.setOpUserName(sysUserDto.getUsername());
        bpriceModesDto.setOpDate(new Date());
        ExecuteResult<String> result = bpriceModesServiceRemote.update(bpriceModesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bpriceModes:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bpriceModesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
