
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BprojectNodeStepsDto;
import io.platform.engineering.dto.BprojectNodesDto;
import io.platform.engineering.web.remote.BprojectNodeStepsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bprojectNodeSteps")
public class BprojectNodeStepsRestController extends AbstractController {

    @Autowired
    private BprojectNodeStepsServiceRemote bprojectNodeStepsServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectProNodeSteps")
    @RequiresPermissions("engineering:bprojectNodeSteps:list")
    public R selectProNodeSteps(@RequestBody BprojectNodeStepsDto bprojectNodeStepsDto) {
        return R.ok().put("list", bprojectNodeStepsServiceRemote.selectProNodeSteps(bprojectNodeStepsDto));
    }

    /**
     * 模糊查询
     *
     * @param bprojectNodeStepsDto
     * @return
     */
    @PostMapping("/fuzzyQueryProjectNodeSt")
    @RequiresPermissions("engineering:bprojectNodeSteps:list")
    public R fuzzyQueryProjectNodeSt(Page page, @RequestBody BprojectNodeStepsDto bprojectNodeStepsDto) {
        return R.ok().put("list", bprojectNodeStepsServiceRemote.fuzzyQueryProjectNodeSt(page, bprojectNodeStepsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bprojectNodeSteps:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bprojectNodeStepsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bprojectNodeSteps:page")
    public R page(Page page, BprojectNodeStepsDto bprojectNodeStepsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        if (sysUserDto.getLoginContractorId() != 1) {
            bprojectNodeStepsDto.setBranchId(sysUserDto.getLoginContractorId());
        }
        return R.ok().put("page", bprojectNodeStepsServiceRemote.getPage(page, bprojectNodeStepsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bprojectNodeSteps:info")
    public R info(@PathVariable("id") Long id) {
        BprojectNodeStepsDto bprojectNodeStepsDto = bprojectNodeStepsServiceRemote.getOne(id);
        return R.ok().put("bprojectNodeStepsDto", bprojectNodeStepsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bprojectNodeSteps:save")
    public R save(@RequestBody BprojectNodeStepsDto bprojectNodeStepsDto) {
        ValidatorUtils.validateEntity(bprojectNodeStepsDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectNodeStepsDto.setOpDate(new Date());
        bprojectNodeStepsDto.setOpUserName(sysUserDto.getUsername());
        bprojectNodeStepsDto.setBranchId(sysUserDto.getLoginContractorId());
        ExecuteResult<String> result = bprojectNodeStepsServiceRemote.save(bprojectNodeStepsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bprojectNodeSteps:edit")
    public R update(@RequestBody BprojectNodeStepsDto bprojectNodeStepsDto) {
        ValidatorUtils.validateEntity(bprojectNodeStepsDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectNodeStepsDto.setOpDate(new Date());
        bprojectNodeStepsDto.setOpUserName(sysUserDto.getUsername());
        bprojectNodeStepsDto.setBranchId(sysUserDto.getLoginContractorId());
        ExecuteResult<String> result = bprojectNodeStepsServiceRemote.update(bprojectNodeStepsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bprojectNodeSteps:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bprojectNodeStepsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
