
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BprojectNodesDto;
import io.platform.engineering.dto.BprojectTypesDto;
import io.platform.engineering.web.remote.BprojectNodesServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bprojectNodes")
public class BprojectNodesRestController extends AbstractController {

    @Autowired
    private BprojectNodesServiceRemote bprojectNodesServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectProNodes")
    @RequiresPermissions("engineering:bprojectNodes:list")
    public R selectProNodes(@RequestBody BprojectNodesDto bprojectNodesDto) {
        return R.ok().put("list", bprojectNodesServiceRemote.selectProNodes(bprojectNodesDto));
    }

    /**
     * 模糊查询
     *
     * @param bprojectNodesDto
     * @return
     */
    @PostMapping("/fuzzyQueryProNodes")
    @RequiresPermissions("engineering:bprojectNodes:list")
    public R fuzzyQueryProjectNodes(Page page, @RequestBody BprojectNodesDto bprojectNodesDto) {
        return R.ok().put("list", bprojectNodesServiceRemote.fuzzyQueryProjectNodes(page, bprojectNodesDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bprojectNodes:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bprojectNodesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bprojectNodes:page")
    public R page(Page page, BprojectNodesDto bprojectNodesDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectNodesDto.setBranchId(sysUserDto.getLoginContractorId());
        return R.ok().put("page", bprojectNodesServiceRemote.getPage(page, bprojectNodesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bprojectNodes:info")
    public R info(@PathVariable("id") Long id) {
        BprojectNodesDto bprojectNodesDto = bprojectNodesServiceRemote.getOne(id);
        return R.ok().put("bprojectNodesDto", bprojectNodesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bprojectNodes:save")
    public R save(@RequestBody BprojectNodesDto bprojectNodesDto) {
        ValidatorUtils.validateEntity(bprojectNodesDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectNodesDto.setOpDate(new Date());
        bprojectNodesDto.setOpUserName(sysUserDto.getUsername());
        bprojectNodesDto.setBranchId(sysUserDto.getLoginContractorId());
        ExecuteResult<String> result = bprojectNodesServiceRemote.save(bprojectNodesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bprojectNodes:edit")
    public R update(@RequestBody BprojectNodesDto bprojectNodesDto) {
        ValidatorUtils.validateEntity(bprojectNodesDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectNodesDto.setOpDate(new Date());
        bprojectNodesDto.setOpUserName(sysUserDto.getUsername());
        bprojectNodesDto.setBranchId(sysUserDto.getLoginContractorId());
        ExecuteResult<String> result = bprojectNodesServiceRemote.update(bprojectNodesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bprojectNodes:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bprojectNodesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
