
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BprojectNodeStepsDto;
import io.platform.engineering.dto.BprojectTypesItemsDto;
import io.platform.engineering.web.remote.BprojectTypesItemsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bprojectTypesItems")
public class BprojectTypesItemsRestController extends AbstractController {

    @Autowired
    private BprojectTypesItemsServiceRemote bprojectTypesItemsServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectProTypsItems")
    @RequiresPermissions("engineering:bprojectTypesItems:list")
    public R selectProTypsItems(@RequestBody BprojectTypesItemsDto bprojectTypesItemsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", bprojectTypesItemsServiceRemote.selectProTypsItems(bprojectTypesItemsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bprojectTypesItems:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bprojectTypesItemsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bprojectTypesItems:page")
    public R page(Page page, BprojectTypesItemsDto bprojectTypesItemsDto) {
        return R.ok().put("page", bprojectTypesItemsServiceRemote.getPage(page, bprojectTypesItemsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bprojectTypesItems:info")
    public R info(@PathVariable("id") Long id) {
        BprojectTypesItemsDto bprojectTypesItemsDto = bprojectTypesItemsServiceRemote.getOne(id);
        return R.ok().put("bprojectTypesItemsDto", bprojectTypesItemsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bprojectTypesItems:save")
    public R save(@RequestBody BprojectTypesItemsDto bprojectTypesItemsDto) {
        ValidatorUtils.validateEntity(bprojectTypesItemsDto);
        SysUserDto sysUser = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectTypesItemsDto.setOpUserName(sysUser.getUsername());
        bprojectTypesItemsDto.setOpDate(new Date());
        ExecuteResult<String> result = bprojectTypesItemsServiceRemote.save(bprojectTypesItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bprojectTypesItems:edit")
    public R update(@RequestBody BprojectTypesItemsDto bprojectTypesItemsDto) {
        SysUserDto sysUser = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectTypesItemsDto.setOpUserName(sysUser.getUsername());
        bprojectTypesItemsDto.setOpDate(new Date());
        ValidatorUtils.validateEntity(bprojectTypesItemsDto);
        ExecuteResult<String> result = bprojectTypesItemsServiceRemote.update(bprojectTypesItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bprojectTypesItems:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bprojectTypesItemsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
