
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BprojectNodesDto;
import io.platform.engineering.dto.BprojectTypesDto;
import io.platform.engineering.web.remote.BprojectTypesServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bprojectTypes")
public class BprojectTypesRestController extends AbstractController {

    @Autowired
    private BprojectTypesServiceRemote bprojectTypesServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectProTypes")
    @RequiresPermissions("engineering:bprojectTypes:list")
    public R selectProTypes(@RequestBody BprojectTypesDto bprojectTypesDto) {
        return R.ok().put("list", bprojectTypesServiceRemote.selectProTypes(bprojectTypesDto));
    }

    /**
     * 模糊查询
     *
     * @param bprojectTypesDto
     * @return
     */
    @PostMapping("/fuzzyQueryProjectTypes")
    @RequiresPermissions("engineering:bprojectTypes:list")
    public R fuzzyQueryProjectTypes(Page page, @RequestBody BprojectTypesDto bprojectTypesDto) {
        return R.ok().put("list", bprojectTypesServiceRemote.fuzzyQueryProjectTypes(page, bprojectTypesDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bprojectTypes:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bprojectTypesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bprojectTypes:page")
    public R page(Page page, BprojectTypesDto bprojectTypesDto) {
        return R.ok().put("page", bprojectTypesServiceRemote.getPage(page, bprojectTypesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bprojectTypes:info")
    public R info(@PathVariable("id") Long id) {
        BprojectTypesDto bprojectTypesDto = bprojectTypesServiceRemote.getOne(id);
        return R.ok().put("bprojectTypesDto", bprojectTypesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bprojectTypes:save")
    public R save(@RequestBody BprojectTypesDto bprojectTypesDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectTypesDto.setOpUserName(sysUserDto.getUsername());
        bprojectTypesDto.setOpDate(new Date());
        ValidatorUtils.validateEntity(bprojectTypesDto);
        ExecuteResult<String> result = bprojectTypesServiceRemote.save(bprojectTypesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bprojectTypes:edit")
    public R update(@RequestBody BprojectTypesDto bprojectTypesDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bprojectTypesDto.setOpUserName(sysUserDto.getUsername());
        bprojectTypesDto.setOpDate(new Date());
        ValidatorUtils.validateEntity(bprojectTypesDto);
        ExecuteResult<String> result = bprojectTypesServiceRemote.update(bprojectTypesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bprojectTypes:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bprojectTypesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
