
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BpurchaseModesDto;
import io.platform.engineering.web.remote.BpurchaseModesServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bpurchaseModes")
public class BpurchaseModesRestController extends AbstractController {

    @Autowired
    private BpurchaseModesServiceRemote bpurchaseModesServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectpurModes")
    @RequiresPermissions("engineering:bpurchaseModes:list")
    public R selectpurModes(@RequestBody BpurchaseModesDto bpurchaseModesDto) {
        return R.ok().put("list", bpurchaseModesServiceRemote.selectpurModes(bpurchaseModesDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bpurchaseModes:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bpurchaseModesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bpurchaseModes:page")
    public R page(Page page, BpurchaseModesDto bpurchaseModesDto) {
        return R.ok().put("page", bpurchaseModesServiceRemote.getPage(page, bpurchaseModesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bpurchaseModes:info")
    public R info(@PathVariable("id") Long id) {
        BpurchaseModesDto bpurchaseModesDto = bpurchaseModesServiceRemote.getOne(id);
        return R.ok().put("bpurchaseModesDto", bpurchaseModesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bpurchaseModes:save")
    public R save(@RequestBody BpurchaseModesDto bpurchaseModesDto) {
        ValidatorUtils.validateEntity(bpurchaseModesDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpurchaseModesDto.setOpUserName(sysUserDto.getUsername());
        bpurchaseModesDto.setOpDate(new Date());
        ExecuteResult<String> result = bpurchaseModesServiceRemote.save(bpurchaseModesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bpurchaseModes:edit")
    public R update(@RequestBody BpurchaseModesDto bpurchaseModesDto) {
        ValidatorUtils.validateEntity(bpurchaseModesDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpurchaseModesDto.setOpUserName(sysUserDto.getUsername());
        bpurchaseModesDto.setOpDate(new Date());
        ExecuteResult<String> result = bpurchaseModesServiceRemote.update(bpurchaseModesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bpurchaseModes:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bpurchaseModesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
