
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BpurchaseSubTypesDto;
import io.platform.engineering.web.remote.BpurchaseSubTypesServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bpurchaseSubTypes")
public class BpurchaseSubTypesRestController extends AbstractController {

    @Autowired
    private BpurchaseSubTypesServiceRemote bpurchaseSubTypesServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectPurchSubTypes")
    @RequiresPermissions("engineering:bpurchaseSubTypes:list")
    public R selectPurchSubTypes(@RequestBody BpurchaseSubTypesDto bpurchaseSubTypesDto) {
        return R.ok().put("list", bpurchaseSubTypesServiceRemote.selectPurchSubTypes(bpurchaseSubTypesDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bpurchaseSubTypes:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bpurchaseSubTypesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bpurchaseSubTypes:page")
    public R page(Page page, BpurchaseSubTypesDto bpurchaseSubTypesDto) {
        return R.ok().put("page", bpurchaseSubTypesServiceRemote.getPage(page, bpurchaseSubTypesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bpurchaseSubTypes:info")
    public R info(@PathVariable("id") Long id) {
        BpurchaseSubTypesDto bpurchaseSubTypesDto = bpurchaseSubTypesServiceRemote.getOne(id);
        return R.ok().put("bpurchaseSubTypesDto", bpurchaseSubTypesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bpurchaseSubTypes:save")
    public R save(@RequestBody BpurchaseSubTypesDto bpurchaseSubTypesDto) {
        ValidatorUtils.validateEntity(bpurchaseSubTypesDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpurchaseSubTypesDto.setOpDate(new Date());
        bpurchaseSubTypesDto.setOpUserName(sysUserDto.getUsername());
        ExecuteResult<String> result = bpurchaseSubTypesServiceRemote.save(bpurchaseSubTypesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bpurchaseSubTypes:edit")
    public R update(@RequestBody BpurchaseSubTypesDto bpurchaseSubTypesDto) {
        ValidatorUtils.validateEntity(bpurchaseSubTypesDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpurchaseSubTypesDto.setOpDate(new Date());
        bpurchaseSubTypesDto.setOpUserName(sysUserDto.getUsername());
        ExecuteResult<String> result = bpurchaseSubTypesServiceRemote.update(bpurchaseSubTypesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bpurchaseSubTypes:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bpurchaseSubTypesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("down")
    public Map<String, Object> down() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return bpurchaseSubTypesServiceRemote.down(sysUserDto);
    }

}
