
package io.platform.engineering.web.controller.rest;


import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BpurchaseTypesDto;
import io.platform.engineering.web.remote.BpurchaseTypesServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bpurchaseTypes")
public class BpurchaseTypesRestController extends AbstractController {

    @Autowired
    private BpurchaseTypesServiceRemote bpurchaseTypesServiceRemote;

    /**
     * 查询所有
     */
    @PostMapping("/selectPurchTypes")
    @RequiresPermissions("engineering:bpurchaseTypes:list")
    public R selectPurchTypes(@RequestBody BpurchaseTypesDto bpurchaseTypesDto) {
        return R.ok().put("list", bpurchaseTypesServiceRemote.selectPurchTypes(bpurchaseTypesDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bpurchaseTypes:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bpurchaseTypesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:bpurchaseTypes:page")
    public R page(Page page, BpurchaseTypesDto bpurchaseTypesDto) {
        return R.ok().put("page", bpurchaseTypesServiceRemote.getPage(page, bpurchaseTypesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bpurchaseTypes:info")
    public R info(@PathVariable("id") Long id) {
        BpurchaseTypesDto bpurchaseTypesDto = bpurchaseTypesServiceRemote.getOne(id);
        return R.ok().put("bpurchaseTypesDto", bpurchaseTypesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bpurchaseTypes:save")
    public R save(@RequestBody BpurchaseTypesDto bpurchaseTypesDto) {
        ValidatorUtils.validateEntity(bpurchaseTypesDto);
        ExecuteResult<String> result = bpurchaseTypesServiceRemote.save(bpurchaseTypesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bpurchaseTypes:edit")
    public R update(@RequestBody BpurchaseTypesDto bpurchaseTypesDto) {
        ValidatorUtils.validateEntity(bpurchaseTypesDto);
        ExecuteResult<String> result = bpurchaseTypesServiceRemote.update(bpurchaseTypesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bpurchaseTypes:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bpurchaseTypesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
