
package io.platform.engineering.web.controller.rest;


import io.platform.base.common.utils.Excel;
import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BpurchasesDto;
import io.platform.engineering.web.remote.BpurchasesServiceRemote;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.boot.configurationprocessor.json.JSONException;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.text.ParseException;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/bpurchases")
public class BpurchasesRestController extends AbstractController {

    @Autowired
    private BpurchasesServiceRemote bpurchasesServiceRemote;
    @Autowired
    private Excel excel;
    /**
     * 查询所有
     */
    @PostMapping("/selectPurchases")
    @RequiresPermissions("engineering:bpurchases:list")
    public R selectPurchases(@RequestBody BpurchasesDto bpurchasesDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpurchasesDto.setBranchId(sysUserDto.getLoginContractorId());
        return R.ok().put("list", bpurchasesServiceRemote.selectPurchases(bpurchasesDto));
    }

    /**
     * 模糊查询
     */
    @PostMapping("/fuzzyQueryPurchases")
    @RequiresPermissions("engineering:bpurchases:list")
    public R fuzzyQueryPurchases(Page page, @RequestBody BpurchasesDto bpurchasesDto) {
        //查询列表数据
        return R.ok().put("list", bpurchasesServiceRemote.fuzzyQueryPurchases(page, bpurchasesDto));
    }


    /**
     * 分页列表
     */
    @PostMapping("/queryDirectPay")
    @RequiresPermissions("engineering:bpurchases:page")
    public R queryDirectPay(Page page, InvoiceBillsDto invoiceBillsDto) {
        return R.ok().put("page", bpurchasesServiceRemote.queryDirectPay(page, invoiceBillsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:bpurchases:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", bpurchasesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
//    @RequiresPermissions("engineering:bpurchases:page")
    public R page(Page page, BpurchasesDto bpurchasesDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        if (sysUserDto.getLoginContractorId() != 1) {
            bpurchasesDto.setBranchId(sysUserDto.getLoginContractorId());
        }
        return R.ok().put("page", bpurchasesServiceRemote.getPage(page, bpurchasesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:bpurchases:info")
    public R info(@PathVariable("id") Long id) {
        BpurchasesDto bpurchasesDto = bpurchasesServiceRemote.getOne(id);
        return R.ok().put("bpurchasesDto", bpurchasesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:bpurchases:save")
    public R save(@RequestBody BpurchasesDto bpurchasesDto) {
        ValidatorUtils.validateEntity(bpurchasesDto);
        SysUserDto dto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpurchasesDto.setBranchId(dto.getLoginContractorId());
        bpurchasesDto.setOpUserId(dto.getUserId());
        ExecuteResult<String> result = bpurchasesServiceRemote.save(bpurchasesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }
    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/saveList")
    @RequiresPermissions("engineering:bpurchases:save")
    public R saveList(@RequestBody List<BpurchasesDto> bpurchasesDtoList) {
        for (BpurchasesDto bpurchasesDto:bpurchasesDtoList){
            ValidatorUtils.validateEntity(bpurchasesDto);
            SysUserDto dto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
            bpurchasesDto.setBranchId(dto.getLoginContractorId());
            bpurchasesDto.setOpUserId(dto.getUserId());
        }
        ExecuteResult<String> result = bpurchasesServiceRemote.saveList(bpurchasesDtoList);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }
    /**
     * 上传
     */
    @PostMapping("/upload")
    public String  upload(@RequestParam("file") MultipartFile file) throws IOException, ParseException, JSONException {

        return excel.excelImportBpurchases(file);
    }
    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:bpurchases:edit")
    public R update(@RequestBody BpurchasesDto bpurchasesDto) {
        SysUserDto dto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        bpurchasesDto.setBranchId(dto.getLoginContractorId());
        ValidatorUtils.validateEntity(bpurchasesDto);
        ExecuteResult<String> result = bpurchasesServiceRemote.update(bpurchasesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:bpurchases:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = bpurchasesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
