
package io.platform.fileManagement.controller.rest;


import io.platform.fileManagement.dto.DataFileManagementDto;
import io.platform.fileManagement.remote.DataFileManagementServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLDecoder;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/dataFileManagement")
public class DataFileManagementRestController extends AbstractController {

    @Autowired
    private DataFileManagementServiceRemote dataFileManagementServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:dataFileManagement:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", dataFileManagementServiceRemote.getList(params));
    }

    /**
     * 所有列表
     */
    @PostMapping("/fileList")
    @RequiresPermissions("engineering:dataFileManagement:fileList")
    public R fileList(@RequestParam("id") Integer id, @RequestParam("type") String type) {
        //查询列表数据
        if (type == null) {
            return R.ok().put("list", dataFileManagementServiceRemote.getFileList(id));
        } else {
            return R.ok().put("list", dataFileManagementServiceRemote.getFileList2(id));
        }

    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:dataFileManagement:page")
    public R page(Page page, DataFileManagementDto dataFileManagementDto) {
        return R.ok().put("page", dataFileManagementServiceRemote.getPage(page, dataFileManagementDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:dataFileManagement:info")
    public R info(@PathVariable("id") Long id) {
        DataFileManagementDto dataFileManagementDto = dataFileManagementServiceRemote.getOne(id);
        return R.ok().put("dataFileManagementDto", dataFileManagementDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:dataFileManagement:save")
    public R save(@RequestBody DataFileManagementDto dataFileManagementDto) {
        ValidatorUtils.validateEntity(dataFileManagementDto);
        ExecuteResult<String> result = dataFileManagementServiceRemote.save(dataFileManagementDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:dataFileManagement:edit")
    public R update(@RequestBody DataFileManagementDto dataFileManagementDto) {
        ValidatorUtils.validateEntity(dataFileManagementDto);
        ExecuteResult<String> result = dataFileManagementServiceRemote.update(dataFileManagementDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:dataFileManagement:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = dataFileManagementServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }


    @GetMapping("/fileDownLoad")
    @RequiresPermissions("engineering:dataFileManagement:fileList")
    private void responseFileStream2(HttpServletRequest request, HttpServletResponse response, String catalog, String filePath) throws Exception {
        download(catalog, filePath, response);
    }

    private void download(String catalog, String filePath, HttpServletResponse response) throws IOException {

        //获取下载的文件路径（注意获取这里获取的是绝对路径，先获取ServletContext再使用ServletContext的getRealPath方法获取绝对路径）

//        String path = "C:\\Users\\ASUS\\Desktop\\es\\" + filePath;

        //设置响应头控制浏览器以下载的形式打开文件
        //attachment =  文件直接下载
        //inline = 文件预览
        response.setHeader("content-disposition",

                "inline;fileName=" + filePath);

//        String filePathUrl = "http://engineering.echepei.com/" + catalog + "/" + filePath; // 测试地址
        String filePathUrl = "http://10.140.124.8/" + catalog + "/" + filePath;
        URL url = new URL(filePathUrl);

        URLConnection conn = url.openConnection();
        InputStream in = conn.getInputStream();

//        InputStream in = new FileInputStream(path); //获取下载文件的输入流

        int count = 0;

        byte[] by = new byte[1024];

        //通过response对象获取OutputStream流

        OutputStream out = response.getOutputStream();

        while ((count = in.read(by)) != -1) {

            out.write(by, 0, count);//将缓冲区的数据输出到浏览器

        }

        in.close();

        out.flush();

        out.close();
    }

}

