
package io.platform.fileManagement.controller.rest;


import io.platform.fileManagement.dto.DataFileStorageDto;
import io.platform.fileManagement.remote.DataFileStorageServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/dataFileStorage")
public class DataFileStorageRestController extends AbstractController {

    @Autowired
    private DataFileStorageServiceRemote dataFileStorageServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:dataFileStorage:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", dataFileStorageServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:dataFileStorage:page")
    public R page(Page page, DataFileStorageDto dataFileStorageDto) {
        return R.ok().put("page", dataFileStorageServiceRemote.getPage(page, dataFileStorageDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:dataFileStorage:info")
    public R info(@PathVariable("id") Long id) {
        DataFileStorageDto dataFileStorageDto = dataFileStorageServiceRemote.getOne(id);
        return R.ok().put("dataFileStorageDto", dataFileStorageDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:dataFileStorage:save")
    public R save(@RequestBody DataFileStorageDto dataFileStorageDto) {
        ValidatorUtils.validateEntity(dataFileStorageDto);
        if (dataFileStorageDto.getFilePath() == null || "".equals(dataFileStorageDto.getFilePath())) {
            return R.error("请输入文件地址");
        }
        if (dataFileStorageDto.getFileType() == null || "".equals(dataFileStorageDto.getFileType())) {
            return R.error("请输入文件类型");
        }
        ExecuteResult<String> result = dataFileStorageServiceRemote.save(dataFileStorageDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:dataFileStorage:edit")
    public R update(@RequestBody DataFileStorageDto dataFileStorageDto) {
        ValidatorUtils.validateEntity(dataFileStorageDto);
        ExecuteResult<String> result = dataFileStorageServiceRemote.update(dataFileStorageDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:dataFileStorage:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = dataFileStorageServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectHomeFileList")
    public List<DataFileStorageDto> selectHomeFileList() {
        return dataFileStorageServiceRemote.selectHomeFileList();
    }
}
