
package io.platform.moneyManagement.web.controller.rest;


import io.platform.moneyManagement.dto.InvoiceBillsAttachsDto;
import io.platform.moneyManagement.web.remote.InvoiceBillsAttachsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/invoiceBillsAttachs")
public class InvoiceBillsAttachsRestController extends AbstractController {

    @Autowired
    private InvoiceBillsAttachsServiceRemote invoiceBillsAttachsServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:invoiceBillsAttachs:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsAttachsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:invoiceBillsAttachs:page")
    public R page(Page page, InvoiceBillsAttachsDto invoiceBillsAttachsDto) {
        return R.ok().put("page", invoiceBillsAttachsServiceRemote.getPage(page, invoiceBillsAttachsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:invoiceBillsAttachs:info")
    public R info(@PathVariable("id") Long id) {
        InvoiceBillsAttachsDto invoiceBillsAttachsDto = invoiceBillsAttachsServiceRemote.getOne(id);
        return R.ok().put("invoiceBillsAttachsDto", invoiceBillsAttachsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:invoiceBillsAttachs:save")
    public R save(@RequestBody InvoiceBillsAttachsDto invoiceBillsAttachsDto) {
        ValidatorUtils.validateEntity(invoiceBillsAttachsDto);
        ExecuteResult<String> result = invoiceBillsAttachsServiceRemote.save(invoiceBillsAttachsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:invoiceBillsAttachs:edit")
    public R update(@RequestBody InvoiceBillsAttachsDto invoiceBillsAttachsDto) {
        ValidatorUtils.validateEntity(invoiceBillsAttachsDto);
        ExecuteResult<String> result = invoiceBillsAttachsServiceRemote.update(invoiceBillsAttachsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:invoiceBillsAttachs:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = invoiceBillsAttachsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
