
package io.platform.moneyManagement.web.controller.rest;


import io.platform.moneyManagement.dto.InvoiceBillsItemsDto;
import io.platform.moneyManagement.web.remote.InvoiceBillsItemsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/invoiceBillsItems")
public class InvoiceBillsItemsRestController extends AbstractController {

    @Autowired
    private InvoiceBillsItemsServiceRemote invoiceBillsItemsServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsItemsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    public R page(Page page, InvoiceBillsItemsDto invoiceBillsItemsDto) {
        return R.ok().put("page", invoiceBillsItemsServiceRemote.getPage(page, invoiceBillsItemsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    public R info(@PathVariable("id") Long id) {
        InvoiceBillsItemsDto invoiceBillsItemsDto = invoiceBillsItemsServiceRemote.getOne(id);
        return R.ok().put("invoiceBillsItemsDto", invoiceBillsItemsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    public R save(@RequestBody InvoiceBillsItemsDto invoiceBillsItemsDto) {
        ValidatorUtils.validateEntity(invoiceBillsItemsDto);
        ExecuteResult<String> result = invoiceBillsItemsServiceRemote.save(invoiceBillsItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    public R update(@RequestBody InvoiceBillsItemsDto invoiceBillsItemsDto) {
        ValidatorUtils.validateEntity(invoiceBillsItemsDto);
        ExecuteResult<String> result = invoiceBillsItemsServiceRemote.update(invoiceBillsItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = invoiceBillsItemsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除单条明细
     */
    @SysLog("删除单条明细")
    @PostMapping("/deleteItem")
    public R deleteItem(@RequestBody InvoiceBillsItemsDto invoiceBillsItemsDto) {
        ExecuteResult<String> result = invoiceBillsItemsServiceRemote.deleteItem(invoiceBillsItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectNumber")
    public Map<String, Object> selectNumber(@RequestParam("subNo") String subNo,
                                            @RequestParam("purchaseId") Integer purchaseId,
                                            @RequestParam("budgetId") Integer budgetId) {
        return invoiceBillsItemsServiceRemote.selectNumber(subNo, purchaseId, budgetId);
    }

    @PostMapping("selectDirectPaymentPurchase")
    public Map<String,Object> selectDirectPaymentPurchase (@RequestParam("subNo") String subNo, @RequestParam("budId") Integer budId) {
        return invoiceBillsItemsServiceRemote.selectDirectPaymentPurchase(subNo,budId, (SysUserDto) SecurityUtils.getSubject().getPrincipal());
    }
}
