
package io.platform.moneyManagement.web.controller.rest;


import io.platform.moneyManagement.dto.InvoiceBillsPlansDto;
import io.platform.moneyManagement.web.remote.InvoiceBillsPlansServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/moneyManagement/invoiceBillsPlans")
public class InvoiceBillsPlansRestController extends AbstractController {

    @Autowired
	private InvoiceBillsPlansServiceRemote invoiceBillsPlansServiceRemote;
	
	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("moneyManagement:invoiceBillsPlans:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", invoiceBillsPlansServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@PostMapping("/page")
	@RequiresPermissions("moneyManagement:invoiceBillsPlans:page")
	public R page(Page page,InvoiceBillsPlansDto invoiceBillsPlansDto){
		return R.ok().put("page", invoiceBillsPlansServiceRemote.getPage(page,invoiceBillsPlansDto));
	}
	/**
	 * 信息
	 */
	@PostMapping("/info/{id}")
	@RequiresPermissions("moneyManagement:invoiceBillsPlans:info")
	public R info(@PathVariable("id") Long id){
		InvoiceBillsPlansDto invoiceBillsPlansDto = invoiceBillsPlansServiceRemote.getOne(id);
		return R.ok().put("invoiceBillsPlansDto", invoiceBillsPlansDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("moneyManagement:invoiceBillsPlans:save")
	public R save(@RequestBody InvoiceBillsPlansDto invoiceBillsPlansDto){
        ValidatorUtils.validateEntity(invoiceBillsPlansDto);
        ExecuteResult<String> result= invoiceBillsPlansServiceRemote.save(invoiceBillsPlansDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("moneyManagement:invoiceBillsPlans:edit")
	public R update(@RequestBody InvoiceBillsPlansDto invoiceBillsPlansDto){
        ValidatorUtils.validateEntity(invoiceBillsPlansDto);
        ExecuteResult<String> result= invoiceBillsPlansServiceRemote.update(invoiceBillsPlansDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("moneyManagement:invoiceBillsPlans:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= invoiceBillsPlansServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

	@PostMapping("selectMaterialPrice")
	public Map<String,Object> selectMaterialPrice(@RequestParam("id") Integer id){
		return invoiceBillsPlansServiceRemote.selectMaterialPrice(id);
	}
	@PostMapping("deleteMaterialPrice")
	public R deleteMaterialPrice(@RequestParam("id") Integer id){
		ExecuteResult<String> result= invoiceBillsPlansServiceRemote.deleteMaterialPrice(id);
		if(result.isSuccess()){
			return R.ok(result.getSuccessMessage());
		}else{
			return R.error(result.getErrorMessages().get(0));
		}
	}
}
