
package io.platform.moneyManagement.web.controller.rest;


import io.platform.budget.dto.ProjectBillsBudgetsDto;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.moneyManagement.web.remote.InvoiceBillsServiceRemote;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.dto.SubContractBillsDto;
import io.platform.purchase.dto.PurchaseBillsItemsDto;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.QRBarCodeUtil;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/invoiceBills")
public class InvoiceBillsRestController extends AbstractController {

    @Autowired
    private InvoiceBillsServiceRemote invoiceBillsServiceRemote;


    @PostMapping("/updateContractNo")
    public R updateContractNo(@RequestBody SubContractBillsDto subContractBillsDto) {
        ExecuteResult<String> result = invoiceBillsServiceRemote.updateContractNo(subContractBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("/updatePayCrContractNo")
    public R updatePayCrContractNo(@RequestBody SubContractBillsDto subContractBillsDto) {
        ExecuteResult<String> result = invoiceBillsServiceRemote.updatePayCrContractNo(subContractBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }
/*---------------------------------------------------------------------------------------------*/
    /**
     * 模糊搜素收付款信息
     */
    @PostMapping("/fuzzyQueryInvoice")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R fuzzyQueryInvoice(Page page, @RequestBody InvoiceBillsDto invoiceBillsDto) {
        ValidatorUtils.validateEntity(invoiceBillsDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", invoiceBillsServiceRemote.fuzzyQueryInvoice(page, invoiceBillsDto, sysUserDto));
    }
    /**
     * 模糊搜素收付款信息
     */
    @PostMapping("/fuzzyQueryInvoice2")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R fuzzyQueryInvoice2(Page page,  InvoiceBillsDto invoiceBillsDto) {
        ValidatorUtils.validateEntity(invoiceBillsDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", invoiceBillsServiceRemote.fuzzyQueryInvoice(page, invoiceBillsDto, sysUserDto));
    }

    /**
     * 查询付款发票材料款信息
     */
    @PostMapping("/invoiceMaterialPage")
    public R invoiceMaterialPage(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", invoiceBillsServiceRemote.invoiceMaterialPage(map,sysUserDto));
    }

    /**
     * 查询付款发票-直接成本暂存信息
     */
    @PostMapping("/queryDirectCostTemporary")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R queryDirectCostTemporary(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsServiceRemote.queryDirectCostTemporary(invoiceBillsDto));
    }

    /**
     * 查询付款发票-其他款项间接成本工程信息
     */
    @PostMapping("/queryPayInvoiceMaintenBudget")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R queryPayInvoiceMaintenBudget(@RequestBody ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsServiceRemote.queryPayInvoiceMaintenBudget(projectBillsBudgetsDto));
    }

    /**
     * 查询付款发票-工程款 分包信息
     */
    @PostMapping("/queryEngineeringSubContract")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R queryEngineeringSubContract(@RequestBody SubContractBillsDto subContractBillsDto) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsServiceRemote.queryEngineeringSubContract(subContractBillsDto));
    }

    /**
     * 收款发票信息查询
     */
    @PostMapping("/changeFuzzyQueryProject")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R changeFuzzyQueryProject(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsServiceRemote.changeFuzzyQueryProject(projectBillsSubsDto));
    }

    /**
     * 查询报销审批单信息
     */
    @PostMapping("/selectPrint")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R selectPrint(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", invoiceBillsServiceRemote.selectPrint(invoiceBillsDto, sysUserDto));
    }

    /**
     * 付款发票-分包工程信息查询
     */
    @PostMapping("/changeFuzzyQueryEngineeringInvoice")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R changeFuzzyQueryEngineeringInvoice(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsServiceRemote.changeFuzzyQueryEngineeringInvoice(projectBillsSubsDto));
    }

    /**
     * 付款发票-间接成本信息查询
     */
    @PostMapping("/changeFuzzyQueryPayInvoice")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R changeFuzzyQueryPayInvoice(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsServiceRemote.changeFuzzyQueryPayInvoice(invoiceBillsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsServiceRemote.getList(params));
    }

    /**
     * 查询其他款项-间接成本分摊工程信息
     */
    @PostMapping("/queryInvoiceIndirect")
    @RequiresPermissions("engineering:invoiceBills:list")
    public R queryInvoiceIndirect(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        return R.ok().put("list", invoiceBillsServiceRemote.queryInvoiceIndirect(invoiceBillsDto));
    }

    /**
     * 收款发票分页列表
     */
    @PostMapping("/invoicePage")
    @RequiresPermissions("engineering:invoiceBills:page")
    public R invoicePage(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", invoiceBillsServiceRemote.invoicePage(map,sysUserDto));
    }

    /**
     * 付款发票间接成本分页列表
     */
    @PostMapping("/payInvoiceMaintenancePage")
    @RequiresPermissions("engineering:invoiceBills:page")
    public R payInvoiceMaintenancePage(Page page, InvoiceBillsDto invoiceBillsDto) {
        return R.ok().put("page", invoiceBillsServiceRemote.payInvoiceMaintenancePage(page, invoiceBillsDto));
    }

    /**
     * 付款发票直接接成本分页列表
     */
    @PostMapping("/directInvoiceCostPage")
    @RequiresPermissions("engineering:invoiceBills:page")
    public R directInvoiceCostPage(Page page, InvoiceBillsDto invoiceBillsDto) {
        return R.ok().put("page", invoiceBillsServiceRemote.directInvoiceCostPage(page, invoiceBillsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:invoiceBills:info")
    public R info(@PathVariable("id") Long id) {
        InvoiceBillsDto invoiceBillsDto = invoiceBillsServiceRemote.getOne(id);
        return R.ok().put("invoiceBillsDto", invoiceBillsDto);
    }

    /**
     * 查询暂存数据
     */
    @SysLog("查询暂存数据")
    @PostMapping("/queryInvoiceTemporary")
    @RequiresPermissions("engineering:invoiceBills:save")
    public R queryInvoiceTemporary(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        return R.ok().put("list", invoiceBillsServiceRemote.queryInvoiceTemporary(invoiceBillsDto));
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/invoiceTemporary")
    @RequiresPermissions("engineering:invoiceBills:save")
    public R invoiceTemporary(@RequestParam(required = false, value = "form") String projectForm,
                              @RequestParam(required = false, value = "progress") String progress,
                              @RequestParam(required = false, value = "maintenance") String maintenance) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.invoiceTemporary(projectForm, progress, maintenance, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询付款发票分包工程暂存数据
     */
    @SysLog("查询付款发票分包工程暂存数据")
    @PostMapping("/queryEngineeringInvoiceTemporary")
    public R queryEngineeringInvoiceTemporary(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", invoiceBillsServiceRemote.queryEngineeringInvoiceTemporary(invoiceBillsDto, sysUserDto));
    }

    /**
     * 付款发票分包工程暂存
     */
    @SysLog("付款发票分包工程暂存")
    @PostMapping("/engineeringInvoiceTemporary")
    @RequiresPermissions("engineering:invoiceBills:save")
    public R engineeringInvoiceTemporary(@RequestParam(required = false, value = "form") String projectForm,
                                         @RequestParam(required = false, value = "payPost") String payPost,
                                         @RequestParam(required = false, value = "invoDeta") String invoDeta) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.engineeringInvoiceTemporary(projectForm, payPost, invoDeta, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 付款发票分包工程提交
     */
    @SysLog("付款发票分包工程提交")
    @PostMapping("/engineeringInvoiceSave")
    public R engineeringInvoiceSave(@RequestParam(required = false, value = "form") String projectForm,
                                    @RequestParam(required = false, value = "payPost") String payPost,
                                    @RequestParam(required = false, value = "invoDeta") String invoDeta) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.engineeringInvoiceSave(projectForm, payPost, invoDeta, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询付款发票维护-间接成本暂存数据
     */
    @SysLog("查询付款发票维护-间接成本暂存数据")
    @PostMapping("/queryPayInvoiceMaintenanceTemporary")
    public R queryPayInvoiceMaintenanceTemporary(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        ValidatorUtils.validateEntity(invoiceBillsDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", invoiceBillsServiceRemote.queryPayInvoiceMaintenanceTemporary(invoiceBillsDto, sysUserDto));
    }

    /**
     * 付款发票维护-间接成本暂存
     */
    @SysLog("付款发票维护-间接成本暂存")
    @PostMapping("/payInvoiceMaintenanceTemporary")
    @RequiresPermissions("engineering:invoiceBills:save")
    public R payInvoiceMaintenanceTemporary(@RequestParam(required = false, value = "form") String projectForm,
                                            @RequestParam(required = false, value = "detailMaintenance") String detailMaintenance,
                                            @RequestParam(required = false, value = "items") String invoiceItem,
                                            @RequestParam(required = false, value = "costSharing") String costSharing,
                                            @RequestParam(required = false, value = "relevantAttachments") String relevantAttach) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.payInvoiceMaintenanceTemporary(projectForm,
                detailMaintenance, invoiceItem, costSharing, relevantAttach, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 付款发票维护-间接成本提交
     */
    @SysLog("付款发票维护-间接成本提交")
    @PostMapping("/payInvoiceMaintenanceSave")
    @RequiresPermissions("engineering:invoiceBills:save")
    public R payInvoiceMaintenanceSave(@RequestParam(required = false, value = "form") String projectForm,
                                       @RequestParam(required = false, value = "detailMaintenance") String detailMaintenance,
                                       @RequestParam(required = false, value = "items") String invoiceItem,
                                       @RequestParam(required = false, value = "costSharing") String costSharing,
                                       @RequestParam(required = false, value = "relevantAttachments") String relevantAttach) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.payInvoiceMaintenanceSave(projectForm,
                detailMaintenance, invoiceItem, costSharing, relevantAttach, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }


    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/invoiceSave")
    @RequiresPermissions("engineering:invoiceBills:save")
    public R invoiceSave(@RequestParam(required = false, value = "form") String projectForm,
                         @RequestParam(required = false, value = "progress") String progress,
                         @RequestParam(required = false, value = "maintenance") String maintenance) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.invoiceSave(projectForm, progress, maintenance, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:invoiceBills:save")
    public R save(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        ValidatorUtils.validateEntity(invoiceBillsDto);
        ExecuteResult<String> result = invoiceBillsServiceRemote.save(invoiceBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:invoiceBills:edit")
    public R update(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        ValidatorUtils.validateEntity(invoiceBillsDto);
        ExecuteResult<String> result = invoiceBillsServiceRemote.update(invoiceBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除收款发票
     */
    @SysLog("删除收款发票")
    @PostMapping("/deleteInvoice")
    @RequiresPermissions("engineering:invoiceBills:delete")
    public R deleteInvoice(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        ExecuteResult<String> result = invoiceBillsServiceRemote.deleteInvoice(invoiceBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除付款发票-分包工程
     */
    @SysLog("删除收款发票-分包工程")
    @PostMapping("/deleteEngineering")
    @RequiresPermissions("engineering:invoiceBills:delete")
    public R deleteEngineering(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        ExecuteResult<String> result = invoiceBillsServiceRemote.deleteEngineering(invoiceBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除付款发票-直接成本
     */
    @SysLog("删除付款发票-直接成本")
    @PostMapping("/deleteDirectInvoice")
    @RequiresPermissions("engineering:invoiceBills:delete")
    public R deleteDirectInvoice(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        ExecuteResult<String> result = invoiceBillsServiceRemote.deleteDirectInvoice(invoiceBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除付款发票-间接成本
     */
    @SysLog("删除付款发票-间接成本")
    @PostMapping("/deletePayInvoice")
    @RequiresPermissions("engineering:invoiceBills:delete")
    public R deletePayInvoice(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        ExecuteResult<String> result = invoiceBillsServiceRemote.deletePayInvoice(invoiceBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectItem")
    public Map<String, Object> selectItem(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return invoiceBillsServiceRemote.selectItem(projectBillsSubsDto);
    }

    @PostMapping("directTemporary")
    public String directTemporary(@RequestParam("zhu") String zhu, @RequestParam("fapiao") String fapiao, @RequestParam("fujian") String fujian) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return invoiceBillsServiceRemote.directTemporary(zhu, fapiao, fujian, sysUserDto);
    }

    /**
     * 查询需求计划
     */
    @PostMapping("selectBillsItem")
    public Map<String, Object> selectBillsItem(@RequestParam("sub") String subNo,@RequestParam("purchaseId") Integer purchaseId) {
        return invoiceBillsServiceRemote.selectBillsItem(subNo,purchaseId);
    }
    /**
     * 更新打印时间、状态
     *
     */
    @PostMapping("updatePrintTime")
    public Boolean updatePrintTime(@RequestParam("id") Integer id) {
        return invoiceBillsServiceRemote.updatePrintTime(id);
    }

    @GetMapping("/createQrCode")
    public void getQRCode(String codeContent, HttpServletResponse response) {
        System.out.println("codeContent=" + codeContent);
        try {
            /**
             * 调用工具类生成二维码并输出到输出流中
             */
            SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss SSS");//设置日期格式
            QRBarCodeUtil.createCodeToOutputStream("打印时间:"+df.format(new Date()) +"\n"+"打印人:"+codeContent, response.getOutputStream());
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    @PostMapping("selectOtherIndirect")
    public Map<String, Object> selectOtherIndirect(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return invoiceBillsServiceRemote.selectOtherIndirect(map,sysUserDto);
    }




    /**
     * 撤销-分包工程
     */
    @SysLog("撤销-分包工程")
    @PostMapping("/revoke")
    public R revoke(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.revoke(invoiceBillsDto,sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }



    /**
     * 撤销-材料款
     *
     */
    @SysLog("撤销材料款")
    @PostMapping("/revokeProjectPirce")
    public R revokeProjectPirce(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.revokeProjectPirce(invoiceBillsDto,sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 撤销-其他款项-直接
     *
     */
    @SysLog("撤销其他款项")
    @PostMapping("/revokeDirectInvoiceCost")
    public R revokeDirectInvoiceCost(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.revokeDirectInvoiceCost(invoiceBillsDto,sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }




    /**
     * 撤销-其他款项-间接
     *
     */
    @SysLog("撤销其他款项")
    @PostMapping("/revokeIndirect")
    public R revokeIndirect(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = invoiceBillsServiceRemote.revokeIndirect(invoiceBillsDto,sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }








}
