
package io.platform.moneyManagement.web.controller.rest;


import io.platform.moneyManagement.dto.InvoiceBillsSharesDto;
import io.platform.moneyManagement.web.remote.InvoiceBillsSharesServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/invoiceBillsShares")
public class InvoiceBillsSharesRestController extends AbstractController {

    @Autowired
    private InvoiceBillsSharesServiceRemote invoiceBillsSharesServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:invoiceBillsShares:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", invoiceBillsSharesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:invoiceBillsShares:page")
    public R page(Page page, InvoiceBillsSharesDto invoiceBillsSharesDto) {
        return R.ok().put("page", invoiceBillsSharesServiceRemote.getPage(page, invoiceBillsSharesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:invoiceBillsShares:info")
    public R info(@PathVariable("id") Long id) {
        InvoiceBillsSharesDto invoiceBillsSharesDto = invoiceBillsSharesServiceRemote.getOne(id);
        return R.ok().put("invoiceBillsSharesDto", invoiceBillsSharesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:invoiceBillsShares:save")
    public R save(@RequestBody InvoiceBillsSharesDto invoiceBillsSharesDto) {
        ValidatorUtils.validateEntity(invoiceBillsSharesDto);
        ExecuteResult<String> result = invoiceBillsSharesServiceRemote.save(invoiceBillsSharesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:invoiceBillsShares:edit")
    public R update(@RequestBody InvoiceBillsSharesDto invoiceBillsSharesDto) {
        ValidatorUtils.validateEntity(invoiceBillsSharesDto);
        ExecuteResult<String> result = invoiceBillsSharesServiceRemote.update(invoiceBillsSharesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:invoiceBillsShares:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = invoiceBillsSharesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
