
package io.platform.moneyManagement.web.controller.rest;


import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.moneyManagement.dto.PayCrBillsDto;
import io.platform.moneyManagement.web.remote.PayCrBillsServiceRemote;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/payCrBills")
public class PayCrBillsRestController extends AbstractController {

    @Autowired
    private PayCrBillsServiceRemote payCrBillsServiceRemote;

    /**
     * 确认付款
     */
    @PostMapping("/editCrAffirmStatus")
    @RequiresPermissions("engineering:payCrBills:finance")
    public R editCrAffirmStatus(@RequestBody PayCrBillsDto payCrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payCrBillsServiceRemote.editCrAffirmStatus(payCrBillsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 付款驳回
     */
    @PostMapping("/turnDownStatus")
    @RequiresPermissions("engineering:payCrBills:finance")
    public R turnDownStatus(@RequestBody PayCrBillsDto payCrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payCrBillsServiceRemote.turnDownStatus(payCrBillsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询付款记录打印信息
     */
    @PostMapping("/selectFundpay")
    public R selectFundpay(@RequestBody PayCrBillsDto payCrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", payCrBillsServiceRemote.selectFundpay(payCrBillsDto, sysUserDto));
    }

    /**
     * 模糊搜素收付款信息
     */
    @PostMapping("/fuzzyQueryPayCr")
    public R fuzzyQueryPayCr(Page page, @RequestBody PayCrBillsDto payCrBillsDto) {
        ValidatorUtils.validateEntity(payCrBillsDto);
        //查询列表数据
        return R.ok().put("page", payCrBillsServiceRemote.fuzzyQueryInvoice(page, payCrBillsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", payCrBillsServiceRemote.getList(params));
    }

    /**
     * 修改打印状态
     */
    @PostMapping("/updatePayCrIndirectPrint")
    @RequiresPermissions("engineering:payCrBills:edit")
    public R updatePayCrIndirectPrint(@RequestBody PayCrBillsDto payCrBillsDto) {
        return R.ok().put("status", payCrBillsServiceRemote.updatePayCrIndirectPrint(payCrBillsDto));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    public R page(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", payCrBillsServiceRemote.getPage(map, sysUserDto));
    }

    /**
     * 查询 付款记录-间接承包信息
     */
    @PostMapping("/payCrIndirectPage")
    public R payCrIndirectPage(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", payCrBillsServiceRemote.payCrIndirectPage(map, sysUserDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    public R info(@PathVariable("id") Long id) {
        PayCrBillsDto payCrBillsDto = payCrBillsServiceRemote.getOne(id);
        return R.ok().put("payCrBillsDto", payCrBillsDto);
    }

    /**
     * 查询暂存
     */
    @PostMapping("/queryPayCrTemporary")
    public R queryPayCrTemporary(@RequestBody PayCrBillsDto payCrBillsDto) {
        ValidatorUtils.validateEntity(payCrBillsDto);
        return R.ok().put("list", payCrBillsServiceRemote.queryPayCrTemporary(payCrBillsDto));
    }

    /**
     * 查询该工程下预算项目
     */
    @SysLog("查询该工程下预算项目")
    @PostMapping("/queryBudgets")
    public R queryBudgets(@RequestBody PayCrBillsDto payCrBillsDto) {
        return R.ok().put("list", payCrBillsServiceRemote.queryBudgets(payCrBillsDto));
    }

    /**
     * 付款-直接成本-暂存
     */
    @SysLog("付款-直接成本-暂存")
    @PostMapping("/directPaymentTemporary")
    public R directPaymentTemporary(@RequestParam("form") String projectForm) {
//        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payCrBillsServiceRemote.directPaymentTemporary(projectForm);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 付款-直接成本-暂存
     */
    @SysLog("付款-直接成本-修改")
    @PostMapping("/updatePayCr")
    public Map<String, Object> updatePayCr(@RequestParam("id") Integer id) {
        return payCrBillsServiceRemote.updatePayCr(id);
    }

    /**
     * 付款-直接成本-提交
     */
    @SysLog("付款-直接成本-提交")
    @PostMapping("/directPaymentSave")
    public R directPaymentSave(@RequestParam("payCr") String projectForm) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payCrBillsServiceRemote.directPaymentSave(projectForm, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 付款维护-间接成本 查询报销审批单信息
     */
    @PostMapping("/selectPayCrIndirectPrint")
    public R selectPayCrIndirectPrint(@RequestBody PayCrBillsDto payCrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", payCrBillsServiceRemote.selectPayCrIndirectPrint(payCrBillsDto, sysUserDto));
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/payCrTemporary")
    public R payCrTemporary(@RequestParam(required = false, value = "form") String projectForm,
                            @RequestParam(required = false, value = "payment") String payment,
                            @RequestParam(required = false, value = "supplier") String supplier,
                            @RequestParam(required = false, value = "paymentSharing") String paymentSharing) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payCrBillsServiceRemote.payCrTemporary(projectForm, payment, supplier, paymentSharing, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/payCrSave")
    public R payCrSave(@RequestParam(required = false, value = "form") String projectForm,
                       @RequestParam(required = false, value = "payment") String payment,
                       @RequestParam(required = false, value = "supplier") String supplier,
                       @RequestParam(required = false, value = "paymentSharing") String paymentSharing) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payCrBillsServiceRemote.payCrSave(projectForm, payment, supplier, paymentSharing, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    public R save(@RequestBody PayCrBillsDto payCrBillsDto) {
        ValidatorUtils.validateEntity(payCrBillsDto);
        ExecuteResult<String> result = payCrBillsServiceRemote.save(payCrBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:payCrBills:edit")
    public R update(@RequestBody PayCrBillsDto payCrBillsDto) {
        ValidatorUtils.validateEntity(payCrBillsDto);
        ExecuteResult<String> result = payCrBillsServiceRemote.update(payCrBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除付款记录-直接成本
     */
    @SysLog("删除付款记录-直接成本")
    @PostMapping("/deleteDirectPayment")
    @RequiresPermissions("engineering:payCrBills:delete")
    public R deleteDirectPayment(@RequestBody PayCrBillsDto payCrBillsDto) {
        ExecuteResult<String> result = payCrBillsServiceRemote.deleteDirectPayment(payCrBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除付款记录-间接成本
     */
    @SysLog("删除付款记录-间接成本")
    @PostMapping("/deletePayCrBill")
    @RequiresPermissions("engineering:payCrBills:delete")
    public R deletePayCrBill(@RequestBody PayCrBillsDto payCrBillsDto) {
        ExecuteResult<String> result = payCrBillsServiceRemote.deletePayCrBill(payCrBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("payCrSelect")
    public Map<String, Object> payCrSelect(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return payCrBillsServiceRemote.payCrSelect(projectBillsSubsDto);
    }


    /**
     * 驳回付款
     */
    @PostMapping("/refute")
    @RequiresPermissions("engineering:payCrBills:list")
    public R refute(@RequestBody PayCrBillsDto payCrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payCrBillsServiceRemote.refute(payCrBillsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("financialDismissal")
    @RequiresPermissions("engineering:payCrBills:finance")
    public String financialDismissal(@RequestParam("id") Integer id, @RequestParam(required = false, value = "affirmantRemarks") String affirmantRemarks) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payCrBillsServiceRemote.financialDismissal(id, affirmantRemarks, sysUserDto);
    }

    @PostMapping("financialSuccess")
    @RequiresPermissions("engineering:payCrBills:finance")
    public String financialSuccess(@RequestParam("id") Integer id, @RequestParam(required = false, value = "affirmantRemarks") String affirmantRemarks) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payCrBillsServiceRemote.financialSuccess(id, affirmantRemarks, sysUserDto);
    }

    /**
     * 存续直接成本 财务确认方法
     */
    @PostMapping("cxFinancialSuccess")
    @RequiresPermissions("engineering:payCrBills:finance")
    public String cxFinancialSuccess(@RequestParam("id") Integer id, @RequestParam(required = false, value = "affirmantRemarks") String affirmantRemarks) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payCrBillsServiceRemote.cxFinancialSuccess(id, affirmantRemarks, sysUserDto);
    }



    /**
     * 撤销
     * 将状态改为2
     */
    @SysLog("删除付款记录-间接成本")
    @PostMapping("/revokePayment")
    public R revokePayment(@RequestBody PayCrBillsDto payCrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payCrBillsServiceRemote.revokePayment(payCrBillsDto,sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }


}
