
package io.platform.moneyManagement.web.controller.rest;


import io.platform.moneyManagement.dto.PayCrBillsSharesDto;
import io.platform.moneyManagement.web.remote.PayCrBillsSharesServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/payCrBillsShares")
public class PayCrBillsSharesRestController extends AbstractController {

    @Autowired
    private PayCrBillsSharesServiceRemote payCrBillsSharesServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:payCrBillsShares:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", payCrBillsSharesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:payCrBillsShares:page")
    public R page(Page page, PayCrBillsSharesDto payCrBillsSharesDto) {
        return R.ok().put("page", payCrBillsSharesServiceRemote.getPage(page, payCrBillsSharesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:payCrBillsShares:info")
    public R info(@PathVariable("id") Long id) {
        PayCrBillsSharesDto payCrBillsSharesDto = payCrBillsSharesServiceRemote.getOne(id);
        return R.ok().put("payCrBillsSharesDto", payCrBillsSharesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:payCrBillsShares:save")
    public R save(@RequestBody PayCrBillsSharesDto payCrBillsSharesDto) {
        ValidatorUtils.validateEntity(payCrBillsSharesDto);
        ExecuteResult<String> result = payCrBillsSharesServiceRemote.save(payCrBillsSharesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:payCrBillsShares:edit")
    public R update(@RequestBody PayCrBillsSharesDto payCrBillsSharesDto) {
        ValidatorUtils.validateEntity(payCrBillsSharesDto);
        ExecuteResult<String> result = payCrBillsSharesServiceRemote.update(payCrBillsSharesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:payCrBillsShares:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = payCrBillsSharesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectPirce")
    public Map<String, Object> selectPirce(@RequestParam("dto") String dto) {
        return payCrBillsSharesServiceRemote.selectPirce(dto);
    }

    @PostMapping("selectProjectNc")
    public Map<String, Object> selectProjectNc(@RequestParam("projectNc") String projectNc, @RequestParam("subNo") String subNo) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payCrBillsSharesServiceRemote.selectProjectNc(projectNc, subNo, sysUserDto);
    }

    /*
    材料款提交方法，不是存续的
     */
    @PostMapping("saveMaterial")
    public String saveMaterial(@RequestParam("zhu") String zhu, @RequestParam("fapiao") String fapiao, @RequestParam("mingxi") String mingxi) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payCrBillsSharesServiceRemote.saveMaterial(zhu, fapiao, mingxi, sysUserDto);
    }

    @PostMapping("selectPricePrint")
    public Map<String, Object> selectPricePrint(@RequestParam("id") Integer id) {
        return payCrBillsSharesServiceRemote.selectPricePrint(id);
    }

    @PostMapping("selectPricePrint2")
    public Map<String, Object> selectPricePrint2(@RequestParam("id") Integer id) {
        return payCrBillsSharesServiceRemote.selectPricePrint2(id);
    }

    @PostMapping("selectDirectPaymentPrint")
    public Map<String, Object> selectDirectPaymentPrint(@RequestParam("id") Integer id) {
        return payCrBillsSharesServiceRemote.selectDirectPaymentPrint(id);
    }

    /**
     * 付款记录打印更新方法
     */
    @PostMapping("updatePayCrPrint")
    public Boolean updatePayCrPrint(@RequestParam("id") Integer id) {
        return payCrBillsSharesServiceRemote.updatePayCrPrint(id);
    }
}
