
package io.platform.moneyManagement.web.controller.rest;


import io.platform.moneyManagement.dto.PayDrBillsItemsDto;
import io.platform.moneyManagement.web.remote.PayDrBillsItemsServiceRemote;
import io.platform.project.dto.ProjectbillsDto;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/payDrBillsItems")
public class PayDrBillsItemsRestController extends AbstractController {

    @Autowired
    private PayDrBillsItemsServiceRemote payDrBillsItemsServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:payDrBillsItems:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", payDrBillsItemsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:payDrBillsItems:page")
    public R page(Page page, PayDrBillsItemsDto payDrBillsItemsDto) {
        return R.ok().put("page", payDrBillsItemsServiceRemote.getPage(page, payDrBillsItemsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:payDrBillsItems:info")
    public R info(@PathVariable("id") Long id) {
        PayDrBillsItemsDto payDrBillsItemsDto = payDrBillsItemsServiceRemote.getOne(id);
        return R.ok().put("payDrBillsItemsDto", payDrBillsItemsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:payDrBillsItems:save")
    public R save(@RequestBody PayDrBillsItemsDto payDrBillsItemsDto) {
        ValidatorUtils.validateEntity(payDrBillsItemsDto);
        ExecuteResult<String> result = payDrBillsItemsServiceRemote.save(payDrBillsItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:payDrBillsItems:edit")
    public R update(@RequestBody PayDrBillsItemsDto payDrBillsItemsDto) {
        ValidatorUtils.validateEntity(payDrBillsItemsDto);
        ExecuteResult<String> result = payDrBillsItemsServiceRemote.update(payDrBillsItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:payDrBillsItems:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = payDrBillsItemsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectDirectCostPrice")
    public Map<String, Object> selectDirectCostPrice(@RequestParam("subNo") String subNo, @RequestParam("ncNo") String ncNo) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.selectDirectCostPrice(subNo, ncNo, sysUserDto);
    }

    @PostMapping("saveDirect")
    public String saveDirect(@RequestParam("zhu") String zhu, @RequestParam("fapiao") String fapiao, @RequestParam("fujian") String fujian) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.saveDirect(zhu, fapiao, fujian, sysUserDto);
    }

    @PostMapping("selectDirect")
    public Map<String, Object> selectDirect(@RequestParam("id") Integer id) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.selectDirect(id, sysUserDto);
    }

    /***
     *
     * 账龄分析列表查询
     */
    @PostMapping("selectPayDrData")
    public List<Map<String, Object>> selectPayDrData() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.selectPayDrData(sysUserDto);
    }

    /*
    账龄分析圆形图 查询数量
     */
    @PostMapping("selectPayDrDataCount")
    public List<Map<String, Object>> selectPayDrDataCount() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.selectPayDrDataCount(sysUserDto);
    }

    /*
    账龄分析圆柱图查询
     */
    @PostMapping("selectPayDrTopData")
    public List<Map<String, Object>> selectPayDrTopData(@RequestParam(value = "name", required = false) String name,
                                                        @RequestParam(value = "typeId", required = false) Integer typeId) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.selectPayDrTopData(name, typeId, sysUserDto);
    }

    /*
        首页图表信息查询
     */
    @PostMapping("selectPayDyAllAmt")
    public List<Map<String, Object>> selectPayDyAllAmt() {
        return payDrBillsItemsServiceRemote.selectPayDyAllAmt();
    }

    /*
        收入支出汇总表 四个数字查询
     */
    @PostMapping("selectSubAmtCrAndDr")
    public Map<String, Object> selectSubAmtCrAndDr() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.selectSubAmtCrAndDr(sysUserDto);
    }

    /*
        收入支出汇总表饼状图与 各公司收入效益分析查询
     */
    @PostMapping("selectBranchSubProjectAmt")
    public List<Map<String, Object>> selectBranchSubProjectAmt() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.selectBranchSubProjectAmt(sysUserDto);
    }

    /*
     毛利率公司分布查询
     */
    @PostMapping("selectAllDrInterestRate")
    public List<Long> selectAllDrInterestRate() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return payDrBillsItemsServiceRemote.selectAllDrInterestRate(sysUserDto);
    }
}
