
package io.platform.moneyManagement.web.controller.rest;


import io.platform.moneyManagement.dto.PayDrBillsDto;
import io.platform.moneyManagement.web.remote.PayDrBillsServiceRemote;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/payDrBills")
public class PayDrBillsRestController extends AbstractController {

    @Autowired
    private PayDrBillsServiceRemote payDrBillsServiceRemote;


    /**
     * 查询退款信息
     */
    @PostMapping("/editAffirmStatus")
    public R editAffirmStatus(@RequestBody PayDrBillsDto payDrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payDrBillsServiceRemote.editAffirmStatus(payDrBillsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改退款打印状态
     * @param payDrBillsDto
     * @return
     */
    @PostMapping("/updatePayCrIndirectPrint")
    public R updatePayCrIndirectPrint(@RequestBody PayDrBillsDto payDrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        payDrBillsDto.setPrintedUser(sysUserDto.getUserId().intValue());
        ExecuteResult<String> result = payDrBillsServiceRemote.updatePayCrIndirectPrint(payDrBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 财务确认
     */
    @PostMapping("/selectPrintInformation")
    public R selectPrintInformation(@RequestBody PayDrBillsDto payDrBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", payDrBillsServiceRemote.selectPrintInformation(payDrBillsDto, sysUserDto));
    }

    /**
     * 收款发票信息查询
     */
    @PostMapping("/changeFuzzyQueryPayDr")
    public R changeFuzzyQueryPayDr(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        //查询列表数据
        return R.ok().put("list", payDrBillsServiceRemote.changeFuzzyQueryPayDr(projectBillsSubsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", payDrBillsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    public R page(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", payDrBillsServiceRemote.getPage(map,sysUserDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    public R info(@PathVariable("id") Long id) {
        PayDrBillsDto payDrBillsDto = payDrBillsServiceRemote.getOne(id);
        return R.ok().put("payDrBillsDto", payDrBillsDto);
    }

    /**
     * 查询暂存数据
     */
    @PostMapping("/queryPayTemporary")
    public R queryPayTemporary(@RequestBody PayDrBillsDto payDrBillsDto) {
        ValidatorUtils.validateEntity(payDrBillsDto);
        return R.ok().put("list", payDrBillsServiceRemote.queryPayTemporary(payDrBillsDto));
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/payDrTemporary")
    public R payDrTemporary(@RequestParam(required = false, value = "form") String payDr,
                            @RequestParam(required = false, value = "payItems") String payDrItems) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payDrBillsServiceRemote.payDrTemporary(payDr, payDrItems, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/payDrSave")
    public R payDrSave(@RequestParam(required = false, value = "form") String payDr,
                       @RequestParam(required = false, value = "payItems") String payDrItems) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = payDrBillsServiceRemote.payDrSave(payDr, payDrItems, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    public R save(@RequestBody PayDrBillsDto payDrBillsDto) {
        ValidatorUtils.validateEntity(payDrBillsDto);
        ExecuteResult<String> result = payDrBillsServiceRemote.save(payDrBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    public R update(@RequestBody PayDrBillsDto payDrBillsDto) {
        ValidatorUtils.validateEntity(payDrBillsDto);
        ExecuteResult<String> result = payDrBillsServiceRemote.update(payDrBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除收款记录
     */
    @SysLog("删除收款记录")
    @PostMapping("/deletePayDr")
    public R deletePayDr(@RequestBody PayDrBillsDto payDrBillsDto) {
        ExecuteResult<String> result = payDrBillsServiceRemote.deletePayDr(payDrBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectAll")
    public R selectAll(PayDrBillsDto payDrBillsDto,Page page){
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", payDrBillsServiceRemote.selectAll(page,payDrBillsDto,sysUserDto));}
}
