
package io.platform.moneyManagement.web.remote;

import com.alibaba.dubbo.config.annotation.Reference;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.budget.dto.ProjectBillsBudgetsDto;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.moneyManagement.service.client.api.InvoiceBillsServiceClient;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.dto.SubContractBillsDto;
import io.platform.purchase.dto.PurchaseBillsItemsDto;
import io.platform.sys.dto.SysUserDto;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Service("invoiceBillsServiceRemote")
public class InvoiceBillsServiceRemote {

    @Reference(check = false)
    private InvoiceBillsServiceClient invoiceBillsServiceClient;

    /**
     * 根据参数获取列表  无分页
     */
    public List<InvoiceBillsDto> getList(Map<String, Object> params) {
        return invoiceBillsServiceClient.queryList(params);
    }

    /**
     * 根据参数进行 分页查询
     */
    public Map<String, Object> invoicePage(Map<String, Object> map,SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.invoicePage(map,sysUserDto);
    }

    /**
     * 根据主键 获取单条数据明细
     */
    public InvoiceBillsDto getOne(Long id) {
        InvoiceBillsDto invoiceBillsDto = invoiceBillsServiceClient.queryObject(id);
        return invoiceBillsDto;
    }

    /**
     * 保存 数据
     */
    public ExecuteResult<String> save(InvoiceBillsDto invoiceBillsDto) {

        return invoiceBillsServiceClient.save(invoiceBillsDto);
    }

    /**
     * 修改单条数据
     */
    public ExecuteResult<String> update(InvoiceBillsDto invoiceBillsDto) {

        return invoiceBillsServiceClient.update(invoiceBillsDto);
    }

    /**
     * 删除收款发票
     *
     * @param invoiceBillsDto
     */
    public ExecuteResult<String> deleteInvoice(InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.deleteInvoice(invoiceBillsDto);
    }

    /**
     * 删除收款发票-分包工程
     *
     * @param invoiceBillsDto
     */
    public ExecuteResult<String> deleteEngineering(InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.deleteEngineering(invoiceBillsDto);
    }

    /**
     * 删除付款发票-直接成本
     *
     * @param invoiceBillsDto
     */
    public ExecuteResult<String> deleteDirectInvoice(InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.deleteDirectInvoice(invoiceBillsDto);
    }

    /**
     * 删除付款发票-间接成本
     *
     * @param invoiceBillsDto
     */
    public ExecuteResult<String> deletePayInvoice(InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.deletePayInvoice(invoiceBillsDto);
    }

    /**
     * 收款发票信息查询
     */
    public Map<String, Object> changeFuzzyQueryProject(ProjectBillsSubsDto projectBillsSubsDto) {
        return invoiceBillsServiceClient.changeFuzzyQueryProject(projectBillsSubsDto);
    }

    /**
     * 暂存
     */
    public ExecuteResult<String> invoiceTemporary(String projectForm, String progress, String maintenance, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.invoiceTemporary(projectForm, progress, maintenance, sysUserDto);
    }

    /**
     * 查询暂存数据
     */
    public Map<String, Object> queryInvoiceTemporary(InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.queryInvoiceTemporary(invoiceBillsDto);
    }

    /**
     * 提交
     */
    public ExecuteResult<String> invoiceSave(String projectForm, String progress, String maintenance, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.invoiceSave(projectForm, progress, maintenance, sysUserDto);
    }

    /**
     * 付款发票-分包工程信息查询
     */
    public Map<String, Object> changeFuzzyQueryEngineeringInvoice(ProjectBillsSubsDto projectBillsSubsDto) {
        return invoiceBillsServiceClient.changeFuzzyQueryEngineeringInvoice(projectBillsSubsDto);
    }

    /**
     * 付款发票分包工程暂存
     */
    public ExecuteResult<String> engineeringInvoiceTemporary(String projectForm, String payPost, String invoDeta, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.engineeringInvoiceTemporary(projectForm, payPost, invoDeta, sysUserDto);
    }

    /**
     * 付款发票分包工程提交
     */
    public ExecuteResult<String> engineeringInvoiceSave(String projectForm, String payPost, String invoDeta, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.engineeringInvoiceSave(projectForm, payPost, invoDeta, sysUserDto);
    }

    /**
     * 查询付款发票分包工程暂存数据
     */
    public Map<String, Object> queryEngineeringInvoiceTemporary(InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.queryEngineeringInvoiceTemporary(invoiceBillsDto, sysUserDto);
    }

    /**
     * 付款发票间接成本分页列表
     */
    public Map<String, Object> payInvoiceMaintenancePage(Page page, InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.payInvoiceMaintenancePage(page, invoiceBillsDto);
    }

    /**
     * 付款发票-间接成本信息查询
     */
    public Map<String, Object> changeFuzzyQueryPayInvoice(InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.changeFuzzyQueryPayInvoice(invoiceBillsDto);
    }

    /**
     * 付款发票维护-间接成本暂存
     */
    public ExecuteResult<String> payInvoiceMaintenanceTemporary(String projectForm, String detailMaintenance, String invoiceItem, String costSharing, String relevantAttach, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.payInvoiceMaintenanceTemporary(projectForm, detailMaintenance, invoiceItem, costSharing, relevantAttach, sysUserDto);
    }

    public Map<String, Object> selectItem(ProjectBillsSubsDto projectBillsSubsDto) {
        return invoiceBillsServiceClient.selectItem(projectBillsSubsDto);
    }


    /**
     * 查询付款发票维护-间接成本暂存数据
     */
    public Map<String, Object> queryPayInvoiceMaintenanceTemporary(InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.queryPayInvoiceMaintenanceTemporary(invoiceBillsDto, sysUserDto);
    }

    /**
     * 付款发票维护-间接成本提交
     */
    public ExecuteResult<String> payInvoiceMaintenanceSave(String projectForm, String detailMaintenance, String invoiceItem,
                                                           String costSharing, String relevantAttach, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.payInvoiceMaintenanceSave(projectForm, detailMaintenance, invoiceItem, costSharing, relevantAttach, sysUserDto);
    }

    /**
     * 模糊搜素收付款信息
     */
    public Map<String, Object> fuzzyQueryInvoice(Page page, InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.fuzzyQueryInvoice(page, invoiceBillsDto, sysUserDto);
    }

    /**
     * 付款发票直接接成本分页列表
     */
    public Map<String, Object> directInvoiceCostPage(Page page, InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.directInvoiceCostPage(page, invoiceBillsDto);
    }

    public String directTemporary(String zhu, String fapiao, String fujian, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.directTemporary(zhu, fapiao, fujian, sysUserDto);
    }

    public Map<String, Object> selectBillsItem(String subNo,Integer purchaseId) {
        return invoiceBillsServiceClient.selectBillsItem(subNo,purchaseId);
    }

    /**
     * 查询付款发票-直接成本暂存信息
     */
    public Map<String, Object> queryDirectCostTemporary(InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.queryDirectCostTemporary(invoiceBillsDto);
    }

    public Map<String, Object> invoiceMaterialPage(Map<String, Object> map,SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.invoiceMaterialPage(map,sysUserDto);
    }

    public Map<String, Object> queryEngineeringSubContract(SubContractBillsDto subContractBillsDto) {
        return invoiceBillsServiceClient.queryEngineeringSubContract(subContractBillsDto);
    }

    public Map<String, Object> queryPayInvoiceMaintenBudget(ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        return invoiceBillsServiceClient.queryPayInvoiceMaintenBudget(projectBillsBudgetsDto);
    }

    public Map<String, Object> selectPrint(InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.selectPrint(invoiceBillsDto, sysUserDto);
    }

    public Map<String, Object> queryInvoiceIndirect(InvoiceBillsDto invoiceBillsDto) {
        return invoiceBillsServiceClient.queryInvoiceIndirect(invoiceBillsDto);
    }

    public Boolean updatePrintTime(Integer id) {
        return invoiceBillsServiceClient.updatePrintTime(id);
    }

    public Map<String, Object> selectOtherIndirect(Map<String, Object> map, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.selectOtherIndirect(map, sysUserDto);
    }

    public ExecuteResult<String> updateContractNo(SubContractBillsDto subContractBillsDto) {
        return invoiceBillsServiceClient.updateContractNo(subContractBillsDto);
    }

    public ExecuteResult<String> updatePayCrContractNo(SubContractBillsDto subContractBillsDto) {
        return invoiceBillsServiceClient.updatePayCrContractNo(subContractBillsDto);
    }

    public ExecuteResult<String> revoke(InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        return invoiceBillsServiceClient.revoke(invoiceBillsDto,sysUserDto);
    }

    /**
     * 撤销-材料款
     * @param invoiceBillsDto
     * @param sysUserDto
     * @return
     */
    public ExecuteResult<String> revokeProjectPirce(InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        return this.invoiceBillsServiceClient.revokeProjectPirce(invoiceBillsDto,sysUserDto);
    }

    /**
     * 撤销 其他款项-直接
     * @param invoiceBillsDto
     * @param sysUserDto
     * @return
     */
    public ExecuteResult<String> revokeDirectInvoiceCost(InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        return this.invoiceBillsServiceClient.revokeDirectInvoiceCost(invoiceBillsDto,sysUserDto);
    }

    /**
     * 撤销-其他款项-间接
     * @param invoiceBillsDto
     * @param sysUserDto
     * @return
     */
    public ExecuteResult<String> revokeIndirect(InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        return this.invoiceBillsServiceClient.revokeIndirect(invoiceBillsDto,sysUserDto);
    }
}
