
package io.platform.progressConfiguration.web.controller.rest;


import io.platform.progressConfiguration.dto.ProjectNodeNexusDto;
import io.platform.progressConfiguration.web.remote.ProjectNodeNexusServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectNodeNexus")
public class ProjectNodeNexusRestController extends AbstractController {

    @Autowired
    private ProjectNodeNexusServiceRemote projectNodeNexusServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:projectNodeNexus:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectNodeNexusServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:projectNodeNexus:page")
    public R page(Page page, ProjectNodeNexusDto projectNodeNexusDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectNodeNexusServiceRemote.getPage(page, projectNodeNexusDto, sysUserDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectNodeNexus:info")
    public R info(@PathVariable("id") Long id) {
        ProjectNodeNexusDto projectNodeNexusDto = projectNodeNexusServiceRemote.getOne(id);
        return R.ok().put("projectNodeNexusDto", projectNodeNexusDto);
    }

    /**
     * 查询所需基础信息
     */
    @PostMapping("/queryProNodeNexus")
    @RequiresPermissions("engineering:projectNodeNexus:list")
    public Map<String, Object> queryProNodeNexus() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return projectNodeNexusServiceRemote.queryProNodeNexus(sysUserDto);
    }

    /**
     * 查询修改信息
     */
    @PostMapping("/queryProNodeNexusTemporary")
    @RequiresPermissions("engineering:projectNodeNexus:list")
    public Map<String, Object> queryProNodeNexusTemporary(@RequestBody ProjectNodeNexusDto projectNodeNexusDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return projectNodeNexusServiceRemote.queryProNodeNexusTemporary(projectNodeNexusDto, sysUserDto);
    }

    /**
     * 保存
     */
    @PostMapping("/saveProNodeNexus")
    @RequiresPermissions("engineering:projectNodeNexus:list")
    public R saveProNodeNexus(@RequestParam("form") String form, @RequestParam("item") String items) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectNodeNexusServiceRemote.saveProNodeNexus(form, items, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectNodeNexus:save")
    public R save(@RequestBody ProjectNodeNexusDto projectNodeNexusDto) {
        ValidatorUtils.validateEntity(projectNodeNexusDto);
        ExecuteResult<String> result = projectNodeNexusServiceRemote.save(projectNodeNexusDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectNodeNexus:edit")
    public R update(@RequestBody ProjectNodeNexusDto projectNodeNexusDto) {
        ValidatorUtils.validateEntity(projectNodeNexusDto);
        ExecuteResult<String> result = projectNodeNexusServiceRemote.update(projectNodeNexusDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:projectNodeNexus:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = projectNodeNexusServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
