
package io.platform.project.web.controller;


import io.platform.project.dto.AttachFilesDto;
import io.platform.project.web.remote.AttachFilesServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/attachFiles")
public class AttachFilesRestController extends AbstractController {

    @Autowired
    private AttachFilesServiceRemote attachFilesServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:attachFiles:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", attachFilesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:attachFiles:page")
    public R page(Page page, AttachFilesDto attachFilesDto) {
        return R.ok().put("page", attachFilesServiceRemote.getPage(page, attachFilesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:attachFiles:info")
    public R info(@PathVariable("id") Long id) {
        AttachFilesDto attachFilesDto = attachFilesServiceRemote.getOne(id);
        return R.ok().put("attachFilesDto", attachFilesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:attachFiles:save")
    public R save(@RequestBody AttachFilesDto attachFilesDto) {
        ValidatorUtils.validateEntity(attachFilesDto);
        ExecuteResult<String> result = attachFilesServiceRemote.save(attachFilesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:attachFiles:edit")
    public R update(@RequestBody AttachFilesDto attachFilesDto) {
        ValidatorUtils.validateEntity(attachFilesDto);
        ExecuteResult<String> result = attachFilesServiceRemote.update(attachFilesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:attachFiles:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = attachFilesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
