
package io.platform.project.web.controller;


import io.platform.project.dto.DictionariesDto;
import io.platform.project.web.remote.DictionariesServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/dictionaries")
public class DictionariesRestController extends AbstractController {

    @Autowired
    private DictionariesServiceRemote dictionariesServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:dictionaries:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", dictionariesServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:dictionaries:page")
    public R page(Page page, DictionariesDto dictionariesDto) {
        return R.ok().put("page", dictionariesServiceRemote.getPage(page, dictionariesDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:dictionaries:info")
    public R info(@PathVariable("id") Long id) {
        DictionariesDto dictionariesDto = dictionariesServiceRemote.getOne(id);
        return R.ok().put("dictionariesDto", dictionariesDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:dictionaries:save")
    public R save(@RequestBody DictionariesDto dictionariesDto) {
        ValidatorUtils.validateEntity(dictionariesDto);
        ExecuteResult<String> result = dictionariesServiceRemote.save(dictionariesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:dictionaries:edit")
    public R update(@RequestBody DictionariesDto dictionariesDto) {
        ValidatorUtils.validateEntity(dictionariesDto);
        ExecuteResult<String> result = dictionariesServiceRemote.update(dictionariesDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:dictionaries:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = dictionariesServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
