
package io.platform.project.web.controller;


import io.platform.project.dto.ProcessBillsDto;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.web.remote.ProcessBillsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/processBills")
public class ProcessBillsRestController extends AbstractController {

    @Autowired
    private ProcessBillsServiceRemote processBillsServiceRemote;

    /**
     * 查询项目进度
     */
    @PostMapping("/changeFuzzyQueryProjectSub")
    @RequiresPermissions("engineering:processBills:list")
    public R changeFuzzyQueryProjectSub(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        //查询列表数据
        return R.ok().put("list", processBillsServiceRemote.changeFuzzyQueryProjectSub(projectBillsSubsDto));
    }

    /**
     * 查询开工申报表
     */
    @PostMapping("/queryProjectStartAttach")
    @RequiresPermissions("engineering:processBills:list")
    public R queryProjectStartAttach(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("url", processBillsServiceRemote.queryProjectStartAttach(projectBillsSubsDto));
    }

    /**
     * 查询项目维护进度
     */
    @PostMapping("/queryProcessValue")
    @RequiresPermissions("engineering:processBills:list")
    public R queryProcessValue(@RequestBody Integer id) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", processBillsServiceRemote.queryProcessValue(id, sysUserDto));
    }

    /**
     * 模糊查询 维护记录
     */
    @PostMapping("/fuzzyQueryProcess")
    @RequiresPermissions("engineering:processBills:list")
    public R fuzzyQueryProcess(Page pageDto, @RequestBody ProcessBillsDto processBillsDto) {
        //查询列表数据
        return R.ok().put("list", processBillsServiceRemote.fuzzyQueryProcess(pageDto, processBillsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:processBills:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", processBillsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:processBills:page")
    public R page(@RequestBody Map<String, Object> map) {
        return R.ok().put("page", processBillsServiceRemote.getPage(map));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:processBills:info")
    public R info(@PathVariable("id") Long id) {
        ProcessBillsDto processBillsDto = processBillsServiceRemote.getOne(id);
        return R.ok().put("processBillsDto", processBillsDto);
    }

    /**
     * 查询暂存
     */
    @SysLog("查询暂存")
    @PostMapping("/queryDataTemporary")
    @RequiresPermissions("engineering:processBills:save")
    public R queryDataTemporary(@RequestBody ProcessBillsDto processBillsDto) {
        ValidatorUtils.validateEntity(processBillsDto);
        return R.ok().put("list", processBillsServiceRemote.queryDataTemporary(processBillsDto));
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/processTemporary")
    @RequiresPermissions("engineering:processBills:save")
    public R processTemporary(@RequestParam(required = false, value = "process") String process,
                              @RequestParam(required = false, value = "processSteps") String processSteps) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = processBillsServiceRemote.processTemporary(process, processSteps, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/processSave")
    @RequiresPermissions("engineering:processBills:save")
    public R processSave(@RequestParam(required = false, value = "process") String process,
                         @RequestParam(required = false, value = "processSteps") String processSteps) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = processBillsServiceRemote.processSave(process, processSteps, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:processBills:save")
    public R save(@RequestBody ProcessBillsDto processBillsDto) {
        ValidatorUtils.validateEntity(processBillsDto);
        ExecuteResult<String> result = processBillsServiceRemote.save(processBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:processBills:edit")
    public R update(@RequestBody ProcessBillsDto processBillsDto) {
        ValidatorUtils.validateEntity(processBillsDto);
        ExecuteResult<String> result = processBillsServiceRemote.update(processBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:processBills:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = processBillsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 形象进度维护主表查询方法
     */
    @PostMapping("/selectProjectProcessData")
    public Map<String, Object> selectProjectProcessData(@RequestParam("id") Integer id) {
        return processBillsServiceRemote.selectProjectProcessData(id);
    }
}
