
package io.platform.project.web.controller;


import io.platform.project.dto.ProcessBillsStepsDto;
import io.platform.project.web.remote.ProcessBillsStepsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/processBillsSteps")
public class ProcessBillsStepsRestController extends AbstractController {

    @Autowired
    private ProcessBillsStepsServiceRemote processBillsStepsServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:processBillsSteps:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", processBillsStepsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:processBillsSteps:page")
    public R page(Page page, ProcessBillsStepsDto processBillsStepsDto) {
        return R.ok().put("page", processBillsStepsServiceRemote.getPage(page, processBillsStepsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:processBillsSteps:info")
    public R info(@PathVariable("id") Long id) {
        ProcessBillsStepsDto processBillsStepsDto = processBillsStepsServiceRemote.getOne(id);
        return R.ok().put("processBillsStepsDto", processBillsStepsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:processBillsSteps:save")
    public R save(@RequestBody ProcessBillsStepsDto processBillsStepsDto) {
        ValidatorUtils.validateEntity(processBillsStepsDto);
        ExecuteResult<String> result = processBillsStepsServiceRemote.save(processBillsStepsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:processBillsSteps:edit")
    public R update(@RequestBody ProcessBillsStepsDto processBillsStepsDto) {
        ValidatorUtils.validateEntity(processBillsStepsDto);
        ExecuteResult<String> result = processBillsStepsServiceRemote.update(processBillsStepsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:processBillsSteps:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = processBillsStepsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
