
package io.platform.project.web.controller;


import io.platform.project.dto.ProjectBillsHistoryDto;
import io.platform.project.web.remote.ProjectBillsHistoryServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectBillsHistory")
public class ProjectBillsHistoryRestController extends AbstractController {

    @Autowired
	private ProjectBillsHistoryServiceRemote projectBillsHistoryServiceRemote;
	
	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("engineering:projectBillsHistory:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", projectBillsHistoryServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@PostMapping("/page")
	@RequiresPermissions("engineering:projectBillsHistory:page")
	public R page(Page page, ProjectBillsHistoryDto projectBillsHistoryDto){
		return R.ok().put("page", projectBillsHistoryServiceRemote.getPage(page,projectBillsHistoryDto));
	}
	/**
	 * 信息
	 */
	@PostMapping("/info/{id}")
	@RequiresPermissions("engineering:projectBillsHistory:info")
	public R info(@PathVariable("id") Long id){
		ProjectBillsHistoryDto projectBillsHistoryDto = projectBillsHistoryServiceRemote.getOne(id);
		return R.ok().put("projectBillsHistoryDto", projectBillsHistoryDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("engineering:projectBillsHistory:save")
	public R save(ProjectBillsHistoryDto projectBillsHistoryDto){
        ValidatorUtils.validateEntity(projectBillsHistoryDto);
        ExecuteResult<String> result= projectBillsHistoryServiceRemote.save(projectBillsHistoryDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("engineering:projectBillsHistory:edit")
	public R update(@RequestBody ProjectBillsHistoryDto projectBillsHistoryDto){
        ValidatorUtils.validateEntity(projectBillsHistoryDto);
        ExecuteResult<String> result= projectBillsHistoryServiceRemote.update(projectBillsHistoryDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("engineering:projectBillsHistory:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= projectBillsHistoryServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
