
package io.platform.project.web.controller;


import io.platform.project.dto.ProjectBillsStepsAdjustDto;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.web.remote.ProjectBillsStepsAdjustServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectBillsStepsAdjust")
public class ProjectBillsStepsAdjustRestController extends AbstractController {

    @Autowired
    private ProjectBillsStepsAdjustServiceRemote projectBillsStepsAdjustServiceRemote;

    /**
     * 模糊查询
     *
     * @param projectBillsStepsAdjustDto
     * @return
     */
    @PostMapping("/fuzzyQueryProjectAdjust")
    @RequiresPermissions("engineering:projectBillsStepsAdjust:list")
    public R fuzzyQueryProjectAdjust(Page page, @RequestBody ProjectBillsStepsAdjustDto projectBillsStepsAdjustDto) {
        return R.ok().put("list", projectBillsStepsAdjustServiceRemote.fuzzyQueryProjectAdjust(page, projectBillsStepsAdjustDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:projectBillsStepsAdjust:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectBillsStepsAdjustServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:projectBillsStepsAdjust:page")
    public R page(Page page, ProjectBillsStepsAdjustDto projectBillsStepsAdjustDto) {
        return R.ok().put("page", projectBillsStepsAdjustServiceRemote.getPage(page, projectBillsStepsAdjustDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectBillsStepsAdjust:info")
    public R info(@PathVariable("id") Long id) {
        ProjectBillsStepsAdjustDto projectBillsStepsAdjustDto = projectBillsStepsAdjustServiceRemote.getOne(id);
        return R.ok().put("projectBillsStepsAdjustDto", projectBillsStepsAdjustDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectBillsStepsAdjust:save")
    public R save(@RequestBody ProjectBillsStepsAdjustDto projectBillsStepsAdjustDto) {
        ValidatorUtils.validateEntity(projectBillsStepsAdjustDto);
        ExecuteResult<String> result = projectBillsStepsAdjustServiceRemote.save(projectBillsStepsAdjustDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectBillsStepsAdjust:edit")
    public R update(@RequestBody ProjectBillsStepsAdjustDto projectBillsStepsAdjustDto) {
        ValidatorUtils.validateEntity(projectBillsStepsAdjustDto);
        ExecuteResult<String> result = projectBillsStepsAdjustServiceRemote.update(projectBillsStepsAdjustDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:projectBillsStepsAdjust:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = projectBillsStepsAdjustServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /*
    首页饼状图查询
     */
    @PostMapping("selectSubCount")
    public Map<String,Object> selectSubCount (){
        return projectBillsStepsAdjustServiceRemote.selectSubCount();
    }
}
