
package io.platform.project.web.controller;

import io.platform.project.dto.ProjectBillsStepsAdjustDto;
import io.platform.project.dto.ProjectBillsStepsDto;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.dto.ProjectbillsDto;
import io.platform.project.web.remote.ProjectBillsStepsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectBillsSteps")
public class ProjectBillsStepsRestController extends AbstractController {

    @Autowired
    private ProjectBillsStepsServiceRemote projectBillsStepsServiceRemote;

    /**
     * 根据单号查询
     *
     * @param projectbillsDto
     * @return
     */
    @PostMapping("/numberQueryContract")
    @RequiresPermissions("engineering:projectBillsSteps:list")
    public R numberQueryContract(@RequestBody ProjectBillsSubsDto projectbillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", projectBillsStepsServiceRemote.numberQueryContract(projectbillsDto, sysUserDto));
    }

    /**
     * 查询修改记录
     */
    @PostMapping("/queryRecords")
    @RequiresPermissions("engineering:projectBillsSteps:list")
    public R queryRecords(@RequestBody ProjectBillsStepsAdjustDto projectBillsStepsAdjustDto) {
        //查询列表数据
        return R.ok().put("list", projectBillsStepsServiceRemote.queryRecords(projectBillsStepsAdjustDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectBillsStepsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    public R page(Page page, ProjectBillsStepsDto projectBillsStepsDto) {
        return R.ok().put("page", projectBillsStepsServiceRemote.getPage(page, projectBillsStepsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectBillsSteps:info")
    public R info(@PathVariable("id") Long id) {
        ProjectBillsStepsDto projectBillsStepsDto = projectBillsStepsServiceRemote.getOne(id);
        return R.ok().put("projectBillsStepsDto", projectBillsStepsDto);
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/projectStepTemporary")
    @RequiresPermissions("engineering:projectBillsSteps:save")
    public R projectStepTemporary(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                                  @RequestParam(required = false, value = "proStep") String projectBillsStls) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectBillsStepsServiceRemote.projectStepTemporary(projectBillsContract, projectBillsStls, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/projectStepSave")
    @RequiresPermissions("engineering:projectBillsSteps:save")
    public R projectStepSave(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                             @RequestParam(required = false, value = "proStep") String projectBillsStls) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectBillsStepsServiceRemote.projectStepSave(projectBillsContract, projectBillsStls, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 编辑提交
     */
    @SysLog("编辑提交")
    @PostMapping("/editMilestoneSave")
    @RequiresPermissions("engineering:projectBillsSteps:save")
    public R editMilestoneSave(@RequestBody List<ProjectBillsStepsAdjustDto> projectBillsStepsAdjustDtos) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectBillsStepsServiceRemote.editMilestoneSave(projectBillsStepsAdjustDtos, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectBillsSteps:save")
    public R save(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                  @RequestParam(required = false, value = "proStep") String projectBillsStls) {
        ExecuteResult<String> result = projectBillsStepsServiceRemote.save(projectBillsContract, projectBillsStls);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectBillsSteps:edit")
    public R update(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                    @RequestParam(required = false, value = "proStep") String projectBillsStls) {
        ExecuteResult<String> result = projectBillsStepsServiceRemote.update(projectBillsContract, projectBillsStls);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:projectBillsSteps:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = projectBillsStepsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 形象进度维护保存
     */
    @PostMapping("/processStepsSave")
    public String processStepsSave(@RequestParam("item") String item) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return projectBillsStepsServiceRemote.processStepsSave(item, sysUserDto);
    }
    /**
     * 形象进度列表查询
     */
    @PostMapping("/selectProjectSubDataList")
    public Page<ProjectBillsSubsDto> selectProjectSubDataList(Page page,ProjectBillsSubsDto projectBillsSubsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return projectBillsStepsServiceRemote.selectProjectSubDataList(page,projectBillsSubsDto,sysUserDto);
    }
}
