
package io.platform.project.web.controller;


import io.platform.base.common.utils.UploadUtil;
import io.platform.budget.dto.ProjectBillsBudgetsDto;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.web.remote.ProjectBillsSubsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.xssf.usermodel.*;
import org.apache.shiro.SecurityUtils;
import org.springframework.mock.web.MockMultipartFile;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectBillsSubs")
public class ProjectBillsSubsRestController extends AbstractController {

    @Autowired
    private ProjectBillsSubsServiceRemote projectBillsSubsServiceRemote;

    /**
     * 模糊查询
     *
     * @param projectBillsSubsDto
     * @return
     */
    @PostMapping("/fuzzyQueryProjectSubs")
    public R fuzzyQueryProjectSubs(Page page, @RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("list", projectBillsSubsServiceRemote.fuzzyQueryProjectSubs(page, projectBillsSubsDto));
    }

    /**
     * 查询项目汇总信息
     */
    @PostMapping("/queryProjectSummaryData")
    public R queryProjectSummaryData(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("list", projectBillsSubsServiceRemote.queryProjectSummaryData(projectBillsSubsDto));
    }

    /**
     * 项目汇总查询信息
     */
    @PostMapping("/getProSummaryPage")
    public R getProSummaryPage(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectBillsSubsServiceRemote.getProSummaryPage(map, sysUserDto));
    }

    /**
     * 查询总包结算过子项目
     */
    @PostMapping("/querySettlementProjectSubs")
    public R querySettlementProjectSubs(Page page, ProjectBillsSubsDto projectBillsSubsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        projectBillsSubsDto.setBranchId(sysUserDto.getLoginContractorId());
        return R.ok().put("list", projectBillsSubsServiceRemote.querySettlementProjectSubs(page, projectBillsSubsDto));
    }

    /**
     * 条件查询
     */
    @PostMapping("/conditionalQueryProjectSubs")
    public R conditionalQueryProjectSubs(Page page, ProjectBillsSubsDto projectBillsSubsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        projectBillsSubsDto.setBranchId(sysUserDto.getLoginContractorId());
        return R.ok().put("list", projectBillsSubsServiceRemote.conditionalQueryProjectSubs(page, projectBillsSubsDto));
    }

    /**
     * 查询付款发票-其他款项-间接成本 二级项目
     */
    @PostMapping("/queryPayInvoiceVal")
    public R queryPayInvoiceVal(Page page, ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        //查询列表数据
        return R.ok().put("list", projectBillsSubsServiceRemote.queryPayInvoiceVal(page, projectBillsBudgetsDto,sysUserDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectBillsSubsServiceRemote.getList(params));
    }

    /**
     * 所有列表
     */
    @PostMapping("/projectBalancePage")
    public R projectBalancePage(@RequestBody Map<String, Object> params) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectBillsSubsServiceRemote.projectBalancePage(params, sysUserDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/getEngineeringPage")
    public R getEngineeringPage(Page page, ProjectBillsSubsDto projectBillsSubsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectBillsSubsServiceRemote.getEngineeringPage(page, projectBillsSubsDto,sysUserDto));
    }

    /**
     * 存续台账导出Excel
     */
    @GetMapping("subsistingExportExcel")
    public String  subsistingExportExcel(HttpServletResponse response, ProjectBillsSubsDto projectBillsSubsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        List<Map<String, Object>> mapList = projectBillsSubsServiceRemote.subsistingExportExcel(projectBillsSubsDto, sysUserDto);
        try {
            if (mapList.size() != 0) {
                XSSFWorkbook wb = new XSSFWorkbook();
                XSSFSheet sheets = wb.createSheet("工程项目台账");
                // 合并单元格：参数：起始行, 终止行, 起始列, 终止列
                CellRangeAddress cra = new CellRangeAddress(0, 0, 0, 13);
                sheets.addMergedRegion(cra);
                XSSFRow xssfRow = sheets.createRow(0);
                //headers表示excel表中第一行的表头
                XSSFCell cell = xssfRow.createCell(0);
                cell.setCellValue(new XSSFRichTextString("公司工程项目台账"));
                CellStyle cellStyle = wb.createCellStyle();
                cellStyle.setAlignment(HorizontalAlignment.CENTER);
                cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                cell.setCellStyle(cellStyle);
                XSSFRow row = sheets.createRow(1);
                int rowNum = 2;
                String[] headers = {"序号", "NC工程编号", "系统工程编号", "工程名称", "工程类型", "承包单位", "业主单位", "实际实施单位", "立项日期",
                        "合同开工日期", "合同竣工日期", "开工日期", "竣工日期", "工程状态"};
                //在excel表中添加表头
                for (int i = 0; i < headers.length; i++) {
                    XSSFCell cell1 = row.createCell(i);
                    XSSFRichTextString text = new XSSFRichTextString(headers[i]);
                    cell1.setCellValue(text);
                }
                //在表中存放查询到的数据放入对应的列
                for (Map<String, Object> mp : mapList) {
                    XSSFRow row1 = sheets.createRow(rowNum);
                    row1.createCell(0).setCellValue((Integer) mp.get("serialNumber"));
                    row1.createCell(1).setCellValue((String) mp.get("ncProjectNo"));
                    row1.createCell(2).setCellValue((String) mp.get("projectSubNo"));
                    row1.createCell(3).setCellValue((String) mp.get("projectSubName"));
                    row1.createCell(4).setCellValue((String) mp.get("projectTypeName"));
                    row1.createCell(5).setCellValue((String) mp.get("branName"));
                    row1.createCell(6).setCellValue((String) mp.get("corpName"));
                    row1.createCell(7).setCellValue((String) mp.get("constructorName"));
                    Date createData = (Date) mapList.get(0).get("createData");
                    Date planStartDate = (Date) mapList.get(0).get("planStartDate");
                    Date planEndDate = (Date) mapList.get(0).get("planEndDate");
                    Date actStartDate = (Date) mapList.get(0).get("actStartDate");
                    Date actEndDate = (Date) mapList.get(0).get("actEndDate");
                    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                    if (createData != null) {
                        row1.createCell(8).setCellValue(sdf.format(createData));
                    } else {
                        row1.createCell(8).setCellValue("");
                    }
                    if (planStartDate != null) {
                        row1.createCell(9).setCellValue(sdf.format(planStartDate));
                    } else {
                        row1.createCell(9).setCellValue("");
                    }
                    if (planEndDate != null) {
                        row1.createCell(10).setCellValue(sdf.format(planEndDate));
                    } else {
                        row1.createCell(10).setCellValue("");
                    }
                    if (actStartDate != null) {
                        row1.createCell(11).setCellValue(sdf.format(actStartDate));
                    } else {
                        row1.createCell(11).setCellValue("");
                    }
                    if (actEndDate != null) {
                        row1.createCell(12).setCellValue(sdf.format(actEndDate));
                    } else {
                        row1.createCell(12).setCellValue("");
                    }
                    row1.createCell(13).setCellValue((String) mp.get("projectStatusName"));
                    rowNum++;
                }
                //业务逻辑，给XSSFWorkbook添加数据
                //end
                ByteArrayOutputStream bos=new ByteArrayOutputStream();
                wb.write(bos);
                byte[] barray=bos.toByteArray();
//is第一转
                InputStream is=new ByteArrayInputStream(barray);
                MultipartFile multipartFile = new MockMultipartFile("S","存续项目台账.xlsx","D",is);
                String path = UploadUtil.newFtpUpload(multipartFile);
                System.out.println(path);
                return path;
                /*FileOutputStream fileOutputStream = new FileOutputStream("d:\\工程项目台账.xlsx");
                try {
                    wb.write(fileOutputStream);
                    wb.close();
                    fileOutputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                    logger.error("异常：" + e.toString(), e);
                    return false;
                }*/
            }
        } catch (Exception e) {
            logger.error("异常：" + e.toString(), e);
            return null;
        }
        return null;
    }

    /**
     * 查询单项工程收付款进度分析
     */
    @PostMapping("/queryProjectBillsSubs")
    public R queryProjectBillsSubs(@RequestBody  ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("list", projectBillsSubsServiceRemote.queryProjectBillsSubs(projectBillsSubsDto));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    public R page(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectBillsSubsServiceRemote.getPage(map, sysUserDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectBillsSubs:info")
    public R info(@PathVariable("id") Long id) {
        ProjectBillsSubsDto projectBillsSubsDto = projectBillsSubsServiceRemote.getOne(id);
        return R.ok().put("projectBillsSubsDto", projectBillsSubsDto);
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/projectSubTemporary")
    public R projectSubTemporary(@RequestBody List<ProjectBillsSubsDto> projectBillsSubsDto) {
        ValidatorUtils.validateEntity(projectBillsSubsDto);
        ExecuteResult<String> result = projectBillsSubsServiceRemote.projectSubTemporary(projectBillsSubsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    public R save(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        ValidatorUtils.validateEntity(projectBillsSubsDto);
        ExecuteResult<String> result = projectBillsSubsServiceRemote.save(projectBillsSubsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    public R update(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        ValidatorUtils.validateEntity(projectBillsSubsDto);
        ExecuteResult<String> result = projectBillsSubsServiceRemote.update(projectBillsSubsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:projectBillsSubs:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = projectBillsSubsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询收付款结算列表
     */
    @PostMapping("/moneySettlementPage")
    @RequiresPermissions("engineering:moneySettlement:page")
    public Map<String, Object> moneySettlementPage(@RequestBody Map<String, Object> params) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return projectBillsSubsServiceRemote.moneySettlementPage(params, sysUserDto);
    }

    /**
     * 查询结项打印信息
     */
    @PostMapping("/queryClosingVal")
    @RequiresPermissions("engineering:contractBills:list")
    public Map<String, Object> queryClosingVal(@RequestBody Integer integer) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return projectBillsSubsServiceRemote.queryClosingVal(integer, sysUserDto);
    }

    @PostMapping("/purchaseSubPage")
    public R purchaseSubPage(Page page, ProjectBillsSubsDto projectBillsSubsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectBillsSubsServiceRemote.purchaseSubPage(page, projectBillsSubsDto,sysUserDto));
    }

    @PostMapping("/selectSubPage")
    public R selectSubPage(Page page, ProjectBillsSubsDto projectBillsSubsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectBillsSubsServiceRemote.selectSubPage(page, projectBillsSubsDto,sysUserDto));
    }
    @GetMapping("engineeringExportExcel")
    public String  engineeringExportExcel(HttpServletResponse response, ProjectBillsSubsDto projectBillsSubsDto) {
        List<Map<String, Object>> mapList = projectBillsSubsServiceRemote.engineeringExportExcel(projectBillsSubsDto);
        try {
            if (mapList.size() != 0) {
                XSSFWorkbook wb = new XSSFWorkbook();
                XSSFSheet sheets = wb.createSheet("工程项目台账");
                // 合并单元格：参数：起始行, 终止行, 起始列, 终止列
                CellRangeAddress cra = new CellRangeAddress(0, 0, 0, 13);
                sheets.addMergedRegion(cra);
                XSSFRow xssfRow = sheets.createRow(0);
                //headers表示excel表中第一行的表头
                XSSFCell cell = xssfRow.createCell(0);
                cell.setCellValue(new XSSFRichTextString("公司工程项目台账"));
                CellStyle cellStyle = wb.createCellStyle();
                cellStyle.setAlignment(HorizontalAlignment.CENTER);
                cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                cell.setCellStyle(cellStyle);
                XSSFRow row = sheets.createRow(1);
                int rowNum = 2;
                String[] headers = {"序号", "单位名称", "工程名称", "系统工程编号", "NC工程编号", "工程类型", "业主单位", "实际实施单位",
                        "立项日期", "合同开工日期", "合同竣工日期", "开工日期", "竣工日期", "工程状态"};
                //在excel表中添加表头
                for (int i = 0; i < headers.length; i++) {
                    XSSFCell cell1 = row.createCell(i);
                    XSSFRichTextString text = new XSSFRichTextString(headers[i]);
                    cell1.setCellValue(text);
                }
                //在表中存放查询到的数据放入对应的列
                for (Map<String, Object> mp : mapList) {
                    XSSFRow row1 = sheets.createRow(rowNum);
                    row1.createCell(0).setCellValue((Integer) mp.get("serialNumber"));
                    row1.createCell(1).setCellValue((String) mp.get("branName"));
                    row1.createCell(2).setCellValue((String) mp.get("projectSubName"));
                    row1.createCell(3).setCellValue((String) mp.get("projectSubNo"));
                    row1.createCell(4).setCellValue((String) mp.get("ncProjectNo"));
                    row1.createCell(5).setCellValue((String) mp.get("projectTypeName"));
                    row1.createCell(6).setCellValue((String) mp.get("corpName"));
                    row1.createCell(7).setCellValue((String) mp.get("constructorName"));
                    Date createData = (Date) mapList.get(0).get("createData");
                    Date planStartDate = (Date) mapList.get(0).get("planStartDate");
                    Date planEndDate = (Date) mapList.get(0).get("planEndDate");
                    Date actStartDate = (Date) mapList.get(0).get("actStartDate");
                    Date actEndDate = (Date) mapList.get(0).get("actEndDate");
                    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                    row1.createCell(8).setCellValue(sdf.format(createData));
                    row1.createCell(9).setCellValue(sdf.format(planStartDate));
                    row1.createCell(10).setCellValue(sdf.format(planEndDate));
                    row1.createCell(11).setCellValue(sdf.format(actStartDate));
                    row1.createCell(12).setCellValue(sdf.format(actEndDate));
                    row1.createCell(13).setCellValue((String) mp.get("projectStatusName"));
                    rowNum++;
                }
                //业务逻辑，给XSSFWorkbook添加数据
                //end
                ByteArrayOutputStream bos=new ByteArrayOutputStream();
                wb.write(bos);
                byte[] barray=bos.toByteArray();
//is第一转
                InputStream is=new ByteArrayInputStream(barray);
                MultipartFile multipartFile = new MockMultipartFile("S","工程项目台账.xlsx","D",is);
                String path = UploadUtil.newFtpUpload(multipartFile);
                System.out.println(path);
                return path;
                /*FileOutputStream fileOutputStream = new FileOutputStream("d:\\工程项目台账.xlsx");
                try {
                    wb.write(fileOutputStream);
                    wb.close();
                    fileOutputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                    logger.error("异常：" + e.toString(), e);
                    return false;
                }*/
            }
        } catch (Exception e) {
            logger.error("异常：" + e.toString(), e);
            return null;
        }
        return null;
    }
}
