
package io.platform.project.web.controller;


import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.approvalConfiguration.dto.AuditItemsDto;
import io.platform.base.common.utils.Excel;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.project.dto.ProjectBS;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.dto.ProjectbillsDto;
import io.platform.project.web.remote.ProjectbillsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.text.ParseException;
import java.util.Calendar;
import java.util.Map;

import java.lang.*;

@RestController
@RequestMapping("/engineering/projectbills")
public class ProjectbillsRestController extends AbstractController {

    @Autowired
    private ProjectbillsServiceRemote projectbillsServiceRemote;
    @Autowired
    private Excel excel;

    /**
     * 根据条件查询该工程该预算该供应商总开票金额
     *
     * @param invoiceBillsDto
     * @return
     */
    @PostMapping("/selectSumPurchaseInvCr")
    public Double selectSumPurchaseInvCr(@RequestBody InvoiceBillsDto invoiceBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return projectbillsServiceRemote.selectSumPurchaseInvCr(invoiceBillsDto, sysUserDto);
    }

    /**
     * 管理员修改总包
     */
    @PostMapping("/contractAdminSave")
    public R contractAdminSave(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                          @RequestParam(required = false, value = "proStls") String projectBillsStls,
                          @RequestParam(required = false, value = "attachs") String attachs) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.contractAdminSave(projectBillsContract, projectBillsStls, attachs, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询立项信息
     */
    @PostMapping("/queryProjectBills")
    public R queryProjectBills(@RequestBody ProjectbillsDto projectbillsDto) {
        //查询列表数据
        return R.ok().put("list", projectbillsServiceRemote.queryProjectBills(projectbillsDto));
    }

    /**
     * 撤回审批
     */
    @PostMapping("/withdrawalApproval")
    public R withdrawalApproval(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.withdrawalApproval(projectBillsSubsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询项目 预算
     */
    @SysLog("查询项目预算")
    @PostMapping("/queryProjectBalance")
    public R queryProjectBalance(@RequestBody ProjectbillsDto projectbillsDto) {
        //查询列表数据
        return R.ok().put("list", projectbillsServiceRemote.queryProjectBalance(projectbillsDto));
    }

    /**
     * 提交结项信息
     */
    @SysLog("提交结项信息")
    @PostMapping("/projectBalanceSave")
    public R projectBalanceSave(@RequestParam("project") String project, @RequestParam("budget") String billsBudgets) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ProjectBS projectBS = JSONArray.parseObject(project, ProjectBS.class);
        ExecuteResult<String> result = projectbillsServiceRemote.projectBalanceSave(projectBS, sysUserDto, billsBudgets);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交收付款结项信息
     */
    @SysLog("提交收付款结项信息")
    @PostMapping("/projectSettlerSave")
    public R projectSettlerSave(@RequestBody ProjectBS projectBS) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.projectSettlerSave(projectBS, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询开工信息
     */
    @PostMapping("/queryProStartDateInformation")
    public R queryProStartDateInformation(@RequestBody ProjectbillsDto projectbillsDto) {
        //查询列表数据
        return R.ok().put("list", projectbillsServiceRemote.queryProStartDateInformation(projectbillsDto));
    }

    /**
     * 查询立项信息提醒
     */
    @PostMapping("/queryProjectWarning")
    public R queryProjectWarning() {
        //查询列表数据
        return R.ok().put("list", projectbillsServiceRemote.queryProjectWarning());
    }

    /**
     * 分页列表
     */
    @PostMapping("/tkPage")
    public R tkPage(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectbillsServiceRemote.tkPage(map, sysUserDto));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    public R page(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectbillsServiceRemote.getPage(map, sysUserDto));
    }

    /**
     * 查询总包结算
     */
    @PostMapping("/queryTurnkeySettlement")
    public R queryTurnkeySettlement(@RequestBody ProjectbillsDto projectbillsDto) {
        return R.ok().put("list", projectbillsServiceRemote.queryTurnkeySettlement(projectbillsDto));
    }

    /**
     * 查询存续项目总包结算
     */
    @PostMapping("/queryTurnkeyExistingBillVal")
    public Map<String, Object> queryTurnkeyExistingBillVal(@RequestBody Integer id) {
        return projectbillsServiceRemote.queryTurnkeyExistingBillVal(id);
    }

    /**
     * 保存存续项目总包结算信息
     */
    @PostMapping("/updateBilling")
    public R updateBilling(@RequestParam("from") String from, @RequestParam("list") String list, @RequestParam("edit") String edit) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.updateBilling(from, list, edit, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询总包结算列表
     */
    @PostMapping("/settlementPage")
    public R settlementPage(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectbillsServiceRemote.settlementPage(map, sysUserDto));
    }

    /**
     * 总包结算记账
     */
    @PostMapping("/turnkeySettlementSave")
    public R turnkeySettlementSave(@RequestParam(required = false, value = "form") String projectbill,
                                   @RequestParam(required = false, value = "dataList") String projectSubs,
                                   @RequestParam(required = false, value = "dataAttachs") String projectAttachs) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.turnkeySettlementSave(projectbill, projectSubs, projectAttachs, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询开工信息
     */
    @PostMapping("/pageStart")
    public R pageStart(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectbillsServiceRemote.pageStart(map, sysUserDto));
    }

    /**
     * 查询付款记录总包开票金额信息
     */
    @PostMapping("/queryProjectSumPayCr")
    public R queryProjectSumPayCr(@RequestBody ProjectbillsDto projectbillsDto) {
        return R.ok().put("list", projectbillsServiceRemote.queryProjectSumPayCr(projectbillsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    public R info(@PathVariable("id") Long id) {
        ProjectbillsDto projectbillsDto = projectbillsServiceRemote.getOne(id);
        return R.ok().put("projectbillsDto", projectbillsDto);
    }

    /**
     * 查询总包暂存数据
     */
    @SysLog("查询总包暂存数据")
    @PostMapping("/queryContractTemporary")
    public R queryContractTemporary(@RequestBody ProjectbillsDto projectbillsDto) {
        return R.ok().put("list", projectbillsServiceRemote.queryContractTemporary(projectbillsDto));
    }

    /**
     * 暂存
     */
    @SysLog("暂存")
    @PostMapping("/contractTemporary")
    public R temporary(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                       @RequestParam(required = false, value = "proStls") String projectBillsStls,
                       @RequestParam(required = false, value = "attachs") String attachs) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.temporary(projectBillsContract, projectBillsStls, attachs, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/contractSave")
    public R contractSave(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                          @RequestParam(required = false, value = "proStls") String projectBillsStls,
                          @RequestParam(required = false, value = "attachs") String attachs) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.contractSave(projectBillsContract, projectBillsStls, attachs, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 暂存
     */
    @SysLog("立项保存")
    @PostMapping("/projectBillsTemporary")
    public R projectBillsTemporary(@RequestParam("project") String project, @RequestParam("dataList") String proSubs) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.projectBillsTemporary(project, proSubs, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 提交开工日期
     */
    @SysLog("提交开工日期")
    @PostMapping("/projectStartUpdate")
    public R projectStartUpdate(@RequestBody ProjectbillsDto projectbillsDto) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.projectStartUpdate(projectbillsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    public R save(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                  @RequestParam(required = false, value = "proStls") String projectBillsStls) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.save(projectBillsContract, projectBillsStls, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 立项提交
     */
    @SysLog("立项提交")
    @PostMapping("/projectBillsUpdate")
    public R projectBillsUpdate(@RequestParam(required = false, value = "project") String project,
                                @RequestParam(required = false, value = "dataList") String proSubs) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.projectBillsUpdate(project, proSubs, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询续存信息
     */
    @PostMapping("/getPageSurvivingPro")
    public R getPageSurvivingPro(@RequestBody Map<String, Object> map) {
        return R.ok().put("page", projectbillsServiceRemote.getPageSurvivingPro(map));
    }

    /**
     * 查询存续信息
     */
    @PostMapping("/getRenewPage")
    public R getRenewPage(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", projectbillsServiceRemote.getRenewPage(map, sysUserDto));
    }

    /**
     * 查询续存项目暂存信息
     */
    @PostMapping("/querySurvivingProTemporary")
    public R querySurvivingProTemporary(@RequestBody ProjectbillsDto projectbillsDto) {
        return R.ok().put("list", projectbillsServiceRemote.querySurvivingProTemporary(projectbillsDto));
    }

    @SysLog("存续项目暂存")
    @PostMapping("/survivingProjectsTemporary")
    public R survivingProjectsTemporary(@RequestParam(required = false, value = "from") String projectBills,
                                        @RequestParam(required = false, value = "dataList") String projects,
                                        @RequestParam(required = false, value = "proCosts") String costSituation,
                                        @RequestParam(required = false, value = "proBudgets") String projectBudgets) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.survivingProjectsTemporary(projectBills, projects, costSituation, projectBudgets, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @SysLog("存续项目提交")
    @PostMapping("/survivingProjectsSave")
    public R survivingProjectsSave(@RequestParam(required = false, value = "from") String projectBills,
                                   @RequestParam(required = false, value = "dataList") String projects,
                                   @RequestParam(required = false, value = "proCosts") String costSituation,
                                   @RequestParam(required = false, value = "proBudgets") String projectBudgets) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.survivingProjectsSave(projectBills, projects, costSituation, projectBudgets, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @SysLog("修改存续项目提交")
    @PostMapping("/survivingProjectsModifyCommit")
    public R survivingProjectsModifyCommit(@RequestParam(required = false, value = "from") String projectBills,
                                           @RequestParam(required = false, value = "dataList") String projects,
                                           @RequestParam(required = false, value = "proCosts") String costSituation,
                                           @RequestParam(required = false, value = "backupData") String backupData,
                                           @RequestParam(required = false, value = "proBudgets") String projectBudgets) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.survivingProjectsModifyCommit(projectBills, projects, costSituation,
                projectBudgets, backupData, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }


    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    public R update(@RequestParam(required = false, value = "proContract") String projectBillsContract,
                    @RequestParam(required = false, value = "proStls") String projectBillsStls) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.update(projectBillsContract, projectBillsStls, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @SysLog("修改")
    @PostMapping("/proBalanceVal")
    public R proBalanceVal(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return R.ok().put("list", projectbillsServiceRemote.proBalanceVal(projectBillsSubsDto));
    }

    /**
     * 删除总包合同
     */
    @SysLog("删除总包合同")
    @PostMapping("/deleteContract")
    public R deleteContract(@RequestBody ProjectbillsDto projectbillsDto) {
        ExecuteResult<String> result = projectbillsServiceRemote.deleteContract(projectbillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询总包结算审批流信息
     */
    @PostMapping("/projectEndQueryPendingVal")
    public R projectEndQueryPendingVal(@RequestBody ProjectbillsDto projectbillsDto) {
        return R.ok().put("list", projectbillsServiceRemote.projectEndQueryPendingVal(projectbillsDto));
    }

    /**
     * 首页查询项目数据
     */
    @PostMapping("/getHomeProList")
    public R getHomeProList(@RequestBody Map<String, Object> map) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", projectbillsServiceRemote.getHomeProList(map, sysUserDto));
    }

    /**
     * 通过审批
     */
    @PostMapping("/approved")
    public R approved(@RequestBody AuditItemsDto auditItemsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.approved(auditItemsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 审批驳回
     */
    @PostMapping("/approvalRejected")
    public R approvalRejected(@RequestBody AuditItemsDto auditItemsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectbillsServiceRemote.approvalRejected(auditItemsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 查询待审事件对应工程id
     */
    @PostMapping("/queryPendingProjectId")
    public R queryPendingProjectId(@RequestBody AuditItemsDto auditItemsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        auditItemsDto.setBranchId(sysUserDto.getLoginContractorId());
        return R.ok().put("dto", projectbillsServiceRemote.queryPendingProjectId(auditItemsDto));
    }

    /**
     * 查询总包-结算计划预警
     */
    @PostMapping("/queryPending")
    public R queryPending(@RequestBody Map<String, Object> maps) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", projectbillsServiceRemote.queryPending(maps, sysUserDto));
    }

    /**
     * 查询所有提醒信息
     */
    @PostMapping("/selectAllWarningsCurrent")
    public R selectAllWarningsCurrent(Page pageDto, ProjectbillsDto projectbillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", projectbillsServiceRemote.selectAllWarningsCurrent(pageDto, projectbillsDto, sysUserDto));
    }

    /**
     * 查询所有预警信息
     */
    @PostMapping("/selectWarningMatters")
    public R selectWarningMatters(Page page, ProjectbillsDto projectbillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("list", projectbillsServiceRemote.selectWarningMatters(page, projectbillsDto, sysUserDto));
    }

    /**
     * 已读竣工后 30天提醒结算
     */
    @PostMapping("/completionReminderRead")
    public R completionReminderRead(@RequestBody ProjectbillsDto projectbillsDto) {
        ExecuteResult<String> result = projectbillsServiceRemote.completionReminderRead(projectbillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 上传
     */
    @PostMapping("/upload")
    public Map<String, Object> upload(@RequestParam("file") MultipartFile file) throws IOException, ParseException {
        Map<String, Object> map = excel.excelImportRenewProject(file);
        return map;
    }

    @PostMapping("/createBillNo")
    public String queryBillNo(String str) {
        Calendar now = Calendar.getInstance();
//        int i = (int) (Math.random() * 900 + 100);
//        String num = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
//        Random random1 = new Random();
//        指定字符串长度，拼接字符并toString
//        StringBuffer sb = new StringBuffer();
//        for (int i = 0; i < 3; i++) {
//            //获取指定长度的字符串中任意一个字符的索引值
//            int number = random1.nextInt(num.length());
//            //根据索引值获取对应的字符
//            char charAt = num.charAt(number);
//            sb.append(charAt);
//        }
        return str + "-" + now.get(Calendar.YEAR) + (now.get(Calendar.MONTH) + 1) + now.get(Calendar.DAY_OF_MONTH) + projectbillsServiceRemote.getSerialNum(str);
    }


}
