
package io.platform.project.web.controller;


import io.platform.project.dto.SubConBillsAttachsDto;
import io.platform.project.web.remote.SubConBillsAttachsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/project/subConBillsAttachs")
public class SubConBillsAttachsRestController extends AbstractController {

    @Autowired
	private SubConBillsAttachsServiceRemote subConBillsAttachsServiceRemote;
	
	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("project:subConBillsAttachs:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", subConBillsAttachsServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@PostMapping("/page")
	@RequiresPermissions("project:subConBillsAttachs:page")
	public R page(Page page,SubConBillsAttachsDto subConBillsAttachsDto){
		return R.ok().put("page", subConBillsAttachsServiceRemote.getPage(page,subConBillsAttachsDto));
	}
	/**
	 * 信息
	 */
	@PostMapping("/info/{id}")
	@RequiresPermissions("project:subConBillsAttachs:info")
	public R info(@PathVariable("id") Long id){
		SubConBillsAttachsDto subConBillsAttachsDto = subConBillsAttachsServiceRemote.getOne(id);
		return R.ok().put("subConBillsAttachsDto", subConBillsAttachsDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("project:subConBillsAttachs:save")
	public R save(@RequestBody SubConBillsAttachsDto subConBillsAttachsDto){
        ValidatorUtils.validateEntity(subConBillsAttachsDto);
        ExecuteResult<String> result= subConBillsAttachsServiceRemote.save(subConBillsAttachsDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("project:subConBillsAttachs:edit")
	public R update(@RequestBody SubConBillsAttachsDto subConBillsAttachsDto){
        ValidatorUtils.validateEntity(subConBillsAttachsDto);
        ExecuteResult<String> result= subConBillsAttachsServiceRemote.update(subConBillsAttachsDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("project:subConBillsAttachs:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= subConBillsAttachsServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
