
package io.platform.project.web.controller;


import io.platform.base.common.utils.UploadUtil;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.dto.SubContractBillsDto;
import io.platform.project.web.remote.SubContractBillsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/project/subContractBills")
public class SubContractBillsRestController extends AbstractController {

    @Autowired
    private SubContractBillsServiceRemote subContractBillsServiceRemote;


    @PostMapping("/selectPaymentInformation")
    public R selectPaymentInformation(@RequestBody SubContractBillsDto subContractBillsDto) {
        ExecuteResult<String> result = subContractBillsServiceRemote.selectPaymentInformation(subContractBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 上传文件
     */
    @PostMapping("/uploadFiles")
    public String fuzzyQuerySubContracts(@RequestParam("headFile") MultipartFile multipartFiles) {
        if (!multipartFiles.isEmpty()) {
            //对文文件的全名进行截取然后在后缀名进行删选。
            int begin = multipartFiles.getOriginalFilename().indexOf(".");
            int last = multipartFiles.getOriginalFilename().length();
            //获得文件后缀名
            String a = multipartFiles.getOriginalFilename().substring(begin, last);
            if (a.endsWith(".html")) {
                logger.error("上传文件类型错误");
                return null;
            } else {
                try {
                    String path = UploadUtil.newFtpUpload(multipartFiles);
                    System.out.println(path);
                    return path.substring(path.lastIndexOf("/") + 1, path.length());
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return null;
    }

    /**
     * 查询分包合同预算款金额
     */
    @PostMapping("/getPrepayments")
    public double getPrepayments(Integer id) {
        return subContractBillsServiceRemote.getPrepayments(id);
    }

    /**
     * 分包结算查询
     */
    @PostMapping("/fuzzyQuerySubContracts")
    public R fuzzyQuerySubContracts(Page page, SubContractBillsDto subContractBillsDto) {
        //查询列表数据
        return R.ok().put("list", subContractBillsServiceRemote.fuzzyQuerySubContracts(page, subContractBillsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("project:subContractBills:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", subContractBillsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("project:subContractBills:page")
    public R page(Page page, SubContractBillsDto subContractBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", subContractBillsServiceRemote.getPage(page, subContractBillsDto, sysUserDto));
    }

    /**
     * 付款发票-分包工程-选择分包工程
     */
    @PostMapping("/enineeringPage")
    public R enineeringPage(Page page, SubContractBillsDto subContractBillsDto) {
        return R.ok().put("page", subContractBillsServiceRemote.enineeringPage(page, subContractBillsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    public R info(@PathVariable("id") Long id) {
        SubContractBillsDto subContractBillsDto = subContractBillsServiceRemote.getOne(id);
        return R.ok().put("subContractBillsDto", subContractBillsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    public R save(@RequestBody SubContractBillsDto subContractBillsDto) {
        ValidatorUtils.validateEntity(subContractBillsDto);
        ExecuteResult<String> result = subContractBillsServiceRemote.save(subContractBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    public R update(@RequestBody SubContractBillsDto subContractBillsDto) {
        ValidatorUtils.validateEntity(subContractBillsDto);
        ExecuteResult<String> result = subContractBillsServiceRemote.update(subContractBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = subContractBillsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectAll")
    public Map<String, Object> selectAll(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        return subContractBillsServiceRemote.selectAll(projectBillsSubsDto);
    }

    /**
     * 查询分包记录信息
     */
    @PostMapping("/querySubContractTemporary")
    public R querySubContractTemporary(@RequestBody SubContractBillsDto subContractBillsDto) {
        ValidatorUtils.validateEntity(subContractBillsDto);
        return R.ok().put("list", subContractBillsServiceRemote.querySubContractTemporary(subContractBillsDto));
    }

    /**
     * 分包合同暂存
     */
    @PostMapping("subContractTemporary")
    public R subContractTemporary(@RequestParam("from") String from, @RequestParam("item") String item, @RequestParam("list") String list) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = subContractBillsServiceRemote.subContractTemporary(from, item, list, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 分包合同提交
     */
    @PostMapping("subContractSave")
    public R subContractSave(@RequestParam("from") String from, @RequestParam("item") String item, @RequestParam("list") String list) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = subContractBillsServiceRemote.subContractSave(from, item, list, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("selectFormData")
    public Map<String, Object> selectFormData(@RequestParam("id") Integer id, @RequestParam("subNo") String subNo) {
        return subContractBillsServiceRemote.selectFormData(id, subNo, (SysUserDto) SecurityUtils.getSubject().getPrincipal());
    }

    @PostMapping("saveSubContract")
    public String saveSubContract(@RequestParam("list") String list, @RequestParam("subNo") String subNo) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return subContractBillsServiceRemote.saveSubContract(list, subNo, sysUserDto);
    }
}
