
package io.platform.projectSettlement.web.controller;


import io.platform.projectSettlement.dto.ProjectBillsAttachsDto;
import io.platform.projectSettlement.web.remote.ProjectBillsAttachsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectBillsAttachs")
public class ProjectBillsAttachsRestController extends AbstractController {

    @Autowired
    private ProjectBillsAttachsServiceRemote projectBillsAttachsServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:projectBillsAttachs:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectBillsAttachsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:projectBillsAttachs:page")
    public R page(Page page, ProjectBillsAttachsDto projectBillsAttachsDto) {
        return R.ok().put("page", projectBillsAttachsServiceRemote.getPage(page, projectBillsAttachsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectBillsAttachs:info")
    public R info(@PathVariable("id") Long id) {
        ProjectBillsAttachsDto projectBillsAttachsDto = projectBillsAttachsServiceRemote.getOne(id);
        return R.ok().put("projectBillsAttachsDto", projectBillsAttachsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectBillsAttachs:save")
    public R save(@RequestBody ProjectBillsAttachsDto projectBillsAttachsDto) {
        ValidatorUtils.validateEntity(projectBillsAttachsDto);
        ExecuteResult<String> result = projectBillsAttachsServiceRemote.save(projectBillsAttachsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectBillsAttachs:edit")
    public R update(@RequestBody ProjectBillsAttachsDto projectBillsAttachsDto) {
        ValidatorUtils.validateEntity(projectBillsAttachsDto);
        ExecuteResult<String> result = projectBillsAttachsServiceRemote.update(projectBillsAttachsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:projectBillsAttachs:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = projectBillsAttachsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
