
package io.platform.projectSettlement.web.controller;


import io.platform.projectSettlement.dto.ProjectStlBillsItemsDto;
import io.platform.projectSettlement.web.remote.ProjectStlBillsItemsServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectStlBillsItems")
public class ProjectStlBillsItemsRestController extends AbstractController {

    @Autowired
    private ProjectStlBillsItemsServiceRemote projectStlBillsItemsServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:projectStlBillsItems:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectStlBillsItemsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("engineering:projectStlBillsItems:page")
    public R page(Page page, ProjectStlBillsItemsDto projectStlBillsItemsDto) {
        return R.ok().put("page", projectStlBillsItemsServiceRemote.getPage(page, projectStlBillsItemsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectStlBillsItems:info")
    public R info(@PathVariable("id") Long id) {
        ProjectStlBillsItemsDto projectStlBillsItemsDto = projectStlBillsItemsServiceRemote.getOne(id);
        return R.ok().put("projectStlBillsItemsDto", projectStlBillsItemsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectStlBillsItems:save")
    public R save(@RequestBody ProjectStlBillsItemsDto projectStlBillsItemsDto) {
        ValidatorUtils.validateEntity(projectStlBillsItemsDto);
        ExecuteResult<String> result = projectStlBillsItemsServiceRemote.save(projectStlBillsItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectStlBillsItems:edit")
    public R update(@RequestBody ProjectStlBillsItemsDto projectStlBillsItemsDto) {
        ValidatorUtils.validateEntity(projectStlBillsItemsDto);
        ExecuteResult<String> result = projectStlBillsItemsServiceRemote.update(projectStlBillsItemsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:projectStlBillsItems:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = projectStlBillsItemsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
