
package io.platform.projectSettlement.web.controller;


import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.dto.SubContractBillsDto;
import io.platform.projectSettlement.dto.ProjectStlBillsDto;
import io.platform.projectSettlement.web.remote.ProjectStlBillsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/projectStlBills")
public class ProjectStlBillsRestController extends AbstractController {

    @Autowired
    private ProjectStlBillsServiceRemote projectStlBillsServiceRemote;

    /**
     * 查询 分包结算 信息
     */
    @PostMapping("/querySubContract")
    @RequiresPermissions("engineering:projectStlBills:list")
    public R querySubContract(@RequestBody ProjectBillsSubsDto projectBillsSubsDto) {
        //查询列表数据
        return R.ok().put("list", projectStlBillsServiceRemote.querySubContract(projectBillsSubsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("engineering:projectStlBills:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", projectStlBillsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/proStlBillsPage")
    public R page(@RequestBody Map<String, Object> map) {
        return R.ok().put("page", projectStlBillsServiceRemote.proStlBillsPage(map));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("engineering:projectStlBills:info")
    public R info(@PathVariable("id") Long id) {
        ProjectStlBillsDto projectStlBillsDto = projectStlBillsServiceRemote.getOne(id);
        return R.ok().put("projectStlBillsDto", projectStlBillsDto);
    }

    /**
     * 查询暂存数据
     */
    @PostMapping("/fuzzyQueryPSTl")
    @RequiresPermissions("engineering:projectStlBills:page")
    public R fuzzyQueryPSTl(@RequestBody ProjectStlBillsDto projectStlBillsDto) {
        ValidatorUtils.validateEntity(projectStlBillsDto);
        return R.ok().put("list", projectStlBillsServiceRemote.fuzzyQueryPSTl(projectStlBillsDto));
    }

    /**
     * 提交
     */
    @SysLog("提交")
    @PostMapping("/projectStlSave")
    @RequiresPermissions("engineering:projectStlBills:save")
    public R projectStlSave(@RequestParam(required = false, value = "form") String projectStlBill,
                            @RequestParam(required = false, value = "projectStls") String projectStls,
                            @RequestParam(required = false, value = "dataAttachs") String dataAttachs) {
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = projectStlBillsServiceRemote.projectStlSave(projectStlBill, projectStls, dataAttachs, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("engineering:projectStlBills:save")
    public R save(@RequestBody ProjectStlBillsDto projectStlBillsDto) {
        ValidatorUtils.validateEntity(projectStlBillsDto);
        ExecuteResult<String> result = projectStlBillsServiceRemote.save(projectStlBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("engineering:projectStlBills:edit")
    public R update(@RequestBody ProjectStlBillsDto projectStlBillsDto) {
        ValidatorUtils.validateEntity(projectStlBillsDto);
        ExecuteResult<String> result = projectStlBillsServiceRemote.update(projectStlBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("engineering:projectStlBills:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = projectStlBillsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
