
package io.platform.purchase.web.controller.rest;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import io.platform.engineering.dto.BpurchasesDto;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.purchase.dto.PurchaseBillsDto;
import io.platform.purchase.dto.PurchaseBillsItemsDto;
import io.platform.purchase.dto.PurchaseBillsProjsDto;
import io.platform.purchase.web.remote.PurchaseBillsItemsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/purchase/purchaseBillsItems")
public class PurchaseBillsItemsRestController extends AbstractController {

    @Autowired
	private PurchaseBillsItemsServiceRemote purchaseBillsItemsServiceRemote;

	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("purchase:purchaseBillsItems:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", purchaseBillsItemsServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@PostMapping("/page")
	public R page(Page page,PurchaseBillsItemsDto purchaseBillsItemsDto){
		return R.ok().put("page", purchaseBillsItemsServiceRemote.getPage(page,purchaseBillsItemsDto));
	}
	/**
	 *  到货记录添加 分页列表
	 */
	@PostMapping("maintenancePage")
	public R maintenancePage(Page page,PurchaseBillsItemsDto purchaseBillsItemsDto,String li){
		return R.ok().put("page", purchaseBillsItemsServiceRemote.maintenancePage(page,purchaseBillsItemsDto,li));
	}
	/**
	 * 信息
	 */
	@PostMapping("/info/{id}")
	@RequiresPermissions("purchase:purchaseBillsItems:info")
	public R info(@PathVariable("id") Long id){
		PurchaseBillsItemsDto purchaseBillsItemsDto = purchaseBillsItemsServiceRemote.getOne(id);
		return R.ok().put("purchaseBillsItemsDto", purchaseBillsItemsDto);
	}

	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("purchase:purchaseBillsItems:save")
	public R save(@RequestBody PurchaseBillsItemsDto purchaseBillsItemsDto){
        ValidatorUtils.validateEntity(purchaseBillsItemsDto);
        ExecuteResult<String> result= purchaseBillsItemsServiceRemote.save(purchaseBillsItemsDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}

	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("purchase:purchaseBillsItems:edit")
	public R update(@RequestBody PurchaseBillsItemsDto purchaseBillsItemsDto){
        ValidatorUtils.validateEntity(purchaseBillsItemsDto);
        ExecuteResult<String> result= purchaseBillsItemsServiceRemote.update(purchaseBillsItemsDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("purchase:purchaseBillsItems:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= purchaseBillsItemsServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

	@PostMapping("deleteItem")
	public R deleteItem(@RequestBody PurchaseBillsItemsDto purchaseBillsItemsDto){
		ExecuteResult<String> result =  purchaseBillsItemsServiceRemote.deleteItem(purchaseBillsItemsDto);
		if(result.isSuccess()){
			return R.ok(result.getSuccessMessage());
		}else{
			return R.error(result.getErrorMessages().get(0));
		}
	}
	@PostMapping("selectArrivalSum")
	public List<PurchaseBillsItemsDto> selectArrivalSum(@RequestParam("purList") String purList){
		JSONArray arrayList = JSONArray.parseArray(purList);
		List<PurchaseBillsItemsDto> list = JSONObject.parseArray(arrayList.toJSONString(), PurchaseBillsItemsDto.class);
		return purchaseBillsItemsServiceRemote.selectArrivalSum(list);
	}
	@PostMapping("selectProjectResult")
	public Map<String,Object> selectProjectResult(@RequestParam("sub") String sub){
		return purchaseBillsItemsServiceRemote.selectProjectResult(sub);
	}
	@PostMapping("selectList")
	public R selectList(Page page, PurchaseBillsDto purchaseBillsDto){
		SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
		return R.ok().put("page",purchaseBillsItemsServiceRemote.selectList(page,purchaseBillsDto,sysUserDto));
	}
	@PostMapping("selectSrcType")
	public Map<String, Object> selectSrcType(@RequestParam("mingxi") String mingxi){
		return purchaseBillsItemsServiceRemote.selectSrcType(mingxi);
	}
	@PostMapping("saveResultItem")
	public R saveResultItem(@RequestParam("list") String mingxi){
		SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
		ExecuteResult<String> result= purchaseBillsItemsServiceRemote.saveResultItem(mingxi,sysUserDto);
		if(result.isSuccess()){
			return R.ok(result.getSuccessMessage());
		}else{
			return R.error(result.getErrorMessages().get(0));
		}
	}
	@PostMapping("selectResultPurchase")
	public Page<BpurchasesDto> selectResultPurchase(Page<BpurchasesDto> page, ProjectBillsSubsDto projectBillsSubsDto){
		SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
		return purchaseBillsItemsServiceRemote.selectResultPurchase(projectBillsSubsDto,page, sysUserDto);
	}
}
