
package io.platform.purchase.web.controller.rest;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import io.platform.purchase.dto.PurchaseBillsDto;
import io.platform.purchase.dto.PurchaseBillsProjsDto;
import io.platform.purchase.dto.PurchaseBillsPuridsDto;
import io.platform.purchase.web.remote.PurchaseBillsProjsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/purchase/purchaseBillsProjs")
public class PurchaseBillsProjsRestController extends AbstractController {

    @Autowired
    private PurchaseBillsProjsServiceRemote purchaseBillsProjsServiceRemote;

    /**
     * 模糊查询分包计划明细
     */
    @PostMapping("/fuzzyQueryPurProjs")
    @RequiresPermissions("purchase:purchaseBillsProjs:list")
    public R fuzzyQueryPurProjs(Page page, @RequestBody PurchaseBillsProjsDto purchaseBillsProjsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        purchaseBillsProjsDto.setBranchId(sysUserDto.getLoginContractorId());
        return R.ok().put("list", purchaseBillsProjsServiceRemote.fuzzyQueryPurProjs(page, purchaseBillsProjsDto));
    }

    /**
     * 选择分包计划明细查询
     */
    @PostMapping("/changeFuzzyQueryPurProjs")
    @RequiresPermissions("purchase:purchaseBillsProjs:list")
    public R changeFuzzyQueryPurProjs(@RequestBody PurchaseBillsProjsDto purchaseBillsProjsDto) {
        return R.ok().put("list", purchaseBillsProjsServiceRemote.changeFuzzyQueryPurProjs(purchaseBillsProjsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("purchase:purchaseBillsProjs:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", purchaseBillsProjsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("purchase:purchaseBillsProjs:page")
    public Map<String, Object> page(Page page, PurchaseBillsProjsDto purchaseBillsProjsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsProjsServiceRemote.getPage(page, purchaseBillsProjsDto, sysUserDto);
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("purchase:purchaseBillsProjs:info")
    public R info(@PathVariable("id") Long id) {
        PurchaseBillsProjsDto purchaseBillsProjsDto = purchaseBillsProjsServiceRemote.getOne(id);
        return R.ok().put("purchaseBillsProjsDto", purchaseBillsProjsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("purchase:purchaseBillsProjs:save")
    public R save(@RequestBody PurchaseBillsProjsDto purchaseBillsProjsDto) {
        ValidatorUtils.validateEntity(purchaseBillsProjsDto);
        ExecuteResult<String> result = purchaseBillsProjsServiceRemote.save(purchaseBillsProjsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("purchase:purchaseBillsProjs:edit")
    public R update(@RequestParam("from") String dto) {
        PurchaseBillsProjsDto purchaseBills = JSONArray.parseObject(dto, PurchaseBillsProjsDto.class);
        ValidatorUtils.validateEntity(purchaseBills);
        ExecuteResult<String> result = purchaseBillsProjsServiceRemote.update(purchaseBills);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("purchase:purchaseBillsProjs:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = purchaseBillsProjsServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /*
     * 主要提交方法
     * */
    @PostMapping("saveWork")
    public String saveWork(@RequestParam("from") String from, @RequestParam("item") String list, @RequestParam("supper") String supper) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsProjsServiceRemote.saveWork(from, list, supper, sysUserDto);
    }

    /*
     * 主要提交方法  招标+单一
     * */
    @PostMapping("savePurchasePro")
    public String savePurchasePro(@RequestParam("from") String from, @RequestParam("item") String list) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsProjsServiceRemote.savePurchasePro(from, list, sysUserDto);
    }

    /*
     工程分包采购计划——应用框架供应商删除方法
     */
    @PostMapping("deleteSupplier")
    public void deleteSupplier(@RequestParam("id") Integer id) {
        purchaseBillsProjsServiceRemote.deleteSupplier(id);
    }

    /*
    工程采购 中标结果 应用框架供应商查询
     */
    @PostMapping("selectProItemPurids")
    public Map<String, Object> selectProItemPurids(@RequestParam("id") Integer id) {
        return purchaseBillsProjsServiceRemote.selectProItemPurids(id);
    }

    /*
     * 主要暂存方法
     * */
    @PostMapping("updateWork")
    public String updateWork(@RequestParam("from") String from, @RequestParam("item") String list, @RequestParam("supper") String supper) {
        return purchaseBillsProjsServiceRemote.updateWork(from, list, supper);
    }

    /*
     * 主要提交方法  招标+单一
     * */
    @PostMapping("updatePurchasePro")
    public String updatePurchasePro(@RequestParam("from") String from, @RequestParam("item") String list) {
        return purchaseBillsProjsServiceRemote.updatePurchasePro(from, list);
    }

    @PostMapping("selectItem")
    public Map<String, Object> selectItem(@RequestParam("billNo") String billNo) {
        return purchaseBillsProjsServiceRemote.selectItem(billNo);
    }

    @PostMapping("editItem")
    public Map<String, Object> editItem(@RequestParam("id") String id) {
        return purchaseBillsProjsServiceRemote.editItem(id);
    }

    @PostMapping("saveProItem")
    public String saveProItem(@RequestParam("bill") String purchaseBillsDto) {
        return purchaseBillsProjsServiceRemote.saveProItem(purchaseBillsDto);
    }

    @PostMapping("adminSaveProItem")
    public String adminSaveProItem(@RequestParam("bill") String purchaseBillsDto) {
        return purchaseBillsProjsServiceRemote.adminSaveProItem(purchaseBillsDto);
    }

    @PostMapping("selectProItem")
    public Map<String, Object> selectProItem(@RequestParam("id") String id) {
        return purchaseBillsProjsServiceRemote.selectProItem(id);
    }
}
