
package io.platform.purchase.web.controller.rest;


import io.platform.base.common.utils.Excel;
import io.platform.purchase.dto.PurchaseBillsDto;
import io.platform.purchase.web.remote.PurchaseBillsServiceRemote;
import io.platform.sys.dto.SysUserDto;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/purchase/purchaseBills")
public class PurchaseBillsRestController extends AbstractController {

    @Autowired
    private PurchaseBillsServiceRemote purchaseBillsServiceRemote;
    @Autowired
    private Excel excel;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("purchase:purchaseBills:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", purchaseBillsServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("purchase:purchaseBills:page")
    public R page(Page page, PurchaseBillsDto purchaseBillsDto) {
        return R.ok().put("page", purchaseBillsServiceRemote.getPage(page, purchaseBillsDto));
    }

    /**
     * 信息
     */
    @PostMapping("/info/{id}")
    @RequiresPermissions("purchase:purchaseBills:info")
    public R info(@PathVariable("id") Long id) {
        PurchaseBillsDto purchaseBillsDto = purchaseBillsServiceRemote.getOne(id);
        return R.ok().put("purchaseBillsDto", purchaseBillsDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("purchase:purchaseBills:save")
    public R save(@RequestBody PurchaseBillsDto purchaseBillsDto) {
        ValidatorUtils.validateEntity(purchaseBillsDto);
        ExecuteResult<String> result = purchaseBillsServiceRemote.save(purchaseBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("purchase:purchaseBills:edit")
    public R update(@RequestBody PurchaseBillsDto purchaseBillsDto) {
        ValidatorUtils.validateEntity(purchaseBillsDto);
        ExecuteResult<String> result = purchaseBillsServiceRemote.update(purchaseBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除 ,对方法进行二次修改
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("purchase:purchaseBills:delete")
    public R delete(@RequestBody PurchaseBillsDto purchaseBillsDto) {
        ExecuteResult<String> result = purchaseBillsServiceRemote.deleteBatch(purchaseBillsDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除工程采购-招标采购信息
     */
    @SysLog("删除")
    @PostMapping("/deletePurchase")
    @RequiresPermissions("purchase:purchaseBills:delete")
    public R deletePurchase(@RequestBody PurchaseBillsDto purchaseBillsDto){
        ExecuteResult<String> result= purchaseBillsServiceRemote.deletePurchase(purchaseBillsDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
    }

    @PostMapping("deleteTender")
    @RequiresPermissions("purchase:purchaseBills:deleteTender")
    public R deleteTender(@RequestBody PurchaseBillsDto purchaseBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = purchaseBillsServiceRemote.deleteTender(purchaseBillsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /*
     * 删除物资采购-应用框架单挑数据
     * */
    @PostMapping("deleteFrame")
    @RequiresPermissions("purchase:purchaseBills:deleteTender")
    public R deleteFrame(@RequestBody PurchaseBillsDto purchaseBillsDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        ExecuteResult<String> result = purchaseBillsServiceRemote.deleteFrame(purchaseBillsDto, sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 物资需求计划提交
     */
    @PostMapping("materialDemand")
    public String materialDemand(@RequestParam("from") String from, @RequestParam("item") String list) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsServiceRemote.materialDemand(from, list, sysUserDto);
    }

    /**
     * 保存台账
     */
    @PostMapping("upLedger")
    public String upLedger(@RequestParam("from") String from, @RequestParam("item") String list) {
        return purchaseBillsServiceRemote.upLedger(from, list);
    }

    /**
     * 暂存
     */
    @PostMapping("cun")
    public String cun(@RequestParam("from") String from
            , @RequestParam("item") String list) {
        return purchaseBillsServiceRemote.zancun(from, list);

    }

    /**
     * 获取登录用户
     */
    @PostMapping("user")
    public Map<String, Object> user() {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsServiceRemote.selectContractor(sysUserDto);
    }

    /**
     * 上传
     */
    @PostMapping("uplod")
    public Map<String, Object> uplod(@RequestParam("file") MultipartFile file) throws IOException, ParseException {
        return excel.excelImport(file);
    }

    @PostMapping("voer")
    public String voer(@RequestParam("from") String from, @RequestParam("item") String list) {
        return purchaseBillsServiceRemote.voer(from, list);
    }

    @PostMapping("getItem")
    public Map<String, Object> getItem(@RequestParam("billNo") String billNo) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsServiceRemote.getItem(billNo, sysUserDto);
    }

    /**
     * 物资台账明细查询
     */
    @PostMapping("getResultItem")
    public Map<String, Object> getResultItem(@RequestParam("billNo") String billNo, @RequestParam("zbNo") String zbNo) {
        return purchaseBillsServiceRemote.getResultItem(billNo, zbNo);
    }

    /*
     * 修改
     * */
    @PostMapping("onceAgain")
    public Map<String, Object> onceAgain(@RequestParam("id") Integer id) {
        return purchaseBillsServiceRemote.onceAgain(id);
    }

    @PostMapping("saveOne")
    public String saveOne(@RequestParam("from") String from, @RequestParam("item") String list, @RequestParam("attach") String attach) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsServiceRemote.saveOne(from, list, sysUserDto, attach);
    }

    /*
     * 暂存物资
     * */
    @PostMapping("temporaryOne")
    public String temporaryOne(@RequestParam("from") String from, @RequestParam("item") String list, @RequestParam("attach") String attach) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsServiceRemote.temporaryOne(from, list, sysUserDto, attach);
    }

    @PostMapping("saveTwo")
    public String saveTwo(@RequestParam("from") String from, @RequestParam("item") String list, @RequestParam("supplier") String supplierList, @RequestParam("attach") String attach) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsServiceRemote.saveTwo(from, list, supplierList, sysUserDto, attach);
    }

    @PostMapping("temporaryTwo")
    public String temporaryTwo(@RequestParam("from") String from, @RequestParam("item") String list, @RequestParam("supplier") String supplierList, @RequestParam("attach") String attach) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsServiceRemote.temporaryTwo(from, list, supplierList, attach, sysUserDto);
    }

    @PostMapping("selectPurchaseTypes")
    public Map<String, Object> selectPurchaseTypes() {
        return purchaseBillsServiceRemote.selectPurchaseTypes();
    }

    @PostMapping("saveSingle")
    public String saveSingle(@RequestParam("from") String from, @RequestParam("item") String list, @RequestParam("attach") String attach) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return purchaseBillsServiceRemote.saveSingle(from, list, sysUserDto, attach);
    }
}
