
package io.platform.sys.web.controller.rest;


import io.platform.sys.dto.SysCaptchaDto;
import io.platform.sys.web.remote.SysCaptchaServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/captcha")
public class SysCaptchaRestController extends AbstractController {

    @Autowired
	private SysCaptchaServiceRemote sysCaptchaServiceRemote;
	
	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("sys:captcha:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", sysCaptchaServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@PostMapping("/page")
	@RequiresPermissions("sys:captcha:page")
	public R page(Page<SysCaptchaDto> page,SysCaptchaDto sysCaptchaDto){

		return R.ok().put("page", sysCaptchaServiceRemote.getPage(page,sysCaptchaDto));
	}
	/**
	 * 信息
	 */
	@PostMapping("/info/{id}")
	@RequiresPermissions("sys:captcha:info")
	public R info(@PathVariable("id") String id){
		SysCaptchaDto sysCaptchaDto = sysCaptchaServiceRemote.getOne(id);
		return R.ok().put("sysCaptchaDto", sysCaptchaDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("sys:captcha:save")
	public R save(@RequestBody SysCaptchaDto sysCaptchaDto){
        ValidatorUtils.validateEntity(sysCaptchaDto);
        ExecuteResult<String> result= sysCaptchaServiceRemote.save(sysCaptchaDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("sys:captcha:update")
	public R update(@RequestBody SysCaptchaDto sysCaptchaDto){
        ValidatorUtils.validateEntity(sysCaptchaDto);
        ExecuteResult<String> result= sysCaptchaServiceRemote.update(sysCaptchaDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("sys:captcha:delete")
	public R delete(@RequestBody List<String> ids){
        ExecuteResult<String> result= sysCaptchaServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
