
package io.platform.sys.web.controller.rest;


import io.platform.sys.dto.SysConfigDto;
import io.platform.sys.web.remote.SysConfigServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/config")
public class SysConfigRestController extends AbstractController {

    @Autowired
	private SysConfigServiceRemote sysConfigServiceRemote;
	
	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("sys:config:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", sysConfigServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@GetMapping("/page")
	@RequiresPermissions("sys:config:page")
	public R page(Page<SysConfigDto> page,SysConfigDto sysConfigDto){
		return R.ok().put("page", sysConfigServiceRemote.getPage(page,sysConfigDto));
	}
	/**
	 * 信息
	 */
	@GetMapping("/info/{id}")
	@RequiresPermissions("sys:config:info")
	public R info(@PathVariable("id") Long id){
		SysConfigDto sysConfigDto = sysConfigServiceRemote.getOne(id);
		return R.ok().put("config", sysConfigDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("sys:config:save")
	public R save(@RequestBody SysConfigDto sysConfigDto){
        ValidatorUtils.validateEntity(sysConfigDto);
        ExecuteResult<String> result= sysConfigServiceRemote.save(sysConfigDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("sys:config:update")
	public R update(@RequestBody SysConfigDto sysConfigDto){
        ValidatorUtils.validateEntity(sysConfigDto);
        ExecuteResult<String> result= sysConfigServiceRemote.update(sysConfigDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("sys:config:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= sysConfigServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
