package io.platform.sys.web.controller.rest;

import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.R;
import io.platform.sys.dto.SysUserDto;
import io.platform.sys.web.query.LoginQuery;
import io.platform.sys.web.remote.SysCaptchaServiceRemote;
import io.platform.sys.web.remote.SysUserServiceRemote;
import io.platform.sys.web.remote.SysUserTokenServiceRemote;
import org.apache.commons.io.IOUtils;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.imageio.ImageIO;
import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.Map;
import java.util.Objects;

import static io.platform.base.common.utils.ShiroUtils.getUserId;

/**
 * 登录相关
 * 
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2016年11月10日 下午1:15:31
 */
@RestController
public class SysLoginController extends AbstractController {
	@Autowired
	private SysUserServiceRemote sysUserServiceRemote;
	@Autowired
	private SysUserTokenServiceRemote sysUserTokenServiceRemote;
	@Autowired
	private SysCaptchaServiceRemote sysCaptchaServiceRemote;

	/**
	 * 验证码
	 */
	@GetMapping("captcha.jpg")
	public void captcha(HttpServletResponse response, String uuid)throws ServletException, IOException {
		response.setHeader("Cache-Control", "no-store, no-cache");
		response.setContentType("image/jpeg");

		//获取图片验证码
		BufferedImage image = sysCaptchaServiceRemote.getCaptcha(uuid);

		ServletOutputStream out = response.getOutputStream();
		ImageIO.write(image, "jpg", out);
		IOUtils.closeQuietly(out);
	}

	/**
	 * 登录
	 */
	@PostMapping("/sys/login")
	public Map<String, Object> login(@RequestBody LoginQuery form)throws IOException {
		boolean captcha = sysCaptchaServiceRemote.validate(form.getUuid(), form.getCaptcha());
		/*if(!captcha){
			return R.error("验证码不正确");
		}*/

		//用户信息
		SysUserDto user = sysUserServiceRemote.queryByUserName(form.getUsername());

		//账号不存在、密码错误
		if(user == null || user.getUserId() == null || !user.getPassword().equals(new Sha256Hash(form.getPassword(), user.getSalt()).toHex())) {
			return R.error("账号或密码不正确");
		}

		//账号锁定
		if(user.getStatus() == 0){
			return R.error("账号已被锁定,请联系管理员");
		}

		//生成token，并保存到数据库
		R r = sysUserTokenServiceRemote.createToken(user.getUserId());
		r.put("userDto",user);
		return r;
	}


	/**
	 * 退出
	 */
	@PostMapping("/sys/logout")
	public R logout() {
		sysUserTokenServiceRemote.logout(getUserId());
		return R.ok();
	}
	
}
