
package io.platform.sys.web.controller.rest;


import io.platform.base.common.utils.Constant;
import io.platform.sys.dto.SysRoleDto;
import io.platform.sys.dto.SysUserDto;
import io.platform.sys.web.remote.SysRoleServiceRemote;
import org.apache.shiro.SecurityUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/role")
public class SysRoleRestController extends AbstractController {

    @Autowired
    private SysRoleServiceRemote sysRoleServiceRemote;

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("sys:role:list")
    public R list(Page<SysRoleDto> page, SysRoleDto sysRoleDto) {
        //查询列表数据
        //如果不是超级管理员，则只查询自己创建的角色列表
        if (getUserId() != Constant.SUPER_ADMIN) {
            sysRoleDto.setCreateUserId(getUserId());
        }
        //获取登录信息
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", sysRoleServiceRemote.getPage(page, sysRoleDto, sysUserDto));
    }

    /**
     * 分页列表
     */
    @PostMapping("/page")
    @RequiresPermissions("sys:role:page")
    public R page(Page<SysRoleDto> page, SysRoleDto sysRoleDto) {
        //获取登录信息
        SysUserDto sysUserDoto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", sysRoleServiceRemote.getPage(page, sysRoleDto, sysUserDoto));
    }

    /**
     * 信息
     */
    @GetMapping("/info/{id}")
    @RequiresPermissions("sys:role:info")
    public R info(@PathVariable("id") Long id) {
        SysRoleDto sysRoleDto = sysRoleServiceRemote.getOne(id);
        return R.ok().put("role", sysRoleDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("sys:role:save")
    public R save(@RequestBody SysRoleDto sysRoleDto) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        sysRoleDto.setBranchId(sysUserDto.getLoginContractorId()); // 新增角色的分公司Id 默认添加人的公司Id
        ValidatorUtils.validateEntity(sysRoleDto);

        ExecuteResult<String> result = sysRoleServiceRemote.save(sysRoleDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("sys:role:update")
    public R update(@RequestBody SysRoleDto sysRoleDto) {
        ValidatorUtils.validateEntity(sysRoleDto);
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        sysRoleDto.setBranchId(sysUserDto.getLoginContractorId()); // 新增角色的分公司Id 默认添加人的公司Id
        ExecuteResult<String> result = sysRoleServiceRemote.update(sysRoleDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("sys:role:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysRoleServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 角色列表
     */
    @GetMapping("/select")
    @RequiresPermissions("sys:role:select")
    public R select(Integer branchId) {
        //如果不是超级管理员，则只查询自己所拥有的角色列表
/*        if (getUserId() != Constant.SUPER_ADMIN) {
            map.put("create_user_id", getUserId());
        }
        Map<String, Object> map = new HashMap<>();*/
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        if (branchId != null) {
            sysUserDto.setLoginContractorId(branchId);
        }
        List<SysRoleDto> list = sysRoleServiceRemote.getList(sysUserDto);

        return R.ok().put("list", list);
    }

}
