
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.Constant;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.utils.ShiroUtils;
import io.platform.base.common.validator.Assert;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.dto.BcorpTypesDto;
import io.platform.sys.dto.SysUserDto;
import io.platform.sys.web.query.PasswordQuery;
import io.platform.sys.web.remote.SysUserRoleServiceRemote;
import io.platform.sys.web.remote.SysUserServiceRemote;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/user")
public class SysUserRestController extends AbstractController {

    @Autowired
    private SysUserServiceRemote sysUserServiceRemote;
    @Autowired
    private SysUserRoleServiceRemote sysUserRoleServiceRemote;

    /**
     * 查询所有
     */
    @RequestMapping("/selectUser")
    @RequiresPermissions("sys:user:list")
    public R selectUser(@RequestBody SysUserDto sysUserDto) {
        SysUserDto sysUser = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        sysUserDto.setContractorId(sysUser.getLoginContractorId());
        sysUserDto.setLoginContractorId(sysUser.getLoginContractorId());
        return R.ok().put("list", sysUserServiceRemote.selectUser(sysUserDto));
    }

    /**
     * 模糊查询经理权限人员
     *
     * @return
     */
    @RequestMapping("/fuzzyQueryUser")
    @RequiresPermissions("sys:user:list")
    public R fuzzyQueryUser(@RequestBody SysUserDto syuse) {
        SysUserDto sysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        sysUserDto.setUsername(syuse.getUsername());
        ValidatorUtils.validateEntity(sysUserDto);
        return R.ok().put("list", sysUserServiceRemote.fuzzyQueryUser(sysUserDto));
    }

    /**
     * 根据承包单位查找经理
     */
    @RequestMapping("/queryProjectManager")
    @RequiresPermissions("sys:user:list")
    public R queryProjectManager(@RequestBody BbranchsDto bbranchsDto) {
        return R.ok().put("list", sysUserServiceRemote.queryProjectManager(bbranchsDto));
    }

    /**
     * 所有列表
     */
    @PostMapping("/list")
    @RequiresPermissions("sys:user:list")
    public R list(Page<SysUserDto> page, SysUserDto sysUserDto) {
        //只有超级管理员，才能查看所有管理员列表
        if (getUserId() != Constant.SUPER_ADMIN) {
            sysUserDto.setCreateUserId(getUserId());
        }
        SysUserDto userDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", sysUserServiceRemote.getPage(page, sysUserDto, userDto));
    }

    /**
     * 分页列表
     */
    @GetMapping("/page")
    @RequiresPermissions("sys:user:page")
    public R page(Page page, SysUserDto sysUserDto) {
        SysUserDto userDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        return R.ok().put("page", sysUserServiceRemote.getPage(page, sysUserDto, userDto));
    }

    /**
     * 信息
     */
    @GetMapping("/info")
    @RequiresPermissions("sys:user:info")
    public R info() {

        return R.ok().put("user", ShiroUtils.getUserEntity());
    }

    /**
     * 用户信息
     */
    @GetMapping("/info/{userId}")
    @RequiresPermissions("sys:user:info")
    public R info(@PathVariable("userId") Long userId) {
        SysUserDto user = sysUserServiceRemote.getOne(userId);

        //获取用户所属的角色列表
        Integer roleIdList = sysUserRoleServiceRemote.queryRoleIdList(userId);
        user.setRoleIdList(roleIdList);

        return R.ok().put("user", user);
    }

    /**
     * 信息
     */
    @PostMapping("/detail")
    @RequiresPermissions("sys:user:info")
    public R detail(Long id) {
        SysUserDto sysUserDto = sysUserServiceRemote.getOne(id);
        return R.ok().put("user", sysUserDto);
    }

    /**
     * 记录集团用户选择分公司
     */
    @SysLog("记录集团用户选择分公司")
    @PostMapping("/saveBranch")
    public R saveBranch(@RequestBody SysUserDto sysUserDto) {
        ValidatorUtils.validateEntity(sysUserDto);
        ExecuteResult<String> result = sysUserServiceRemote.saveBranch(sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @PostMapping("/save")
    @RequiresPermissions("sys:user:save")
    public R save(@RequestBody SysUserDto sysUserDto) {
        ValidatorUtils.validateEntity(sysUserDto);
        SysUserDto createSysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        sysUserDto.setCreateContractorId(createSysUserDto.getLoginContractorId());
        ExecuteResult<String> result = sysUserServiceRemote.save(sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @PostMapping("/update")
    @RequiresPermissions("sys:user:update")
    public R update(@RequestBody SysUserDto sysUserDto) {
        ValidatorUtils.validateEntity(sysUserDto);
        SysUserDto createSysUserDto = (SysUserDto) SecurityUtils.getSubject().getPrincipal();
        sysUserDto.setCreateContractorId(createSysUserDto.getLoginContractorId());
        ExecuteResult<String> result = sysUserServiceRemote.update(sysUserDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @PostMapping("/delete")
    @RequiresPermissions("sys:user:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysUserServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改登录用户密码
     */
    @SysLog("修改密码")
    @PostMapping("/password")
    public R password(@RequestBody PasswordQuery form) {
        Assert.isBlank(form.getNewPassword(), "新密码不为能空");

        //sha256加密
        String password = new Sha256Hash(form.getPassword(), getUser().getSalt()).toHex();
        //sha256加密
        String newPassword = new Sha256Hash(form.getNewPassword(), getUser().getSalt()).toHex();

        //更新密码
        boolean flag = sysUserServiceRemote.updatePassword(getUserId(), password, newPassword);
        if (!flag) {
            return R.error("原密码不正确");
        }

        return R.ok();
    }

    /**
     * 修改登录用户密码
     */
    @SysLog("获取sysUser")
    @PostMapping("/getLoginContractorId")
    public SysUserDto getLoginContractorId() {
        return (SysUserDto) SecurityUtils.getSubject().getPrincipal();
    }


}
