
package io.platform.sys.web.controller.rest;


import io.platform.sys.dto.SysUserRoleDto;
import io.platform.sys.web.remote.SysUserRoleServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/sysUserRole")
public class SysUserRoleRestController extends AbstractController {

    @Autowired
	private SysUserRoleServiceRemote sysUserRoleServiceRemote;
	
	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("sys:sysUserRole:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", sysUserRoleServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@PostMapping("/page")
	@RequiresPermissions("sys:sysUserRole:page")
	public R page(Page<SysUserRoleDto> page,SysUserRoleDto sysUserRoleDto){

		return R.ok().put("page", sysUserRoleServiceRemote.getPage(page,sysUserRoleDto));
	}
	/**
	 * 信息
	 */
	@PostMapping("/info/{id}")
	@RequiresPermissions("sys:sysUserRole:info")
	public R info(@PathVariable("id") Long id){
		SysUserRoleDto sysUserRoleDto = sysUserRoleServiceRemote.getOne(id);
		return R.ok().put("sysUserRoleDto", sysUserRoleDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("sys:sysUserRole:save")
	public R save(@RequestBody SysUserRoleDto sysUserRoleDto){
        ValidatorUtils.validateEntity(sysUserRoleDto);
        ExecuteResult<String> result= sysUserRoleServiceRemote.save(sysUserRoleDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("sys:sysUserRole:update")
	public R update(@RequestBody SysUserRoleDto sysUserRoleDto){
        ValidatorUtils.validateEntity(sysUserRoleDto);
        ExecuteResult<String> result= sysUserRoleServiceRemote.update(sysUserRoleDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("sys:sysUserRole:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= sysUserRoleServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
