
package io.platform.sys.web.controller.rest;


import io.platform.sys.dto.TbUserDto;
import io.platform.sys.web.remote.TbUserServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/tbuser")
public class TbUserRestController extends AbstractController {

    @Autowired
	private TbUserServiceRemote tbUserServiceRemote;
	
	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("sys:tbUser:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", tbUserServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@PostMapping("/page")
	@RequiresPermissions("sys:tbUser:page")
	public R page(Page<TbUserDto> page,TbUserDto tbUserDto){

		return R.ok().put("page", tbUserServiceRemote.getPage(page,tbUserDto));
	}
	/**
	 * 信息
	 */
	@PostMapping("/info/{id}")
	@RequiresPermissions("sys:tbUser:info")
	public R info(@PathVariable("id") Long id){
		TbUserDto tbUserDto = tbUserServiceRemote.getOne(id);
		return R.ok().put("tbUserDto", tbUserDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("sys:tbUser:save")
	public R save(@RequestBody TbUserDto tbUserDto){
        ValidatorUtils.validateEntity(tbUserDto);
        ExecuteResult<String> result= tbUserServiceRemote.save(tbUserDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("sys:tbUser:update")
	public R update(@RequestBody TbUserDto tbUserDto){
        ValidatorUtils.validateEntity(tbUserDto);
        ExecuteResult<String> result= tbUserServiceRemote.update(tbUserDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("sys:tbUser:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= tbUserServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
