
package io.platform.tasklistsHistory.controller.rest;


import io.platform.tasklistsHistory.dto.TasklistsHistoryDto;
import io.platform.tasklistsHistory.remote.TasklistsHistoryServiceRemote;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.PageUtils;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/engineering/tasklistsHistory")
public class TasklistsHistoryRestController extends AbstractController {

    @Autowired
	private TasklistsHistoryServiceRemote tasklistsHistoryServiceRemote;
	
	/**
	 * 所有列表
	 */
	@PostMapping("/list")
	@RequiresPermissions("engineering:tasklistsHistory:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", tasklistsHistoryServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@PostMapping("/page")
	@RequiresPermissions("engineering:tasklistsHistory:page")
	public R page(Page page, TasklistsHistoryDto tasklistsHistoryDto){
		return R.ok().put("page", tasklistsHistoryServiceRemote.getPage(page,tasklistsHistoryDto));
	}
	/**
	 * 信息
	 */
	@PostMapping("/info/{id}")
	@RequiresPermissions("engineering:tasklistsHistory:info")
	public R info(@PathVariable("id") Long id){
		TasklistsHistoryDto tasklistsHistoryDto = tasklistsHistoryServiceRemote.getOne(id);
		return R.ok().put("tasklistsHistoryDto", tasklistsHistoryDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@PostMapping("/save")
	@RequiresPermissions("engineering:tasklistsHistory:save")
	public R save(@RequestBody TasklistsHistoryDto tasklistsHistoryDto){
        ValidatorUtils.validateEntity(tasklistsHistoryDto);
        ExecuteResult<String> result= tasklistsHistoryServiceRemote.save(tasklistsHistoryDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@PostMapping("/update")
	@RequiresPermissions("engineering:tasklistsHistory:edit")
	public R update(@RequestBody TasklistsHistoryDto tasklistsHistoryDto){
        ValidatorUtils.validateEntity(tasklistsHistoryDto);
        ExecuteResult<String> result= tasklistsHistoryServiceRemote.update(tasklistsHistoryDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@PostMapping("/delete")
	@RequiresPermissions("engineering:tasklistsHistory:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= tasklistsHistoryServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
