
package io.platform.approvalConfiguration.biz.service;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.service.impl.ServiceImpl;

import io.platform.approvalConfiguration.biz.entity.*;
import io.platform.approvalConfiguration.biz.mapper.AuditItemsMapper;
import io.platform.project.dto.ProjectBillsSubsDto;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

import javax.annotation.Resource;
import java.util.*;


@Service("auditItemsService")
public class AuditItemsService extends ServiceImpl<AuditItemsMapper, AuditItems> {
    @Resource
    private AuditItemsService auditItemsService;
    @Resource
    private AuditItemsUsersService auditItemsUsersService;

    public int updateAuditStatus(AuditItems at) {
        return baseMapper.updateAuditStatus(at);
    }

    public int deleteUpLevelId(AuditItems auditItem) {
        return baseMapper.deleteUpLevelId(auditItem);
    }

    public int selectAuditItemTotal(Map<String, Object> maps) {
        return baseMapper.selectAuditItemTotal(maps);
    }

    public List<Map<String, Object>> selectAuditItemRecords(Map<String, Object> maps) {
        return baseMapper.selectAuditItemRecords(maps);
    }

    @Transactional(rollbackFor = Exception.class)
    public boolean createApprovalFlow(Audit audit) {
        try {
            List<AuditPathsLevels> auditPathsLevels = baseMapper.queryAuditLevels(audit);
            if (auditPathsLevels.size() != 0) {
                AuditItems auditItems = new AuditItems();
                auditItems.setBillNo(audit.getBillNo());
                auditItems.setActId(audit.getActId());
                auditItems.setLevelId(audit.getLevelId());
                auditItems.setIffinalItem(audit.getIffinalItem());
                auditItems.setSubJect(audit.getSubJect());
                auditItems.setProjectNo(audit.getProjectNo());
                auditItems.setBranchId(audit.getBranchId());
                auditItems.setSendUserId(audit.getSendUserId());
                auditItems.setSendName(audit.getSendName());
                auditItems.setSendTime(audit.getSendTime());
                auditItems.setAuditUserId(audit.getAuditUserId());
                auditItems.setAuditItem(audit.getAuditItem());
                auditItems.setAuditMsg(audit.getAuditMsg());
                auditItems.setAuditStatus(audit.getAuditStatus());
                boolean insert = auditItemsService.insert(auditItems);
                if (!insert) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    return false;
                }
                int num = 0;
                for (AuditPathsLevels ap : auditPathsLevels) {
                    num++;
                    JSONArray jsonArray = JSONArray.parseArray(ap.getAuditUserId());
                    List<Integer> integerList = JSONObject.parseArray(jsonArray.toJSONString(), Integer.class);
                    AuditItems auditItem = new AuditItems();
                    auditItem.setBillNo(auditItems.getBillNo());
                    auditItem.setActId(auditItems.getActId());
                    auditItem.setLevelId(ap.getLevelId());
                    auditItem.setIffinalItem(ap.getIffinalItem());
                    auditItem.setSubJect(auditItems.getSubJect());
                    auditItem.setProjectNo(auditItems.getProjectNo());
                    auditItem.setBranchId(auditItems.getBranchId());
                    auditItem.setSendUserId(auditItems.getSendUserId());
                    auditItem.setSendName(auditItems.getSendName());
                    auditItem.setSendTime(new Date());
                    if ("F".equals(ap.getIffixAuditUser())) {
                        auditItem.setAuditUserId(audit.getProjectMngId());
                    } else {
                        auditItem.setAuditUserId(integerList.get(0));
                    }
                    if (Objects.equals(num, 1)) {
                        auditItem.setAuditStatus("S");
                    } else {
                        auditItem.setAuditStatus("N");
                    }
                    boolean auditItemInsert = auditItemsService.insert(auditItem);
                    if (!auditItemInsert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        return false;
                    }
                    if (!"F".equals(ap.getIffixAuditUser())) {
                        for (Integer it : integerList) {
                            AuditItemsUsers auditItemsUsers = new AuditItemsUsers();
                            auditItemsUsers.setPid(auditItem.getId());
                            auditItemsUsers.setBillNo(auditItem.getBillNo());
                            auditItemsUsers.setActId(auditItem.getActId());
                            auditItemsUsers.setUserId(it);
                            if (Objects.equals(num, 1)) {
                                auditItemsUsers.setAuditStatus("S");
                            } else {
                                auditItemsUsers.setAuditStatus("N");
                            }
                            boolean update = auditItemsUsersService.insertOrUpdate(auditItemsUsers);
                            if (!update) {
                                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                                return false;
                            }
                        }
                    }
                }
            } else {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return false;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            return false;
        }
        return true;
    }

    public List<Map<String, Object>> selectClsingAuditItems(Integer integer, Integer loginContractorId) {
        return baseMapper.selectClsingAuditItems(integer, loginContractorId);
    }

    public int deletePurchaseApproval(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.deletePurchaseApproval(projectBillsSubsDto);
    }

    public int deleteProSubsApproval(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.deleteProSubsApproval(projectBillsSubsDto);
    }

    public int deleteProjectApproval(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.deleteProjectApproval(projectBillsSubsDto);
    }

    public int deleteInvoiceApproval(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.deleteInvoiceApproval(projectBillsSubsDto);
    }

    public int deleteInvoiceIndirectApproval(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.deleteInvoiceIndirectApproval(projectBillsSubsDto);
    }

    public int deletePayCrApproval(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.deletePayCrApproval(projectBillsSubsDto);
    }

    public int deleteAdjusts(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.deleteAdjusts(projectBillsSubsDto);
    }

    public int deletePayCrUpLevelId(AuditItems auditItem) {
        return baseMapper.deletePayCrUpLevelId(auditItem);
    }

    public List<AuditItems> selectAuditItems(Map<String, Object> map) {
        return baseMapper.selectAuditItems(map);
    }

    public int deleteInvoiceShareApproval(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.deleteInvoiceShareApproval(projectBillsSubsDto);
    }

    public int deleteInvShareUpLevelId(AuditItems auditItem) {
        return baseMapper.deleteInvShareUpLevelId(auditItem);
    }

    public int updateInvShareAuditStatus(AuditItems at) {
        return baseMapper.updateInvShareAuditStatus(at);
    }

    public List<AuditItems> selectApprovedEvents(int intValue) {
        return baseMapper.selectApprovedEvents(intValue);
    }
}
