
package io.platform.approvalConfiguration.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.approvalConfiguration.biz.entity.AuditItems;
import io.platform.approvalConfiguration.biz.service.AuditItemsService;
import io.platform.approvalConfiguration.dto.AuditItemsDto;
import io.platform.approvalConfiguration.service.client.api.AuditItemsServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class AuditItemsServiceClientImpl extends BaseServiceClient<AuditItems, AuditItemsDto> implements AuditItemsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private AuditItemsService auditItemsService;

    @Override
    public AuditItemsDto queryObject(Long id) {
        AuditItems auditItems = auditItemsService.selectById(id);
        AuditItemsDto auditItemsDto = new AuditItemsDto();
        BeanUtils.copyProperties(auditItems, auditItemsDto);
        return auditItemsDto;
    }

    @Override
    public List<AuditItemsDto> queryList(Map<String, Object> map) {
        List<AuditItems> auditItemsList = auditItemsService.selectByMap(map);
        return convertList(auditItemsList, AuditItemsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<AuditItems> ew = new EntityWrapper<>();
        ew.allEq(map);
        return auditItemsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(AuditItemsDto auditItemsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            AuditItems auditItems = new AuditItems();
            revert(auditItemsDto, auditItems);
            boolean flag = auditItemsService.insert(auditItems);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(AuditItemsDto auditItemsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            AuditItems auditItems = new AuditItems();
            revert(auditItemsDto, auditItems);

            boolean flag = auditItemsService.updateById(auditItems);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = auditItemsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = auditItemsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<AuditItemsDto> getPage(Page<AuditItemsDto> pageDto, AuditItemsDto auditItemsDto) {
        Page<AuditItems> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        AuditItems auditItems = new AuditItems();
        revert(auditItemsDto, auditItems);
        EntityWrapper<AuditItems> wrapper = new EntityWrapper<>();
        wrapper.setEntity(auditItems);
        page = auditItemsService.selectPage(page, wrapper);
        List<AuditItemsDto> auditItemsDtoList = convertList(page.getRecords(), AuditItemsDto.class);
        pageDto.setTotal(auditItemsService.selectCount(wrapper));
        pageDto.setRecords(auditItemsDtoList);
        return pageDto;
    }
}
