
package io.platform.approvalConfiguration.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.approvalConfiguration.biz.entity.AuditItems;
import io.platform.approvalConfiguration.biz.entity.AuditPaths;
import io.platform.approvalConfiguration.biz.entity.AuditPathsActs;
import io.platform.approvalConfiguration.biz.entity.AuditPathsLevels;
import io.platform.approvalConfiguration.biz.service.AuditItemsService;
import io.platform.approvalConfiguration.biz.service.AuditPathsActsService;
import io.platform.approvalConfiguration.biz.service.AuditPathsLevelsService;
import io.platform.approvalConfiguration.biz.service.AuditPathsService;
import io.platform.approvalConfiguration.dto.AuditPathsActsDto;
import io.platform.approvalConfiguration.dto.AuditPathsDto;
import io.platform.approvalConfiguration.service.client.api.AuditPathsServiceClient;
import io.platform.base.common.utils.DateUtils;
import io.platform.project.biz.entity.ProjectBillsSubs;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.rmi.CORBA.UtilDelegate;
import java.util.*;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = AuditPathsServiceClient.class)
public class AuditPathsServiceClientImpl extends BaseServiceClient<AuditPaths, AuditPathsDto> implements AuditPathsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysUserService sysUserService;
    @Resource
    private AuditItemsService auditItemsService;
    @Resource
    private AuditPathsService auditPathsService;
    @Resource
    private AuditPathsActsService auditPathsActsService;
    @Resource
    private AuditPathsLevelsService auditPathsLevelsService;

    @Override
    public AuditPathsDto queryObject(Long id) {
        AuditPaths auditPaths = auditPathsService.selectById(id);
        AuditPathsDto auditPathsDto = new AuditPathsDto();
        BeanUtils.copyProperties(auditPaths, auditPathsDto);
        return auditPathsDto;
    }

    @Override
    public List<AuditPathsDto> queryList(Map<String, Object> map) {
        List<AuditPaths> auditPathsList = auditPathsService.selectByMap(map);
        return convertList(auditPathsList, AuditPathsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<AuditPaths> ew = new EntityWrapper<>();
        ew.allEq(map);
        return auditPathsService.selectCount(ew);
    }

    @Override
    public Map<String, Object> queryAuditPath(AuditPathsDto auditPathsDto, SysUserDto sysUserDto) {
        if (auditPathsDto.getId() != null) {
            Map<String, Object> map = new HashMap<>();
            AuditPaths auditPaths = auditPathsService.selectById(auditPathsDto.getId());
            map.put("audit", auditPaths);
            EntityWrapper<AuditPathsLevels> auditPathsLevelsEntityWrapper = new EntityWrapper<>();
            auditPathsLevelsEntityWrapper.eq("path_id", auditPaths.getId());
            List<AuditPathsLevels> auditPathsLevelsList = auditPathsLevelsService.selectList(auditPathsLevelsEntityWrapper);
            if (auditPathsLevelsList.size() != 0) {
                List<List<Integer>> integers = new ArrayList<>();
                for (AuditPathsLevels ap : auditPathsLevelsList) {
                    List<Integer> integerList = new ArrayList<>();
                    if (ap.getAuditUserId() != null) {
                        JSONArray jsonArray = JSONArray.parseArray(ap.getAuditUserId());
                        integerList = JSONObject.parseArray(jsonArray.toJSONString(), Integer.class);
                    }
                    integers.add(integerList);
                }
                map.put("auditUserIds", integers);
                map.put("auditPathsLevels", auditPathsLevelsList);
            }
            EntityWrapper<SysUser> sysUserEntityWrapper = new EntityWrapper<>();
            sysUserEntityWrapper.eq("status", 1);
            if (sysUserDto.getLoginContractorId() != 1) {
                sysUserEntityWrapper.eq("login_contractor_id", sysUserDto.getLoginContractorId())
                        .or().eq("contractor_id", 1);
            }
            sysUserEntityWrapper.orderBy("CONVERT ( actualname USING gbk ) asc");
            List<SysUser> sysUsers = sysUserService.selectList(sysUserEntityWrapper);
            if (sysUsers.size() != 0) {
                map.put("users", sysUsers);
            }
            return map;
        }
        return null;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> save(String auditPathsDto, String auditPathsLevelsDto, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            AuditPaths auditPaths = JSONArray.parseObject(auditPathsDto, AuditPaths.class);
            JSONArray jsonArray = JSONArray.parseArray(auditPathsLevelsDto);
            List<AuditPathsLevels> auditPathsLevelsList = JSONObject.parseArray(jsonArray.toJSONString(), AuditPathsLevels.class);
            if (auditPaths != null) {
                auditPaths.setOpUserId(sysUserDto.getUserId().intValue());
                auditPaths.setOpUserName(sysUserDto.getUsername());
                auditPaths.setBranchId(sysUserDto.getLoginContractorId());
                auditPaths.setOpDate(new Date());
                if (auditPaths.getId() != null) {
                    boolean updateById = auditPathsService.updateById(auditPaths);
                    if (!updateById) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("保存失败: 更新数据失败");
                        return result;
                    }
                } else {
                    EntityWrapper<AuditPaths> entityWrapper = new EntityWrapper<>();
                    entityWrapper.eq("path_name", auditPaths.getPathName()).eq("branch_id", auditPaths.getBranchId());
                    AuditPaths paths = auditPathsService.selectOne(entityWrapper);
                    if (paths != null) {
                        result.addErrorMessage("审核路径名已存在");
                        return result;
                    }
                    boolean insert = auditPathsService.insert(auditPaths);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("保存失败: 新增数据失败");
                        return result;
                    }
                }
            } else {
                result.addErrorMessage("保存失败: 未找到信息");
                return result;
            }
            EntityWrapper<AuditPathsLevels> auditPathsLevelsEntityWrapper = new EntityWrapper<>();
            auditPathsLevelsEntityWrapper.eq("path_id", auditPaths.getId());
            boolean delete = auditPathsLevelsService.delete(auditPathsLevelsEntityWrapper);
            if (!delete) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                result.addErrorMessage("保存失败: 删除旧数据失败");
                return result;
            }
            if (auditPathsLevelsList.size() != 0) {
                if ("F".equals(auditPathsLevelsList.get(auditPathsLevelsList.size() - 1).getIffinalItem())) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("保存失败: 最后一级有误");
                    return result;
                }
                int level = 0;
                int iffinalItem = 0;
                for (AuditPathsLevels le : auditPathsLevelsList) {
                    if ("S".equals(le.getIffinalItem()) && le.getAuditUserId() == null) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("保存失败: 请维护审核人");
                        return result;
                    }
                    level++;
                    if ("T".equals(le.getIffinalItem())) {
                        iffinalItem++;
                    }
                    if (iffinalItem > 1) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("保存失败: 最后一级不得超过一次");
                        return result;
                    }
                    le.setLevelId(level);
                    le.setPathId(auditPaths.getId());
                    boolean insert = auditPathsLevelsService.insert(le);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("保存失败: 新增数据失败");
                        return result;
                    }
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 保存失败：" + e.toString(), e);
            result.addErrorMessage("保存失败：提交信息有误");
            return result;
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(AuditPathsDto auditPathsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            AuditPaths auditPaths = new AuditPaths();
            revert(auditPathsDto, auditPaths);

            boolean flag = auditPathsService.updateById(auditPaths);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = auditPathsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> deleteAuditPaths(Integer ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean deleteById = auditPathsService.deleteById(ids);
            if (!deleteById) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                result.addErrorMessage("网络异常：删除失败");
                return result;
            }
            EntityWrapper<AuditPathsLevels> auditPathsLevelsEntityWrapper = new EntityWrapper<>();
            auditPathsLevelsEntityWrapper.eq("path_id", ids);
            boolean delete = auditPathsLevelsService.delete(auditPathsLevelsEntityWrapper);
            if (!delete) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                result.addErrorMessage("网络异常：删除失败");
                return result;
            }
            EntityWrapper<AuditItems> auditItemsEntityWrapper = new EntityWrapper<>();
            auditItemsEntityWrapper.eq("path_id", ids);
            boolean auditItemsDelete = auditItemsService.delete(auditItemsEntityWrapper);
            if (!auditItemsDelete) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                result.addErrorMessage("网络异常：删除失败");
                return result;
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Map<String, Object> selectAuditPathAct(Page page, AuditPathsActsDto auditPathsActsDto) {
        Map<String, Object> map = new HashMap<>();
        Map<String, Object> countMap = new HashMap<>();
        Page pageDto = DataUtils.processingPage(page);
        int count = auditPathsService.selectAuditPathActsCount(auditPathsActsDto);
        if (count != 0) {
            countMap.put("page", pageDto);
            countMap.put("dto", auditPathsActsDto);
            List<Map<String, Object>> mapList = auditPathsService.selectAuditPathActs(countMap);
            page.setRecords(mapList);
            pageDto.setTotal(count);
            map.put("page", pageDto);
        }
        Wrapper<AuditPaths> entityWrapper = new EntityWrapper<AuditPaths>();
        if (auditPathsActsDto.getBranchId() != 1) {
            entityWrapper.eq("branch_id", auditPathsActsDto.getBranchId());
        }
        entityWrapper.orderBy("CONVERT ( path_name USING gbk ) asc");
        List<AuditPaths> auditPaths = auditPathsService.selectList(entityWrapper);
        map.put("auditPaths", auditPaths);
        return map;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> saveAuditPathAct(String auditPathsActsDtoList, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            JSONArray arrayList = JSONArray.parseArray(auditPathsActsDtoList);
            List<AuditPathsActs> auditPathsActsList = JSONObject.parseArray(arrayList.toJSONString(), AuditPathsActs.class);
            if (auditPathsActsList.size() != 0) {
                for (AuditPathsActs ap : auditPathsActsList) {
                    boolean updateById = auditPathsActsService.updateById(ap);
                    if (!updateById) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("保存失败");
                        return result;
                    }
                }
            } else {
                result.addErrorMessage("未找到信息");
                return result;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 审批流保存错误：" + e.toString(), e);
            result.addErrorMessage("保存失败");
            return result;
        }
        return result;
    }

    @Override
    public Map<String, Object> selectApprovedEvents(SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        List<AuditItems> auditItems = auditItemsService.selectApprovedEvents(sysUserDto.getUserId().intValue());
        if (auditItems.size() != 0) {
            map.put("audit", auditItems);
            return map;
        }
        return null;
    }

    @Override
    public Page getPage(Page pageDto, AuditPathsDto auditPathsDto, SysUserDto sysUserDto) {
        EntityWrapper<AuditPaths> auditPathsEntityWrapper = new EntityWrapper<>();
        if (auditPathsDto.getPathName() != null) {
            auditPathsEntityWrapper.like("path_name", "%" + auditPathsDto.getPathName() + "%");
        }
        if (auditPathsDto.getStatus() != null) {
            auditPathsEntityWrapper.eq("status", auditPathsDto.getStatus());
        }
        Map<String, Object> map = new HashMap<>();
        map.put("aud", auditPathsDto);
        map.put("use", sysUserDto);
        if (sysUserDto.getLoginContractorId() != 1) {
            map.put("branchId", sysUserDto.getLoginContractorId());
        }
        int count = auditPathsService.selectListTotal(map);
        if (count != 0) {
            Page page = DataUtils.processingPage(pageDto);
            map.put("size", page.getSize());
            map.put("current", page.getCurrent());
            List<Map<String, Object>> maps = auditPathsService.selectListCurrent(map);
            page.setTotal(count);
            page.setRecords(maps);
            return page;
        }
        return null;
    }
}
