
package io.platform.budget.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;

import io.platform.approvalConfiguration.dto.AuditItemsDto;
import io.platform.budget.biz.entity.BudgetAdjustBills;
import io.platform.budget.biz.service.BudgetAdjustBillsService;
import io.platform.budget.dto.BudgetAdjustBillsDto;
import io.platform.budget.service.client.api.BudgetAdjustBillsServiceClient;
import io.platform.approvalConfiguration.biz.entity.AuditItems;
import io.platform.approvalConfiguration.biz.service.AuditItemsService;
import io.platform.sys.dto.SysUserDto;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = BudgetAdjustBillsServiceClient.class)
public class BudgetAdjustBillsServiceClientImpl extends BaseServiceClient<BudgetAdjustBills, BudgetAdjustBillsDto> implements BudgetAdjustBillsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BudgetAdjustBillsService budgetAdjustBillsService;
    @Resource
    private AuditItemsService auditItemsService;

    @Override
    public BudgetAdjustBillsDto queryObject(Long id) {
        BudgetAdjustBills budgetAdjustBills = budgetAdjustBillsService.selectById(id);
        BudgetAdjustBillsDto budgetAdjustBillsDto = new BudgetAdjustBillsDto();
        BeanUtils.copyProperties(budgetAdjustBills, budgetAdjustBillsDto);
        return budgetAdjustBillsDto;
    }

    @Override
    public List<BudgetAdjustBillsDto> queryList(Map<String, Object> map) {
        List<BudgetAdjustBills> budgetAdjustBillsList = budgetAdjustBillsService.selectByMap(map);
        return convertList(budgetAdjustBillsList, BudgetAdjustBillsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BudgetAdjustBills> ew = new EntityWrapper<>();
        ew.allEq(map);
        return budgetAdjustBillsService.selectCount(ew);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> save(BudgetAdjustBillsDto budgetAdjustBillsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BudgetAdjustBills budgetAdjustBills = new BudgetAdjustBills();
            revert(budgetAdjustBillsDto, budgetAdjustBills);
            boolean flag = budgetAdjustBillsService.insert(budgetAdjustBills);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> update(BudgetAdjustBillsDto budgetAdjustBillsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BudgetAdjustBills budgetAdjustBills = new BudgetAdjustBills();
            revert(budgetAdjustBillsDto, budgetAdjustBills);

            boolean flag = budgetAdjustBillsService.updateById(budgetAdjustBills);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = budgetAdjustBillsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = budgetAdjustBillsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BudgetAdjustBillsDto> getPage(Page<BudgetAdjustBillsDto> pageDto, BudgetAdjustBillsDto budgetAdjustBillsDto) {
        Page<BudgetAdjustBills> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BudgetAdjustBills budgetAdjustBills = new BudgetAdjustBills();
        revert(budgetAdjustBillsDto, budgetAdjustBills);
        EntityWrapper<BudgetAdjustBills> wrapper = new EntityWrapper<>();
        wrapper.setEntity(budgetAdjustBills);
        page = budgetAdjustBillsService.selectPage(page, wrapper);
        List<BudgetAdjustBillsDto> budgetAdjustBillsDtoList = convertList(page.getRecords(), BudgetAdjustBillsDto.class);
        pageDto.setTotal(budgetAdjustBillsService.selectCount(wrapper));
        pageDto.setRecords(budgetAdjustBillsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> selectAllAuditItems(String status, SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        map.put("user", sysUserDto);
        map.put("status", status);
        List<AuditItems> auditItems = auditItemsService.selectAuditItems(map);
        map.put("audit", auditItems);
        return map;
    }
}
