
package io.platform.budget.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.approvalConfiguration.biz.entity.Audit;
import io.platform.approvalConfiguration.biz.service.AuditItemsService;
import io.platform.budget.biz.entity.ProjectBillsAdjusts;
import io.platform.budget.biz.entity.ProjectBillsBudgets;
import io.platform.budget.biz.service.ProjectBillsBudgetsService;
import io.platform.budget.dto.ProjectBillsBudgetsDto;
import io.platform.budget.service.client.api.ProjectBillsBudgetsServiceClient;
import io.platform.engineering.biz.entity.Bbranchs;
import io.platform.engineering.biz.entity.Bbudgets;
import io.platform.engineering.biz.entity.Bcorps;
import io.platform.engineering.biz.entity.BprojectTypes;
import io.platform.engineering.biz.service.BbranchsService;
import io.platform.engineering.biz.service.BbudgetsService;
import io.platform.engineering.biz.service.BcorpsService;
import io.platform.engineering.biz.service.BprojectTypesService;
import io.platform.project.biz.entity.ProjectBillsSubs;
import io.platform.project.biz.service.ProjectBillsSubsService;
import io.platform.project.dto.ProjectBS;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.dto.ProjectbillsDto;
import io.platform.project.dto.SubContractBillsDto;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.*;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = ProjectBillsBudgetsServiceClient.class)
public class ProjectBillsBudgetsServiceClientImpl extends BaseServiceClient<ProjectBillsBudgets, ProjectBillsBudgetsDto> implements ProjectBillsBudgetsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BcorpsService bcorpsService;
    @Resource
    private BbranchsService bbranchsService;
    @Resource
    private BbudgetsService bbudgetsService;
    @Resource
    private AuditItemsService auditItemsService;
    @Resource
    private BprojectTypesService bprojectTypesService;
    @Resource
    private ProjectBillsSubsService projectBillsSubsService;
    @Resource
    private ProjectBillsBudgetsService projectBillsBudgetsService;

    @Override
    public ProjectBillsBudgetsDto queryObject(Long id) {
        ProjectBillsBudgets projectBillsBudgets = projectBillsBudgetsService.selectById(id);
        ProjectBillsBudgetsDto projectBillsBudgetsDto = new ProjectBillsBudgetsDto();
        BeanUtils.copyProperties(projectBillsBudgets, projectBillsBudgetsDto);
        return projectBillsBudgetsDto;
    }

    @Override
    public List<ProjectBillsBudgetsDto> queryList(Map<String, Object> map) {
        List<ProjectBillsBudgets> projectBillsBudgetsList = projectBillsBudgetsService.selectByMap(map);
        return convertList(projectBillsBudgetsList, ProjectBillsBudgetsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<ProjectBillsBudgets> ew = new EntityWrapper<>();
        ew.allEq(map);
        return projectBillsBudgetsService.selectCount(ew);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> save(ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBillsBudgets projectBillsBudgets = new ProjectBillsBudgets();
            revert(projectBillsBudgetsDto, projectBillsBudgets);
            boolean flag = projectBillsBudgetsService.insert(projectBillsBudgets);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> update(ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBillsBudgets projectBillsBudgets = new ProjectBillsBudgets();
            revert(projectBillsBudgetsDto, projectBillsBudgets);

            boolean flag = projectBillsBudgetsService.updateById(projectBillsBudgets);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectBillsBudgetsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> deleteProjectBudget(ProjectBillsSubsDto projectBillsSubsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (projectBillsSubsDto != null && projectBillsSubsDto.getId() != null) {
                EntityWrapper<ProjectBillsSubs> entityWrapper = new EntityWrapper<>();
                entityWrapper.eq("id", projectBillsSubsDto.getId());
                ProjectBillsSubs billsSubs = projectBillsSubsService.selectOne(entityWrapper);
                if (Objects.equals(billsSubs.getProjectBudgetStatus(), 6)) {
                    result.addErrorMessage("已提交的预算编制不允许删除");
                    return result;
                }
                EntityWrapper<ProjectBillsBudgets> projectBillsBudgetsEntityWrapper = new EntityWrapper<>();
                projectBillsBudgetsEntityWrapper.setSqlSelect("id").eq("project_sub_no", billsSubs.getProjectSubNo());
                List<ProjectBillsBudgets> projectBillsBudgetsList = projectBillsBudgetsService.selectList(projectBillsBudgetsEntityWrapper);
                if (projectBillsBudgetsList.size() != 0) {
                    for (ProjectBillsBudgets pb : projectBillsBudgetsList) {
                        boolean deleteById = projectBillsBudgetsService.deleteById(pb);
                        if (!deleteById) {
                            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                            result.addErrorMessage("预算项目删除失败");
                            return result;
                        }
                    }
                }
                EntityWrapper<ProjectBillsSubs> projectBillsSubsEntityWrapper = new EntityWrapper<>();
                projectBillsSubsEntityWrapper.setSqlSelect("id").eq("id", billsSubs.getId());
                ProjectBillsSubs proSub = projectBillsSubsService.selectOne(projectBillsSubsEntityWrapper);
                if (proSub != null) {
                    proSub.setProjectBudgetStatus(1);
                    proSub.setBudgetOrgDate(null);
                    proSub.setBudgetOrgAmt(0.0);
                    proSub.setBudgetOrgProfit(0.0);
                    proSub.setBudgetOrgProfitRate(0.0);
                    proSub.setBudgetAmt(0.0);
                    proSub.setBudgetProfit(0.0);
                    proSub.setBudgetProfitRate(0.0);
                    proSub.setBudgetUserName(null);
                    boolean updateById = projectBillsSubsService.updateById(proSub);
                    if (!updateById) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("更新子项目失败");
                        return result;
                    }
                }
            } else {
                result.addErrorMessage("未发现子项目请确认后提交");
                return result;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("预算编制删除失败");
            return result;
        }
        return result;
    }

    @Override
    public Page<ProjectBillsBudgetsDto> getPage(Page<ProjectBillsBudgetsDto> pageDto, ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        Page<ProjectBillsBudgets> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        ProjectBillsBudgets projectBillsBudgets = new ProjectBillsBudgets();
        revert(projectBillsBudgetsDto, projectBillsBudgets);
        EntityWrapper<ProjectBillsBudgets> wrapper = new EntityWrapper<>();
        wrapper.setEntity(projectBillsBudgets);
        page = projectBillsBudgetsService.selectPage(page, wrapper);
        List<ProjectBillsBudgetsDto> projectBillsBudgetsDtoList = convertList(page.getRecords(), ProjectBillsBudgetsDto.class);
        pageDto.setTotal(projectBillsBudgetsService.selectCount(wrapper));
        pageDto.setRecords(projectBillsBudgetsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> budgetsQueryContract(Integer id) {
        if (id != null) {
            Map<String, Object> map = new HashMap<>();
            ProjectBS projectBS = projectBillsBudgetsService.selectProBS(id);
            if (projectBS != null) {
                EntityWrapper<Bcorps> bcorpsEntityWrapper = new EntityWrapper<>();
                bcorpsEntityWrapper.setSqlSelect("id", "c_name").eq("id", projectBS.getCorpId());
                Bcorps bcorps = bcorpsService.selectOne(bcorpsEntityWrapper);
                EntityWrapper<BprojectTypes> bprojectTypesEntityWrapper = new EntityWrapper<>();
                bprojectTypesEntityWrapper.setSqlSelect("id", "project_type_name").eq("id", projectBS.getProjectTypeId());
                BprojectTypes bprojectTypes = bprojectTypesService.selectOne(bprojectTypesEntityWrapper);
                EntityWrapper<Bbranchs> bbranchsEntityWrapper = new EntityWrapper<>();
                bbranchsEntityWrapper.setSqlSelect("id", "c_name").eq("id", projectBS.getConstructorId());
                Bbranchs bbranchs = bbranchsService.selectOne(bbranchsEntityWrapper);
                EntityWrapper<ProjectBillsBudgets> projectBillsBudgetsEntityWrapper = new EntityWrapper<>();
                projectBillsBudgetsEntityWrapper.eq("project_sub_no", projectBS.getProjectSubNo());
                List<ProjectBillsBudgets> projectBillsBudgets = projectBillsBudgetsService.selectList(projectBillsBudgetsEntityWrapper);
                if (projectBillsBudgets.size() != 0) {
                    map.put("proSudgets", projectBillsBudgets);
                }
                /*..................................................*/
                EntityWrapper<Bbudgets> bbudgetsEntityWrapper = new EntityWrapper<>();
                bbudgetsEntityWrapper.setSqlSelect("id", "budget_name").ne("id", 1).or().ne("id", 2);
                List<Bbudgets> bbudgetsList = bbudgetsService.selectList(bbudgetsEntityWrapper);
                if (bbudgetsList.size() != 0) {
                    map.put("budgets", bbudgetsList);
                }
                /*..................................................*/
                map.put("corps", bcorps);
                map.put("branch", bbranchs);
                map.put("proType", bprojectTypes);
                map.put("proBS", projectBS);
                return map;
            }
        }
        return null;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> projectBudgetTemporary(String projectBillsSubs, String projectBudget, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBS projectBS = JSONArray.parseObject(projectBillsSubs, ProjectBS.class);
            JSONArray jsonArray = JSONArray.parseArray(projectBudget);
            List<ProjectBillsBudgets> projectBillsBudgetsList = JSONObject.parseArray(jsonArray.toJSONString(), ProjectBillsBudgets.class);
            if (projectBillsBudgetsList.size() != 0) {
                EntityWrapper<ProjectBillsSubs> projectBillsSubsEntityWrapper = new EntityWrapper<>();
                projectBillsSubsEntityWrapper.eq("id", projectBS.getId());
                ProjectBillsSubs billsSubs = projectBillsSubsService.selectOne(projectBillsSubsEntityWrapper);
                billsSubs.setProjectBudgetStatus(2);
                billsSubs.setBudgetOrgDate(new Date());
                billsSubs.setDrawingDate(projectBS.getDrawingDate());
                billsSubs.setBudgetOrgAmt(projectBS.getBudgetAmt());
                billsSubs.setBudgetOrgProfit(projectBS.getBudgetProfit());
                billsSubs.setBudgetOrgProfitRate(projectBS.getBudgetProfitRate());
                billsSubs.setBudgetAmt(projectBS.getBudgetAmt());
                billsSubs.setBudgetProfit(projectBS.getBudgetProfit());
                billsSubs.setBudgetProfitRate(projectBS.getBudgetProfitRate());
                billsSubs.setBudgetUserName(sysUserDto.getUsername());
                boolean updateById = projectBillsSubsService.updateById(billsSubs);
                if (!updateById) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("暂存失败，更新状态失败");
                    return result;
                }
                EntityWrapper<ProjectBillsBudgets> projectBillsBudgetsEntityWrapper = new EntityWrapper<>();
                projectBillsBudgetsEntityWrapper.eq("project_sub_no", billsSubs.getProjectSubNo())
                        .eq("branch_id", billsSubs.getBranchId());
                boolean delete = projectBillsBudgetsService.delete(projectBillsBudgetsEntityWrapper);
                if (!delete) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("删除原预算失败");
                    return result;
                }
                int line = 0;
                for (ProjectBillsBudgets pb : projectBillsBudgetsList) {
                    line++;
                    pb.setBillNo(projectBS.getBillNo());
                    pb.setId(0);
                    pb.setLineNo(line);
                    pb.setActId(105);
                    pb.setBudgetOrgAmt(pb.getBudgetAmt());
                    pb.setBranchId(billsSubs.getBranchId());
                    boolean insert = projectBillsBudgetsService.insert(pb);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("暂存失败。");
                        return result;
                    }
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 暂存错误：" + e.toString(), e);
            result.addErrorMessage("暂存失败，请确认后重新提交");
            return result;
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> projectBudgetSave(String projectBillsSubs, String projectBudget, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBillsSubs projectbillsDto = JSONArray.parseObject(projectBillsSubs, ProjectBillsSubs.class);
            JSONArray jsonArray = JSONArray.parseArray(projectBudget);
            List<ProjectBillsBudgets> projectBillsBudgetsList = JSONObject.parseArray(jsonArray.toJSONString(), ProjectBillsBudgets.class);
            if (projectBillsBudgetsList.size() != 0) {
                ProjectBillsSubs billsSubs = projectBillsSubsService.selectById(projectbillsDto.getId());
                billsSubs.setProjectBudgetStatus(4);
                billsSubs.setBudgetOrgDate(new Date());
                billsSubs.setDrawingDate(projectbillsDto.getDrawingDate());
                billsSubs.setBudgetOrgAmt(projectbillsDto.getBudgetAmt());
                billsSubs.setBudgetOrgProfit(projectbillsDto.getBudgetProfit());
                billsSubs.setBudgetOrgProfitRate(projectbillsDto.getBudgetProfitRate());
                billsSubs.setBudgetAmt(projectbillsDto.getBudgetAmt());
                billsSubs.setBudgetProfit(projectbillsDto.getBudgetProfit());
                billsSubs.setBudgetProfitRate(projectbillsDto.getBudgetProfitRate());
                billsSubs.setBudgetUserName(sysUserDto.getUsername());
                billsSubs.setBudgetRemarks(projectbillsDto.getBudgetRemarks());
                boolean updateById = projectBillsSubsService.updateById(billsSubs);
                if (!updateById) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("提交失败，更新状态失败");
                    return result;
                }
                EntityWrapper<ProjectBillsBudgets> projectBillsBudgetsEntityWrapper = new EntityWrapper<>();
                projectBillsBudgetsEntityWrapper.eq("bill_no", billsSubs.getBillNo())
                        .eq("project_sub_no", billsSubs.getProjectSubNo())
                        .eq("branch_id", billsSubs.getBranchId());
                boolean delete = projectBillsBudgetsService.delete(projectBillsBudgetsEntityWrapper);
                if (!delete) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("删除原预算失败");
                    return result;
                }
                int line = 0;
                for (ProjectBillsBudgets pb : projectBillsBudgetsList) {
                    line++;
                    pb.setId(0);
                    pb.setBillNo(projectbillsDto.getBillNo());
                    pb.setLineNo(line);
                    pb.setActId(105);
                    pb.setBranchId(billsSubs.getBranchId());
                    pb.setBudgetOrgAmt(pb.getBudgetAmt());
                    boolean insert = projectBillsBudgetsService.insert(pb);
                    if (!insert) {
                        result.addErrorMessage("提交失败。");
                        break;
                    }
                }
                Audit audit = new Audit();
                audit.setBillNo(billsSubs.getBillNo());
                audit.setActId(730);
                audit.setLevelId(0);
                audit.setIffinalItem("F");
                audit.setSubJect(billsSubs.getProjectSubName());
                audit.setProjectNo(billsSubs.getProjectSubNo());
                audit.setBranchId(billsSubs.getApprovalBranchId());
                audit.setSendUserId(sysUserDto.getUserId().intValue());
                audit.setSendName(sysUserDto.getActualname());
                audit.setSendTime(new Date());
                audit.setAuditUserId(sysUserDto.getUserId().intValue());
                audit.setAuditItem(new Date());
                audit.setAuditMsg("提交");
                audit.setAuditStatus("O");
                audit.setProjectMngId(billsSubs.getProjectSubMngId());
                boolean approvalFlow = auditItemsService.createApprovalFlow(audit);
                if (!approvalFlow) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("审批流异常请检查提交信息");
                    return result;
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error("保存错误：" + e.toString(), e);
            result.addErrorMessage("保存失败，请确认后提交");
            return result;
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> editBudgetSave(List<ProjectBillsBudgetsDto> projectBillsBudgetsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (projectBillsBudgetsDto.size() != 0) {
                EntityWrapper<ProjectBillsBudgets> projectBillsBudgetsEntityWrapper = new EntityWrapper<>();
                projectBillsBudgetsEntityWrapper.setSqlSelect("id").eq("project_sub_no", projectBillsBudgetsDto.get(0).getProjectSubNo());
                List<ProjectBillsBudgets> projectBillsBudgets = projectBillsBudgetsService.selectList(projectBillsBudgetsEntityWrapper);
                if (projectBillsBudgets.size() != 0) {
                    for (ProjectBillsBudgets pb : projectBillsBudgets) {
                        boolean deleteById = projectBillsBudgetsService.deleteById(pb);
                        if (!deleteById) {
                            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                            result.addErrorMessage("删除原预算失败");
                            return result;
                        }
                    }
                }
                int line = 0;
                for (ProjectBillsBudgetsDto pb : projectBillsBudgetsDto) {
                    line++;
                    pb.setId(0);
                    pb.setLineNo(line);
                    pb.setActId(105);
                    pb.setBudgetAmt(pb.getBudgetOrgAmt());
                    ProjectBillsBudgets billsBudgets = new ProjectBillsBudgets();
                    revert(pb, billsBudgets);
                    boolean insert = projectBillsBudgetsService.insert(billsBudgets);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("提交失败。");
                        return result;
                    }
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存失败，请确认后提交");
            return result;
        }
        return result;
    }

    @Override
    public Map<String, Object> selectBillsBudget(ProjectBillsBudgetsDto projectBillsBudgetsDto) {
        Map<String, Object> map = new HashMap<>();
        ProjectBillsBudgets billsBudgets = new ProjectBillsBudgets();
        revert(projectBillsBudgetsDto, billsBudgets);
        EntityWrapper<ProjectBillsBudgets> billsBudgetsEntityWrapper = new EntityWrapper<>();
        billsBudgetsEntityWrapper.eq("project_sub_no", projectBillsBudgetsDto.getProjectSubNo());
        billsBudgetsEntityWrapper.eq("budget_id", projectBillsBudgetsDto.getBudgetId());
        map.put("budget", projectBillsBudgetsService.selectOne(billsBudgetsEntityWrapper));
        return map;
    }

}
