
package io.platform.contract.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.contract.biz.entity.OtherProject;
import io.platform.contract.biz.service.OtherProjectService;
import io.platform.contract.dto.OtherProjectDto;
import io.platform.contract.service.client.api.OtherProjectServiceClient;
import io.platform.moneyManagement.biz.entity.InvoiceBills;
import io.platform.moneyManagement.biz.service.InvoiceBillsService;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.project.biz.entity.SubContractBills;
import io.platform.project.biz.service.SubContractBillsService;
import io.platform.project.service.client.api.ProjectbillsServiceClient;
import io.platform.sys.biz.entity.SysRole;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.ZoneId;
import java.util.*;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = OtherProjectServiceClient.class)
public class OtherProjectServiceClientImpl extends BaseServiceClient<OtherProject, OtherProjectDto> implements OtherProjectServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private OtherProjectService otherProjectService;
    @Resource
    private InvoiceBillsService invoiceBillsService;
    @Resource
    private SubContractBillsService subContractBillsService;

    @Override
    public OtherProjectDto queryObject(Long id) {
        OtherProject otherProject = otherProjectService.selectById(id);
        OtherProjectDto otherProjectDto = new OtherProjectDto();
        BeanUtils.copyProperties(otherProject, otherProjectDto);
        return otherProjectDto;
    }

    @Override
    public List<OtherProjectDto> queryList(Map<String, Object> map) {
        List<OtherProject> otherProjectList = otherProjectService.selectByMap(map);
        return convertList(otherProjectList, OtherProjectDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<OtherProject> ew = new EntityWrapper<>();
        ew.allEq(map);
        return otherProjectService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(OtherProjectDto otherProjectDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            OtherProject otherProject = new OtherProject();
            revert(otherProjectDto, otherProject);
            boolean flag = otherProjectService.insert(otherProject);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(OtherProjectDto otherProjectDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            OtherProject otherProject = new OtherProject();
            revert(otherProjectDto, otherProject);

            boolean flag = otherProjectService.updateById(otherProject);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = otherProjectService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = otherProjectService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Map<String, Object> getPage(Map<String, Object> map, SysUserDto sysUserDto) {
        Map<String, Object> objectMap = new HashMap<>();
        SysRole sysRole = subContractBillsService.selectRole(sysUserDto);
        map.put("user", sysUserDto);
        map.put("role", sysRole);
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            if (map.containsKey("startDate") && map.get("startDate") != null) {
                long startimes = (long) map.get("startDate");
                String startTime = sdf.format(new Date(startimes));
                map.put("startDateTime", startTime);
            }
            if (map.containsKey("endDate") && map.get("endDate") != null) {
                long endtimes = (long) map.get("endDate");
                LocalDateTime localDateTime = LocalDateTime.ofInstant(Instant.ofEpochMilli(endtimes), ZoneId.systemDefault());
                LocalDateTime endOfDay = localDateTime.with(LocalTime.MAX);
                Date from = Date.from(endOfDay.atZone(ZoneId.systemDefault()).toInstant());
                String endTime = sdf.format(from);
                map.put("endDateTime", endTime);
            }
            int num = otherProjectService.selectOtherProPageTotal(map);
            if (num != 0) {
                int current = (int) map.get("current");
                int size = (int) map.get("size");
                if (current <= 1) {
                    current = 0;
                } else {
                    current = (current - 1) * size;
                }
                map.put("size", size);
                map.put("current", current);
                List<Map<String, Object>> mapList = otherProjectService.selectOtherProPageRecords(map);
                Page pageDto = new Page<>();
                pageDto.setRecords(mapList);
                pageDto.setTotal(num);
                objectMap.put("page", pageDto);
            }
            return objectMap;
        } catch (Exception e) {
            logger.error("操作异常：" + e.toString(), e);
        }
        return objectMap;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> otherProTemporary(OtherProjectDto otherProjectDto, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            OtherProject otherProject = new OtherProject();
            otherProject.setId(otherProjectDto.getId());
            otherProject.setPurchaseNcNo(otherProjectDto.getPurchaseNcNo());
            otherProject.setPurchasesId(otherProjectDto.getPurchasesId());
            otherProject.setBudgetId(otherProjectDto.getBudgetId());
            otherProject.setContractAmt(otherProjectDto.getContractAmt());
            otherProject.setAttachId(otherProjectDto.getAttachId());
            otherProject.setAttachName(otherProjectDto.getAttachName());
            otherProject.setOpUserId(sysUserDto.getUserId().intValue());
            otherProject.setOpDate(new Date());
            otherProject.setStatus(2);
            boolean update = otherProjectService.insertOrUpdate(otherProject);
            if (!update) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                result.addErrorMessage("暂存失败：请确认信息重新提交");
                return result;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 暂存错误：" + e.toString(), e);
            result.addErrorMessage("暂存失败：请确认信息重新提交");
            return result;
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> otherProSave(OtherProjectDto otherProjectDto, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            OtherProject otherProject = new OtherProject();
            otherProject.setId(otherProjectDto.getId());
            otherProject.setPurchaseNcNo(otherProjectDto.getPurchaseNcNo());
            otherProject.setPurchasesId(otherProjectDto.getPurchasesId());
            otherProject.setBudgetId(otherProjectDto.getBudgetId());
            otherProject.setContractAmt(otherProjectDto.getContractAmt());
            otherProject.setAttachId(otherProjectDto.getAttachId());
            otherProject.setAttachName(otherProjectDto.getAttachName());
            otherProject.setOpUserId(sysUserDto.getUserId().intValue());
            otherProject.setOpDate(new Date());
            otherProject.setStatus(6);
            boolean update = otherProjectService.insertOrUpdate(otherProject);
            if (!update) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                result.addErrorMessage("提交失败：请确认信息重新提交");
                return result;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 提交错误：" + e.toString(), e);
            result.addErrorMessage("提交失败：请确认信息重新提交");
            return result;
        }
        return result;
    }

    @Override
    public Map<String, Object> queryOtherProTemporary(OtherProjectDto otherProjectDto) {
        if (otherProjectDto != null && otherProjectDto.getId() != null) {
            Map<String, Object> map = new HashMap<>();
            EntityWrapper<OtherProject> entityWrapper = new EntityWrapper<>();
            entityWrapper.eq("id", otherProjectDto.getId());
            OtherProject otherProject = otherProjectService.selectOne(entityWrapper);
            if (otherProject != null) {
                map.put("other", otherProject);
            }
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> queryOtherProPurchaseNcNo(OtherProjectDto otherProjectDto, SysUserDto sysUserDto) {
        if (otherProjectDto != null) {
            Map<String, Object> map = new HashMap<>();
            EntityWrapper<OtherProject> entityWrapper = new EntityWrapper<>();
            entityWrapper.eq("purchase_nc_no", otherProjectDto.getPurchaseNcNo())
                    .eq("branch_id", sysUserDto.getLoginContractorId());
            OtherProject otherProject = otherProjectService.selectOne(entityWrapper);
            if (otherProject != null) {
                map.put("opther", otherProject);
            }
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> purchaseNcPage(Page page, InvoiceBillsDto invoiceBillsDto, SysUserDto sysUserDto) {
        Page pageDto = DataUtils.processingPage(page);
        Map<String, Object> map = new HashMap<>();
        if (invoiceBillsDto.getBudgetId() == 1) {
            EntityWrapper<SubContractBills> subContractBillsEntityWrapper = new EntityWrapper<>();
            if (sysUserDto.getLoginContractorId() != 1) {
                subContractBillsEntityWrapper.eq("branch_id", sysUserDto.getLoginContractorId());
            }
            subContractBillsEntityWrapper.eq("project_sub_no", invoiceBillsDto.getProjectSubNo())
                    .eq("purchase_id", invoiceBillsDto.getPurchaseId())
                    .ne("purchase_nc_no", "");
            int sum = subContractBillsService.selectCount(subContractBillsEntityWrapper);
            if (sum != 0) {
                subContractBillsEntityWrapper.orderBy(true, "id", false);
                subContractBillsEntityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<SubContractBills> subContractBillsList = subContractBillsService.selectList(subContractBillsEntityWrapper);
                pageDto.setTotal(sum);
                pageDto.setRecords(subContractBillsList);
                map.put("page", pageDto);
                return map;
            }
        } else {
            Map<String, Object> xmap = new HashMap<>();
            xmap.put("dto", invoiceBillsDto);
            xmap.put("curr", pageDto.getCurrent());
            xmap.put("size", pageDto.getSize());
            xmap.put("user", sysUserDto);
            List<OtherProject> otherProjectList = otherProjectService.purchaseNcPage(xmap);
            int sum = otherProjectList.size();
            if (sum != 0) {
                pageDto.setTotal(sum);
                pageDto.setRecords(otherProjectList);
                map.put("page", pageDto);
                return map;
            }
        }
        return null;
    }
}
