
package io.platform.contract.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.contract.biz.entity.Tasklists;
import io.platform.contract.biz.service.TasklistsService;
import io.platform.contract.dto.TasklistsDto;
import io.platform.contract.service.client.api.ProjectBillsStlPlansServiceClient;
import io.platform.contract.service.client.api.TasklistsServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = TasklistsServiceClient.class)
public class TasklistsServiceClientImpl extends BaseServiceClient<Tasklists, TasklistsDto> implements TasklistsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private TasklistsService tasklistsService;

    @Override
    public TasklistsDto queryObject(Long id) {
        Tasklists tasklists = tasklistsService.selectById(id);
        TasklistsDto tasklistsDto = new TasklistsDto();
        BeanUtils.copyProperties(tasklists, tasklistsDto);
        return tasklistsDto;
    }

    @Override
    public List<TasklistsDto> queryList(Map<String, Object> map) {
        List<Tasklists> tasklistsList = tasklistsService.selectByMap(map);
        return convertList(tasklistsList, TasklistsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<Tasklists> ew = new EntityWrapper<>();
        ew.allEq(map);
        return tasklistsService.selectCount(ew);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> save(TasklistsDto tasklistsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Tasklists tasklists = new Tasklists();
            revert(tasklistsDto, tasklists);
            boolean flag = tasklistsService.insert(tasklists);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> update(TasklistsDto tasklistsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Tasklists tasklists = new Tasklists();
            revert(tasklistsDto, tasklists);

            boolean flag = tasklistsService.updateById(tasklists);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = tasklistsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = tasklistsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<TasklistsDto> getPage(Page<TasklistsDto> pageDto, TasklistsDto tasklistsDto) {
        Page<Tasklists> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        Tasklists tasklists = new Tasklists();
        revert(tasklistsDto, tasklists);
        EntityWrapper<Tasklists> wrapper = new EntityWrapper<>();
        wrapper.setEntity(tasklists);
        page = tasklistsService.selectPage(page, wrapper);
        List<TasklistsDto> tasklistsDtoList = convertList(page.getRecords(), TasklistsDto.class);
        pageDto.setTotal(tasklistsService.selectCount(wrapper));
        pageDto.setRecords(tasklistsDtoList);
        return pageDto;
    }
}
