
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import com.google.gson.JsonObject;
import io.platform.approvalConfiguration.biz.entity.AuditPaths;
import io.platform.approvalConfiguration.biz.entity.AuditPathsActs;
import io.platform.approvalConfiguration.biz.entity.AuditPathsActsMould;
import io.platform.approvalConfiguration.biz.service.AuditPathsActsMouldService;
import io.platform.approvalConfiguration.biz.service.AuditPathsActsService;
import io.platform.approvalConfiguration.biz.service.AuditPathsService;
import io.platform.approvalConfiguration.service.client.api.AuditPathsServiceClient;
import io.platform.engineering.biz.entity.Bbranchs;
import io.platform.engineering.biz.entity.BprojectTypes;
import io.platform.engineering.biz.service.BbranchsService;
import io.platform.engineering.dto.BbranchsDto;
import io.platform.engineering.service.client.api.BbranchsServiceClient;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import lombok.SneakyThrows;
import org.springframework.beans.BeanUtils;
import org.springframework.boot.configurationprocessor.json.JSONArray;
import org.springframework.boot.configurationprocessor.json.JSONException;
import org.springframework.boot.configurationprocessor.json.JSONObject;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.*;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = BbranchsServiceClient.class)
public class BbranchsServiceClientImpl extends BaseServiceClient<Bbranchs, BbranchsDto> implements BbranchsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BbranchsService bbranchsService;
    @Resource
    private AuditPathsService auditPathsService;
    @Resource
    private AuditPathsActsService auditPathsActsService;
    @Resource
    private AuditPathsActsMouldService auditPathsActsMouldService;

    @Override
    public BbranchsDto queryObject(Long id) {
        Bbranchs bbranchs = bbranchsService.selectById(id);
        BbranchsDto bbranchsDto = new BbranchsDto();
        BeanUtils.copyProperties(bbranchs, bbranchsDto);
        return bbranchsDto;
    }

    @Override
    public List<BbranchsDto> queryList(Map<String, Object> map) {
        List<Bbranchs> bbranchsList = bbranchsService.selectByMap(map);
        return convertList(bbranchsList, BbranchsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<Bbranchs> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bbranchsService.selectCount(ew);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> branchSave(BbranchsDto bbranchsDto, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bbranchs bbranchs = new Bbranchs();
            bbranchs.setBranchNo(bbranchsDto.getBranchNo());
            bbranchs.setSname(bbranchsDto.getSname());
            bbranchs.setCname(bbranchsDto.getCname());
            bbranchs.setCaddr(bbranchsDto.getCaddr());
            bbranchs.setTaxNo(bbranchsDto.getTaxNo());
            bbranchs.setBank(bbranchsDto.getBank());
            bbranchs.setDetails(bbranchsDto.getDetails());
            bbranchs.setStatus(bbranchsDto.getStatus());
            bbranchs.setRemarks(bbranchsDto.getRemarks());
            if (bbranchsDto.getId() != null) {
                bbranchs.setId(bbranchsDto.getId());
                boolean updateById = bbranchsService.updateById(bbranchs);
                if (!updateById) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("提交失败");
                    return result;
                }
            } else {
                EntityWrapper<Bbranchs> entityWrapper = new EntityWrapper<>();
                entityWrapper.eq("c_name", bbranchsDto.getCname());
                Bbranchs bran = bbranchsService.selectOne(entityWrapper);
                if (bran != null) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("单位名称不得重复");
                    return result;
                }
                boolean insert = bbranchsService.insert(bbranchs);
                if (!insert) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("提交失败");
                    return result;
                }
            }
            EntityWrapper<AuditPathsActsMould> pathsActsMouldEntityWrapper = new EntityWrapper<>();
            pathsActsMouldEntityWrapper.eq("template_type", "F");
            List<AuditPathsActsMould> auditPathsActsMoulds = auditPathsActsMouldService.selectList(pathsActsMouldEntityWrapper);
            if (auditPathsActsMoulds.size() != 0) {
                for (AuditPathsActsMould ap : auditPathsActsMoulds) {
                    AuditPaths auditPaths = new AuditPaths();
                    auditPaths.setPathName(ap.getPathName());
                    auditPaths.setBranchId(bbranchs.getId());
                    boolean insert = auditPathsService.insert(auditPaths);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("生成审批失败");
                        return result;
                    }
                }
            }
            EntityWrapper<AuditPathsActsMould> actsMouldEntityWrapper = new EntityWrapper<>();
            actsMouldEntityWrapper.eq("template_type", "T");
            List<AuditPathsActsMould> auditPathsActsMouldList = auditPathsActsMouldService.selectList(actsMouldEntityWrapper);
            if (auditPathsActsMouldList.size() != 0) {
                for (AuditPathsActsMould ap : auditPathsActsMouldList) {
                    AuditPathsActs auditPathsActs = new AuditPathsActs();
                    auditPathsActs.setBranchId(bbranchs.getId());
                    auditPathsActs.setActId(ap.getActId());
                    auditPathsActs.setReviewConditions(ap.getReviewConditions());
                    boolean insert = auditPathsActsService.insert(auditPathsActs);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("生成审批失败");
                        return result;
                    }
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BbranchsDto bbranchsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bbranchs bbranchs = new Bbranchs();
            revert(bbranchsDto, bbranchs);

            boolean flag = bbranchsService.updateById(bbranchs);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bbranchsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bbranchsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BbranchsDto> getPage(Page<BbranchsDto> pageDto, BbranchsDto bbranchsDto) {
        Page<Bbranchs> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        Bbranchs bbranchs = new Bbranchs();
        revert(bbranchsDto, bbranchs);
        EntityWrapper<Bbranchs> wrapper = new EntityWrapper<>();
//        wrapper.setEntity(bbranchs);
        wrapper.like("branch_no",bbranchs.getBranchNo());
        wrapper.like("c_name",bbranchs.getCname());
        wrapper.notIn("id",1);
        page = bbranchsService.selectPage(page, wrapper);
        List<BbranchsDto> bbranchsDtoList = convertList(page.getRecords(), BbranchsDto.class);
        pageDto.setTotal(bbranchsService.selectCount(wrapper));
        pageDto.setRecords(bbranchsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryBranch(Page page, BbranchsDto bbranchsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bbranchsDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<Bbranchs> entityWrapper = new EntityWrapper<>();
            if (bbranchsDto.getOpDate() != null) {
                entityWrapper.eq("op_date", bbranchsDto.getOpDate());
            }
            if (bbranchsDto.getStatus() != null && !bbranchsDto.getStatus().equals("")) {
                entityWrapper.eq("status", bbranchsDto.getStatus());
            }
            if (bbranchsDto.getBranchNo() != null && !bbranchsDto.getBranchNo().equals("")) {
                entityWrapper.like("branch_no", "%" + bbranchsDto.getBranchNo() + "%");
            }
            if (bbranchsDto.getSname() != null && !bbranchsDto.getSname().equals("")) {
                entityWrapper.like("s_name", "%" + bbranchsDto.getSname() + "%");
            }
            if (bbranchsDto.getCname() != null && !bbranchsDto.getCname().equals("")) {
                entityWrapper.like("c_name", "%" + bbranchsDto.getCname() + "%");
            }
            if (bbranchsDto.getCaddr() != null && !bbranchsDto.getCaddr().equals("")) {
                entityWrapper.like("caddr", "%" + bbranchsDto.getCaddr() + "%");
            }
            if (bbranchsDto.getTel() != null && !bbranchsDto.getTel().equals("")) {
                entityWrapper.like("tel", "%" + bbranchsDto.getTel() + "%");
            }
            if (bbranchsDto.getFax() != null && !bbranchsDto.getFax().equals("")) {
                entityWrapper.like("fax", "%" + bbranchsDto.getFax() + "%");
            }
            if (bbranchsDto.getPostAddr() != null && !bbranchsDto.getPostAddr().equals("")) {
                entityWrapper.like("post_addr", "%" + bbranchsDto.getPostAddr() + "%");
            }
            if (bbranchsDto.getManAger() != null && !bbranchsDto.getManAger().equals("")) {
                entityWrapper.like("man_ager", "%" + bbranchsDto.getManAger() + "%");
            }
            if (bbranchsDto.getAttn() != null && !bbranchsDto.getAttn().equals("")) {
                entityWrapper.like("attn", "%" + bbranchsDto.getAttn() + "%");
            }
            if (bbranchsDto.getTaxNo() != null && !bbranchsDto.getTaxNo().equals("")) {
                entityWrapper.like("taxNo", "%" + bbranchsDto.getTaxNo() + "%");
            }
            if (bbranchsDto.getBankAccNo() != null && !bbranchsDto.getBankAccNo().equals("")) {
                entityWrapper.like("bank_acc_no", "%" + bbranchsDto.getBankAccNo() + "%");
            }
            if (bbranchsDto.getOpUserName() != null && !bbranchsDto.getOpUserName().equals("")) {
                entityWrapper.like("op_user_name", "%" + bbranchsDto.getOpUserName() + "%");
            }
            if (bbranchsDto.getRemarks() != null && !bbranchsDto.getRemarks().equals("")) {
                entityWrapper.like("remarks", "%" + bbranchsDto.getRemarks() + "%");
            }
            int number = bbranchsService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<Bbranchs> bbranchs = bbranchsService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bbranchs);
                map.put("page", pageDto);
                return map;
            }
            return null;
        }
        return null;
    }


    @Override
    public Map<String, Object> selectbranchs(BbranchsDto bbranchsDto, SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        if (bbranchsDto.getId() != null) {
            EntityWrapper<Bbranchs> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "c_name", "abbr_no");
            List<Bbranchs> bbranchs = bbranchsService.selectList(entityWrapper);
            if (bbranchs != null) {
                map.put("branch", bbranchs);
                return map;
            }
        }
        if (bbranchsDto.getPostAddr() != null) {
            if (bbranchsDto.getPostAddr().equals("audit")) {
                EntityWrapper<Bbranchs> entityWrapper = new EntityWrapper<>();
                entityWrapper.setSqlSelect("id", "c_name", "abbr_no");
                if (sysUserDto.getLoginContractorId() != 1) {
                    entityWrapper.eq("id", sysUserDto.getLoginContractorId());
                }
                List<Bbranchs> bbranchsList = bbranchsService.selectList(entityWrapper);
                if (bbranchsList.size() != 0) {
                    map.put("branchs", bbranchsList);
                    return map;
                }
                return null;
            }
        }
        EntityWrapper<Bbranchs> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "c_name", "abbr_no"); //.eq("id", bbranchsDto.getBranchId())
        List<Bbranchs> bbranchsList = bbranchsService.selectList(entityWrapper);
        if (bbranchsList.size() != 0) {
            map.put("branchs", bbranchsList);
            return map;
        }
        return null;
    }

    @SneakyThrows
    @Override
    public String selectbranchsTree() {
        JSONArray jsonArray = new JSONArray();
        List<HashMap<String, Object>> bbranchsList = bbranchsService.selectbranchsTree();
        for (int i = 0; i < bbranchsList.size(); i++) {
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("id", bbranchsList.get(i).get("id"));
            jsonObject.put("dataName", bbranchsList.get(i).get("dataName"));
            jsonObject.put("sub", bbranchsList.get(i).get("sub"));
            jsonObject.put("level", 1);
            if (!bbranchsList.get(i).get("sub").equals("0")) {
                List<HashMap<String, Object>> deptList = bbranchsService.selectDeptTree(jsonObject.getInt("id"));
                JSONArray jsonArray1 = new JSONArray();
                for (int j = 0; j < deptList.size(); j++) {
                    JSONObject jsonObject1 = new JSONObject();
                    jsonObject1.put("id", deptList.get(j).get("id"));
                    jsonObject1.put("dataName", deptList.get(j).get("dataName"));
                    jsonObject1.put("sub", deptList.get(j).get("sub"));
                    jsonObject1.put("level", 2);
                    if (!deptList.get(j).get("sub").equals("0")) {
                        List<HashMap<String, Object>> personList = bbranchsService.selectPersonTree(jsonObject1.getInt("id"));
                        JSONArray jsonArray2 = new JSONArray();
                        for (int k = 0; k < personList.size(); k++) {
                            JSONObject jsonObject2 = new JSONObject();
                            jsonObject2.put("id", personList.get(k).get("id"));
                            jsonObject2.put("dataName", personList.get(k).get("dataName"));
                            jsonObject2.put("level", 3);
                            jsonArray2.put( jsonObject2);
                        }
                        jsonObject1.put("children", jsonArray2);
                    }
                    jsonArray1.put(jsonObject1);
                }
                jsonObject.put("children", jsonArray1);
            }
            jsonArray.put(jsonObject);
        }

        return jsonArray.toString();
    }

    @Override
    public Map<String, Object> homeGetBranchs(SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        List<Bbranchs> bbranchs = new ArrayList<>();
        EntityWrapper<Bbranchs> bbranchsEntityWrapper = new EntityWrapper<>();
        if (Objects.equals(sysUserDto.getLoginContractorId(), 1) || Objects.equals(sysUserDto.getContractorId(), 1)) {
            bbranchsEntityWrapper.setSqlSelect("id", "c_name");
            bbranchs = bbranchsService.selectList(bbranchsEntityWrapper);
        } else {
            bbranchsEntityWrapper.setSqlSelect("id", "c_name").eq("id", sysUserDto.getLoginContractorId());
            Bbranchs branch = bbranchsService.selectOne(bbranchsEntityWrapper);
            if (branch != null) {
                bbranchs.add(branch);
            }
        }
        map.put("branchs", bbranchs);
        return map;
    }
}
