
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.budget.biz.entity.ProjectBillsBudgets;
import io.platform.budget.biz.service.ProjectBillsBudgetsService;
import io.platform.engineering.biz.entity.Bbranchs;
import io.platform.engineering.biz.entity.Bbudgets;
import io.platform.engineering.biz.entity.BcorpTypes;
import io.platform.engineering.biz.entity.BpayPropertys;
import io.platform.engineering.biz.service.BbudgetsService;
import io.platform.engineering.dto.BbudgetsDto;
import io.platform.engineering.service.client.api.BbudgetsServiceClient;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.project.biz.entity.Projectbills;
import io.platform.project.biz.service.ProjectbillsService;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BbudgetsServiceClientImpl extends BaseServiceClient<Bbudgets, BbudgetsDto> implements BbudgetsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BbudgetsService bbudgetsService;
    @Resource
    private ProjectBillsBudgetsService projectBillsBudgetsService;

    @Override
    public BbudgetsDto queryObject(Long id) {
        Bbudgets bbudgets = bbudgetsService.selectById(id);
        BbudgetsDto bbudgetsDto = new BbudgetsDto();
        BeanUtils.copyProperties(bbudgets, bbudgetsDto);
        return bbudgetsDto;
    }

    @Override
    public List<BbudgetsDto> queryList(Map<String, Object> map) {
        List<Bbudgets> bbudgetsList = bbudgetsService.selectByMap(map);
        return convertList(bbudgetsList, BbudgetsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<Bbudgets> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bbudgetsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BbudgetsDto bbudgetsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bbudgets bbudgets = new Bbudgets();
            revert(bbudgetsDto, bbudgets);

            EntityWrapper<Bbudgets> wrapper = new EntityWrapper<>();
            wrapper.eq("budget_name", bbudgets.getBudgetName());
            List<Bbudgets> list = bbudgetsService.selectList(wrapper);
            if (list.size() > 0) {
                result.addErrorMessage("费用项目名称已存在。");
                return result;
            }

            boolean flag = bbudgetsService.insert(bbudgets);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BbudgetsDto bbudgetsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bbudgets bbudgets = new Bbudgets();
            revert(bbudgetsDto, bbudgets);

            EntityWrapper<Bbudgets> wrapper = new EntityWrapper<>();
            wrapper.eq("budget_name", bbudgets.getBudgetName());
            List<Bbudgets> list = bbudgetsService.selectList(wrapper);
            if (list.size() > 0) {
                if (list.size() == 1 && (list.get(0).getId() + "").equals(bbudgets.getId() + "")) {

                } else {
                    result.addErrorMessage("费用项目名称已存在。");
                    return result;
                }
            }

            boolean flag = bbudgetsService.updateById(bbudgets);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bbudgetsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<ProjectBillsBudgets> wrapper = new EntityWrapper<>();
            wrapper.eq("budget_id", id);
            if (projectBillsBudgetsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,预算项目已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bbudgetsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BbudgetsDto> getPage(Page<BbudgetsDto> pageDto, BbudgetsDto bbudgetsDto) {
        Page<Bbudgets> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        Bbudgets bbudgets = new Bbudgets();
        revert(bbudgetsDto, bbudgets);
        EntityWrapper<Bbudgets> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bbudgets);
        if (bbudgets.getBudgetNo() != null) {
            wrapper.like("budget_no", "%" + bbudgets.getBudgetNo() + "%");
            bbudgets.setBudgetNo(null);
        }
        if (bbudgets.getBudgetName() != null) {
            wrapper.like("budget_name", "%" + bbudgets.getBudgetName() + "%");
            bbudgets.setBudgetName(null);
        }
        page = bbudgetsService.selectPage(page, wrapper);
        List<BbudgetsDto> bbudgetsDtoList = convertList(page.getRecords(), BbudgetsDto.class);
        pageDto.setTotal(bbudgetsService.selectCount(wrapper));
        pageDto.setRecords(bbudgetsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryBudget(Page page, BbudgetsDto bbudgetsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bbudgetsDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<Bbudgets> bbudgetsEntityWrapper = new EntityWrapper<>();
            if (bbudgetsDto.getId() != null && bbudgetsDto.getId() != 0) {
                bbudgetsEntityWrapper.eq("id", bbudgetsDto.getId());
            }
            if (bbudgetsDto.getStatus() != null && !bbudgetsDto.getStatus().equals("")) {
                bbudgetsEntityWrapper.eq("status", bbudgetsDto.getStatus());
            }
            if (bbudgetsDto.getBudgetNo() != null && !bbudgetsDto.getBudgetNo().equals("")) {
                bbudgetsEntityWrapper.like("budget_no", "%" + bbudgetsDto.getBudgetNo() + "%");
            }
            if (bbudgetsDto.getBudgetName() != null && !bbudgetsDto.getBudgetName().equals("")) {
                bbudgetsEntityWrapper.like("budget_name", "%" + bbudgetsDto.getBudgetName() + "%");
            }
            if (bbudgetsDto.getOpUserName() != null && !bbudgetsDto.getOpUserName().equals("")) {
                bbudgetsEntityWrapper.like("op_user_name", "%" + bbudgetsDto.getOpUserName() + "%");
            }
            int number = bbudgetsService.selectCount(bbudgetsEntityWrapper);
            if (number > 0) {
                bbudgetsEntityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<Bbudgets> bbudgets = bbudgetsService.selectList(bbudgetsEntityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bbudgets);
                map.put("page", pageDto);
                return map;
            }
            return null;
        }
        return null;
    }


    /*
     * 暂用！！！！！！！！！！！！！！！暂用！！！！！！！！！！
     */
    @Override
    public Map<String, Object> zYQueryBudgetId(InvoiceBillsDto invoiceBillsDto) {
        Map<String, Object> map = new HashMap<>();
        EntityWrapper<ProjectBillsBudgets> entityWrapper = new EntityWrapper<>();
        entityWrapper.eq("project_sub_no", invoiceBillsDto.getProjectSubNo())
                .eq("budget_id", invoiceBillsDto.getBudgetId());
        ProjectBillsBudgets billsBudgets = projectBillsBudgetsService.selectOne(entityWrapper);
        if (billsBudgets != null) {
            map.put("proBudget", billsBudgets);
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> selectBudgets(BbudgetsDto bbudgetsDto) {
        Map<String, Object> map = new HashMap<>();
        EntityWrapper<Bbudgets> entityWrapper = new EntityWrapper<>();
        if (bbudgetsDto.getRemarks() != null && bbudgetsDto.getRemarks().equals("renewPro")) {
            entityWrapper.setSqlSelect("id", "budget_name").ne("id", 1);
            List<Bbudgets> bbranch = bbudgetsService.selectList(entityWrapper);
            if (bbranch != null) {
                map.put("budgets", bbranch);
                return map;
            }
        }
        if (bbudgetsDto.getId() != null) {
            entityWrapper.setSqlSelect("id", "budget_name").eq("id", bbudgetsDto.getId());
            Bbudgets bbranch = bbudgetsService.selectOne(entityWrapper);
            if (bbranch != null) {
                map.put("budget", bbranch);
                return map;
            }
        }
        entityWrapper.setSqlSelect("id", "budget_name");
        List<Bbudgets> bbudgets = bbudgetsService.selectList(entityWrapper);
        if (bbudgets.size() != 0) {
            map.put("budgets", bbudgets);
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> selectOtherBudgets(BbudgetsDto bbudgetsDto) {
        Map<String, Object> map = new HashMap<>();
        EntityWrapper<Bbudgets> bbudgetsEntityWrapper = new EntityWrapper<>();
        bbudgetsEntityWrapper.ne("id", 1).and().ne("id", 2);
        List<Bbudgets> bbudgets = bbudgetsService.selectList(bbudgetsEntityWrapper);
        if (bbudgets.size() != 0) {
            map.put("budgets", bbudgets);
        }
        return map;
    }
}
