
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.Bbudgets;
import io.platform.engineering.biz.entity.BcorpTypes;
import io.platform.engineering.biz.entity.Bcorps;
import io.platform.engineering.biz.service.BcorpTypesService;
import io.platform.engineering.dto.BcorpTypesDto;
import io.platform.engineering.service.client.api.BcorpTypesServiceClient;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BcorpTypesServiceClientImpl extends BaseServiceClient<BcorpTypes, BcorpTypesDto> implements BcorpTypesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BcorpTypesService bcorpTypesService;

    @Override
    public BcorpTypesDto queryObject(Long id) {
        BcorpTypes bcorpTypes = bcorpTypesService.selectById(id);
        BcorpTypesDto bcorpTypesDto = new BcorpTypesDto();
        BeanUtils.copyProperties(bcorpTypes, bcorpTypesDto);
        return bcorpTypesDto;
    }

    @Override
    public List<BcorpTypesDto> queryList(Map<String, Object> map) {
        List<BcorpTypes> bcorpTypesList = bcorpTypesService.selectByMap(map);
        return convertList(bcorpTypesList, BcorpTypesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BcorpTypes> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bcorpTypesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BcorpTypesDto bcorpTypesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BcorpTypes bcorpTypes = new BcorpTypes();
            revert(bcorpTypesDto, bcorpTypes);
            boolean flag = bcorpTypesService.insert(bcorpTypes);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BcorpTypesDto bcorpTypesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BcorpTypes bcorpTypes = new BcorpTypes();
            revert(bcorpTypesDto, bcorpTypes);

            boolean flag = bcorpTypesService.updateById(bcorpTypes);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bcorpTypesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bcorpTypesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BcorpTypesDto> getPage(Page<BcorpTypesDto> pageDto, BcorpTypesDto bcorpTypesDto) {
        Page<BcorpTypes> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BcorpTypes bcorpTypes = new BcorpTypes();
        revert(bcorpTypesDto, bcorpTypes);
        EntityWrapper<BcorpTypes> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bcorpTypes);
        page = bcorpTypesService.selectPage(page, wrapper);
        List<BcorpTypesDto> bcorpTypesDtoList = convertList(page.getRecords(), BcorpTypesDto.class);
        pageDto.setTotal(bcorpTypesService.selectCount(wrapper));
        pageDto.setRecords(bcorpTypesDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryCorpsType(Page page, BcorpTypesDto bcorpTypesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bcorpTypesDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<BcorpTypes> entityWrapper = new EntityWrapper<>();
            if (bcorpTypesDto.getStatus() != null && !bcorpTypesDto.getStatus().equals("")) {
                entityWrapper.eq("status", bcorpTypesDto.getStatus());
            }
            if (bcorpTypesDto.getCorpTypeNo() != null && !bcorpTypesDto.getCorpTypeNo().equals("")) {
                entityWrapper.like("corp_type_no", "%" + bcorpTypesDto.getCorpTypeNo() + "%");
            }
            if (bcorpTypesDto.getCorpTypeName() != null && !bcorpTypesDto.getCorpTypeName().equals("")) {
                entityWrapper.like("corp_type_name", "%" + bcorpTypesDto.getCorpTypeName() + "%");
            }
            if (bcorpTypesDto.getOpUserName() != null && !bcorpTypesDto.getOpUserName().equals("")) {
                entityWrapper.like("op_user_name", "%" + bcorpTypesDto.getOpUserName() + "%");
            }
            if (bcorpTypesDto.getRemarks() != null && !bcorpTypesDto.getRemarks().equals("")) {
                entityWrapper.like("remarks", "%" + bcorpTypesDto.getRemarks() + "%");
            }
            int number = bcorpTypesService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<BcorpTypes> bcorpTypes = bcorpTypesService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bcorpTypes);
                map.put("page", pageDto);
                return map;
            }
            return null;
        }
        return null;
    }

    @Override
    public Map<String, Object> selectCorpType(BcorpTypesDto bcorpTypesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bcorpTypesDto.getId() != null) {
            EntityWrapper<BcorpTypes> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "corp_type_name").eq("id", bcorpTypesDto.getId());
            BcorpTypes bcorpType = bcorpTypesService.selectOne(entityWrapper);
            if (bcorpType != null) {
                map.put("corpType", bcorpType);
                return map;
            }
        }
        EntityWrapper<BcorpTypes> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "corp_type_name");
        List<BcorpTypes> bcorpTypes = bcorpTypesService.selectList(entityWrapper);
        if (bcorpTypes.size() != 0) {
            map.put("corpTypes", bcorpTypes);
            return map;
        }
        return null;
    }
}
