
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.Bbudgets;
import io.platform.engineering.biz.entity.Bcorps;
import io.platform.engineering.biz.entity.BprojectTypes;
import io.platform.engineering.biz.service.BcorpsService;
import io.platform.engineering.dto.BcorpsDto;
import io.platform.engineering.dto.BprojectTypesDto;
import io.platform.engineering.service.client.api.BcorpsServiceClient;
import io.platform.fileManagement.biz.entity.DataFileOperating;
import io.platform.project.biz.entity.Dictionaries;
import io.platform.project.biz.entity.Projectbills;
import io.platform.project.biz.service.DictionariesService;
import io.platform.project.biz.service.ProjectbillsService;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.beans.Transient;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BcorpsServiceClientImpl extends BaseServiceClient<Bcorps, BcorpsDto> implements BcorpsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BcorpsService bcorpsService;
    @Resource
    private ProjectbillsService projectbillsService;

    @Resource
    private DictionariesService dictionariesService;


    @Override
    public BcorpsDto queryObject(Long id) {
        Bcorps bcorps = bcorpsService.selectById(id);
        BcorpsDto bcorpsDto = new BcorpsDto();
        BeanUtils.copyProperties(bcorps, bcorpsDto);
        return bcorpsDto;
    }

    @Override
    public List<BcorpsDto> queryList(Map<String, Object> map) {
        List<Bcorps> bcorpsList = bcorpsService.selectByMap(map);
        return convertList(bcorpsList, BcorpsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<Bcorps> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bcorpsService.selectCount(ew);
    }

    /**
     * 新增业主单位
     * 1.查询字典中存储业主单位id 号
     * 2.业主类型进行拼接  业主类型 + 单位id
     * 3.保存
     * 4.更新字典表
     *
     * @param bcorpsDto
     * @return
     */
    @Override
    @Transient
    public ExecuteResult<String> save(BcorpsDto bcorpsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bcorps bcorps = new Bcorps();
            revert(bcorpsDto, bcorps);
            //N W类型为必选不能为null
            if (!"".equals(bcorps.getSystemType()) && bcorps.getSystemType() != null) {
                String systemType = null;
                if (1 == bcorpsDto.getSystemType()) {
                    systemType = "N";
                } else {
                    systemType = "W";
                }
                //*  1.查询字典中存储业主单位id 号
                EntityWrapper<Dictionaries> entityWrapper = new EntityWrapper<>();
                entityWrapper.eq("dictionaries_name", "owner_id");
                entityWrapper.eq("dictionaries_value", systemType);
                Dictionaries dictionaries = dictionariesService.selectOne(entityWrapper);
                if (dictionaries != null) {
                    int count = 9999;
                    //2.最大序号值 00x 取非0部分转int+1  00051  51  52
                    int dictionariesValue = dictionaries.getDictionariesNumber();
                    if (dictionariesValue > count) {
                        logger.error("保存失败");
                        result.addErrorMessage("主办单位数量已到最大值!");
                        return result;
                    }
                    int dictionariesValueNow = dictionariesValue + 1;
                    String corpNo = systemType + String.format("%03d", dictionariesValueNow);
                    //3.添加业主类型
                    //设置类型 业主类型 + 单位id
                    bcorps.setOwnerNo(corpNo);
                    EntityWrapper<Bcorps> wrapper = new EntityWrapper<>();
                    wrapper.eq("C_NAME", bcorps.getCname());
                    wrapper.eq("branch_id", bcorps.getBranchId());
                    List<Bcorps> list = bcorpsService.selectList(wrapper);
                    if (list != null && list.size() > 0) {
                        logger.error("保存失败");
                        result.addErrorMessage("单位名称已存在!");
                        return result;
                    }
                    //4.添加
                    boolean flag = bcorpsService.insert(bcorps);
                    if (!flag) {
                        result.addErrorMessage("保存失败。");
                    } else {
                        //成功更新,修改字典值
                        dictionaries.setDictionariesNumber(dictionariesValueNow);
                        boolean b = dictionariesService.updateById(dictionaries);
                    }
                } else {
                    result.addErrorMessage("字典序列‘owner_id’值异常。");
                    return result;
                }
            } else {
                logger.error(" 保存失败");
                result.addErrorMessage("参数异常");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transient
    public ExecuteResult<String> saveList(List<BcorpsDto> bcorpsDtoList) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        int i = 2;
        String str = "第";

        for (BcorpsDto bcorpsDto : bcorpsDtoList) {
            i++;
            try {
                Bcorps bcorps = new Bcorps();
                revert(bcorpsDto, bcorps);
                if (
                        (bcorps.getSystemType() == null)
                                &&
                                (bcorps.getCname() == null || bcorps.getCname().equals(""))
                ) {
                    continue;
                }
                if (bcorps.getSystemType() == null) {
                    str += i + "、";
                    continue;
                }
                if (bcorps.getCname() == null || bcorps.getCname().equals("")) {
                    str += i + "、";
                    continue;
                }
                //N W类型为必选不能为null
                if (!"".equals(bcorps.getSystemType()) && bcorps.getSystemType() != null) {
                    String systemType = null;
                    if (1 == bcorpsDto.getSystemType()) {
                        systemType = "N";
                    } else {
                        systemType = "W";
                    }
                    //*  1.查询字典中存储业主单位id 号
                    EntityWrapper<Dictionaries> entityWrapper = new EntityWrapper<>();
                    entityWrapper.eq("dictionaries_name", "owner_id");
                    entityWrapper.eq("dictionaries_value", systemType);
                    Dictionaries dictionaries = dictionariesService.selectOne(entityWrapper);
                    if (dictionaries != null) {
                        //2.最大序号值 00x 取非0部分转int+1  00051  51  52
                        int dictionariesValue = dictionaries.getDictionariesNumber();
                        if (dictionariesValue > 999) {
                            logger.error("保存失败");
                            str += i + "、";
                            continue;
                        }
                        int dictionariesValueNow = dictionariesValue + 1;
                        String corpNo = systemType + String.format("%03d", dictionariesValueNow);
                        //3.添加业主类型
                        //设置类型 业主类型 + 单位id
                        bcorps.setOwnerNo(corpNo);

                        EntityWrapper<Bcorps> wrapper = new EntityWrapper<>();
                        wrapper.eq("C_NAME", bcorps.getCname());
                        wrapper.eq("branch_id", bcorps.getBranchId());
                        List<Bcorps> list = bcorpsService.selectList(wrapper);
                        if (list != null && list.size() > 0) {
                            logger.error("保存失败");
                            str += i + "、";
                            continue;
                        }

                        //4.添加
                        boolean flag = bcorpsService.insert(bcorps);
                        if (!flag) {
                            str += i + "、";
                        } else {
                            //成功更新,修改字典值
                            dictionaries.setDictionariesNumber(dictionariesValueNow);
                            boolean b = dictionariesService.updateById(dictionaries);
                        }
                    } else {
                        str += i + "、";
                        continue;
                    }
                } else {
                    logger.error(" 保存失败");
                    str += i + "、";
                }
            } catch (Exception e) {
                logger.error(" 保存错误：" + e.toString(), e);
                str += i + "、";
            }


        }
        if (str.equals("第")) {

        } else {
            str = str.substring(0, str.length() - 1);
            str += "行存在错误";
            result.addErrorMessage(str);
        }


        return result;
    }

    @Override
    public ExecuteResult<String> update(BcorpsDto bcorpsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bcorps bcorps = new Bcorps();
            revert(bcorpsDto, bcorps);

            EntityWrapper<Bcorps> wrapper = new EntityWrapper<>();
            wrapper.eq("C_NAME", bcorps.getCname());
            wrapper.eq("branch_id", bcorps.getBranchId());
            List<Bcorps> list = bcorpsService.selectList(wrapper);
            if (list != null && list.size() > 0) {
                if (list.size() == 1 && (list.get(0).getId() + "").equals(bcorps.getId() + "")) {

                } else {
                    logger.error("保存失败");
                    result.addErrorMessage("单位名称已存在!");
                    return result;
                }

            }


            boolean flag = bcorpsService.updateById(bcorps);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bcorpsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<Projectbills> wrapper = new EntityWrapper<>();
            wrapper.eq("corp_id", id);
            if (projectbillsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,业主单位已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bcorpsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BcorpsDto> getPage(Page<BcorpsDto> pageDto, BcorpsDto bcorpsDto, SysUserDto sysUserDto) {
        Page<Bcorps> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        if (sysUserDto.getLoginContractorId() != 1) {
            bcorpsDto.setBranchId(sysUserDto.getLoginContractorId());
        }
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        Bcorps bcorps = new Bcorps();
        revert(bcorpsDto, bcorps);
        EntityWrapper<Bcorps> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bcorps);
        if (bcorps.getCname() != null) {
            wrapper.like("c_name", "%" + bcorps.getCname() + "%");
            bcorps.setCname(null);
        }
        page = bcorpsService.selectPage(page, wrapper);
        List<BcorpsDto> bcorpsDtoList = convertList(page.getRecords(), BcorpsDto.class);
        pageDto.setTotal(bcorpsService.selectCount(wrapper));
        pageDto.setRecords(bcorpsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryCorps(Page page, BcorpsDto bcorpsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bcorpsDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<Bcorps> entityWrapper = new EntityWrapper<>();
            if (bcorpsDto.getOpDate() != null) {
                entityWrapper.eq("op_date", bcorpsDto.getOpDate());
            }
            if (bcorpsDto.getStatus() != null && !bcorpsDto.getStatus().equals("")) {
                entityWrapper.eq("status", bcorpsDto.getStatus());
            }
            if (bcorpsDto.getCorpNo() != null && !bcorpsDto.getCorpNo().equals("")) {
                entityWrapper.like("corp_no", "%" + bcorpsDto.getCorpNo() + "%");
            }
            if (bcorpsDto.getSname() != null && !bcorpsDto.getSname().equals("")) {
                entityWrapper.like("s_name", "%" + bcorpsDto.getSname() + "%");
            }
            if (bcorpsDto.getCname() != null && !bcorpsDto.getCname().equals("")) {
                entityWrapper.like("c_name", "%" + bcorpsDto.getCname() + "%");
            }
            if (bcorpsDto.getCaddr() != null && !bcorpsDto.getCaddr().equals("")) {
                entityWrapper.like("caddr", "%" + bcorpsDto.getCaddr() + "%");
            }
            if (bcorpsDto.getTel() != null && !bcorpsDto.getTel().equals("")) {
                entityWrapper.like("tel", "%" + bcorpsDto.getTel() + "%");
            }
            if (bcorpsDto.getFax() != null && !bcorpsDto.getFax().equals("")) {
                entityWrapper.like("fax", "%" + bcorpsDto.getFax() + "%");
            }
            if (bcorpsDto.getPoStaddr() != null && !bcorpsDto.getPoStaddr().equals("")) {
                entityWrapper.like("po_staddr", "%" + bcorpsDto.getPoStaddr() + "%");
            }
            if (bcorpsDto.getManAger() != null && !bcorpsDto.getManAger().equals("")) {
                entityWrapper.like("man_ager", "%" + bcorpsDto.getManAger() + "%");
            }
            if (bcorpsDto.getManAgerTel() != null && !bcorpsDto.getManAgerTel().equals("")) {
                entityWrapper.like("man_ager_tel", "%" + bcorpsDto.getManAgerTel() + "%");
            }
            if (bcorpsDto.getAttn() != null && !bcorpsDto.getAttn().equals("")) {
                entityWrapper.like("attn", "%" + bcorpsDto.getAttn() + "%");
            }
            if (bcorpsDto.getAttnTel() != null && !bcorpsDto.getAttnTel().equals("")) {
                entityWrapper.like("attn_tel", "%" + bcorpsDto.getAttnTel() + "%");
            }
            if (bcorpsDto.getTaxNo() != null && !bcorpsDto.getTaxNo().equals("")) {
                entityWrapper.like("tax_no", "%" + bcorpsDto.getTaxNo() + "%");
            }
            if (bcorpsDto.getOpUserName() != null && !bcorpsDto.getOpUserName().equals("")) {
                entityWrapper.like("op_user_name", "%" + bcorpsDto.getOpUserName() + "%");
            }
            int number = bcorpsService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<Bcorps> bcorps = bcorpsService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bcorps);
                map.put("page", pageDto);
                return map;
            }
            return null;
        }
        return null;
    }

    @Override
    public Map<String, Object> selectCorps(BcorpsDto bcorpsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bcorpsDto.getId() != null) {
            EntityWrapper<Bcorps> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "c_name");
            if (bcorpsDto.getBranchId() != 1) {
                entityWrapper.eq("id", bcorpsDto.getId());
            }
            Bcorps corp = bcorpsService.selectOne(entityWrapper);
            if (corp != null) {
                map.put("corp", corp);
                return map;
            }
        }
        EntityWrapper<Bcorps> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "c_name");
        if (bcorpsDto.getBranchId() != 1) {
            entityWrapper.eq("branch_id", bcorpsDto.getBranchId());
        }
        List<Bcorps> bcorps = bcorpsService.selectList(entityWrapper);
        if (bcorps.size() != 0) {
            map.put("corps", bcorps);
            return map;
        }
        return null;
    }
}
