
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.Bbranchs;
import io.platform.engineering.biz.entity.Bdepts;
import io.platform.engineering.biz.service.BdeptsService;
import io.platform.engineering.dto.BdeptsDto;
import io.platform.engineering.service.client.api.BdeptsServiceClient;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BdeptsServiceClientImpl extends BaseServiceClient<Bdepts, BdeptsDto> implements BdeptsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BdeptsService bdeptsService;
    @Resource
    private SysUserService sysUserService;

    @Override
    public BdeptsDto queryObject(Long id) {
        Bdepts bdepts = bdeptsService.selectById(id);
        BdeptsDto bdeptsDto = new BdeptsDto();
        BeanUtils.copyProperties(bdepts, bdeptsDto);
        return bdeptsDto;
    }

    @Override
    public List<BdeptsDto> queryList(Map<String, Object> map) {
        List<Bdepts> bdeptsList = bdeptsService.selectByMap(map);
        return convertList(bdeptsList, BdeptsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<Bdepts> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bdeptsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BdeptsDto bdeptsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bdepts bdepts = new Bdepts();
            revert(bdeptsDto, bdepts);
            boolean flag = bdeptsService.insert(bdepts);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BdeptsDto bdeptsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bdepts bdepts = new Bdepts();
            revert(bdeptsDto, bdepts);

            boolean flag = bdeptsService.updateById(bdepts);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bdeptsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bdeptsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BdeptsDto> getPage(Page<BdeptsDto> pageDto, BdeptsDto bdeptsDto) {
        Page<Bdepts> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        Bdepts bdepts = new Bdepts();
        revert(bdeptsDto, bdepts);
        EntityWrapper<Bdepts> wrapper = new EntityWrapper<>();
//        wrapper.setEntity(bdepts);
        wrapper.like("dept_no", bdepts.getDeptNo());
        wrapper.like("dept_name", bdepts.getDeptName());
        wrapper.like("manager_tel", bdepts.getManagerTel());
//        if (bdepts.getBranchId() != null && bdepts.getBranchId() != 1) {
            wrapper.eq("branch_id", bdepts.getBranchId());
//        }

        page = bdeptsService.selectPage(page, wrapper);
        List<BdeptsDto> bdeptsDtoList = convertList(page.getRecords(), BdeptsDto.class);
        pageDto.setTotal(bdeptsService.selectCount(wrapper));
        pageDto.setRecords(bdeptsDtoList);
        return pageDto;
    }


    @Override
    public Map<String, Object> selectDepts(BdeptsDto bdeptsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bdeptsDto.getId() != null) {
            EntityWrapper<Bdepts> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "dept_name").eq("id", bdeptsDto.getId());
            entityWrapper.eq("branch_Id",bdeptsDto.getBranchId());
            Bdepts bdept = bdeptsService.selectOne(entityWrapper);
            if (bdept != null) {
                map.put("dept", bdept);
                return map;
            }
        }
        EntityWrapper<Bdepts> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "dept_name");
        if (bdeptsDto.getBranchId() != 1) {
            entityWrapper.eq("branch_id", bdeptsDto.getBranchId());
        }
        List<Bdepts> bdeptsList = bdeptsService.selectList(entityWrapper);
        if (bdeptsList.size() != 0) {
            map.put("depts", bdeptsList);
            return map;
        }
        return null;
    }
}
