
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.Bdepts;
import io.platform.engineering.biz.entity.Bempls;
import io.platform.engineering.biz.service.BdeptsService;
import io.platform.engineering.biz.service.BemplsService;
import io.platform.engineering.dto.BemplsDto;
import io.platform.engineering.service.client.api.BemplsServiceClient;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BemplsServiceClientImpl extends BaseServiceClient<Bempls, BemplsDto> implements BemplsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BemplsService bemplsService;
    @Resource
    private BdeptsService bdeptsService;

    @Override
    public BemplsDto queryObject(Long id) {
        Bempls bempls = bemplsService.selectById(id);
        BemplsDto bemplsDto = new BemplsDto();
        BeanUtils.copyProperties(bempls, bemplsDto);
        return bemplsDto;
    }

    @Override
    public List<BemplsDto> queryList(Map<String, Object> map) {
        List<Bempls> bemplsList = bemplsService.selectByMap(map);
        return convertList(bemplsList, BemplsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<Bempls> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bemplsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BemplsDto bemplsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bempls bempls = new Bempls();
            revert(bemplsDto, bempls);
            boolean flag = bemplsService.insert(bempls);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BemplsDto bemplsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bempls bempls = new Bempls();
            revert(bemplsDto, bempls);

            boolean flag = bemplsService.updateById(bempls);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bemplsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bemplsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BemplsDto> getPage(Page<BemplsDto> pageDto, BemplsDto bemplsDto) {
        Page<Bempls> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        Bempls bempls = new Bempls();
        revert(bemplsDto, bempls);
        EntityWrapper<Bempls> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bempls);
        page = bemplsService.selectPage(page, wrapper);
        List<BemplsDto> bemplsDtoList = convertList(page.getRecords(), BemplsDto.class);
        pageDto.setTotal(bemplsService.selectCount(wrapper));
        pageDto.setRecords(bemplsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryEmpls(Page page, BemplsDto bemplsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bemplsDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<Bempls> entityWrapper = new EntityWrapper<>();
            if (bemplsDto.getDeptId() != null) {
                entityWrapper.eq("dept_id", bemplsDto.getDeptId());
            }
            if (bemplsDto.getBranchId() != null) {
                entityWrapper.eq("branch_id", bemplsDto.getBranchId());
            }
            if (bemplsDto.getGender() != null) {
                entityWrapper.eq("gender", bemplsDto.getGender());
            }
            if (bemplsDto.getStatus() != null) {
                entityWrapper.eq("status", bemplsDto.getStatus());
            }
            if (bemplsDto.getEmplNo() != null && !bemplsDto.getEmplNo().equals("")) {
                entityWrapper.like("empl_no", "%" + bemplsDto.getEmplNo() + "%");
            }
            if (bemplsDto.getEmplName() != null && !bemplsDto.getEmplName().equals("")) {
                entityWrapper.like("empl_name", "%" + bemplsDto.getEmplName() + "%");
            }
            if (bemplsDto.getRemarks() != null && !bemplsDto.getRemarks().equals("")) {
                entityWrapper.like("remarks", "%" + bemplsDto.getRemarks() + "%");
            }
            int number = bemplsService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<Bempls> bempls = bemplsService.selectList(entityWrapper);
                List<Integer> deptId = new ArrayList<>();
                for (Bempls em : bempls) {
                    if (em.getDeptId() != null && em.getDeptId() !=0) {
                        deptId.add(em.getDeptId());
                    }
                }
                List<Integer> integers = DataUtils.integerDeduplication(deptId);
                List<Bdepts> bdeptsList = new ArrayList<>();
                for (Integer i : integers) {
                    EntityWrapper<Bdepts> bdeptsEntityWrapper = new EntityWrapper<>();
                    bdeptsEntityWrapper.setSqlSelect("id", "dept_name").eq("id", i);
                    Bdepts bdepts = bdeptsService.selectOne(bdeptsEntityWrapper);
                    bdeptsList.add(bdepts);
                }
                if (bdeptsList.size() != 0) {
                    map.put("depts", bdeptsList);
                }
                pageDto.setTotal(number);
                pageDto.setRecords(bempls);
                map.put("page", pageDto);
                return map;
            }
            return null;
        }
        return null;
    }
}
