
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.Bempls;
import io.platform.engineering.biz.entity.BpayPropertys;
import io.platform.engineering.biz.entity.BpriceModes;
import io.platform.engineering.biz.service.BpayPropertysService;
import io.platform.engineering.dto.BemplsDto;
import io.platform.engineering.dto.BpayPropertysDto;
import io.platform.engineering.service.client.api.BpayPropertysServiceClient;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BpayPropertysServiceClientImpl extends BaseServiceClient<BpayPropertys, BpayPropertysDto> implements BpayPropertysServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BpayPropertysService bpayPropertysService;

    @Override
    public BpayPropertysDto queryObject(Long id) {
        BpayPropertys bpayPropertys = bpayPropertysService.selectById(id);
        BpayPropertysDto bpayPropertysDto = new BpayPropertysDto();
        BeanUtils.copyProperties(bpayPropertys, bpayPropertysDto);
        return bpayPropertysDto;
    }

    @Override
    public List<BpayPropertysDto> queryList(Map<String, Object> map) {
        List<BpayPropertys> bpayPropertysList = bpayPropertysService.selectByMap(map);
        return convertList(bpayPropertysList, BpayPropertysDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BpayPropertys> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bpayPropertysService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BpayPropertysDto bpayPropertysDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpayPropertys bpayPropertys = new BpayPropertys();
            revert(bpayPropertysDto, bpayPropertys);

            EntityWrapper<BpayPropertys> wrapper = new EntityWrapper<>();
            wrapper.eq("pay_property_name", bpayPropertys.getPayPropertyName());
            List<BpayPropertys> list = bpayPropertysService.selectList(wrapper);
            if (list.size() > 0) {
                result.addErrorMessage("款项性质名称已存在。");
                return result;
            }

            boolean flag = bpayPropertysService.insert(bpayPropertys);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BpayPropertysDto bpayPropertysDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpayPropertys bpayPropertys = new BpayPropertys();
            revert(bpayPropertysDto, bpayPropertys);


            EntityWrapper<BpayPropertys> wrapper = new EntityWrapper<>();
            wrapper.eq("pay_property_name", bpayPropertys.getPayPropertyName());
            List<BpayPropertys> list = bpayPropertysService.selectList(wrapper);
            if (list.size() > 0) {
                if (list.size() == 1 && list.get(0).getId() == bpayPropertys.getId()) {

                } else {
                    result.addErrorMessage("款项性质名称已存在。");
                    return result;
                }
            }

            boolean flag = bpayPropertysService.updateById(bpayPropertys);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bpayPropertysService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bpayPropertysService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BpayPropertysDto> getPage(Page<BpayPropertysDto> pageDto, BpayPropertysDto bpayPropertysDto) {
        Page<BpayPropertys> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BpayPropertys bpayPropertys = new BpayPropertys();
        revert(bpayPropertysDto, bpayPropertys);
        EntityWrapper<BpayPropertys> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bpayPropertys);
        page = bpayPropertysService.selectPage(page, wrapper);
        List<BpayPropertysDto> bpayPropertysDtoList = convertList(page.getRecords(), BpayPropertysDto.class);
        pageDto.setTotal(bpayPropertysService.selectCount(wrapper));
        pageDto.setRecords(bpayPropertysDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryPayProperty(Page page, BpayPropertysDto bpayPropertysDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpayPropertysDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<BpayPropertys> entityWrapper = new EntityWrapper<>();
            if (bpayPropertysDto.getStatus() != null) {
                entityWrapper.eq("status", bpayPropertysDto.getStatus());
            }
            if (bpayPropertysDto.getPayPropertyName() != null && !bpayPropertysDto.getPayPropertyName().equals("")) {
                entityWrapper.like("pay_property_name", "%" + bpayPropertysDto.getPayPropertyName() + "%");
            }
            if (bpayPropertysDto.getOpUserName() != null && !bpayPropertysDto.getOpUserName().equals("")) {
                entityWrapper.like("opUserName", "%" + bpayPropertysDto.getOpUserName() + "%");
            }
            int number = bpayPropertysService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<BpayPropertys> bpayPropertys = bpayPropertysService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bpayPropertys);
            }
            map.put("page", pageDto);
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> selectPayPropertys(BpayPropertysDto bpayPropertysDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpayPropertysDto.getId() != null) {
            EntityWrapper<BpayPropertys> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "pay_property_name").eq("id", bpayPropertysDto.getId());
            BpayPropertys bpayProperty = bpayPropertysService.selectOne(entityWrapper);
            if (bpayProperty != null) {
                map.put("payProperty", bpayProperty);
                return map;
            }
        }
        EntityWrapper<BpayPropertys> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "pay_property_name");
        List<BpayPropertys> bpriceModesList = bpayPropertysService.selectList(entityWrapper);
        if (bpriceModesList.size() != 0) {
            map.put("payPropertys", bpriceModesList);
            return map;
        }
        return null;
    }
}
