
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.BpriceModes;
import io.platform.engineering.biz.entity.BprojectNodes;
import io.platform.engineering.biz.entity.BprojectTypes;
import io.platform.engineering.biz.service.BpriceModesService;
import io.platform.engineering.dto.BpriceModesDto;
import io.platform.engineering.service.client.api.BpriceModesServiceClient;
import io.platform.project.biz.entity.Projectbills;
import io.platform.project.biz.service.ProjectbillsService;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BpriceModesServiceClientImpl extends BaseServiceClient<BpriceModes, BpriceModesDto> implements BpriceModesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BpriceModesService bpriceModesService;
    @Resource
    private ProjectbillsService projectbillsService;

    @Override
    public BpriceModesDto queryObject(Long id) {
        BpriceModes bpriceModes = bpriceModesService.selectById(id);
        BpriceModesDto bpriceModesDto = new BpriceModesDto();
        BeanUtils.copyProperties(bpriceModes, bpriceModesDto);
        return bpriceModesDto;
    }

    @Override
    public List<BpriceModesDto> queryList(Map<String, Object> map) {
        List<BpriceModes> bpriceModesList = bpriceModesService.selectByMap(map);
        return convertList(bpriceModesList, BpriceModesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BpriceModes> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bpriceModesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BpriceModesDto bpriceModesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpriceModes bpriceModes = new BpriceModes();
            revert(bpriceModesDto, bpriceModes);

            EntityWrapper<BpriceModes> wrapper = new EntityWrapper<>();
            wrapper.eq("price_mode_name", bpriceModes.getPriceModeName());
            List<BpriceModes> list = bpriceModesService.selectList(wrapper);
            if (list.size() > 0) {
                result.addErrorMessage("价款确定名称已存在。");
                return result;
            }

            boolean flag = bpriceModesService.insert(bpriceModes);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BpriceModesDto bpriceModesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpriceModes bpriceModes = new BpriceModes();
            revert(bpriceModesDto, bpriceModes);

            EntityWrapper<BpriceModes> wrapper = new EntityWrapper<>();
            wrapper.eq("price_mode_name", bpriceModes.getPriceModeName());
            List<BpriceModes> list = bpriceModesService.selectList(wrapper);
            if (list.size() > 0) {
                if (list.size() == 1 && (list.get(0).getId() + "").equals(bpriceModes.getId() + "")) {
                } else {
                    result.addErrorMessage("价款确定名称已存在。");
                    return result;
                }
            }

            boolean flag = bpriceModesService.updateById(bpriceModes);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bpriceModesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<Projectbills> wrapper = new EntityWrapper<>();
            wrapper.eq("price_mode_id", id);
            if (projectbillsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,价款方式已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bpriceModesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BpriceModesDto> getPage(Page<BpriceModesDto> pageDto, BpriceModesDto bpriceModesDto) {
        Page<BpriceModes> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BpriceModes bpriceModes = new BpriceModes();
        revert(bpriceModesDto, bpriceModes);
        EntityWrapper<BpriceModes> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bpriceModes);
        if (bpriceModes.getPriceModeNo() != null) {
            wrapper.like("price_mode_no", "%" + bpriceModes.getPriceModeNo() + "%");
            bpriceModes.setPriceModeNo(null);
        }
        if (bpriceModes.getPriceModeName() != null) {
            wrapper.like("price_mode_name", "%" + bpriceModes.getPriceModeName() + "%");
            bpriceModes.setPriceModeName(null);
        }
        page = bpriceModesService.selectPage(page, wrapper);
        List<BpriceModesDto> bpriceModesDtoList = convertList(page.getRecords(), BpriceModesDto.class);
        pageDto.setTotal(bpriceModesService.selectCount(wrapper));
        pageDto.setRecords(bpriceModesDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryPriceModes(Page page, BpriceModesDto bpriceModesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpriceModesDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<BpriceModes> entityWrapper = new EntityWrapper<>();
            if (bpriceModesDto.getOpDate() != null) {
                entityWrapper.eq("op_date", bpriceModesDto.getOpDate());
            }
            if (bpriceModesDto.getPriceModeId() != null && bpriceModesDto.getPriceModeId() != 0) {
                entityWrapper.eq("price_mode_id", bpriceModesDto.getPriceModeId());
            }
            if (bpriceModesDto.getStatus() != null && !bpriceModesDto.getStatus().equals("")) {
                entityWrapper.eq("status", bpriceModesDto.getStatus());
            }
            if (bpriceModesDto.getPriceModeName() != null && !bpriceModesDto.getPriceModeName().equals("")) {
                entityWrapper.like("price_mode_name", "%" + bpriceModesDto.getPriceModeName() + "%");
            }
            if (bpriceModesDto.getOpUserName() != null && !bpriceModesDto.getOpUserName().equals("")) {
                entityWrapper.like("op_user_name", "%" + bpriceModesDto.getOpUserName() + "%");
            }
            if (bpriceModesDto.getRemarks() != null && !bpriceModesDto.getRemarks().equals("")) {
                entityWrapper.like("remarks", "%" + bpriceModesDto.getRemarks() + "%");
            }
            int number = bpriceModesService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<BpriceModes> bpriceModes = bpriceModesService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bpriceModes);
                map.put("page", pageDto);
                return map;
            }
            return null;
        }
        return null;
    }

    @Override
    public Map<String, Object> selectProModes(BpriceModesDto bpriceModesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpriceModesDto.getId() != null) {
            EntityWrapper<BpriceModes> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "price_mode_name").eq("id", bpriceModesDto.getId());
            BpriceModes bpriceModes = bpriceModesService.selectOne(entityWrapper);
            if (bpriceModes != null) {
                map.put("priceMode", bpriceModes);
                return map;
            }
        }
        EntityWrapper<BpriceModes> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "price_mode_name");
        List<BpriceModes> bpriceModesList = bpriceModesService.selectList(entityWrapper);
        if (bpriceModesList.size() != 0) {
            map.put("priceModes", bpriceModesList);
            return map;
        }
        return null;
    }
}
