
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.BprojectNodeSteps;
import io.platform.engineering.biz.entity.BprojectNodes;
import io.platform.engineering.biz.service.BprojectNodeStepsService;
import io.platform.engineering.biz.service.BprojectNodesService;
import io.platform.engineering.dto.BprojectNodeStepsDto;
import io.platform.engineering.dto.BprojectNodesDto;
import io.platform.engineering.service.client.api.BprojectNodeStepsServiceClient;
import io.platform.progressConfiguration.biz.entity.ProjectNodeNexusItem;
import io.platform.progressConfiguration.biz.service.ProjectNodeNexusItemService;
import io.platform.project.biz.entity.ProjectBillsSteps;
import io.platform.project.biz.service.ProjectBillsStepsService;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BprojectNodeStepsServiceClientImpl extends BaseServiceClient<BprojectNodeSteps, BprojectNodeStepsDto> implements BprojectNodeStepsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BprojectNodesService bprojectNodesService;
    @Resource
    private BprojectNodeStepsService bprojectNodeStepsService;
    @Resource
    private ProjectNodeNexusItemService projectNodeNexusItemService;
    @Resource
    private ProjectBillsStepsService projectBillsStepsService;

    @Override
    public BprojectNodeStepsDto queryObject(Long id) {
        BprojectNodeSteps bprojectNodeSteps = bprojectNodeStepsService.selectById(id);
        BprojectNodeStepsDto bprojectNodeStepsDto = new BprojectNodeStepsDto();
        BeanUtils.copyProperties(bprojectNodeSteps, bprojectNodeStepsDto);
        return bprojectNodeStepsDto;
    }

    @Override
    public List<BprojectNodeStepsDto> queryList(Map<String, Object> map) {
        List<BprojectNodeSteps> bprojectNodeStepsList = bprojectNodeStepsService.selectByMap(map);
        return convertList(bprojectNodeStepsList, BprojectNodeStepsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BprojectNodeSteps> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bprojectNodeStepsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BprojectNodeStepsDto bprojectNodeStepsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (bprojectNodeStepsDto.getSortNum() != null) {
                EntityWrapper<BprojectNodeSteps> entityWrapper = new EntityWrapper<>();
                entityWrapper.eq("branch_id", bprojectNodeStepsDto.getBranchId()).eq("sort_num", bprojectNodeStepsDto.getSortNum());
                BprojectNodeSteps bp = bprojectNodeStepsService.selectOne(entityWrapper);
                if (bp != null) {
                    result.addErrorMessage("排序值已被占用");
                    return result;
                }
                BprojectNodeSteps bprojectNodeSteps = new BprojectNodeSteps();
                revert(bprojectNodeStepsDto, bprojectNodeSteps);

                EntityWrapper<BprojectNodeSteps> wrapper = new EntityWrapper<>();
                wrapper.eq("project_step_name", bprojectNodeSteps.getProjectStepName());
                wrapper.eq("branch_id", bprojectNodeSteps.getBranchId());
                List<BprojectNodeSteps> list = bprojectNodeStepsService.selectList(wrapper);
                if (list.size() > 0) {
                    result.addErrorMessage("工程步骤名称已存在。");
                    return result;
                }


                boolean flag = bprojectNodeStepsService.insertOrUpdate(bprojectNodeSteps);
                if (!flag) {
                    result.addErrorMessage("保存失败。");
                }
            } else {
                result.addErrorMessage("请维护排序值");
                return result;
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BprojectNodeStepsDto bprojectNodeStepsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BprojectNodeSteps bprojectNodeSteps = new BprojectNodeSteps();
            revert(bprojectNodeStepsDto, bprojectNodeSteps);

            EntityWrapper<BprojectNodeSteps> wrapper = new EntityWrapper<>();
            wrapper.eq("project_step_name", bprojectNodeSteps.getProjectStepName());
            wrapper.eq("branch_id", bprojectNodeSteps.getBranchId());
            List<BprojectNodeSteps> list = bprojectNodeStepsService.selectList(wrapper);
            if (list.size() > 0) {
                if (list.size() == 1 && (list.get(0).getId() + "").equals(bprojectNodeSteps.getId() + "")) {

                } else {
                    result.addErrorMessage("工程步骤名称已存在。");
                    return result;
                }
            }
            boolean flag = bprojectNodeStepsService.updateById(bprojectNodeSteps);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bprojectNodeStepsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<ProjectBillsSteps> wrapper = new EntityWrapper<>();
            wrapper.eq("project_step_id", id);
            if (projectBillsStepsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,工程步骤已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bprojectNodeStepsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    //根据排序字段排序
    @Override
    public Page<BprojectNodeStepsDto> getPage(Page<BprojectNodeStepsDto> pageDto, BprojectNodeStepsDto bprojectNodeStepsDto) {
        Page<BprojectNodeSteps> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BprojectNodeSteps bprojectNodeSteps = new BprojectNodeSteps();
        revert(bprojectNodeStepsDto, bprojectNodeSteps);
        EntityWrapper<BprojectNodeSteps> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bprojectNodeSteps);
        if (bprojectNodeSteps.getBranchId() != null && bprojectNodeSteps.getBranchId() != 1) {
            wrapper.eq("branch_id", bprojectNodeSteps.getBranchId());
        }
        if (bprojectNodeSteps.getProjectStepNo() != null) {
            wrapper.like("project_step_no", "%" + bprojectNodeSteps.getProjectStepNo() + "%");
            bprojectNodeSteps.setProjectStepNo(null);
        }
        if (bprojectNodeSteps.getProjectStepName() != null) {
            wrapper.like("project_step_name", "%" + bprojectNodeSteps.getProjectStepName() + "%");
            bprojectNodeSteps.setProjectStepName(null);
        }
        wrapper.orderBy("sort_num");
        page = bprojectNodeStepsService.selectPage(page, wrapper);
        List<BprojectNodeStepsDto> bprojectNodeStepsDtoList = convertList(page.getRecords(), BprojectNodeStepsDto.class);
        pageDto.setTotal(bprojectNodeStepsService.selectCount(wrapper));
        pageDto.setRecords(bprojectNodeStepsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryProjectNodeSt(Page page, BprojectNodeStepsDto bprojectNodeStepsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bprojectNodeStepsDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<BprojectNodeSteps> entityWrapper = new EntityWrapper<>();
            if (bprojectNodeStepsDto.getProjectNodeId() != null && bprojectNodeStepsDto.getProjectNodeId() != 0) {
                entityWrapper.eq("project_node_id", bprojectNodeStepsDto.getProjectNodeId());
            }
            if (bprojectNodeStepsDto.getStatus() != null && !bprojectNodeStepsDto.getStatus().equals("")) {
                entityWrapper.eq("status", bprojectNodeStepsDto.getStatus());
            }
            if (bprojectNodeStepsDto.getProjectStepNo() != null && !bprojectNodeStepsDto.getProjectStepNo().equals("")) {
                entityWrapper.like("project_step_no", "%" + bprojectNodeStepsDto.getProjectStepNo() + "%");
            }
            if (bprojectNodeStepsDto.getProjectStepName() != null && !bprojectNodeStepsDto.getProjectStepName().equals("")) {
                entityWrapper.like("project_step_name", "%" + bprojectNodeStepsDto.getProjectStepName() + "%");
            }
            int number = bprojectNodeStepsService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<BprojectNodeSteps> bprojectNodes = bprojectNodeStepsService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bprojectNodes);
                map.put("page", pageDto);
                return map;
            }
        }
        return null;
    }

    @Override
    public Map<String, Object> selectProNodeSteps(BprojectNodeStepsDto bprojectNodeStepsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bprojectNodeStepsDto.getId() != null) {
            EntityWrapper<BprojectNodeSteps> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "project_step_no", "project_step_name", "project_node_id").eq("id", bprojectNodeStepsDto.getId());
            BprojectNodeSteps bprojectNodeSteps = bprojectNodeStepsService.selectOne(entityWrapper);
            if (bprojectNodeSteps != null) {
                EntityWrapper<BprojectNodes> bprojectNodeStepsEntityWrapper = new EntityWrapper<>();
                bprojectNodeStepsEntityWrapper.setSqlSelect("id", "project_node_name").eq("id", bprojectNodeSteps.getProjectNodeId());
                BprojectNodes bprojectNodes = bprojectNodesService.selectOne(bprojectNodeStepsEntityWrapper);
                if (bprojectNodes != null) {
                    map.put("proNode", bprojectNodes);
                }
                map.put("proNodeSteps", bprojectNodeSteps);
                return map;
            }
        }
        EntityWrapper<BprojectNodes> bprojectNodeStepsEntityWrapper = new EntityWrapper<>();
        List<BprojectNodes> bprojectNodes = bprojectNodesService.selectList(bprojectNodeStepsEntityWrapper);
        if (bprojectNodes != null) {
            map.put("proNodes", bprojectNodes);
        }
        EntityWrapper<BprojectNodeSteps> entityWrapper = new EntityWrapper<>();
        List<BprojectNodeSteps> bprojectNodeStepsList = bprojectNodeStepsService.selectList(entityWrapper);
        if (bprojectNodeStepsList.size() != 0) {
            map.put("proNodeSteps", bprojectNodeStepsList);
        }
        return map;
    }
}
