
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.BprojectNodes;
import io.platform.engineering.biz.service.BprojectNodesService;
import io.platform.engineering.dto.BprojectNodesDto;
import io.platform.engineering.service.client.api.BprojectNodesServiceClient;
import io.platform.project.biz.entity.ProjectBillsSteps;
import io.platform.project.biz.service.ProjectBillsStepsService;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BprojectNodesServiceClientImpl extends BaseServiceClient<BprojectNodes, BprojectNodesDto> implements BprojectNodesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BprojectNodesService bprojectNodesService;
    @Resource
    private ProjectBillsStepsService projectBillsStepsService;

    @Override
    public BprojectNodesDto queryObject(Long id) {
        BprojectNodes bprojectNodes = bprojectNodesService.selectById(id);
        BprojectNodesDto bprojectNodesDto = new BprojectNodesDto();
        BeanUtils.copyProperties(bprojectNodes, bprojectNodesDto);
        return bprojectNodesDto;
    }

    @Override
    public List<BprojectNodesDto> queryList(Map<String, Object> map) {
        List<BprojectNodes> bprojectNodesList = bprojectNodesService.selectByMap(map);
        return convertList(bprojectNodesList, BprojectNodesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BprojectNodes> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bprojectNodesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BprojectNodesDto bprojectNodesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (bprojectNodesDto.getSortNum() != null) {
                EntityWrapper<BprojectNodes> entityWrapper = new EntityWrapper<>();
                entityWrapper.eq("branch_id", bprojectNodesDto.getBranchId()).eq("sort_num", bprojectNodesDto.getSortNum());
                BprojectNodes bp = bprojectNodesService.selectOne(entityWrapper);
                if (bp != null) {
                    result.addErrorMessage("排序值已被占用");
                    return result;
                }
                BprojectNodes bprojectNodes = new BprojectNodes();
                revert(bprojectNodesDto, bprojectNodes);


                EntityWrapper<BprojectNodes> wrapper = new EntityWrapper<>();
                wrapper.eq("project_node_name", bprojectNodes.getProjectNodeName());
                wrapper.eq("branch_id", bprojectNodes.getBranchId());
                List<BprojectNodes> list = bprojectNodesService.selectList(wrapper);
                if (list.size() > 0) {
                    result.addErrorMessage("工程节点名称已存在。");
                    return result;
                }


                boolean flag = bprojectNodesService.insertOrUpdate(bprojectNodes);
                if (!flag) {
                    result.addErrorMessage("保存失败。");
                }
            } else {
                result.addErrorMessage("请维护排序值");
                return result;
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BprojectNodesDto bprojectNodesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BprojectNodes bprojectNodes = new BprojectNodes();
            revert(bprojectNodesDto, bprojectNodes);

            EntityWrapper<BprojectNodes> wrapper = new EntityWrapper<>();
            wrapper.eq("project_node_name", bprojectNodes.getProjectNodeName());
            wrapper.eq("branch_id", bprojectNodes.getBranchId());
            List<BprojectNodes> list = bprojectNodesService.selectList(wrapper);
            if (list.size() > 0) {
                if (list.size() == 1 && (list.get(0).getId() + "").equals(bprojectNodes.getId() + "")) {

                } else {
                    result.addErrorMessage("工程节点名称已存在。");
                    return result;
                }
            }

            boolean flag = bprojectNodesService.updateById(bprojectNodes);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bprojectNodesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<ProjectBillsSteps> wrapper = new EntityWrapper<>();
            wrapper.eq("project_node_id", id);
            if (projectBillsStepsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,工程节点已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bprojectNodesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BprojectNodesDto> getPage(Page<BprojectNodesDto> pageDto, BprojectNodesDto bprojectNodesDto) {
        BprojectNodes bprojectNodes = new BprojectNodes();
        revert(bprojectNodesDto, bprojectNodes);
        EntityWrapper<BprojectNodes> wrapper = new EntityWrapper<>();
        if (bprojectNodes.getBranchId() != null && bprojectNodes.getBranchId() != 1) {
            wrapper.eq("branch_id", bprojectNodes.getBranchId());
        }
        if (bprojectNodes.getProjectNodeNo() != null) {
            wrapper.like("project_node_no", "%" + bprojectNodes.getProjectNodeNo() + "%");
        }
        if (bprojectNodes.getProjectNodeName() != null) {
            wrapper.like("project_node_name", "%" + bprojectNodes.getProjectNodeName() + "%");
        }
        int count = bprojectNodesService.selectCountNum(bprojectNodesDto);
        if (count > 0) {
            Map<String, Object> map = new HashMap<>();
            Page page = DataUtils.processingPage(pageDto);
            map.put("page", page);
            map.put("proNode", bprojectNodesDto);
            List<BprojectNodesDto> bprojectNodesList = bprojectNodesService.selectLists(map);
            pageDto.setTotal(count);
            pageDto.setRecords(bprojectNodesList);
        }
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryProjectNodes(Page page, BprojectNodesDto bprojectNodesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bprojectNodesDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<BprojectNodes> entityWrapper = new EntityWrapper<>();
            if (bprojectNodesDto.getProjectTypeId() != null && bprojectNodesDto.getProjectTypeId() != 0) {
                entityWrapper.eq("project_type_id", bprojectNodesDto.getProjectTypeId());
            }
            if (bprojectNodesDto.getStatus() != null && !bprojectNodesDto.getStatus().equals("")) {
                entityWrapper.eq("status", bprojectNodesDto.getStatus());
            }
            if (bprojectNodesDto.getProjectNodeNo() != null && !bprojectNodesDto.getProjectNodeNo().equals("")) {
                entityWrapper.like("project_node_no", "%" + bprojectNodesDto.getProjectNodeNo() + "%");
            }
            if (bprojectNodesDto.getProjectNodeName() != null && !bprojectNodesDto.getProjectNodeName().equals("")) {
                entityWrapper.like("project_node_name", "%" + bprojectNodesDto.getProjectNodeName() + "%");
            }
            int number = bprojectNodesService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<BprojectNodes> bprojectNodes = bprojectNodesService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bprojectNodes);
                map.put("page", pageDto);
                return map;
            }
        }
        return null;
    }

    @Override
    public Map<String, Object> selectProNodes(BprojectNodesDto bprojectNodesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bprojectNodesDto.getId() != null) {
            EntityWrapper<BprojectNodes> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "project_node_no", "project_node_name", "project_type_id").eq("id", bprojectNodesDto.getId());
            BprojectNodes bprojectNodes = bprojectNodesService.selectOne(entityWrapper);
            if (bprojectNodes != null) {
                map.put("proNode", bprojectNodes);
                return map;
            }
        }
        EntityWrapper<BprojectNodes> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "project_node_no", "project_node_name", "project_type_id");
        List<BprojectNodes> bprojectNodes = bprojectNodesService.selectList(entityWrapper);
        if (bprojectNodes.size() != 0) {
            map.put("proNodes", bprojectNodes);
            return map;
        }
        return null;
    }
}
