
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.BcorpTypes;
import io.platform.engineering.biz.entity.BprojectTypes;
import io.platform.engineering.biz.entity.BprojectTypesItems;
import io.platform.engineering.biz.service.BprojectTypesItemsService;
import io.platform.engineering.dto.BprojectTypesItemsDto;
import io.platform.engineering.service.client.api.BprojectTypesItemsServiceClient;
import io.platform.progressConfiguration.biz.entity.ProjectNodeNexus;
import io.platform.progressConfiguration.biz.service.ProjectNodeNexusService;
import io.platform.project.biz.entity.Projectbills;
import io.platform.project.biz.service.ProjectbillsService;
import io.platform.project.dto.ProjectbillsDto;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BprojectTypesItemsServiceClientImpl extends BaseServiceClient<BprojectTypesItems, BprojectTypesItemsDto> implements BprojectTypesItemsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BprojectTypesItemsService bprojectTypesItemsService;
    @Resource
    private ProjectbillsService projectbillsService;
    @Resource
    private ProjectNodeNexusService projectNodeNexusService;

    @Override
    public BprojectTypesItemsDto queryObject(Long id) {
        BprojectTypesItems bprojectTypesItems = bprojectTypesItemsService.selectById(id);
        BprojectTypesItemsDto bprojectTypesItemsDto = new BprojectTypesItemsDto();
        BeanUtils.copyProperties(bprojectTypesItems, bprojectTypesItemsDto);
        return bprojectTypesItemsDto;
    }

    @Override
    public List<BprojectTypesItemsDto> queryList(Map<String, Object> map) {
        List<BprojectTypesItems> bprojectTypesItemsList = bprojectTypesItemsService.selectByMap(map);
        return convertList(bprojectTypesItemsList, BprojectTypesItemsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BprojectTypesItems> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bprojectTypesItemsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BprojectTypesItemsDto bprojectTypesItemsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BprojectTypesItems bprojectTypesItems = new BprojectTypesItems();
            revert(bprojectTypesItemsDto, bprojectTypesItems);

            EntityWrapper<BprojectTypesItems> wrapper = new EntityWrapper<>();
            wrapper.eq("project_type_item_name", bprojectTypesItems.getProjectTypeItemName());
            List<BprojectTypesItems> list = bprojectTypesItemsService.selectList(wrapper);
            if (list != null && list.size() > 0) {
                result.addErrorMessage("工程小类名称已存在。");
                return result;
            }

            boolean flag = bprojectTypesItemsService.insert(bprojectTypesItems);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BprojectTypesItemsDto bprojectTypesItemsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BprojectTypesItems bprojectTypesItems = new BprojectTypesItems();
            revert(bprojectTypesItemsDto, bprojectTypesItems);

            EntityWrapper<BprojectTypesItems> wrapper = new EntityWrapper<>();
            wrapper.eq("project_type_item_name", bprojectTypesItems.getProjectTypeItemName());
            List<BprojectTypesItems> list = bprojectTypesItemsService.selectList(wrapper);
            if (list.size() > 0) {
                if (list != null && list.size() == 1 && (list.get(0).getId() + "").equals(bprojectTypesItems.getId() + "")) {

                } else {
                    result.addErrorMessage("工程小类名称已存在。");
                    return result;
                }
            }

            boolean flag = bprojectTypesItemsService.updateById(bprojectTypesItems);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bprojectTypesItemsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<Projectbills> wrapper = new EntityWrapper<>();
            wrapper.eq("project_type_item_id", id);
            if (projectbillsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,工程小类已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bprojectTypesItemsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BprojectTypesItemsDto> getPage(Page<BprojectTypesItemsDto> pageDto, BprojectTypesItemsDto bprojectTypesItemsDto) {
        Page<BprojectTypesItems> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BprojectTypesItems bprojectTypesItems = new BprojectTypesItems();
        revert(bprojectTypesItemsDto, bprojectTypesItems);
        EntityWrapper<BprojectTypesItems> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bprojectTypesItems);
        if (bprojectTypesItems.getProjectTypeItemNo() != null) {
            wrapper.like("project_type_item_no", "%" + bprojectTypesItems.getProjectTypeItemNo() + "%");
            bprojectTypesItems.setProjectTypeItemNo(null);
        }
        if (bprojectTypesItems.getProjectTypeItemName() != null) {
            wrapper.like("project_type_item_name", "%" + bprojectTypesItems.getProjectTypeItemName() + "%");
            bprojectTypesItems.setProjectTypeItemName(null);
        }
        page = bprojectTypesItemsService.selectPage(page, wrapper);
        List<BprojectTypesItemsDto> bprojectTypesItemsDtoList = convertList(page.getRecords(), BprojectTypesItemsDto.class);
        pageDto.setTotal(bprojectTypesItemsService.selectCount(wrapper));
        pageDto.setRecords(bprojectTypesItemsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> selectProTypsItems(BprojectTypesItemsDto bprojectTypesItemsDto) {
        Map<String, Object> map = new HashMap<>();
        if (bprojectTypesItemsDto.getId() != null) {
            EntityWrapper<BprojectTypesItems> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "project_type_id", "project_type_item_no", "project_type_item_name").eq("id", bprojectTypesItemsDto.getId());
            BprojectTypesItems bprojectTypesItems = bprojectTypesItemsService.selectOne(entityWrapper);
            if (bprojectTypesItems != null) {
                map.put("proTypsItem", bprojectTypesItems);
            }
            return map;
        }
        EntityWrapper<BprojectTypesItems> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "project_type_id", "project_type_item_no", "project_type_item_name");
        List<BprojectTypesItems> bprojectTypesItems = bprojectTypesItemsService.selectList(entityWrapper);
        if (bprojectTypesItems.size() != 0) {
            map.put("proTypesItems", bprojectTypesItems);
            return map;
        }
        return null;
    }
}
