
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.base.common.utils.DateUtils;
import io.platform.engineering.biz.entity.BprojectNodes;
import io.platform.engineering.biz.entity.BprojectTypes;
import io.platform.engineering.biz.entity.Bpurchases;
import io.platform.engineering.biz.service.BprojectTypesService;
import io.platform.engineering.dto.BprojectTypesDto;
import io.platform.engineering.service.client.api.BprojectTypesServiceClient;
import io.platform.progressConfiguration.biz.entity.ProjectNodeNexus;
import io.platform.progressConfiguration.biz.service.ProjectNodeNexusItemService;
import io.platform.progressConfiguration.biz.service.ProjectNodeNexusService;
import io.platform.project.biz.entity.Projectbills;
import io.platform.project.biz.service.ProjectbillsService;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BprojectTypesServiceClientImpl extends BaseServiceClient<BprojectTypes, BprojectTypesDto> implements BprojectTypesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BprojectTypesService bprojectTypesService;
    @Resource
    private ProjectbillsService projectbillsService;
    @Resource
    private ProjectNodeNexusService projectNodeNexusService;

    @Override
    public BprojectTypesDto queryObject(Long id) {
        BprojectTypes bprojectTypes = bprojectTypesService.selectById(id);
        BprojectTypesDto bprojectTypesDto = new BprojectTypesDto();
        BeanUtils.copyProperties(bprojectTypes, bprojectTypesDto);
        return bprojectTypesDto;
    }

    @Override
    public List<BprojectTypesDto> queryList(Map<String, Object> map) {
        List<BprojectTypes> bprojectTypesList = bprojectTypesService.selectByMap(map);
        return convertList(bprojectTypesList, BprojectTypesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BprojectTypes> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bprojectTypesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BprojectTypesDto bprojectTypesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BprojectTypes bprojectTypes = new BprojectTypes();
            revert(bprojectTypesDto, bprojectTypes);
            EntityWrapper<BprojectTypes> wrapper = new EntityWrapper<>();
            wrapper.eq("project_type_name", bprojectTypes.getProjectTypeName());
            List<BprojectTypes> list = bprojectTypesService.selectList(wrapper);
            if (list.size() > 0) {
                result.addErrorMessage("工程大类名称已存在。");
                return result;
            }
            boolean flag = bprojectTypesService.insert(bprojectTypes);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BprojectTypesDto bprojectTypesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BprojectTypes bprojectTypes = new BprojectTypes();
            revert(bprojectTypesDto, bprojectTypes);

            EntityWrapper<BprojectTypes> wrapper = new EntityWrapper<>();
            wrapper.eq("project_type_name", bprojectTypes.getProjectTypeName());
            List<BprojectTypes> list = bprojectTypesService.selectList(wrapper);
            if (list.size() > 0) {
                if (list.size() == 1 && (list.get(0).getId() + "").equals(bprojectTypes.getId() + "")) {
                } else {
                    result.addErrorMessage("工程大类名称已存在。");
                    return result;
                }
            }
            boolean flag = bprojectTypesService.updateById(bprojectTypes);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bprojectTypesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<Projectbills> wrapper = new EntityWrapper<>();
            wrapper.eq("project_type_id", id);
            if (projectbillsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,工程大类已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bprojectTypesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BprojectTypesDto> getPage(Page<BprojectTypesDto> pageDto, BprojectTypesDto bprojectTypesDto) {
        Page<BprojectTypes> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BprojectTypes bprojectTypes = new BprojectTypes();
        revert(bprojectTypesDto, bprojectTypes);
        EntityWrapper<BprojectTypes> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bprojectTypes);
        if (bprojectTypes.getProjectTypeNo() != null) {
            wrapper.like("project_type_no", "%" + bprojectTypes.getProjectTypeNo() + "%");
            bprojectTypes.setProjectTypeNo(null);
        }
        if (bprojectTypes.getProjectTypeName() != null) {
            wrapper.like("project_type_name", "%" + bprojectTypes.getProjectTypeName() + "%");
            bprojectTypes.setProjectTypeName(null);
        }
        if (bprojectTypes.getOpUserName() != null) {
            wrapper.like("op_user_name", "%" + bprojectTypes.getOpUserName() + "%");
            bprojectTypes.setOpUserName(null);
        }
        page = bprojectTypesService.selectPage(page, wrapper);
        List<BprojectTypesDto> bprojectTypesDtoList = convertList(page.getRecords(), BprojectTypesDto.class);
        pageDto.setTotal(bprojectTypesService.selectCount(wrapper));
        pageDto.setRecords(bprojectTypesDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryProjectTypes(Page page, BprojectTypesDto bprojectTypesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bprojectTypesDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<BprojectTypes> entityWrapper = new EntityWrapper<>();
            if (bprojectTypesDto.getOpDate() != null) {
                entityWrapper.eq("op_date", bprojectTypesDto.getOpDate());
            }
            if (bprojectTypesDto.getStatus() != null && !bprojectTypesDto.getStatus().equals("")) {
                entityWrapper.eq("status", bprojectTypesDto.getStatus());
            }
            if (bprojectTypesDto.getProjectTypeId() != null && bprojectTypesDto.getProjectTypeId() != 0) {
                entityWrapper.eq("project_type_id", bprojectTypesDto.getProjectTypeId());
            }
            if (bprojectTypesDto.getProjectTypeNo() != null && !bprojectTypesDto.getProjectTypeNo().equals("")) {
                entityWrapper.like("project_type_no", "%" + bprojectTypesDto.getProjectTypeNo() + "%");
            }
            if (bprojectTypesDto.getProjectTypeName() != null && !bprojectTypesDto.getProjectTypeName().equals("")) {
                entityWrapper.like("project_type_name", "%" + bprojectTypesDto.getProjectTypeName() + "%");
            }
            if (bprojectTypesDto.getOpUserName() != null && !bprojectTypesDto.getOpUserName().equals("")) {
                entityWrapper.like("op_user_name", "%" + bprojectTypesDto.getOpUserName() + "%");
            }
            if (bprojectTypesDto.getRemarks() != null && !bprojectTypesDto.getRemarks().equals("")) {
                entityWrapper.like("remarks", "%" + bprojectTypesDto.getRemarks() + "%");
            }
            int number = bprojectTypesService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<BprojectTypes> bprojectTypes = bprojectTypesService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bprojectTypes);
                map.put("page", pageDto);
                return map;
            }
            return null;
        }
        return null;
    }

    @Override
    public Map<String, Object> selectProTypes(BprojectTypesDto bprojectTypesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bprojectTypesDto.getId() != null) {
            EntityWrapper<BprojectTypes> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "project_type_no", "project_type_name").eq("id", bprojectTypesDto.getId());
            BprojectTypes bprojectTypes = bprojectTypesService.selectOne(entityWrapper);
            if (bprojectTypes != null) {
                map.put("proType", bprojectTypes);
                return map;
            }
        }
        EntityWrapper<BprojectTypes> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "project_type_no", "project_type_name");
        List<BprojectTypes> bprojectTypesList = bprojectTypesService.selectList(entityWrapper);
        if (bprojectTypesList.size() != 0) {
            map.put("proTyps", bprojectTypesList);
            return map;
        }
        return null;
    }
}
