
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.Bbudgets;
import io.platform.engineering.biz.entity.BpurchaseModes;
import io.platform.engineering.biz.entity.BpurchaseSubTypes;
import io.platform.engineering.biz.service.BpurchaseModesService;
import io.platform.engineering.dto.BpurchaseModesDto;
import io.platform.engineering.service.client.api.BpurchaseModesServiceClient;
import io.platform.purchase.biz.entity.PurchaseBillsProjs;
import io.platform.purchase.biz.service.PurchaseBillsProjsService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BpurchaseModesServiceClientImpl extends BaseServiceClient<BpurchaseModes, BpurchaseModesDto> implements BpurchaseModesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BpurchaseModesService bpurchaseModesService;
    @Resource
    private PurchaseBillsProjsService purchaseBillsProjsService;

    @Override
    public BpurchaseModesDto queryObject(Long id) {
        BpurchaseModes bpurchaseModes = bpurchaseModesService.selectById(id);
        BpurchaseModesDto bpurchaseModesDto = new BpurchaseModesDto();
        BeanUtils.copyProperties(bpurchaseModes, bpurchaseModesDto);
        return bpurchaseModesDto;
    }

    @Override
    public List<BpurchaseModesDto> queryList(Map<String, Object> map) {
        List<BpurchaseModes> bpurchaseModesList = bpurchaseModesService.selectByMap(map);
        return convertList(bpurchaseModesList, BpurchaseModesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BpurchaseModes> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bpurchaseModesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BpurchaseModesDto bpurchaseModesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpurchaseModes bpurchaseModes = new BpurchaseModes();
            revert(bpurchaseModesDto, bpurchaseModes);

            EntityWrapper<BpurchaseModes> wrapper = new EntityWrapper<>();
            wrapper.eq("purchase_mode_name", bpurchaseModes.getPurchaseModeName());
            List<BpurchaseModes> list = bpurchaseModesService.selectList(wrapper);
            if (list.size() > 0) {
                result.addErrorMessage("采购方式名称已存在。");
                return result;
            }

            boolean flag = bpurchaseModesService.insert(bpurchaseModes);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BpurchaseModesDto bpurchaseModesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpurchaseModes bpurchaseModes = new BpurchaseModes();
            revert(bpurchaseModesDto, bpurchaseModes);

            EntityWrapper<BpurchaseModes> wrapper = new EntityWrapper<>();
            wrapper.eq("purchase_mode_name", bpurchaseModes.getPurchaseModeName());
            List<BpurchaseModes> list = bpurchaseModesService.selectList(wrapper);
            if (list.size() > 0) {
                if (list.size() == 1 && (list.get(0).getId() + "").equals(bpurchaseModes.getId() + "")) {
                } else {
                    result.addErrorMessage("采购方式名称已存在。");
                    return result;
                }
            }


            boolean flag = bpurchaseModesService.updateById(bpurchaseModes);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bpurchaseModesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<PurchaseBillsProjs> wrapper = new EntityWrapper<>();
            wrapper.eq("purchase_Mode_id", id);
            if (purchaseBillsProjsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,采购方式已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bpurchaseModesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BpurchaseModesDto> getPage(Page<BpurchaseModesDto> pageDto, BpurchaseModesDto bpurchaseModesDto) {
        Page<BpurchaseModes> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BpurchaseModes bpurchaseModes = new BpurchaseModes();
        revert(bpurchaseModesDto, bpurchaseModes);
        EntityWrapper<BpurchaseModes> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bpurchaseModes);
        if (!bpurchaseModes.getPurchaseModeNo().equals("")) {
            wrapper.like("purchase_mode_no", "%" + bpurchaseModes.getPurchaseModeNo() + "%");
            bpurchaseModes.setPurchaseModeNo("");
        }
        if (!bpurchaseModes.getPurchaseModeName().equals("")) {
            wrapper.like("purchase_mode_name", "%" + bpurchaseModes.getPurchaseModeName() + "%");
            bpurchaseModes.setPurchaseModeName("");
        }
        page = bpurchaseModesService.selectPage(page, wrapper);
        List<BpurchaseModesDto> bpurchaseModesDtoList = convertList(page.getRecords(), BpurchaseModesDto.class);
        pageDto.setTotal(bpurchaseModesService.selectCount(wrapper));
        pageDto.setRecords(bpurchaseModesDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> selectpurModes(BpurchaseModesDto bpurchaseModesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpurchaseModesDto.getId() != null) {
            EntityWrapper<BpurchaseModes> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "purchase_mode_name").eq("id", bpurchaseModesDto.getId());
            BpurchaseModes bpurchaseMode = bpurchaseModesService.selectOne(entityWrapper);
            if (bpurchaseMode != null) {
                map.put("purchMode", bpurchaseMode);
                return map;
            }
        }
        EntityWrapper<BpurchaseModes> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "purchase_mode_name");
        List<BpurchaseModes> bpurchaseModesList = bpurchaseModesService.selectList(entityWrapper);
        if (bpurchaseModesList.size() != 0) {
            map.put("purchModes", bpurchaseModesList);
            return map;
        }


        return null;
    }
}
