
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.*;
import io.platform.engineering.biz.service.BpurchaseModesService;
import io.platform.engineering.biz.service.BpurchaseSubTypesService;
import io.platform.engineering.biz.service.BpurchasesService;
import io.platform.engineering.dto.BpurchaseSubTypesDto;
import io.platform.engineering.service.client.api.BpurchaseSubTypesServiceClient;
import io.platform.progressConfiguration.biz.entity.ProjectNodeNexusItem;
import io.platform.purchase.biz.entity.PurchaseBillsProjs;
import io.platform.purchase.biz.service.PurchaseBillsProjsService;
import io.platform.sys.dto.SysUserDto;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BpurchaseSubTypesServiceClientImpl extends BaseServiceClient<BpurchaseSubTypes, BpurchaseSubTypesDto> implements BpurchaseSubTypesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BpurchaseSubTypesService bpurchaseSubTypesService;
    @Resource
    private BpurchaseModesService bpurchaseModesService;
    @Resource
    private BpurchasesService bpurchasesService;
    @Resource
    private PurchaseBillsProjsService purchaseBillsProjsService;

    @Override
    public BpurchaseSubTypesDto queryObject(Long id) {
        BpurchaseSubTypes bpurchaseSubTypes = bpurchaseSubTypesService.selectById(id);
        BpurchaseSubTypesDto bpurchaseSubTypesDto = new BpurchaseSubTypesDto();
        BeanUtils.copyProperties(bpurchaseSubTypes, bpurchaseSubTypesDto);
        return bpurchaseSubTypesDto;
    }

    @Override
    public List<BpurchaseSubTypesDto> queryList(Map<String, Object> map) {
        List<BpurchaseSubTypes> bpurchaseSubTypesList = bpurchaseSubTypesService.selectByMap(map);
        return convertList(bpurchaseSubTypesList, BpurchaseSubTypesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BpurchaseSubTypes> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bpurchaseSubTypesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BpurchaseSubTypesDto bpurchaseSubTypesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpurchaseSubTypes bpurchaseSubTypes = new BpurchaseSubTypes();
            revert(bpurchaseSubTypesDto, bpurchaseSubTypes);

            EntityWrapper<BpurchaseSubTypes> wrapper = new EntityWrapper<>();
            wrapper.eq("purchase_sub_type_name", bpurchaseSubTypes.getPurchaseSubTypeName());
            List<BpurchaseSubTypes> list = bpurchaseSubTypesService.selectList(wrapper);
            if (list.size() > 0) {
                result.addErrorMessage("采购分包类型名称已存在。");
                return result;
            }

            boolean flag = bpurchaseSubTypesService.insert(bpurchaseSubTypes);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BpurchaseSubTypesDto bpurchaseSubTypesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpurchaseSubTypes bpurchaseSubTypes = new BpurchaseSubTypes();
            revert(bpurchaseSubTypesDto, bpurchaseSubTypes);

            EntityWrapper<BpurchaseSubTypes> wrapper = new EntityWrapper<>();
            wrapper.eq("purchase_sub_type_name", bpurchaseSubTypes.getPurchaseSubTypeName());
            List<BpurchaseSubTypes> list = bpurchaseSubTypesService.selectList(wrapper);
            if (list.size() > 0) {
                if (list.size() == 1 && (list.get(0).getId() + "").equals(bpurchaseSubTypes.getId() + "")) {
                } else {
                    result.addErrorMessage("采购分包类型名称已存在。");
                    return result;
                }
            }

            boolean flag = bpurchaseSubTypesService.updateById(bpurchaseSubTypes);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bpurchaseSubTypesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();

        for (Long id : ids) {
            EntityWrapper<PurchaseBillsProjs> wrapper = new EntityWrapper<>();
            wrapper.eq("purchase_SubType_id", id);
            if (purchaseBillsProjsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,分包类型已被使用。");
                return result;
            }
        }

        try {
            boolean flag = bpurchaseSubTypesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BpurchaseSubTypesDto> getPage(Page<BpurchaseSubTypesDto> pageDto, BpurchaseSubTypesDto bpurchaseSubTypesDto) {
        Page<BpurchaseSubTypes> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BpurchaseSubTypes bpurchaseSubTypes = new BpurchaseSubTypes();
        revert(bpurchaseSubTypesDto, bpurchaseSubTypes);
        EntityWrapper<BpurchaseSubTypes> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bpurchaseSubTypes);
        if (!bpurchaseSubTypes.getPurchaseSubTypeNo().equals("")) {
            wrapper.like("purchase_sub_type_no", "%" + bpurchaseSubTypes.getPurchaseSubTypeNo() + "%");
            bpurchaseSubTypes.setPurchaseSubTypeNo("");
        }
        if (!bpurchaseSubTypes.getPurchaseSubTypeName().equals("")) {
            wrapper.like("purchase_sub_type_name", "%" + bpurchaseSubTypes.getPurchaseSubTypeName() + "%");
            bpurchaseSubTypes.setPurchaseSubTypeName("");
        }
        page = bpurchaseSubTypesService.selectPage(page, wrapper);
        List<BpurchaseSubTypesDto> bpurchaseSubTypesDtoList = convertList(page.getRecords(), BpurchaseSubTypesDto.class);
        pageDto.setTotal(bpurchaseSubTypesService.selectCount(wrapper));
        pageDto.setRecords(bpurchaseSubTypesDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> down(SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        List<BpurchaseSubTypes> subTypes = bpurchaseSubTypesService.down(sysUserDto);
        List<BpurchaseModes> modes = bpurchaseModesService.down(sysUserDto);
        List<Bpurchases> bpurchases = bpurchasesService.down(sysUserDto);
        map.put("sub", subTypes);
        map.put("mode", modes);
        map.put("chases", bpurchases);
        return map;
    }

    @Override
    public Map<String, Object> selectPurchSubTypes(BpurchaseSubTypesDto bpurchaseSubTypesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpurchaseSubTypesDto.getId() != null) {
            EntityWrapper<BpurchaseSubTypes> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "purchase_sub_type_name").eq("id", bpurchaseSubTypesDto.getId());
            BpurchaseSubTypes bpurchaseSubType = bpurchaseSubTypesService.selectOne(entityWrapper);
            if (bpurchaseSubType != null) {
                map.put("bpurchSubType", bpurchaseSubType);
                return map;
            }
        }
        EntityWrapper<BpurchaseSubTypes> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "purchase_sub_type_name");
        List<BpurchaseSubTypes> bpurchaseSubTypesList = bpurchaseSubTypesService.selectList(entityWrapper);
        if (bpurchaseSubTypesList.size() != 0) {
            map.put("bpurchSubTypes", bpurchaseSubTypesList);
            return map;
        }
        return null;
    }
}
