
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.engineering.biz.entity.Bbudgets;
import io.platform.engineering.biz.entity.BpurchaseTypes;
import io.platform.engineering.biz.service.BpurchaseTypesService;
import io.platform.engineering.dto.BpurchaseTypesDto;
import io.platform.engineering.service.client.api.BpurchaseTypesServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BpurchaseTypesServiceClientImpl extends BaseServiceClient<BpurchaseTypes, BpurchaseTypesDto> implements BpurchaseTypesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BpurchaseTypesService bpurchaseTypesService;

    @Override
    public BpurchaseTypesDto queryObject(Long id) {
        BpurchaseTypes bpurchaseTypes = bpurchaseTypesService.selectById(id);
        BpurchaseTypesDto bpurchaseTypesDto = new BpurchaseTypesDto();
        BeanUtils.copyProperties(bpurchaseTypes, bpurchaseTypesDto);
        return bpurchaseTypesDto;
    }

    @Override
    public List<BpurchaseTypesDto> queryList(Map<String, Object> map) {
        List<BpurchaseTypes> bpurchaseTypesList = bpurchaseTypesService.selectByMap(map);
        return convertList(bpurchaseTypesList, BpurchaseTypesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<BpurchaseTypes> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bpurchaseTypesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BpurchaseTypesDto bpurchaseTypesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpurchaseTypes bpurchaseTypes = new BpurchaseTypes();
            revert(bpurchaseTypesDto, bpurchaseTypes);
            boolean flag = bpurchaseTypesService.insert(bpurchaseTypes);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(BpurchaseTypesDto bpurchaseTypesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            BpurchaseTypes bpurchaseTypes = new BpurchaseTypes();
            revert(bpurchaseTypesDto, bpurchaseTypes);

            boolean flag = bpurchaseTypesService.updateById(bpurchaseTypes);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bpurchaseTypesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bpurchaseTypesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BpurchaseTypesDto> getPage(Page<BpurchaseTypesDto> pageDto, BpurchaseTypesDto bpurchaseTypesDto) {
        Page<BpurchaseTypes> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        BpurchaseTypes bpurchaseTypes = new BpurchaseTypes();
        revert(bpurchaseTypesDto, bpurchaseTypes);
        EntityWrapper<BpurchaseTypes> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bpurchaseTypes);
        page = bpurchaseTypesService.selectPage(page, wrapper);
        List<BpurchaseTypesDto> bpurchaseTypesDtoList = convertList(page.getRecords(), BpurchaseTypesDto.class);
        pageDto.setTotal(bpurchaseTypesService.selectCount(wrapper));
        pageDto.setRecords(bpurchaseTypesDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> selectPurchTypes(BpurchaseTypesDto bpurchaseTypesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpurchaseTypesDto.getId() != null) {
            EntityWrapper<BpurchaseTypes> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "purchase_type_name").eq("id", bpurchaseTypesDto.getId());
            BpurchaseTypes bpurchaseType = bpurchaseTypesService.selectOne(entityWrapper);
            if (bpurchaseType != null) {
                map.put("purchType", bpurchaseType);
                return map;
            }
        }
        EntityWrapper<BpurchaseTypes> entityWrapper = new EntityWrapper<>();
        entityWrapper.setSqlSelect("id", "purchase_type_name");
        List<BpurchaseTypes> bpurchaseTypesList = bpurchaseTypesService.selectList(entityWrapper);
        if (bpurchaseTypesList.size() != 0) {
            map.put("purchTypes", bpurchaseTypesList);
            return map;
        }
        return null;
    }
}
