
package io.platform.engineering.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.engineering.biz.entity.Bpurchases;
import io.platform.engineering.biz.service.BpurchasesService;
import io.platform.engineering.dto.BpurchasesDto;
import io.platform.engineering.service.client.api.BpurchasesServiceClient;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.project.biz.entity.Projectbills;
import io.platform.project.biz.entity.SubContractBills;
import io.platform.project.biz.service.ProjectbillsService;
import io.platform.project.biz.service.SubContractBillsService;
import io.platform.utils.DataUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class BpurchasesServiceClientImpl extends BaseServiceClient<Bpurchases, BpurchasesDto> implements BpurchasesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BpurchasesService bpurchasesService;
    @Resource
    private ProjectbillsService projectbillsService;

    @Override
    public BpurchasesDto queryObject(Long id) {
        Bpurchases bpurchases = bpurchasesService.selectById(id);
        BpurchasesDto bpurchasesDto = new BpurchasesDto();
        BeanUtils.copyProperties(bpurchases, bpurchasesDto);
        return bpurchasesDto;
    }

    @Override
    public List<BpurchasesDto> queryList(Map<String, Object> map) {
        List<Bpurchases> bpurchasesList = bpurchasesService.selectByMap(map);
        return convertList(bpurchasesList, BpurchasesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<Bpurchases> ew = new EntityWrapper<>();
        ew.allEq(map);
        return bpurchasesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(BpurchasesDto bpurchasesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bpurchases bpurchases = new Bpurchases();
            revert(bpurchasesDto, bpurchases);

            EntityWrapper<Bpurchases> wrapper = new EntityWrapper<>();
            wrapper.eq("C_NAME", bpurchases.getCname());
            wrapper.eq("branch_id", bpurchases.getBranchId());
            List<Bpurchases> list = bpurchasesService.selectList(wrapper);
            if (list != null && list.size() > 0) {
                result.addErrorMessage("单位全称已存在！");
                return result;
            }

            boolean flag = bpurchasesService.insert(bpurchases);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> saveList(List<BpurchasesDto> bpurchasesDtoList) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        int i = 2;
        String message = "第";

        for (BpurchasesDto bpurchasesDto : bpurchasesDtoList) {
            i++;

            if ((bpurchasesDto.getCname() == null || "".equals(bpurchasesDto.getCname()))
                    && (bpurchasesDto.getBank() == null || "".equals(bpurchasesDto.getBank()))
                    && (bpurchasesDto.getBankAccNo() == null || "".equals(bpurchasesDto.getBankAccNo()))
//                    && (bpurchasesDto.getBankNumber() == null || "".equals(bpurchasesDto.getBankNumber())

            ) {
                continue;
            }
            if (bpurchasesDto.getCname() == null || "".equals(bpurchasesDto.getCname())) {
                message += i + "、";
                continue;
            }
            if (bpurchasesDto.getBank() == null || "".equals(bpurchasesDto.getBank())) {
                message += i + "、";
                continue;
            }
            if (bpurchasesDto.getBankAccNo() == null || "".equals(bpurchasesDto.getBankAccNo())) {
                message += i + "、";
                continue;
            }
//            if (bpurchasesDto.getBankNumber() == null || "".equals(bpurchasesDto.getBankNumber())) {
//                message += i + "、";
//                continue;
//            }
            try {
                Bpurchases bpurchases = new Bpurchases();
                revert(bpurchasesDto, bpurchases);
                EntityWrapper<Bpurchases> wrapper = new EntityWrapper<>();
                wrapper.eq("C_NAME", bpurchases.getCname());
                wrapper.eq("branch_id", bpurchases.getBranchId());
                List<Bpurchases> list = bpurchasesService.selectList(wrapper);
                if (list != null && list.size() > 0) {
                    message += i + "、";
                    continue;
                }

                boolean flag = bpurchasesService.insert(bpurchases);
                if (!flag) {
                    message += i + "、";
                }
            } catch (Exception e) {
                message += i + "、";
            }
        }
        if (message.equals("第")) {

        } else {
            message = message.substring(0, message.length() - 1);
            message += "行保存错误";
            result.addErrorMessage(message);
        }

        return result;
    }

    @Override
    public ExecuteResult<String> update(BpurchasesDto bpurchasesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Bpurchases bpurchases = new Bpurchases();
            revert(bpurchasesDto, bpurchases);

            EntityWrapper<Bpurchases> wrapper = new EntityWrapper<>();
            wrapper.eq("C_NAME", bpurchases.getCname());
            wrapper.eq("branch_id", bpurchases.getBranchId());
            List<Bpurchases> list = bpurchasesService.selectList(wrapper);
            if (list != null && list.size() > 0) {
                if (list.size() == 1 && (("" + list.get(0).getId()).equals(bpurchases.getId() + ""))) {

                } else {
                    result.addErrorMessage("单位全称已存在！");
                    return result;
                }
            }

            boolean flag = bpurchasesService.updateById(bpurchases);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = bpurchasesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Resource
    private SubContractBillsService subContractBillsService;

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        for (Long id : ids) {
            EntityWrapper<Projectbills> wrapper = new EntityWrapper<>();
            wrapper.eq("branch_id", id);
            if (projectbillsService.selectList(wrapper).size() > 0) {
                result.addErrorMessage("删除失败,供应商已被使用。");
                return result;
            }
            EntityWrapper<SubContractBills> wrapper1 = new EntityWrapper<>();
            wrapper1.eq("purchase_id", id);
            if (subContractBillsService.selectList(wrapper1).size() > 0) {
                result.addErrorMessage("删除失败,供应商已被使用。");
                return result;
            }
        }
        try {
            boolean flag = bpurchasesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<BpurchasesDto> getPage(Page<BpurchasesDto> pageDto, BpurchasesDto bpurchasesDto) {
        Page<Bpurchases> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        Bpurchases bpurchases = new Bpurchases();
        revert(bpurchasesDto, bpurchases);
        EntityWrapper<Bpurchases> wrapper = new EntityWrapper<>();
        wrapper.setEntity(bpurchases);
        if (bpurchases.getCname() != null) {
            wrapper.like("c_name", bpurchases.getCname());
            bpurchases.setCname(null);
        }
        wrapper.orderBy("CONVERT(c_name USING gbk)");
        page = bpurchasesService.selectPage(page, wrapper);
        List<BpurchasesDto> bpurchasesDtoList = convertList(page.getRecords(), BpurchasesDto.class);
        pageDto.setTotal(bpurchasesService.selectCount(wrapper));
        pageDto.setRecords(bpurchasesDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> fuzzyQueryPurchases(Page page, BpurchasesDto bpurchasesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpurchasesDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<Bpurchases> entityWrapper = new EntityWrapper<>();
            if (bpurchasesDto.getId() != null && bpurchasesDto.getId() != 0) {
                entityWrapper.eq("id", bpurchasesDto.getId());
            }
            if (bpurchasesDto.getStatus() != null && !bpurchasesDto.getStatus().equals("")) {
                entityWrapper.eq("status", bpurchasesDto.getStatus());
            }
            if (bpurchasesDto.getPurchaseNo() != null && !bpurchasesDto.getPurchaseNo().equals("")) {
                entityWrapper.like("purchase_no", "%" + bpurchasesDto.getPurchaseNo() + "%");
            }
            if (bpurchasesDto.getCname() != null && !bpurchasesDto.getCname().equals("")) {
                entityWrapper.like("c_name", "%" + bpurchasesDto.getCname() + "%");
            }
            int number = bpurchasesService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<Bpurchases> bpurchases = bpurchasesService.selectList(entityWrapper);
                pageDto.setTotal(number);
                pageDto.setRecords(bpurchases);
                map.put("page", pageDto);
                return map;
            }
        }
        return null;
    }

    @Override
    public Map<String, Object> selectPurchases(BpurchasesDto bpurchasesDto) {
        Map<String, Object> map = new HashMap<>();
        if (bpurchasesDto.getId() != null) {
            EntityWrapper<Bpurchases> entityWrapper = new EntityWrapper<>();
            entityWrapper.eq("id", bpurchasesDto.getId());
            Bpurchases bpurchase = bpurchasesService.selectOne(entityWrapper);
            if (bpurchase != null) {
                map.put("purchase", bpurchase);
                return map;
            }
        }
        EntityWrapper<Bpurchases> entityWrapper = new EntityWrapper<>();
        if (bpurchasesDto.getBranchId() != 1) {
            entityWrapper.eq("branch_id", bpurchasesDto.getBranchId());
        }
        entityWrapper.orderBy("CONVERT(c_name USING gbk)");
        List<Bpurchases> bpurchasesList = bpurchasesService.selectList(entityWrapper);
        if (bpurchasesList.size() != 0) {
            map.put("purchases", bpurchasesList);
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> queryDirectPay(Page page, InvoiceBillsDto invoiceBillsDto) {
        if (invoiceBillsDto != null && invoiceBillsDto.getProjectSubNo() != null && invoiceBillsDto.getBudgetId() != null) {
            Map<String, Object> map = new HashMap<>();
            map.put("invoice", invoiceBillsDto);
            int total = bpurchasesService.queryDirectPayTotal(map);
            if (total != 0) {
                Page pageDto = DataUtils.processingPage(page);
                map.put("current", pageDto.getCurrent());
                map.put("size", pageDto.getSize());
                List<Bpurchases> invoiceBills = bpurchasesService.queryDirectPayRecords(map);
                pageDto.setTotal(total);
                pageDto.setRecords(invoiceBills);
                map.put("page", pageDto);
            }
            return map;
        }
        return null;
    }

    @Override
    public List<BpurchasesDto> selectProjectPriceBudget(String subNo, Integer loginContractorId) {
        return bpurchasesService.selectProjectPriceBudget(subNo,loginContractorId);
    }
}
