
package io.platform.fileManagement.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.fileManagement.biz.entity.DataFileManagement;
import io.platform.fileManagement.biz.service.DataFileManagementService;
import io.platform.fileManagement.dto.DataFileManagementDto;
import io.platform.fileManagement.service.client.api.DataFileManagementServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.boot.configurationprocessor.json.JSONArray;
import org.springframework.boot.configurationprocessor.json.JSONException;
import org.springframework.boot.configurationprocessor.json.JSONObject;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class DataFileManagementServiceClientImpl extends BaseServiceClient<DataFileManagement, DataFileManagementDto> implements DataFileManagementServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private DataFileManagementService dataFileManagementService;

    @Override
    public DataFileManagementDto queryObject(Long id) {
        DataFileManagement dataFileManagement = dataFileManagementService.selectById(id);
        DataFileManagement dataFileManagement2 = dataFileManagementService.selectById(dataFileManagement.getParentId());
        DataFileManagementDto dataFileManagementDto = new DataFileManagementDto();
        BeanUtils.copyProperties(dataFileManagement, dataFileManagementDto);
        if (dataFileManagement2 == null) {
            dataFileManagementDto.setParentName("");
        } else {
            dataFileManagementDto.setParentName(dataFileManagement2.getDataName());
        }
        return dataFileManagementDto;
    }

    @Override
    public List<DataFileManagementDto> queryList(Map<String, Object> map) {
        List<DataFileManagement> dataFileManagementList = dataFileManagementService.selectByMap(map);
        return convertList(dataFileManagementList, DataFileManagementDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<DataFileManagement> ew = new EntityWrapper<>();
        ew.allEq(map);
        return dataFileManagementService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(DataFileManagementDto dataFileManagementDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            DataFileManagement dataFileManagement = new DataFileManagement();
            revert(dataFileManagementDto, dataFileManagement);
            boolean flag = dataFileManagementService.insert(dataFileManagement);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(DataFileManagementDto dataFileManagementDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            DataFileManagement dataFileManagement = new DataFileManagement();
            revert(dataFileManagementDto, dataFileManagement);

            boolean flag = dataFileManagementService.updateById(dataFileManagement);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = dataFileManagementService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = dataFileManagementService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<DataFileManagementDto> getPage(Page<DataFileManagementDto> pageDto, DataFileManagementDto dataFileManagementDto) {
        Page<DataFileManagement> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        DataFileManagement dataFileManagement = new DataFileManagement();
        revert(dataFileManagementDto, dataFileManagement);
        EntityWrapper<DataFileManagement> wrapper = new EntityWrapper<>();
        wrapper.setEntity(dataFileManagement);
        page = dataFileManagementService.selectPage(page, wrapper);
        List<DataFileManagementDto> dataFileManagementDtoList = convertList(page.getRecords(), DataFileManagementDto.class);
        pageDto.setTotal(dataFileManagementService.selectCount(wrapper));
        pageDto.setRecords(dataFileManagementDtoList);
        return pageDto;
    }

    @Override
    public List<HashMap<String, String>> getFileList(Integer id) {
        List<HashMap<String, String>> dataFileManagementList = dataFileManagementService.queryFileList(id);
//        JSONArray a=  getFileSub(id);
        return dataFileManagementList;
    }

    @Override
    public String getFileList2(Integer id) {
        return getFileSub(id).toString();
    }

    public JSONArray getFileSub(Integer id) {
        JSONArray array = new JSONArray();
        List<HashMap<String, String>> dataFileManagementList = dataFileManagementService.queryFileList(id);
        for (HashMap<String, String> map : dataFileManagementList) {
            JSONObject object = new JSONObject();
            try {
                object.put("id", map.get("id"));
                object.put("parentId", map.get("parentId"));
                object.put("dataName", map.get("dataName"));
                JSONArray arraySub = new JSONArray();
                if (!map.get("sub").equals("0")) {
                    object.put("children", getFileSub(object.getInt("id")));
                }
                array.put(object);
            } catch (JSONException e) {
                e.printStackTrace();
            }

        }
        return array;
    }
}
