
package io.platform.fileManagement.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.fileManagement.biz.entity.DataFileStorage;
import io.platform.fileManagement.biz.service.DataFileStorageService;
import io.platform.fileManagement.dto.DataFileStorageDto;
import io.platform.fileManagement.service.client.api.DataFileStorageServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class DataFileStorageServiceClientImpl extends BaseServiceClient<DataFileStorage, DataFileStorageDto> implements DataFileStorageServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private DataFileStorageService dataFileStorageService;

    @Override
    public DataFileStorageDto queryObject(Long id) {
        DataFileStorage dataFileStorage = dataFileStorageService.selectById(id);
        DataFileStorageDto dataFileStorageDto = new DataFileStorageDto();
        BeanUtils.copyProperties(dataFileStorage, dataFileStorageDto);
        return dataFileStorageDto;
    }

    @Override
    public List<DataFileStorageDto> queryList(Map<String, Object> map) {
        List<DataFileStorage> dataFileStorageList = dataFileStorageService.selectByMap(map);
        return convertList(dataFileStorageList, DataFileStorageDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<DataFileStorage> ew = new EntityWrapper<>();
        ew.allEq(map);
        return dataFileStorageService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(DataFileStorageDto dataFileStorageDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            DataFileStorage dataFileStorage = new DataFileStorage();
            revert(dataFileStorageDto, dataFileStorage);
            if (dataFileStorage.getFileNumber() == null) {
                SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");//设置日期格式
                dataFileStorage.setFileNumber(df.format(new Date()));
            }
            if (null == dataFileStorage.getFileName() || "".equals(dataFileStorage.getFileName())) {
                dataFileStorage.setFileName(dataFileStorage.getFilePath().substring(dataFileStorage.getFilePath().lastIndexOf("/") + 1, dataFileStorage.getFilePath().length()));
            }
            dataFileStorage.setFileDate(new Date());
            boolean flag = dataFileStorageService.insert(dataFileStorage);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
            result.setSuccessMessage(dataFileStorage.getId() + "");
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(DataFileStorageDto dataFileStorageDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            DataFileStorage dataFileStorage = new DataFileStorage();
            revert(dataFileStorageDto, dataFileStorage);
            if (dataFileStorage.getFileNumber() == null) {
                SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");//设置日期格式
                dataFileStorage.setFileNumber(df.format(new Date()));
            }
            if (dataFileStorage.getDelFlag() != 0) {
                if (null == dataFileStorage.getFileName() || "".equals(dataFileStorage.getFileName())) {
                    dataFileStorage.setFileName(dataFileStorage.getFilePath().substring(dataFileStorage.getFilePath().lastIndexOf("/") + 1, dataFileStorage.getFilePath().length()));
                }
            }
            dataFileStorage.setFileDate(new Date());
            boolean flag = dataFileStorageService.updateById(dataFileStorage);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = dataFileStorageService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = dataFileStorageService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<DataFileStorageDto> getPage(Page<DataFileStorageDto> pageDto, DataFileStorageDto dataFileStorageDto) {
        Page<DataFileStorage> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        DataFileStorage dataFileStorage = new DataFileStorage();
        revert(dataFileStorageDto, dataFileStorage);
        if (dataFileStorageDto.getFileEndDate() != null&& !"".equals(dataFileStorageDto.getFileEndDate())) {
            dataFileStorageDto.setFileEndDate(dataFileStorageDto.getFileEndDate() + " 23:59:59");
        }
        EntityWrapper<DataFileStorage> wrapper = new EntityWrapper<>();
        wrapper.setEntity(dataFileStorage);
        wrapper.orderBy("id desc");
//        page = dataFileStorageService.selectPage(page,wrapper);
//        List<DataFileStorageDto> dataFileStorageDtoList = convertList(page.getRecords(),DataFileStorageDto.class);
        pageDto.setTotal(dataFileStorageService.queryFileListCount(page, dataFileStorageDto));
        pageDto.setRecords(dataFileStorageService.queryFileList(page, dataFileStorageDto));
        return pageDto;
    }


    @Override
    public List<DataFileStorageDto> selectHomeFileList() {
        EntityWrapper<DataFileStorage> dataFileOperatingEntityWrapper = new EntityWrapper<>();
        dataFileOperatingEntityWrapper.setEntity(new DataFileStorage());
        dataFileOperatingEntityWrapper.orderBy("id", false);
        dataFileOperatingEntityWrapper.last("LIMIT" + " " + 0 + "," + 3);
        List<DataFileStorage> dataFileOperating = dataFileStorageService.selectList(dataFileOperatingEntityWrapper);
        return convertList(dataFileOperating, DataFileStorageDto.class);
    }
}
