
package io.platform.moneyManagement.biz.service;

import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.service.impl.ServiceImpl;

import io.platform.budget.biz.entity.ProjectBillsBudgets;
import io.platform.budget.biz.service.ProjectBillsBudgetsService;
import io.platform.contract.biz.entity.ProjectBillsStlPlans;
import io.platform.moneyManagement.biz.entity.InvoiceBills;
import io.platform.moneyManagement.biz.mapper.InvoiceBillsMapper;
import io.platform.moneyManagement.dto.InvoiceBillsDto;
import io.platform.moneyManagement.dto.PayCrBillsDto;
import io.platform.project.biz.entity.ProjectBillsSubs;
import io.platform.project.biz.service.ProjectBillsSubsService;
import io.platform.project.dto.ProjectBS;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.utils.DataUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


@Service("invoiceBillsService")
public class InvoiceBillsService extends ServiceImpl<InvoiceBillsMapper, InvoiceBills> {
    @Resource
    private ProjectBillsBudgetsService projectBillsBudgetsService;
    @Resource
    private ProjectBillsSubsService projectBillsSubsService;


    public ProjectBS selectInvoice(ProjectBillsSubsDto projectBillsSubsDto) {
        return baseMapper.selectInvoice(projectBillsSubsDto);
    }

    public List<ProjectBillsStlPlans> selectProStlPlans(ProjectBS projectBS) {
        return baseMapper.selectProStlPlans(projectBS);
    }

    public ProjectBS selectDirectCostTemporary(Map<String, Object> map) {
        return baseMapper.selectDirectCostTemporary(map);
    }

    public int selectInvoiceTotal(Map<String, Object> map) {
        return baseMapper.selectInvoiceTotal(map);
    }

    public List<Map<String, Object>> selectInvoiceRecords(Map<String, Object> map) {
        return baseMapper.selectInvoiceRecords(map);
    }

    public int selectInvoiceMaterialTotal(Map<String, Object> map) {
        return baseMapper.selectInvoiceMaterialTotal(map);
    }

    public List<Map<String, Object>> selectInvoiceMaterialRecords(Map<String, Object> map) {
        return baseMapper.selectInvoiceMaterialRecords(map);
    }

    public Map<String, Object> selectReimbursementPrint(InvoiceBillsDto invoiceBillsDto) {
        return baseMapper.selectReimbursementPrint(invoiceBillsDto);
    }

    @Transactional(rollbackFor = Exception.class)
    public String updateProjectPrice(InvoiceBills invoiceBills) {
        EntityWrapper<ProjectBillsBudgets> budgetsEntityWrapper = new EntityWrapper<>();
        budgetsEntityWrapper.eq("project_sub_no", invoiceBills.getProjectSubNo())
                .eq("budget_id", invoiceBills.getBudgetId())
                .eq("branch_id", invoiceBills.getBranchId());
        ProjectBillsBudgets billsBudgets = projectBillsBudgetsService.selectOne(budgetsEntityWrapper);
        if (billsBudgets.getSubInvAmtCr() != 0.0) {
            billsBudgets.setSubInvAmtCr(DataUtils.keepDecimals(billsBudgets.getSubInvAmtCr() + invoiceBills.getInvAmt()));
        } else {
            billsBudgets.setSubInvAmtCr(invoiceBills.getInvAmt());
        }
        if (invoiceBills.getIsSpecial() == 0) {
            if (billsBudgets.getSubInvAmtCr() > billsBudgets.getBudgetAmt()) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return "成本开票金额超出成本预算金额";
            }
        }
        boolean billsBudgetsType = projectBillsBudgetsService.updateById(billsBudgets);
        if (!billsBudgetsType) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            return "更新项目预算失败";
        }
        EntityWrapper<ProjectBillsSubs> subsEntityWrapper = new EntityWrapper<>();
        subsEntityWrapper.eq("project_sub_no", invoiceBills.getProjectSubNo())
                .eq("branch_id", invoiceBills.getBranchId());
        ProjectBillsSubs projectBillsSubs = projectBillsSubsService.selectOne(subsEntityWrapper);
        double sum = projectBillsBudgetsService.selectApprovedAmountSum(billsBudgets);
        projectBillsSubs.setActualBudgetAmt(sum);
        if (projectBillsSubs.getSubInvAmtCr() != 0.0) {
            projectBillsSubs.setSubInvAmtCr(DataUtils.keepDecimals(projectBillsSubs.getSubInvAmtCr() + invoiceBills.getInvAmt()));
        } else {
            projectBillsSubs.setSubInvAmtCr(invoiceBills.getInvAmt());
        }
        boolean subType = projectBillsSubsService.updateById(projectBillsSubs);
        if (!subType) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            return "更新项目发票失败";
        }
        return "成功";
    }

    public int selectPaymentInvoiceCount(Map<String, Object> map) {
        return baseMapper.selectPaymentInvoiceCount(map);
    }

    public List<InvoiceBills> selectPaymentInvoiceRecords(Map<String, Object> map) {
        return baseMapper.selectPaymentInvoiceRecords(map);
    }

    public List<Map<String, Object>> selectInvoiceIndirectPro(InvoiceBillsDto invoiceBillsDto) {
        return baseMapper.selectInvoiceIndirectPro(invoiceBillsDto);
    }

    public Map<String, Object> selectPayInvoProSub(InvoiceBillsDto invoiceBillsDto) {
        return baseMapper.selectPayInvoProSub(invoiceBillsDto);
    }

    public Map<String, Object> selectPayCrIndirectPrint(PayCrBillsDto payCrBillsDto) {
        return baseMapper.selectPayCrIndirectPrint(payCrBillsDto);
    }

    public List<ProjectBillsSubs> selectPayCrIndirectPrintProSub(PayCrBillsDto payCrBillsDto) {
        return baseMapper.selectPayCrIndirectPrintProSub(payCrBillsDto);
    }

    public int selectOtherIndirectCount(Map<String, Object> map) {
        return baseMapper.selectOtherIndirectCount(map);
    }

    public List<Map<String, Object>> selectOtherIndirect(Map<String, Object> map) {
        return baseMapper.selectOtherIndirect(map);
    }
}
