
package io.platform.moneyManagement.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.engineering.biz.entity.Bpurchases;
import io.platform.moneyManagement.biz.entity.InvoiceBills;
import io.platform.moneyManagement.biz.entity.InvoiceBillsItems;
import io.platform.moneyManagement.biz.service.InvoiceBillsItemsService;
import io.platform.moneyManagement.biz.service.InvoiceBillsService;
import io.platform.moneyManagement.dto.InvoiceBillsItemsDto;
import io.platform.moneyManagement.service.client.api.InvoiceBillsItemsServiceClient;
import io.platform.moneyManagement.service.client.api.InvoiceBillsPlansServiceClient;
import io.platform.sys.dto.SysUserDto;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = InvoiceBillsItemsServiceClient.class)
public class InvoiceBillsItemsServiceClientImpl extends BaseServiceClient<InvoiceBillsItems, InvoiceBillsItemsDto> implements InvoiceBillsItemsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private InvoiceBillsItemsService invoiceBillsItemsService;
    @Resource
    private InvoiceBillsService invoiceBillsService;

    @Override
    public InvoiceBillsItemsDto queryObject(Long id) {
        InvoiceBillsItems invoiceBillsItems = invoiceBillsItemsService.selectById(id);
        InvoiceBillsItemsDto invoiceBillsItemsDto = new InvoiceBillsItemsDto();
        BeanUtils.copyProperties(invoiceBillsItems, invoiceBillsItemsDto);
        return invoiceBillsItemsDto;
    }

    @Override
    public List<InvoiceBillsItemsDto> queryList(Map<String, Object> map) {
        List<InvoiceBillsItems> invoiceBillsItemsList = invoiceBillsItemsService.selectByMap(map);
        return convertList(invoiceBillsItemsList, InvoiceBillsItemsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<InvoiceBillsItems> ew = new EntityWrapper<>();
        ew.allEq(map);
        return invoiceBillsItemsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(InvoiceBillsItemsDto invoiceBillsItemsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            InvoiceBillsItems invoiceBillsItems = new InvoiceBillsItems();
            revert(invoiceBillsItemsDto, invoiceBillsItems);
            boolean flag = invoiceBillsItemsService.insert(invoiceBillsItems);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(InvoiceBillsItemsDto invoiceBillsItemsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            InvoiceBillsItems invoiceBillsItems = new InvoiceBillsItems();
            revert(invoiceBillsItemsDto, invoiceBillsItems);

            boolean flag = invoiceBillsItemsService.updateById(invoiceBillsItems);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = invoiceBillsItemsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = invoiceBillsItemsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<InvoiceBillsItemsDto> getPage(Page<InvoiceBillsItemsDto> pageDto, InvoiceBillsItemsDto invoiceBillsItemsDto) {
        Page<InvoiceBillsItems> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        InvoiceBillsItems invoiceBillsItems = new InvoiceBillsItems();
        revert(invoiceBillsItemsDto, invoiceBillsItems);
        EntityWrapper<InvoiceBillsItems> wrapper = new EntityWrapper<>();
        wrapper.setEntity(invoiceBillsItems);
        page = invoiceBillsItemsService.selectPage(page, wrapper);
        List<InvoiceBillsItemsDto> invoiceBillsItemsDtoList = convertList(page.getRecords(), InvoiceBillsItemsDto.class);
        pageDto.setTotal(invoiceBillsItemsService.selectCount(wrapper));
        pageDto.setRecords(invoiceBillsItemsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> selectNumber(String subNo, Integer purchaseId, Integer budgetId) {
        Map<String, Object> map = new HashMap<>();
        double number = 0d;
        InvoiceBills invoiceBills = new InvoiceBills();
        invoiceBills.setProjectSubNo(subNo);
        invoiceBills.setPurchaseId(purchaseId);
        invoiceBills.setBudgetId(budgetId);
        List<InvoiceBills> invoiceBillsList = invoiceBillsService.selectList(new EntityWrapper<>(invoiceBills));
        for (InvoiceBills bills : invoiceBillsList) {
            double numberCopy = 0d;
            EntityWrapper<InvoiceBillsItems> itemsEntityWrapper = new EntityWrapper<>();
            itemsEntityWrapper.eq("bill_no", bills.getBillNo()); // TODO: 此处无法区分是不是该供应商的
            List<InvoiceBillsItems> invoiceBillsItemsList = invoiceBillsItemsService.selectList(itemsEntityWrapper);
            for (InvoiceBillsItems billsItems : invoiceBillsItemsList) {
                numberCopy = billsItems.getInvoiceAmt() + number;
            }
            number = numberCopy;
        }
        map.put("number", number);
        return map;
    }

    @Override
    public ExecuteResult<String> deleteItem(InvoiceBillsItemsDto invoiceBillsItemsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (invoiceBillsItemsDto != null && invoiceBillsItemsDto.getId() != null) {
                boolean deleteById = invoiceBillsItemsService.deleteById(invoiceBillsItemsDto.getId());
                if (!deleteById) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("删除失败");
                    return result;
                }
            } else {
                result.addErrorMessage("删除失败");
                return result;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Map<String, Object> selectDirectPaymentPurchase(String subNo, Integer budId, SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        List<Bpurchases> list = invoiceBillsItemsService.selectDirectPaymentPurchase(subNo,budId,sysUserDto);
        map.put("purchaseList",list);
        return map;
    }

}
