
package io.platform.project.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.moneyManagement.service.client.api.PayDrBillsServiceClient;
import io.platform.project.biz.entity.AttachFiles;
import io.platform.project.biz.service.AttachFilesService;
import io.platform.project.dto.AttachFilesDto;
import io.platform.project.service.client.api.AttachFilesServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = AttachFilesServiceClient.class)
public class AttachFilesServiceClientImpl extends BaseServiceClient<AttachFiles, AttachFilesDto> implements AttachFilesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private AttachFilesService attachFilesService;

    @Override
    public AttachFilesDto queryObject(Long id) {
        AttachFiles attachFiles = attachFilesService.selectById(id);
        AttachFilesDto attachFilesDto = new AttachFilesDto();
        BeanUtils.copyProperties(attachFiles, attachFilesDto);
        return attachFilesDto;
    }

    @Override
    public List<AttachFilesDto> queryList(Map<String, Object> map) {
        List<AttachFiles> attachFilesList = attachFilesService.selectByMap(map);
        return convertList(attachFilesList, AttachFilesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<AttachFiles> ew = new EntityWrapper<>();
        ew.allEq(map);
        return attachFilesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(AttachFilesDto attachFilesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            AttachFiles attachFiles = new AttachFiles();
            revert(attachFilesDto, attachFiles);
            boolean flag = attachFilesService.insert(attachFiles);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> update(AttachFilesDto attachFilesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            AttachFiles attachFiles = new AttachFiles();
            revert(attachFilesDto, attachFiles);

            boolean flag = attachFilesService.updateById(attachFiles);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = attachFilesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = attachFilesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<AttachFilesDto> getPage(Page<AttachFilesDto> pageDto, AttachFilesDto attachFilesDto) {
        Page<AttachFiles> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        AttachFiles attachFiles = new AttachFiles();
        revert(attachFilesDto, attachFiles);
        EntityWrapper<AttachFiles> wrapper = new EntityWrapper<>();
        wrapper.setEntity(attachFiles);
        page = attachFilesService.selectPage(page, wrapper);
        List<AttachFilesDto> attachFilesDtoList = convertList(page.getRecords(), AttachFilesDto.class);
        pageDto.setTotal(attachFilesService.selectCount(wrapper));
        pageDto.setRecords(attachFilesDtoList);
        return pageDto;
    }
}
