
package io.platform.project.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.project.biz.entity.Dictionaries;
import io.platform.project.biz.service.DictionariesService;
import io.platform.project.dto.DictionariesDto;
import io.platform.project.service.client.api.DictionariesServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class DictionariesServiceClientImpl extends BaseServiceClient<Dictionaries, DictionariesDto> implements DictionariesServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private DictionariesService dictionariesService;

    @Override
    public DictionariesDto queryObject(Long id) {
        Dictionaries dictionaries = dictionariesService.selectById(id);
        DictionariesDto dictionariesDto = new DictionariesDto();
        BeanUtils.copyProperties(dictionaries, dictionariesDto);
        return dictionariesDto;
    }

    @Override
    public List<DictionariesDto> queryList(Map<String, Object> map) {
        List<Dictionaries> dictionariesList = dictionariesService.selectByMap(map);
        return convertList(dictionariesList, DictionariesDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<Dictionaries> ew = new EntityWrapper<>();
        ew.allEq(map);
        return dictionariesService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(DictionariesDto dictionariesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Dictionaries dictionaries = new Dictionaries();
            revert(dictionariesDto, dictionaries);
            boolean flag = dictionariesService.insert(dictionaries);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(DictionariesDto dictionariesDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Dictionaries dictionaries = new Dictionaries();
            revert(dictionariesDto, dictionaries);

            boolean flag = dictionariesService.updateById(dictionaries);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = dictionariesService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = dictionariesService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<DictionariesDto> getPage(Page<DictionariesDto> pageDto, DictionariesDto dictionariesDto) {
        Page<Dictionaries> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        Dictionaries dictionaries = new Dictionaries();
        revert(dictionariesDto, dictionaries);
        EntityWrapper<Dictionaries> wrapper = new EntityWrapper<>();
        wrapper.setEntity(dictionaries);
        page = dictionariesService.selectPage(page, wrapper);
        List<DictionariesDto> dictionariesDtoList = convertList(page.getRecords(), DictionariesDto.class);
        pageDto.setTotal(dictionariesService.selectCount(wrapper));
        pageDto.setRecords(dictionariesDtoList);
        return pageDto;
    }
}
