
package io.platform.project.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;

import io.platform.base.common.utils.CopyUtils;
import io.platform.engineering.biz.entity.*;
import io.platform.engineering.biz.service.*;
import io.platform.engineering.dto.BprojectNodeStepsDto;
import io.platform.project.biz.entity.*;
import io.platform.project.biz.service.*;
import io.platform.project.dto.ProcessBillsDto;
import io.platform.project.dto.ProjectBS;
import io.platform.project.dto.ProjectBillsStepsDto;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.project.service.client.api.ProcessBillsServiceClient;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.ZoneId;
import java.util.*;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;
import org.springframework.web.bind.annotation.RequestBody;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = ProcessBillsServiceClient.class)
public class ProcessBillsServiceClientImpl extends BaseServiceClient<ProcessBills, ProcessBillsDto> implements ProcessBillsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BcorpsService bcorpsService;
    @Resource
    private BdeptsService bdeptsService;
    @Resource
    private SysUserService sysUserService;
    @Resource
    private BbranchsService bbranchsService;
    @Resource
    private ProjectbillsService projectBillsService;
    @Resource
    private ProcessBillsService processBillsService;
    @Resource
    private BprojectNodesService bprojectNodesService;
    @Resource
    private ProjectBillsSubsService projectBillsSubsService;
    @Resource
    private ProjectBillsStepsService projectBillsStepsService;
    @Resource
    private BprojectNodeStepsService bprojectNodeStepsService;
    @Resource
    private ProcessBillsStepsService processBillsStepsService;

    @Override
    public ProcessBillsDto queryObject(Long id) {
        ProcessBills processBills = processBillsService.selectById(id);
        ProcessBillsDto processBillsDto = new ProcessBillsDto();
        BeanUtils.copyProperties(processBills, processBillsDto);
        return processBillsDto;
    }

    @Override
    public List<ProcessBillsDto> queryList(Map<String, Object> map) {
        List<ProcessBills> processBillsList = processBillsService.selectByMap(map);
        return convertList(processBillsList, ProcessBillsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<ProcessBills> ew = new EntityWrapper<>();
        ew.allEq(map);
        return processBillsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(ProcessBillsDto processBillsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProcessBills processBills = new ProcessBills();
            revert(processBillsDto, processBills);
            boolean flag = processBillsService.insert(processBills);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(ProcessBillsDto processBillsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProcessBills processBills = new ProcessBills();
            revert(processBillsDto, processBills);

            boolean flag = processBillsService.updateById(processBills);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = processBillsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = processBillsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Map<String, Object> getPage(@RequestBody Map<String, Object> map) {
        Map<String, Object> hashMap = new HashMap<>();
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            if (map.get("startDate") != null && map.get("startDate") != "") {
                long startimes = (long) map.get("startDate");
                String startTime = sdf.format(new Date(startimes));
                map.put("startDateTime", startTime);
            }
            if (map.get("endDate") != null && map.get("endDate") != "") {
                long endtimes = (long) map.get("endDate");
                LocalDateTime localDateTime = LocalDateTime.ofInstant(Instant.ofEpochMilli(endtimes), ZoneId.systemDefault());
                LocalDateTime endOfDay = localDateTime.with(LocalTime.MAX);
                Date from = Date.from(endOfDay.atZone(ZoneId.systemDefault()).toInstant());
                String endTime = sdf.format(from);
                map.put("endDateTime", endTime);
            }
            int num = processBillsService.selectProcessTotal(map);
            if (num != 0) {
                int current = (int) map.get("current");
                int size = (int) map.get("size");
                if (current <= 1) {
                    current = 0;
                } else {
                    current = (current - 1) * size;
                }
                map.put("size", size);
                map.put("current", current);
                List<Map<String, Object>> mapList = processBillsService.selectProcessRecords(map);
                Page pageDto = new Page<>();
                pageDto.setRecords(mapList);
                pageDto.setTotal(num);
                hashMap.put("page", pageDto);
            }
            return hashMap;
        } catch (Exception e) {
            logger.error("操作异常：" + e.toString(), e);
        }
        return null;
    }

    @Override
    public Map<String, Object> changeFuzzyQueryProjectSub(ProjectBillsSubsDto projectBillsSubsDto) {
        if (projectBillsSubsDto.getId() != null && projectBillsSubsDto.getId() != 0) {
            Map<String, Object> map = new HashMap<>();
            ProjectBS projectBS = processBillsService.selectProjectSub(projectBillsSubsDto);
            if (projectBS != null) {
                map.put("project", projectBS);
                List<ProjectBillsSteps> projectBillsSteps = processBillsService.selectProStepsDate(projectBS);
                if (projectBillsSteps.size() != 0) {
                    map.put("projectSteps", projectBillsSteps);
                    List<BprojectNodes> bprojectNodes = new ArrayList<>();
                    List<BprojectNodeSteps> bprojectNodeSteps = new ArrayList<>();
                    EntityWrapper<BprojectNodes> bprojectNodesEntityWrapper = new EntityWrapper<>();
                    bprojectNodesEntityWrapper.setSqlSelect("id", "project_node_name");
                    bprojectNodes = bprojectNodesService.selectList(bprojectNodesEntityWrapper);
                    if (bprojectNodes != null) {
                        map.put("nodes", bprojectNodes);
                    }
                    EntityWrapper<BprojectNodeSteps> bprojectNodeStepsEntityWrapper = new EntityWrapper<>();
                    bprojectNodeStepsEntityWrapper.setSqlSelect("id", "project_step_name");
                    bprojectNodeSteps = bprojectNodeStepsService.selectList(bprojectNodeStepsEntityWrapper);
                    if (bprojectNodeSteps != null) {
                        map.put("nodeSteps", bprojectNodeSteps);
                    }
                }
                if (projectBS.getCorpId() != null && projectBS.getCorpId() != 0) {
                    EntityWrapper<Bcorps> bcorpsEntityWrapper = new EntityWrapper<>();
                    bcorpsEntityWrapper.setSqlSelect("id", "c_name").eq("id", projectBS.getCorpId());
                    Bcorps bcorps = bcorpsService.selectOne(bcorpsEntityWrapper);
                    map.put("corp", bcorps);
                }
                if (projectBS.getConstructorId() != null && projectBS.getConstructorId() != 0) {
                    EntityWrapper<Bbranchs> bbranchsEntityWrapper = new EntityWrapper<>();
                    bbranchsEntityWrapper.setSqlSelect("id", "c_name").eq("id", projectBS.getConstructorId());
                    Bbranchs bbranchs = bbranchsService.selectOne(bbranchsEntityWrapper);
                    map.put("branch", bbranchs);
                }
                if (projectBS.getProjectSubMngId() != null && projectBS.getProjectSubMngId() != 0) {
                    SysUser sysUser = sysUserService.selectById(projectBS.getProjectSubMngId());
                    map.put("user", sysUser);
                }
                if (projectBS.getProjectSubMngDeptId() != null && projectBS.getProjectSubMngDeptId() != 0) {
                    EntityWrapper<Bdepts> bdeptsEntityWrapper = new EntityWrapper<>();
                    bdeptsEntityWrapper.setSqlSelect("id", "dept_name").eq("id", projectBS.getProjectSubMngDeptId());
                    Bdepts bdepts = bdeptsService.selectOne(bdeptsEntityWrapper);
                    map.put("dept", bdepts);
                }
                return map;
            }
        }
        return null;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> processTemporary(String process, String processSteps, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProcessBills processBills = JSONArray.parseObject(process, ProcessBills.class);
            JSONArray jsonArray = JSONArray.parseArray(processSteps);
            List<ProcessBillsSteps> processBillsStepsList = JSONObject.parseArray(jsonArray.toJSONString(), ProcessBillsSteps.class);
            EntityWrapper<ProcessBillsSteps> processBillsStepsEntityWrapper = new EntityWrapper<>();
            processBillsStepsEntityWrapper.setSqlSelect("id")
                    .eq("bill_no", processBills.getBillNo()).eq("project_sub_no", processBills.getProjectSubNo());
            List<ProcessBillsSteps> billsSteps = processBillsStepsService.selectList(processBillsStepsEntityWrapper);
            if (billsSteps.size() != 0) {
                for (ProcessBillsSteps pb : billsSteps) {
                    processBillsStepsService.deleteById(pb);
                }
            }
            if (processBillsStepsList.size() != 0) {
                int line = 0;
                for (ProcessBillsSteps pb : processBillsStepsList) {
                    if (pb.getActEndDate() != null) {
                        line++;
                        pb.setBillNo(processBills.getBillNo());
                        pb.setLineNo(line);
                        pb.setActId(106);
                        boolean insertStep = processBillsStepsService.insert(pb);
                        if (!insertStep) {
                            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                            result.addErrorMessage("暂存失败, 新增明细失败");
                            return result;
                        }
                    }
                }
            }
            processBills.setActId(106);
            processBills.setBillStatus(2);
            processBills.setOpUserId(sysUserDto.getUserId().intValue());
            processBills.setOpUserName(sysUserDto.getUsername());
            processBills.setCreateDate(new Date());
            processBills.setBillDate(new Date());
            boolean update = processBillsService.insertOrUpdate(processBills);
            if (!update) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                result.addErrorMessage("暂存失败,请确认信息重新提交");
                return result;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 暂存失败：" + e.toString(), e);
            result.addErrorMessage("暂存失败：请确认信息重新提交");
            return result;
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> processSave(String process, String processSteps, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProcessBills processBills = JSONArray.parseObject(process, ProcessBills.class);
            JSONArray jsonArray = JSONArray.parseArray(processSteps);
            List<ProcessBillsSteps> processBillsStepsList = JSONObject.parseArray(jsonArray.toJSONString(), ProcessBillsSteps.class);
            EntityWrapper<ProcessBillsSteps> billsStepsEntityWrapper = new EntityWrapper<>();
            billsStepsEntityWrapper.setSqlSelect("id").eq("bill_no", processBills.getBillNo())
                    .eq("project_sub_no", processBills.getProjectSubNo());
            List<ProcessBillsSteps> billsSteps = processBillsStepsService.selectList(billsStepsEntityWrapper);
            if (billsSteps.size() != 0) {
                for (ProcessBillsSteps pb : billsSteps) {
                    processBillsStepsService.deleteById(pb);
                }
            }
            String billNo = null;
            if (processBillsStepsList.size() != 0) {
                int line = 0;
                for (ProcessBillsSteps pb : processBillsStepsList) {
                    if (pb.getActEndDate() != null) {
                        if (pb.getActDays() != null) {
                            EntityWrapper<ProjectBillsSteps> projectBillsStepsEntityWrapper = new EntityWrapper<>();
                            projectBillsStepsEntityWrapper.setSqlSelect("id", "project_work_rate").eq("project_sub_no", pb.getProjectSubNo())
                                    .eq("project_node_id", pb.getProjectNodeId()).eq("project_step_id", pb.getProjectStepId());
                            ProjectBillsSteps projectBillsSteps = projectBillsStepsService.selectOne(projectBillsStepsEntityWrapper);
                            if (projectBillsSteps != null) {
                                projectBillsSteps.setActEndDate(pb.getActEndDate());
                                projectBillsSteps.setActDays(pb.getActDays());
                                boolean proStepUpdate = projectBillsStepsService.updateById(projectBillsSteps);
                                if (!proStepUpdate) {
                                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                                    result.addErrorMessage("提交失败：更新节点表失败");
                                    return result;
                                }
                                EntityWrapper<ProjectBillsSubs> projectBillsSubsEntityWrapper = new EntityWrapper<>();
                                projectBillsSubsEntityWrapper.setSqlSelect("id", "bill_no", "current_progress")
                                        .eq("project_sub_no", processBills.getProjectSubNo());
                                ProjectBillsSubs billsSubs = projectBillsSubsService.selectOne(projectBillsSubsEntityWrapper);
                                if (billsSubs != null) {
                                    billNo = billsSubs.getBillNo();
                                    billsSubs.setCurrentProgress(billsSubs.getCurrentProgress() + projectBillsSteps.getProjectWorkRate());
                                    boolean updateById = projectBillsSubsService.updateById(billsSubs);
                                    if (!updateById) {
                                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                                        result.addErrorMessage("提交失败：更新项目表失败");
                                        return result;
                                    }
                                }
                            } else {
                                result.addErrorMessage("里程碑未找到失败。");
                                return result;
                            }
                            line++;
                            pb.setLineNo(line);
                            pb.setActId(106);
                            boolean insertStep = processBillsStepsService.insert(pb);
                            if (!insertStep) {
                                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                                result.addErrorMessage("提交失败：请确认信息后提交");
                                return result;
                            }
                        } else {
                            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                            result.addErrorMessage("提交失败：请填写实际施工日期与实际施工天数");
                            return result;
                        }
                    }
                }
            }
            EntityWrapper<ProjectBillsSubs> projectBillsSubsEntityWrapper = new EntityWrapper<>();
            projectBillsSubsEntityWrapper.setSqlSelect("id", "bill_no").eq("bill_no", billNo)
                    .ne("current_progress", 100);
            List<ProjectBillsSubs> projectBillsSubsList = projectBillsSubsService.selectList(projectBillsSubsEntityWrapper);
            if (Objects.equals(projectBillsSubsList.size(), 0)) {
                EntityWrapper<Projectbills> projectbillsEntityWrapper = new EntityWrapper<>();
                projectbillsEntityWrapper.setSqlSelect("id", "pro_current_status").eq("bill_no", billNo);
                Projectbills projectbills = projectBillsService.selectOne(projectbillsEntityWrapper);
                projectbills.setProCurrentStatus(6);
                boolean updateById = projectBillsService.updateById(projectbills);
                if (!updateById) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("提交失败：更新总包数据失败");
                    return result;
                }
            }
            processBills.setActId(106);
            processBills.setBillStatus(6);
            processBills.setOpUserId(sysUserDto.getUserId().intValue());
            processBills.setOpUserName(sysUserDto.getUsername());
            processBills.setCreateDate(new Date());
            processBills.setBillDate(new Date());
            processBills.setPostDate(new Date());
            boolean insertProcess = processBillsService.insertOrUpdate(processBills);
            if (!insertProcess) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                result.addErrorMessage("提交失败：请确认信息重新提交");
                return result;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 提交失败：" + e.toString(), e);
            result.addErrorMessage("提交失败：请确认信息重新提交");
            return result;
        }
        return result;
    }

    @Override
    public Map<String, Object> fuzzyQueryProcess(Page pageDto, ProcessBillsDto processBillsDto) {
        if (processBillsDto != null) {
            Map<String, Object> map = new HashMap<>();
            EntityWrapper<ProcessBills> entityWrapper = new EntityWrapper<>();
            if (processBillsDto.getBillStatus() != null && processBillsDto.getBillStatus() != 0) {
                entityWrapper.eq("bill_status", processBillsDto.getBillStatus());
            }
            if (processBillsDto.getBranchId() != null && processBillsDto.getBranchId() != 0) {
                entityWrapper.eq("branch_id", processBillsDto.getBranchId());
            }
            if (processBillsDto.getBillNo() != null && !processBillsDto.getBillNo().equals("")) {
                entityWrapper.like("bill_no", "%" + processBillsDto.getBillNo() + "%");
            }
            if (processBillsDto.getRemarks() != null && !processBillsDto.getRemarks().equals("")) {
                entityWrapper.like("remarks", "%" + processBillsDto.getRemarks() + "%");
            }
            if (processBillsDto.getProjectSubNo() != null && !processBillsDto.getProjectSubNo().equals("")) {
                entityWrapper.like("project_sub_no", "%" + processBillsDto.getProjectSubNo() + "%");
            }
            int num = processBillsService.selectCount(entityWrapper);
            if (num != 0) {
                Page page = DataUtils.processingPage(pageDto);
                entityWrapper.last("LIMIT " + page.getCurrent() + "," + page.getSize());
                List<ProcessBills> processBills = processBillsService.selectList(entityWrapper);
                if (processBills.size() != 0) {
                    pageDto.setTotal(num);
                    pageDto.setRecords(processBills);
                }
                map.put("page", pageDto);
                return map;
            }
        }
        return null;
    }

    @Override
    public String queryProjectStartAttach(ProjectBillsSubsDto projectBillsSubsDto) {
        if (projectBillsSubsDto != null && projectBillsSubsDto.getProjectSubNo() != null) {
            EntityWrapper<ProjectBillsSubs> projectBillsSubsEntityWrapper = new EntityWrapper<>();
            projectBillsSubsEntityWrapper.setSqlSelect("id", "bill_no").eq("project_sub_no", projectBillsSubsDto.getProjectSubNo());
            ProjectBillsSubs projectBillsSubs = projectBillsSubsService.selectOne(projectBillsSubsEntityWrapper);
            if (projectBillsSubs != null) {
                EntityWrapper<Projectbills> entityWrapper = new EntityWrapper<>();
                entityWrapper.setSqlSelect("id", "set_start_attach_id").eq("bill_no", projectBillsSubs.getBillNo());
                Projectbills projectbills = projectBillsService.selectOne(entityWrapper);
                if (projectbills != null) {
                    return projectbills.getSetStartAttachId();
                }
            }
        }
        return null;
    }

    @Override
    public Map<String, Object> queryProcessValue(Integer id, SysUserDto sysUserDto) {
        if (id != null) {
            List<ProcessBillsSteps> billsSteps = processBillsStepsService.selectProcessVal(id);
            if (billsSteps.size() != 0) {
                Map<String, Object> map = new HashMap<>();
                map.put("billSteps", billsSteps);
                EntityWrapper<BprojectNodes> bprojectNodesEntityWrapper = new EntityWrapper<>();
                if (sysUserDto.getLoginContractorId() != 1) {
                    bprojectNodesEntityWrapper.eq("branch_id", sysUserDto.getLoginContractorId());
                }
                List<BprojectNodes> bprojectNodes = bprojectNodesService.selectList(bprojectNodesEntityWrapper);
                if (bprojectNodes.size() != 0) {
                    map.put("proNodes", bprojectNodes);
                }
                EntityWrapper<BprojectNodeSteps> bprojectNodeStepsEntityWrapper = new EntityWrapper<>();
                if (sysUserDto.getLoginContractorId() != 1) {
                    bprojectNodeStepsEntityWrapper.eq("branch_id", sysUserDto.getLoginContractorId());
                }
                List<BprojectNodeSteps> bprojectNodeSteps = bprojectNodeStepsService.selectList(bprojectNodeStepsEntityWrapper);
                if (bprojectNodeSteps.size() != 0) {
                    map.put("proNodeSteps", bprojectNodeSteps);
                }
                return map;
            }
        }
        return null;
    }

    @Override
    public Map<String, Object> selectProjectProcessData(Integer id) {
        Map<String, Object> map = new HashMap<>();
        Map<String, Object> maps = processBillsService.selectProjectProcessData(id);
        String subNo = maps.get("projectSubNo").toString();
        EntityWrapper<ProjectBillsSteps> processBillsStepsEntityWrapper = new EntityWrapper<>();
        processBillsStepsEntityWrapper.eq("project_sub_no", subNo);
        map.put("projectData",maps);
        map.put("steps", projectBillsStepsService.selectList(processBillsStepsEntityWrapper));
        return map;
    }

    @Override
    public Map<String, Object> queryDataTemporary(ProcessBillsDto processBillsDto) {
        if (processBillsDto.getId() != null && processBillsDto.getId() != 0) {
            Map<String, Object> map = new HashMap<>();
            EntityWrapper<ProcessBills> processBillsEntityWrapper = new EntityWrapper<>();
            processBillsEntityWrapper.eq("id", processBillsDto.getId());
            ProcessBills processBills = processBillsService.selectOne(processBillsEntityWrapper);
            if (processBills != null) {
                EntityWrapper<ProjectBillsSubs> billsSubsEntityWrapper = new EntityWrapper<>();
                billsSubsEntityWrapper.setSqlSelect("id").eq("project_sub_no", processBills.getProjectSubNo());
                ProjectBillsSubs billsSubs = projectBillsSubsService.selectOne(billsSubsEntityWrapper);
                ProjectBillsSubsDto projectBillsSubsDto = new ProjectBillsSubsDto();
                CopyUtils.copyProperties(billsSubs, projectBillsSubsDto);
                ProjectBS projectBS = processBillsService.selectDataTemporary(projectBillsSubsDto);
                if (projectBS.getCorpId() != null && projectBS.getCorpId() != 0) {
                    EntityWrapper<Bcorps> bcorpsEntityWrapper = new EntityWrapper<>();
                    bcorpsEntityWrapper.setSqlSelect("id", "c_name").eq("id", projectBS.getCorpId());
                    Bcorps bcorps = bcorpsService.selectOne(bcorpsEntityWrapper);
                    map.put("corp", bcorps);
                }
                if (projectBS.getConstructorId() != null && projectBS.getConstructorId() != 0) {
                    EntityWrapper<Bbranchs> bbranchsEntityWrapper = new EntityWrapper<>();
                    bbranchsEntityWrapper.setSqlSelect("id", "c_name").eq("id", projectBS.getConstructorId());
                    Bbranchs bbranchs = bbranchsService.selectOne(bbranchsEntityWrapper);
                    map.put("branch", bbranchs);
                }
                if (projectBS.getProjectSubMngId() != null && projectBS.getProjectSubMngId() != 0) {
                    SysUser sysUser = sysUserService.selectById(projectBS.getProjectSubMngId());
                    map.put("user", sysUser);
                }
                if (projectBS.getProjectSubMngDeptId() != null && projectBS.getProjectSubMngDeptId() != 0) {
                    EntityWrapper<Bdepts> bdeptsEntityWrapper = new EntityWrapper<>();
                    bdeptsEntityWrapper.setSqlSelect("id", "dept_name").eq("id", projectBS.getProjectSubMngDeptId());
                    Bdepts bdepts = bdeptsService.selectOne(bdeptsEntityWrapper);
                    map.put("dept", bdepts);
                }
                projectBS.setId(processBills.getId());
                projectBS.setBillNo(processBills.getBillNo());
                map.put("proBs", projectBS);
                EntityWrapper<ProcessBillsSteps> stepsEntityWrapper = new EntityWrapper<>();
                stepsEntityWrapper.eq("bill_no", processBills.getBillNo()).eq("project_sub_no", processBills.getProjectSubNo());
                List<ProcessBillsSteps> billsSteps = processBillsStepsService.selectList(stepsEntityWrapper);
                map.put("proSteps", billsSteps);
                if (billsSteps.size() != 0) {
                    List<Integer> nodeId = new ArrayList<>();
                    List<Integer> stepIdId = new ArrayList<>();
                    for (ProcessBillsSteps pb : billsSteps) {
                        if (pb.getProjectNodeId() != 0) {
                            nodeId.add(pb.getProjectNodeId());
                        }
                        if (pb.getProjectStepId() != 0) {
                            stepIdId.add(pb.getProjectStepId());
                        }
                    }
                    List<BprojectNodes> bprojectNodes = new ArrayList<>();
                    List<BprojectNodeSteps> bprojectNodeSteps = new ArrayList<>();
                    List<Integer> nodes = DataUtils.integerDeduplication(nodeId);
                    List<Integer> steps = DataUtils.integerDeduplication(stepIdId);
                    for (Integer i : nodes) {
                        EntityWrapper<BprojectNodes> bprojectNodesEntityWrapper = new EntityWrapper<>();
                        bprojectNodesEntityWrapper.setSqlSelect("id", "project_node_name").eq("id", i);
                        BprojectNodes projectNode = bprojectNodesService.selectOne(bprojectNodesEntityWrapper);
                        if (projectNode != null) {
                            bprojectNodes.add(projectNode);
                        }
                    }
                    for (Integer i : steps) {
                        EntityWrapper<BprojectNodeSteps> bprojectNodeStepsEntityWrapper = new EntityWrapper<>();
                        bprojectNodeStepsEntityWrapper.setSqlSelect("id", "project_step_name").eq("id", i);
                        BprojectNodeSteps projectNodeSteps = bprojectNodeStepsService.selectOne(bprojectNodeStepsEntityWrapper);
                        if (projectNodeSteps != null) {
                            bprojectNodeSteps.add(projectNodeSteps);
                        }
                    }
                    map.put("nodes", bprojectNodes);
                    map.put("nodeSteps", bprojectNodeSteps);
                }
                return map;
            }
        }
        return null;
    }

}
