
package io.platform.project.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.project.biz.entity.ProjectBillsHistory;
import io.platform.project.biz.service.ProjectBillsHistoryService;
import io.platform.project.dto.ProjectBillsHistoryDto;
import io.platform.project.service.client.api.ProjectBillsHistoryServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class ProjectBillsHistoryServiceClientImpl extends BaseServiceClient<ProjectBillsHistory, ProjectBillsHistoryDto> implements ProjectBillsHistoryServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private ProjectBillsHistoryService projectBillsHistoryService;

    @Override
    public ProjectBillsHistoryDto queryObject(Long id) {
        ProjectBillsHistory projectBillsHistory = projectBillsHistoryService.selectById(id);
        ProjectBillsHistoryDto projectBillsHistoryDto = new ProjectBillsHistoryDto();
        BeanUtils.copyProperties(projectBillsHistory, projectBillsHistoryDto);
        return projectBillsHistoryDto;
    }

    @Override
    public List<ProjectBillsHistoryDto> queryList(Map<String, Object> map) {
        List<ProjectBillsHistory> projectBillsHistoryList = projectBillsHistoryService.selectByMap(map);
        return convertList(projectBillsHistoryList, ProjectBillsHistoryDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<ProjectBillsHistory> ew = new EntityWrapper<>();
        ew.allEq(map);
        return projectBillsHistoryService.selectCount(ew);
    }

    /**
     * 获取现在时间
     *
     * @return返回字符串格式yyyyMMddHHmmss
     */
    public static String getStringDate() {
        Date currentTime = new Date();
        SimpleDateFormat formatter = new SimpleDateFormat("yyyyMMddHHmmss");
        String dateString = formatter.format(currentTime);
        System.out.println("TIME:::" + dateString);
        return dateString;
    }

    /**
     * 由年月日时分秒+3位随机数
     * 生成流水号
     *
     * @return
     */
    public static String Getnum() {
        String t = getStringDate();
        int x = (int) (Math.random() * 900) + 100;
        String serial = t + x;
        return serial;
    }

    @Override
    public ExecuteResult<String> save(ProjectBillsHistoryDto projectBillsHistoryDto) {
//        projectBillsHistoryDto.setHistoryDate(new Date());
        projectBillsHistoryDto.setSerialNumber(Getnum());
        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");//设置日期格式
//        projectBillsHistoryDto.setHistoryName(df.format(new Date())+"修改记录");
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBillsHistory projectBillsHistory = new ProjectBillsHistory();
            revert(projectBillsHistoryDto, projectBillsHistory);
            boolean flag = projectBillsHistoryService.insert(projectBillsHistory);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(ProjectBillsHistoryDto projectBillsHistoryDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBillsHistory projectBillsHistory = new ProjectBillsHistory();
            revert(projectBillsHistoryDto, projectBillsHistory);

            boolean flag = projectBillsHistoryService.updateById(projectBillsHistory);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectBillsHistoryService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectBillsHistoryService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<ProjectBillsHistoryDto> getPage(Page<ProjectBillsHistoryDto> pageDto, ProjectBillsHistoryDto projectBillsHistoryDto) {
        Page<ProjectBillsHistory> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        ProjectBillsHistory projectBillsHistory = new ProjectBillsHistory();
        revert(projectBillsHistoryDto, projectBillsHistory);
        EntityWrapper<ProjectBillsHistory> wrapper = new EntityWrapper<>();
        wrapper.setEntity(projectBillsHistory);
        wrapper.orderBy("history_date desc");
        page = projectBillsHistoryService.selectPage(page, wrapper);
        List<ProjectBillsHistoryDto> projectBillsHistoryDtoList = convertList(page.getRecords(), ProjectBillsHistoryDto.class);
        pageDto.setTotal(projectBillsHistoryService.selectCount(wrapper));
        pageDto.setRecords(projectBillsHistoryDtoList);
        return pageDto;
    }
}
