
package io.platform.project.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;

import io.platform.approvalConfiguration.biz.entity.Audit;
import io.platform.approvalConfiguration.biz.service.AuditItemsService;
import io.platform.base.common.utils.CopyUtils;
import io.platform.engineering.biz.entity.*;
import io.platform.engineering.biz.service.*;
import io.platform.project.biz.entity.*;
import io.platform.project.biz.service.*;
import io.platform.project.dto.*;
import io.platform.project.service.client.api.ProjectBillsStepsServiceClient;
import io.platform.sys.biz.entity.SysRole;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.*;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = ProjectBillsStepsServiceClient.class)
public class ProjectBillsStepsServiceClientImpl extends BaseServiceClient<ProjectBillsSteps, ProjectBillsStepsDto> implements ProjectBillsStepsServiceClient {
    Logger logger = LoggerFactory.getLogger(ProjectBillsStepsServiceClientImpl.class);

    @Resource
    private BcorpsService bcorpsService;
    @Resource
    private BdeptsService bdeptsService;
    @Resource
    private SysUserService sysUserService;
    @Resource
    private BbranchsService bbranchsService;
    @Resource
    private AuditItemsService auditItemsService;
    @Resource
    private ProjectbillsService projectbillsService;
    @Resource
    private BprojectTypesService bprojectTypesService;
    @Resource
    private BprojectNodesService bprojectNodesService;
    @Resource
    private ProjectBillsSubsService projectBillsSubsService;
    @Resource
    private BprojectNodeStepsService bprojectNodeStepsService;
    @Resource
    private ProjectBillsStepsService projectBillsStepsService;
    @Resource
    private BprojectTypesItemsService bprojectTypesItemsService;
    @Resource
    private ProjectBillsStepsAdjustService projectBillsStepsAdjustService;
    @Resource
    private ProcessBillsStepsService processBillsStepsService;
    @Resource
    private SubContractBillsService subContractBillsService;

    @Override
    public ProjectBillsStepsDto queryObject(Long id) {
        ProjectBillsSteps projectBillsSteps = projectBillsStepsService.selectById(id);
        ProjectBillsStepsDto projectBillsStepsDto = new ProjectBillsStepsDto();
        BeanUtils.copyProperties(projectBillsSteps, projectBillsStepsDto);
        return projectBillsStepsDto;
    }

    @Override
    public List<ProjectBillsStepsDto> queryList(Map<String, Object> map) {
        List<ProjectBillsSteps> projectBillsStepsList = projectBillsStepsService.selectByMap(map);
        return convertList(projectBillsStepsList, ProjectBillsStepsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<ProjectBillsSteps> ew = new EntityWrapper<>();
        ew.allEq(map);
        return projectBillsStepsService.selectCount(ew);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> save(String projectBillsContract, String projectBillsStls) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectbillsDto projectbillsDto = JSONArray.parseObject(projectBillsContract, ProjectbillsDto.class);
            JSONArray jsonArray = JSONArray.parseArray(projectBillsStls);
            List<ProjectBillsSteps> projectBillsStlsList = JSONObject.parseArray(jsonArray.toJSONString(), ProjectBillsSteps.class);
            if (projectBillsStlsList.size() != 0) {
                for (ProjectBillsSteps pb : projectBillsStlsList) {
                    pb.setActId(104);
                    pb.setPlanOrgStartDate(projectbillsDto.getPlanStartDate());
                    pb.setPlanOrgEndDate(projectbillsDto.getPlanEndDate());
                    boolean insert = projectBillsStepsService.insert(pb);
                    if (!insert) {
                        result.addErrorMessage("提交失败。");
                        break;
                    }
                }
            }
        } catch (Exception e) {
            logger.error(" 提交错误：" + e.toString(), e);
            result.addErrorMessage("提交错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> update(String projectBillsContract, String projectBillsStls) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectbillsDto projectbillsDto = JSONArray.parseObject(projectBillsContract, ProjectbillsDto.class);
            JSONArray jsonArray = JSONArray.parseArray(projectBillsStls);
            List<ProjectBillsSteps> projectBillsStlsList = JSONObject.parseArray(jsonArray.toJSONString(), ProjectBillsSteps.class);
            if (projectBillsStlsList.size() != 0) {
                EntityWrapper<ProjectBillsSteps> projectBillsStepsEntityWrapper = new EntityWrapper<>();
                projectBillsStepsEntityWrapper.setSqlSelect("id").eq("project_sub_no", projectBillsStlsList.get(0).getProjectSubNo());
                List<ProjectBillsSteps> projectBillsSteps = projectBillsStepsService.selectList(projectBillsStepsEntityWrapper);
                if (projectBillsSteps.size() != 0) {
                    for (ProjectBillsSteps pbs : projectBillsSteps) {
                        projectBillsStepsService.deleteById(pbs.getId());
                    }
                }
                for (ProjectBillsSteps pb : projectBillsStlsList) {
                    pb.setActId(104);
                    pb.setPlanOrgStartDate(projectbillsDto.getPlanStartDate());
                    pb.setPlanOrgEndDate(projectbillsDto.getPlanEndDate());
                    boolean insert = projectBillsStepsService.insert(pb);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("提交失败。");
                        break;
                    }
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 提交错误：" + e.toString(), e);
            result.addErrorMessage("提交错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectBillsStepsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectBillsStepsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<ProjectBillsStepsDto> getPage(Page<ProjectBillsStepsDto> pageDto, ProjectBillsStepsDto projectBillsStepsDto) {
        Page<ProjectBillsSteps> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        ProjectBillsSteps projectBillsSteps = new ProjectBillsSteps();
        revert(projectBillsStepsDto, projectBillsSteps);
        EntityWrapper<ProjectBillsSteps> wrapper = new EntityWrapper<>();
        wrapper.setEntity(projectBillsSteps);
        page = projectBillsStepsService.selectPage(page, wrapper);
        List<ProjectBillsStepsDto> projectBillsStepsDtoList = convertList(page.getRecords(), ProjectBillsStepsDto.class);
        pageDto.setTotal(projectBillsStepsService.selectCount(wrapper));
        pageDto.setRecords(projectBillsStepsDtoList);
        return pageDto;
    }

    @Override
    public Map<String, Object> numberQueryContract(ProjectBillsSubsDto projectbillsDto, SysUserDto sysUserDto) {
        if (projectbillsDto != null && projectbillsDto.getId() != null && projectbillsDto.getBillNo() != null) {
            Map<String, Object> map = new HashMap<>();
            ProjectBS projectBS = projectBillsStepsService.selectProBS(projectbillsDto);
            if (projectBS != null) {
                map.put("proBS", projectBS);
                EntityWrapper<ProjectBillsSteps> projectBillsStepsEntityWrapper = new EntityWrapper<>();
                projectBillsStepsEntityWrapper.eq("project_sub_no", projectBS.getProjectSubNo());
                List<ProjectBillsSteps> projectBillsSteps = projectBillsStepsService.selectList(projectBillsStepsEntityWrapper);
                if (projectBillsSteps.size() != 0) {
                    map.put("proSteps", projectBillsSteps);
                    EntityWrapper<BprojectNodeSteps> bprojectNodeStepsEntityWrapper = new EntityWrapper<>();
                    bprojectNodeStepsEntityWrapper.setSqlSelect("id", "project_step_name", "project_node_id");
                    List<BprojectNodeSteps> bprojectNodeSteps = bprojectNodeStepsService.selectList(bprojectNodeStepsEntityWrapper);
                    if (bprojectNodeSteps.size() != 0) {
                        map.put("proNodeSteps", bprojectNodeSteps);
                    }
                } else {
                    map.put("proBs", projectBS);
                    if (Objects.equals(sysUserDto.getLoginContractorId(), 1)) {
                        map.put("branchId", null);
                    } else {
                        map.put("branchId", sysUserDto.getLoginContractorId());
                    }
                    List<ProjectBillsSteps> projectBillsStepsList = projectBillsStepsService.selectSteps(map);
                    if (projectBillsStepsList.size() != 0) {
                        map.put("proSteps", projectBillsStepsList);
                    }
                }
                if (projectBS.getProjectSubMngId() != null) {
                    SysUser sysUser = sysUserService.selectById(projectBS.getProjectSubMngId());
                    Bdepts bdept = bdeptsService.selectById(projectBS.getProjectSubMngDeptId());
                    map.put("user", sysUser);
                    map.put("dept", bdept);
                }
                map.put("proType", bprojectTypesService.selectById(projectBS.getProjectTypeId()));
                map.put("proTypeItem", bprojectTypesItemsService.selectById(projectBS.getProjectTypeItemId()));
                map.put("corp", bcorpsService.selectById(projectBS.getCorpId()));
                map.put("branch", bbranchsService.selectById(projectBS.getConstructorId()));
                EntityWrapper<BprojectNodes> nodesEntityWrapper = new EntityWrapper<>();
                nodesEntityWrapper.setSqlSelect("id", "project_node_name").eq("branch_id", projectBS.getBranchId());
                List<BprojectNodes> bprojectNodes = bprojectNodesService.selectList(nodesEntityWrapper);
                map.put("proNodes", bprojectNodes);
                EntityWrapper<BprojectNodeSteps> stepsEntityWrapper = new EntityWrapper<>();
                stepsEntityWrapper.setSqlSelect("id", "project_step_name").eq("branch_id", projectBS.getBranchId());
                List<BprojectNodeSteps> bprojectNodeSteps = bprojectNodeStepsService.selectList(stepsEntityWrapper);
                map.put("proNodeSteps", bprojectNodeSteps);
                return map;
            }
        }
        return null;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> projectStepTemporary(String projectBillsContract, String projectBillsStls, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBS projectbillsDto = JSONArray.parseObject(projectBillsContract, ProjectBS.class);
            JSONArray jsonArray = JSONArray.parseArray(projectBillsStls);
            List<ProjectBillsSteps> projectBillsStlsList = JSONObject.parseArray(jsonArray.toJSONString(), ProjectBillsSteps.class);
            if (projectBillsStlsList.size() != 0) {
                EntityWrapper<ProjectBillsSteps> projectBillsStepsEntityWrapper = new EntityWrapper<>();
                projectBillsStepsEntityWrapper.setSqlSelect("id").eq("project_sub_no", projectBillsStlsList.get(0).getProjectSubNo());
                List<ProjectBillsSteps> projectBillsSteps = projectBillsStepsService.selectList(projectBillsStepsEntityWrapper);
                if (projectBillsSteps.size() != 0) {
                    for (ProjectBillsSteps pbs : projectBillsSteps) {
                        projectBillsStepsService.deleteById(pbs.getId());
                    }
                }
                int lin = 0;
                for (ProjectBillsSteps pb : projectBillsStlsList) {
                    lin++;
                    pb.setActId(104);
                    pb.setLineNo(lin);
                    pb.setPlanOrgStartDate(pb.getPlanStartDate());
                    pb.setPlanOrgEndDate(pb.getPlanEndDate());
                    pb.setPlanOrgDays(pb.getPlanDays());
                    boolean insert = projectBillsStepsService.insert(pb);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("暂存失败：新增节点失败");
                        break;
                    }
                }
                EntityWrapper<ProjectBillsSubs> projectBillsSubsEntityWrapper = new EntityWrapper<>();
                projectBillsSubsEntityWrapper.setSqlSelect("id", "project_steps_status").eq("id", projectbillsDto.getId());
                ProjectBillsSubs projectBillsSubs = projectBillsSubsService.selectOne(projectBillsSubsEntityWrapper);
                projectBillsSubs.setProjectStepsStatus(2);
                projectBillsSubs.setProjectStepsUserName(sysUserDto.getUsername());
                projectBillsSubs.setStepsCreateDate(new Date());
                boolean updateById = projectBillsSubsService.updateById(projectBillsSubs);
                if (!updateById) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("暂存失败：修改节点状态失败");
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(e.getMessage());
            result.addErrorMessage("修改失败");
            return result;
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> projectStepSave(String projectBillsContract, String projectBillsStls, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBS projectbillsDto = JSONArray.parseObject(projectBillsContract, ProjectBS.class);
            JSONArray jsonArray = JSONArray.parseArray(projectBillsStls);
            List<ProjectBillsSteps> projectBillsStlsList = JSONObject.parseArray(jsonArray.toJSONString(), ProjectBillsSteps.class);
            if (projectBillsStlsList.size() != 0) {
                EntityWrapper<ProjectBillsSteps> projectBillsStepsEntityWrapper = new EntityWrapper<>();
                projectBillsStepsEntityWrapper.setSqlSelect("id").eq("project_sub_no", projectBillsStlsList.get(0).getProjectSubNo());
                boolean delete = projectBillsStepsService.delete(projectBillsStepsEntityWrapper);
                if (!delete) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("提交失败: 删除旧数据失败");
                    return result;
                }
                ProjectBillsSubs projectBillsSubs = projectBillsSubsService.selectById(projectbillsDto.getId());
                projectBillsSubs.setProjectStepsStatus(6);
                projectBillsSubs.setProjectStepsUserName(sysUserDto.getUsername());
                projectBillsSubs.setStepsCreateDate(new Date());
                boolean updateById = projectBillsSubsService.updateById(projectBillsSubs);
                if (!updateById) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("提交失败: 修改里程碑状态失败");
                    return result;
                }
                EntityWrapper<ProjectBillsSubs> projectSubs = new EntityWrapper<>();
                projectSubs.setSqlSelect("id").eq("bill_no", projectBillsSubs.getBillNo()).ne("project_steps_status", 6);
                List<ProjectBillsSubs> projectBillsSubsList = projectBillsSubsService.selectList(projectSubs);
                if (Objects.equals(projectBillsSubsList.size(), 0)) {
                    EntityWrapper<Projectbills> projectbillsEntityWrapper = new EntityWrapper<>();
                    projectbillsEntityWrapper.setSqlSelect("id", "project_steps_status")
                            .eq("bill_no", projectBillsSubs.getBillNo())
                            .eq("branch_id", sysUserDto.getLoginContractorId());
                    Projectbills projectbills = projectbillsService.selectOne(projectbillsEntityWrapper);
                    if (projectbills != null) {
                        projectbills.setProjectStepsStatus(6);
                        boolean update = projectbillsService.updateById(projectbills);
                        if (!update) {
                            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                            result.addErrorMessage("提交失败: 更新合同状态失败");
                            return result;
                        }
                    }
                }
                int lin = 0;
                for (ProjectBillsSteps pb : projectBillsStlsList) {
                    lin++;
                    pb.setBillNo(projectbillsDto.getBillNo());
                    pb.setLineNo(lin);
                    pb.setActId(104);
                    pb.setProjectSubNo(projectBillsSubs.getProjectSubNo());
                    pb.setBranchId(projectbillsDto.getBranchId());
                    pb.setPlanOrgStartDate(pb.getPlanStartDate());
                    pb.setPlanOrgEndDate(pb.getPlanEndDate());
                    pb.setPlanOrgDays(pb.getPlanDays());
                    boolean insert = projectBillsStepsService.insert(pb);
                    if (!insert) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("提交失败: 创建节点失败");
                        return result;
                    }
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(e.getMessage());
            result.addErrorMessage("修改失败");
            return result;
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> editMilestoneSave(List<ProjectBillsStepsAdjustDto> projectBillsStepsAdjustDtos, SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (projectBillsStepsAdjustDtos.size() != 0) {
                int line = 0;
                for (ProjectBillsStepsAdjustDto pbs : projectBillsStepsAdjustDtos) {
                    line++;
                    EntityWrapper<ProjectBillsSteps> projectBillsStepsEntityWrapper = new EntityWrapper<>();
                    projectBillsStepsEntityWrapper.setSqlSelect("id", "project_work_rate").eq("project_sub_no", pbs.getProjectSubNo())
                            .eq("project_node_id", pbs.getProjectNodeId()).eq("project_step_id", pbs.getProjectStepId());
                    ProjectBillsSteps projectBillsSteps = projectBillsStepsService.selectOne(projectBillsStepsEntityWrapper);
                    if (projectBillsSteps != null) {
                        if (!Double.toString(projectBillsSteps.getProjectWorkRate()).equals(Double.toString(pbs.getProjectWorkRate()))) {
                            projectBillsSteps.setProjectWorkRate(pbs.getProjectWorkRate());
                            boolean updateById = projectBillsStepsService.updateById(projectBillsSteps);
                            if (!updateById) {
                                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                                result.addErrorMessage("修改失败: 修改节点占比失败");
                                return result;
                            }
                            ProjectBillsStepsAdjust billsStepsAdjust = new ProjectBillsStepsAdjust();
                            billsStepsAdjust.setBillNo(pbs.getBillNo());
                            billsStepsAdjust.setLineNo(line);
                            billsStepsAdjust.setActId(114);
                            billsStepsAdjust.setRemarks(pbs.getRemarks());
                            billsStepsAdjust.setProjectSubNo(pbs.getProjectSubNo());
                            billsStepsAdjust.setProjectNodeId(pbs.getProjectNodeId());
                            billsStepsAdjust.setProjectStepId(pbs.getProjectStepId());
                            billsStepsAdjust.setPlanStartDate(pbs.getPlanStartDate());
                            billsStepsAdjust.setPlanEndDate(pbs.getPlanEndDate());
                            billsStepsAdjust.setPlantDays(pbs.getPlantDays());
                            billsStepsAdjust.setOpUserId(sysUserDto.getUserId().intValue());
                            billsStepsAdjust.setOpUserName(sysUserDto.getUsername());
                            billsStepsAdjust.setOpDate(new Date());
                            billsStepsAdjust.setProjectWorkRate(pbs.getProjectWorkRate());
                            boolean insertStatus = projectBillsStepsAdjustService.insert(billsStepsAdjust);
                            if (!insertStatus) {
                                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                                result.addErrorMessage("修改失败: 新建记录失败");
                                return result;
                            }
                        }
                    } else {
                        ProjectBillsStepsAdjust billsStepsAdjust = new ProjectBillsStepsAdjust();
                        billsStepsAdjust.setBillNo(pbs.getBillNo());
                        billsStepsAdjust.setLineNo(line);
                        billsStepsAdjust.setActId(114);
                        billsStepsAdjust.setRemarks(pbs.getRemarks());
                        billsStepsAdjust.setProjectSubNo(pbs.getProjectSubNo());
                        billsStepsAdjust.setProjectNodeId(pbs.getProjectNodeId());
                        billsStepsAdjust.setProjectStepId(pbs.getProjectStepId());
                        billsStepsAdjust.setPlanStartDate(pbs.getPlanStartDate());
                        billsStepsAdjust.setPlanEndDate(pbs.getPlanEndDate());
                        billsStepsAdjust.setPlantDays(pbs.getPlantDays());
                        billsStepsAdjust.setOpUserId(sysUserDto.getUserId().intValue());
                        billsStepsAdjust.setOpUserName(sysUserDto.getUsername());
                        billsStepsAdjust.setOpDate(new Date());
                        billsStepsAdjust.setProjectWorkRate(pbs.getProjectWorkRate());
                        boolean insertStatus = projectBillsStepsAdjustService.insert(billsStepsAdjust);
                        if (!insertStatus) {
                            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                            result.addErrorMessage("修改失败: 新建记录失败");
                            return result;
                        }
                        ProjectBillsSteps billsSteps = new ProjectBillsSteps();
                        billsSteps.setBillNo(billsStepsAdjust.getBillNo());
                        billsSteps.setActId(104);
                        billsSteps.setRemarks(billsStepsAdjust.getRemarks());
                        billsSteps.setProjectSubNo(billsStepsAdjust.getProjectSubNo());
                        billsSteps.setProjectNodeId(billsStepsAdjust.getProjectNodeId());
                        billsSteps.setProjectStepId(billsStepsAdjust.getProjectStepId());
                        billsSteps.setProjectWorkRate(billsStepsAdjust.getProjectWorkRate());
                        billsSteps.setPlanOrgStartDate(billsStepsAdjust.getPlanStartDate());
                        billsSteps.setPlanEndDate(billsStepsAdjust.getPlanEndDate());
                        billsSteps.setPlanOrgDays(billsStepsAdjust.getPlantDays());
                        billsSteps.setPlanStartDate(billsStepsAdjust.getPlanStartDate());
                        billsSteps.setPlanEndDate(billsStepsAdjust.getPlanEndDate());
                        billsSteps.setPlanDays(billsStepsAdjust.getPlantDays());
                        boolean insert = projectBillsStepsService.insert(billsSteps);
                        if (!insert) {
                            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                            result.addErrorMessage("修改失败: 新建节点失败");
                            return result;
                        }
                    }
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(e.getMessage());
            result.addErrorMessage("修改失败");
            return result;
        }
        return result;
    }

    @Override
    public Map<String, Object> queryRecords(ProjectBillsStepsAdjustDto projectBillsStepsAdjustDto) {
        if (projectBillsStepsAdjustDto.getProjectSubNo() != null && projectBillsStepsAdjustDto.getProjectNodeId() != null) {
            Map<String, Object> map = new HashMap<>();
            EntityWrapper<ProjectBillsStepsAdjust> entityWrapper = new EntityWrapper<>();
            entityWrapper.eq("project_sub_no", projectBillsStepsAdjustDto.getProjectSubNo())
                    .eq("project_node_id", projectBillsStepsAdjustDto.getProjectNodeId())
                    .eq("project_step_id", projectBillsStepsAdjustDto.getProjectStepId());
            List<ProjectBillsStepsAdjust> projectBillsStepsAdjusts = projectBillsStepsAdjustService.selectList(entityWrapper);
            if (projectBillsStepsAdjusts.size() != 0) {
                map.put("proStepsAdjusts", projectBillsStepsAdjusts);
            }
            return map;
        }
        return null;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String processStepsSave(String item, SysUserDto sysUserDto) {
        JSONArray jsonArray = JSONArray.parseArray(item);
        List<ProjectBillsSteps> projectBillsStepsList = JSONObject.parseArray(jsonArray.toJSONString(), ProjectBillsSteps.class);
        if (projectBillsStepsList.size() != 0) {
            EntityWrapper<ProjectBillsSubs> subsEntityWrapper = new EntityWrapper<>();
            subsEntityWrapper.eq("project_sub_no", projectBillsStepsList.get(0).getProjectSubNo())
                    .eq("branch_id", projectBillsStepsList.get(0).getBranchId());
            ProjectBillsSubs projectBillsSubs = projectBillsSubsService.selectOne(subsEntityWrapper);
            for (ProjectBillsSteps projectBillsSteps : projectBillsStepsList) {
                if (projectBillsSteps.getAttach1() != null && projectBillsSteps.getActDays() != null
                        && projectBillsSteps.getActEndDate() != null && projectBillsSteps.getStatus() != 6) {
                    projectBillsSteps.setStatus(4);
                    if (!projectBillsStepsService.updateById(projectBillsSteps)) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        return "更新形象进度维护失败，请检查列表数据";
                    }
                }
            }
            Audit audit = new Audit();
            audit.setBillNo(projectBillsSubs.getBillNo());
            audit.setActId(310);
            audit.setLevelId(0);
            audit.setIffinalItem("F");
            audit.setSubJect(projectBillsSubs.getProjectSubName());
            audit.setProjectNo(projectBillsSubs.getProjectSubNo());
            audit.setBranchId(projectBillsSubs.getApprovalBranchId());
            audit.setSendUserId(sysUserDto.getUserId().intValue());
            audit.setSendName(sysUserDto.getActualname());
            audit.setSendTime(new Date());
            audit.setAuditUserId(sysUserDto.getUserId().intValue());
            audit.setAuditItem(new Date());
            audit.setAuditMsg("提交");
            audit.setAuditStatus("O");
            audit.setProjectMngId(projectBillsSubs.getProjectSubMngId());
            boolean approvalFlow = auditItemsService.createApprovalFlow(audit);
            if (!approvalFlow) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return "审批流异常请检查提交信息";
            }
        } else {
            return "未找到信息";
        }
        return "提交成功";
    }

    @Override
    public Page<ProjectBillsSubsDto> selectProjectSubDataList(Page<ProjectBillsSubsDto> page, ProjectBillsSubsDto projectBillsSubsDto, SysUserDto sysUserDto) {
        Page pageDto = DataUtils.processingPage(page);
        SysRole sysRole = subContractBillsService.selectRole(sysUserDto);
        int subCount = projectBillsStepsService.selectProjectSubDataCount(projectBillsSubsDto, sysUserDto, sysRole);
        if (subCount != 0) {
            pageDto.setTotal(subCount);
            pageDto.setRecords(projectBillsStepsService.selectProjectSubDataList(pageDto.getCurrent(), pageDto.getSize(), projectBillsSubsDto, sysUserDto, sysRole));
            return pageDto;
        }
        return null;
    }
}
