
package io.platform.project.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.approvalConfiguration.biz.service.AuditItemsService;
import io.platform.budget.biz.entity.ProjectBillsBudgets;
import io.platform.budget.dto.ProjectBillsBudgetsDto;
import io.platform.engineering.biz.entity.Bdepts;
import io.platform.moneyManagement.biz.service.PayDrBillsItemsService;
import io.platform.project.biz.entity.ProjectBillsSubs;
import io.platform.engineering.biz.service.BdeptsService;
import io.platform.project.biz.entity.SubConBillsAttachs;
import io.platform.project.biz.entity.SubContractBills;
import io.platform.project.biz.service.ProjectBillsSubsService;
import io.platform.project.biz.service.SubContractBillsService;
import io.platform.project.service.client.api.ProjectBillsSubsServiceClient;
import io.platform.project.dto.ProjectBillsSubsDto;
import io.platform.sys.biz.entity.SysRole;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysUserDto;
import io.platform.utils.DataUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.ZoneId;
import java.util.*;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = ProjectBillsSubsServiceClient.class)
public class ProjectBillsSubsServiceClientImpl extends BaseServiceClient<ProjectBillsSubs, ProjectBillsSubsDto> implements ProjectBillsSubsServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BdeptsService bdeptsService;
    @Resource
    private SysUserService sysUserService;
    @Resource
    private AuditItemsService auditItemsService;
    @Resource
    private ProjectBillsSubsService projectBillsSubsService;
    @Resource
    private PayDrBillsItemsService payDrBillsItemsService;
    @Resource
    private SubContractBillsService subContractBillsService;

    @Override
    public ProjectBillsSubsDto queryObject(Long id) {
        ProjectBillsSubs projectBillsSubs = projectBillsSubsService.selectById(id);
        ProjectBillsSubsDto projectBillsSubsDto = new ProjectBillsSubsDto();
        BeanUtils.copyProperties(projectBillsSubs, projectBillsSubsDto);
        return projectBillsSubsDto;
    }

    @Override
    public List<ProjectBillsSubsDto> queryList(Map<String, Object> map) {
        List<ProjectBillsSubs> projectBillsSubsList = projectBillsSubsService.selectByMap(map);
        return convertList(projectBillsSubsList, ProjectBillsSubsDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<ProjectBillsSubs> ew = new EntityWrapper<>();
        ew.allEq(map);
        return projectBillsSubsService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(ProjectBillsSubsDto projectBillsSubsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBillsSubs projectBillsSubs = new ProjectBillsSubs();
            revert(projectBillsSubsDto, projectBillsSubs);
            boolean flag = projectBillsSubsService.insert(projectBillsSubs);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(ProjectBillsSubsDto projectBillsSubsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectBillsSubs projectBillsSubs = new ProjectBillsSubs();
            revert(projectBillsSubsDto, projectBillsSubs);
            boolean flag = projectBillsSubsService.updateById(projectBillsSubs);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectBillsSubsService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectBillsSubsService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Map<String, Object> getPage(Map<String, Object> map, SysUserDto sysUserDto) {
        Map<String, Object> objectMap = new HashMap<>();
        SysRole sysRole = subContractBillsService.selectRole(sysUserDto);
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            if (map.get("startDate") != null && map.get("startDate") != "") {
                long startimes = (long) map.get("startDate");
                String startTime = sdf.format(new Date(startimes));
                map.put("startDateTime", startTime);
            }
            if (map.get("endDate") != null && map.get("endDate") != "") {
                long endtimes = (long) map.get("endDate");
                LocalDateTime localDateTime = LocalDateTime.ofInstant(Instant.ofEpochMilli(endtimes), ZoneId.systemDefault());
                LocalDateTime endOfDay = localDateTime.with(LocalTime.MAX);
                Date from = Date.from(endOfDay.atZone(ZoneId.systemDefault()).toInstant());
                String endTime = sdf.format(from);
                endTime += "23:59:59";
                map.put("endDateTime", endTime);
            }
            map.put("user", sysUserDto);
            map.put("role", sysRole);
            int num = projectBillsSubsService.selectProSubsTotal(map);
            if (num != 0) {
                int current = (int) map.get("current");
                int size = (int) map.get("size");
                if (current <= 1) {
                    current = 0;
                } else {
                    current = (current - 1) * size;
                }
                map.put("size", size);
                map.put("current", current);
                List<Map<String, Object>> mapList = projectBillsSubsService.selectProSubsRecords(map);
                for (Map<String, Object> m : mapList) {
                    int statusNum = (int) m.get("project_status");
                    m.put("proStatus", statusNum / 10);
                }
                Page page = new Page();
                page.setRecords(mapList);
                page.setTotal(num);
                objectMap.put("page", page);
                return objectMap;
            }
        } catch (Exception e) {
            logger.error("操作异常：" + e.toString(), e);
        }
        return null;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> projectSubTemporary(List<ProjectBillsSubsDto> projectBillsSubsDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        if (projectBillsSubsDto.size() != 0) {
            EntityWrapper<ProjectBillsSubs> projectBillsSubsEntityWrapper = new EntityWrapper<>();
            projectBillsSubsEntityWrapper.setSqlSelect("id").eq("bill_no", projectBillsSubsDto.get(0).getBillNo());
            List<ProjectBillsSubs> billsSubs = projectBillsSubsService.selectList(projectBillsSubsEntityWrapper);
            if (billsSubs.size() != 0) {
                for (ProjectBillsSubs pb : billsSubs) {
                    projectBillsSubsService.deleteById(pb.getId());
                }
            }
            int lin = 0;
            for (ProjectBillsSubsDto pb : projectBillsSubsDto) {
                lin++;
                pb.setLineNo(lin);
                pb.setActId(103);
                pb.setBillStatus(2);
                pb.setIfProjectSub("T");
                ProjectBillsSubs projectBillsSubs = new ProjectBillsSubs();
                revert(pb, projectBillsSubs);
                boolean insert = projectBillsSubsService.insert(projectBillsSubs);
                if (!insert) {
                    result.addErrorMessage("暂存失败");
                }
            }
        }
        return result;
    }

    @Override
    public Map<String, Object> fuzzyQueryProjectSubs(Page page, ProjectBillsSubsDto projectBillsSubsDto) {
        Map<String, Object> map = new HashMap<>();
        if (projectBillsSubsDto != null) {
            Page pageDto = DataUtils.processingPage(page);
            EntityWrapper<ProjectBillsSubs> entityWrapper = new EntityWrapper<>();
            if (projectBillsSubsDto.getActId() != null) {
                entityWrapper.eq("act_id", projectBillsSubsDto.getActId());
            }
            if (projectBillsSubsDto.getBillStatus() != null) {
                entityWrapper.eq("bill_status", projectBillsSubsDto.getBillStatus());
            }
            if (projectBillsSubsDto.getProjectSubMngId() != null) {
                entityWrapper.eq("project_sub_mng_id", projectBillsSubsDto.getProjectSubMngId());
            }
            if (projectBillsSubsDto.getProjectSubMngDeptId() != null) {
                entityWrapper.eq("project_sub_mng_dept_id", projectBillsSubsDto.getProjectSubMngDeptId());
            }
            if (projectBillsSubsDto.getBillNo() != null && !projectBillsSubsDto.getBillNo().equals("")) {
                entityWrapper.like("bill_no", "%" + projectBillsSubsDto.getBillNo() + "%");
            }
            if (projectBillsSubsDto.getRemarks() != null && !projectBillsSubsDto.getRemarks().equals("")) {
                entityWrapper.like("remarks", "%" + projectBillsSubsDto.getRemarks() + "%");
            }
            if (projectBillsSubsDto.getNcProjectNo() != null && !projectBillsSubsDto.getNcProjectNo().equals("")) {
                entityWrapper.like("nc_project_no", "%" + projectBillsSubsDto.getNcProjectNo() + "%");
            }
            if (projectBillsSubsDto.getProjectSubNo() != null && !projectBillsSubsDto.getProjectSubNo().equals("")) {
                entityWrapper.like("project_sub_no", "%" + projectBillsSubsDto.getProjectSubNo() + "%");
            }
            int number = projectBillsSubsService.selectCount(entityWrapper);
            if (number > 0) {
                entityWrapper.last("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
                List<ProjectBillsSubs> projectBillsSubs = projectBillsSubsService.selectList(entityWrapper);
                List<Integer> integers = new ArrayList<>();
                List<Integer> userInt = new ArrayList<>();
                List<Bdepts> bdeptsList = new ArrayList<>();
                List<SysUser> userList = new ArrayList<>();
                for (ProjectBillsSubs pb : projectBillsSubs) {
                    if (pb.getProjectSubMngId() != null && pb.getProjectSubMngId() != 0) {
                        userInt.add(pb.getProjectSubMngId());
                    }
                    if (pb.getProjectSubMngDeptId() != null && pb.getProjectSubMngDeptId() != 0) {
                        integers.add(pb.getProjectSubMngDeptId());
                    }
                }
                List<Integer> deptId = DataUtils.integerDeduplication(integers);
                List<Integer> userId = DataUtils.integerDeduplication(userInt);
                for (Integer i : deptId) {
                    EntityWrapper<Bdepts> bdeptsEntityWrapper = new EntityWrapper<>();
                    bdeptsEntityWrapper.setSqlSelect("id", "dept_name").eq("id", i);
                    Bdepts bdepts = bdeptsService.selectOne(bdeptsEntityWrapper);
                    bdeptsList.add(bdepts);
                }
                for (Integer i : userId) {
                    SysUser user = sysUserService.selectById(i);
                    userList.add(user);
                }
                map.put("depts", bdeptsList);
                map.put("user", userList);
                pageDto.setTotal(number);
                pageDto.setRecords(projectBillsSubs);
                map.put("page", pageDto);
                return map;
            }
            return null;
        }
        return null;
    }

    @Override
    public Map<String, Object> conditionalQueryProjectSubs(Page page, ProjectBillsSubsDto projectBillsSubsDto) {
        Map<String, Object> map = new HashMap<>();
        Page pageDto = DataUtils.processingPage(page);
        map.put("size", pageDto.getSize());
        map.put("sub", projectBillsSubsDto);
        map.put("current", pageDto.getCurrent());
        map.put("sur", projectBillsSubsDto.getIsSur());
        int count = projectBillsSubsService.conditionalQueryProjectSubsNum(map);
        if (count != 0) {
            pageDto.setTotal(count);
            List<Map<String, Object>> projectBillsSubsList = projectBillsSubsService.conditionalQueryProjectSubs(map);
            pageDto.setRecords(projectBillsSubsList);
            map.put("page", pageDto);
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> querySettlementProjectSubs(Page pageDto, ProjectBillsSubsDto projectBillsSubsDto) {
        Map<String, Object> mapVal = new HashMap<>();
        Page page = DataUtils.processingPage(pageDto);
        mapVal.put("size", page.getSize());
        mapVal.put("current", page.getCurrent());
        mapVal.put("proSub", projectBillsSubsDto);
        int count = projectBillsSubsService.querySettlementProjectSubsCount(mapVal);
        if (count != 0) {
            List<ProjectBillsSubs> projectBillsSubsList = projectBillsSubsService.querySettlementProjectSubs(mapVal);
            page.setTotal(count);
            page.setRecords(projectBillsSubsList);
            mapVal.put("page", page);
            return mapVal;
        }
        return null;
    }

    @Override
    public Map<String, Object> queryProjectSummaryData(ProjectBillsSubsDto projectBillsSubsDto) {
        boolean isNull = false;
        if (projectBillsSubsDto != null && projectBillsSubsDto.getId() != null) {
            Map<String, Object> map = new HashMap<>();
            map.put("proSub", projectBillsSubsDto);
            Map<String, Object> mapList = projectBillsSubsService.selectProjectSummaryData(map);
            map.put("form", mapList);
            if (mapList.containsKey("projectSubNo")) {
                map.put("projectSubNo", mapList.get("projectSubNo"));
                List<Map<String, Object>> maps = projectBillsSubsService.selectSubContractData(map);
                if (maps.size() != 0) {
                    map.put("subPro", maps);
                } else {
                    isNull = true;
                }
                ProjectBillsSubs projectBillsSubs = projectBillsSubsService.selectById(projectBillsSubsDto.getId());
                map.put("isNull", isNull);
                List<Map<String, Object>> budgetsDatas = new ArrayList<>();
                budgetsDatas = projectBillsSubsService.selectSubBudgetsData(map);
                if (budgetsDatas.size() != 0) {
                    List<Map<String, Object>> budgetsData = projectBillsSubsService.selectSubInvSharesData(map);
                    for (int i = 0; i < budgetsData.size() - 1; i++) {
                        for (int j = budgetsData.size() - 1; j > i; j--) {
                            String budgetNameI = (String) budgetsData.get(i).get("budgetName");
                            String budgetNameJ = (String) budgetsData.get(j).get("budgetName");
                            String purchNameI = (String) budgetsData.get(i).get("purchName");
                            String purchNameJ = (String) budgetsData.get(j).get("purchName");
                            String budgetAmtI = ((double) budgetsData.get(i).get("budgetAmt") + "");
                            String budgetAmtJ = ((double) budgetsData.get(j).get("budgetAmt") + "");
                            if (budgetNameI.equals(budgetNameJ) && purchNameI.equals(purchNameJ) && budgetAmtI.equals(budgetAmtJ)) {
                                double subAmtCrI = (double) budgetsData.get(i).get("subAmtCr");
                                double subAmtCrJ = (double) budgetsData.get(j).get("subAmtCr");
                                double contractAmtI = (double) budgetsData.get(i).get("contractAmt");
                                double contractAmtJ = (double) budgetsData.get(j).get("contractAmt");
                                double subInvAmtCrI = (double) budgetsData.get(i).get("subInvAmtCr");
                                double subInvAmtCrJ = (double) budgetsData.get(j).get("subInvAmtCr");
                                double contractAuditAmtI = (double) budgetsData.get(i).get("contractAuditAmt");
                                double contractAuditAmtJ = (double) budgetsData.get(j).get("contractAuditAmt");
                                budgetsData.get(i).put("subAmtCr", Double.parseDouble(String.format("%.4f", subAmtCrI + subAmtCrJ)));
                                budgetsData.get(i).put("contractAmt", Double.parseDouble(String.format("%.4f", contractAmtI + contractAmtJ)));
                                budgetsData.get(i).put("subInvAmtCr", Double.parseDouble(String.format("%.4f", subInvAmtCrI + subInvAmtCrJ)));
                                budgetsData.get(i).put("contractAuditAmt", Double.parseDouble(String.format("%.4f", contractAuditAmtI + contractAuditAmtJ)));
                                budgetsData.remove(j);
                            }
                        }
                    }
                    if (budgetsData.size() != 0) {
                        for (int i = 0; i < budgetsData.size(); i++) {
                            String budgetName = (String) budgetsData.get(i).get("budgetName");
                            double iSubInvAmtCr = (double) budgetsData.get(i).get("subInvAmtCr");
                            double iContractAuditAmt = (double) budgetsData.get(i).get("contractAuditAmt");
                            double iContractAmt = (double) budgetsData.get(i).get("contractAmt");
                            String iPurchName = (String) budgetsData.get(i).get("purchName");
                            double iSubAmtCr = (double) budgetsData.get(i).get("subAmtCr");
                            for (int x = 0; x < budgetsDatas.size(); x++) {
                                double xSubInvAmtCr = (double) budgetsDatas.get(x).get("subInvAmtCr");
                                double xContractAuditAmt = (double) budgetsDatas.get(x).get("contractAuditAmt");
                                double xSubAmtCr = (double) budgetsDatas.get(x).get("subAmtCr");
                                String name = (String) budgetsDatas.get(x).get("budgetName");
                                String xPurchName = (String) budgetsDatas.get(x).get("purchName");
                                if (name.equals((budgetName))) {
                                    if (xPurchName == null && "T".equals(projectBillsSubs.getIsSur())) {
                                        budgetsDatas.get(x).put("subInvAmtCr", xSubInvAmtCr - iSubInvAmtCr);
                                        budgetsDatas.get(x).put("subAmtCr", xSubAmtCr - iSubAmtCr);
                                    }
                                    if (xPurchName != null) {
                                        if (iPurchName.equals(xPurchName)) {
                                            budgetsDatas.get(x).put("subInvAmtCr", iSubInvAmtCr + xSubInvAmtCr);
                                            budgetsDatas.get(x).put("contractAuditAmt", iContractAuditAmt + xContractAuditAmt);
                                            budgetsDatas.get(x).put("subAmtCr", iSubAmtCr);
                                            break;
                                        } else {
                                            if ("T".equals(projectBillsSubs.getIsSur())) {
                                                budgetsDatas.add(x + 1, budgetsData.get(i));
                                                break;
                                            }
                                            budgetsDatas.add(x, budgetsData.get(i));
                                            break;
                                        }
                                    } else {
                                        if ("T".equals(projectBillsSubs.getIsSur())) {
                                            budgetsDatas.add(x + 1, budgetsData.get(i));
                                            break;
                                        }
                                        budgetsDatas.get(x).put("purchName", iPurchName);
                                        budgetsDatas.get(x).put("contractAmt", iContractAmt);
                                        budgetsDatas.get(x).put("subInvAmtCr", iSubInvAmtCr);
                                        budgetsDatas.get(x).put("contractAuditAmt", iContractAuditAmt);
                                        budgetsDatas.get(x).put("subAmtCr", iSubAmtCr);
                                        break;
                                    }
                                }
                            }
                        }
                    }
                }
                List<Map<String, Object>> payCrShares = projectBillsSubsService.selectPayCrShares(map);
                if (payCrShares.size() != 0) {
                    for (int y = 0; y < payCrShares.size(); y++) {
                        String yBudgetName = (String) payCrShares.get(y).get("budgetName");
                        String yPurchName = (String) payCrShares.get(y).get("purchName");
                        double ySubInvAmtCr = (double) payCrShares.get(y).get("subInvAmtCr");
                        double yContractAuditAmt = (double) payCrShares.get(y).get("contractAuditAmt");
                        double ySubAmtCr = (double) payCrShares.get(y).get("subAmtCr");
                        long yContractAmt = (long) payCrShares.get(y).get("contractAmt");
                        for (int x = 0; x < budgetsDatas.size(); x++) {
                            String xBudgetName = (String) budgetsDatas.get(x).get("budgetName");
                            String xPurchName = (String) budgetsDatas.get(x).get("purchName");
                            double xSubInvAmtCr = (double) budgetsDatas.get(x).get("subInvAmtCr");
                            double xContractAuditAmt = (double) budgetsDatas.get(x).get("contractAuditAmt");
                            double xSubAmtCr = (double) budgetsDatas.get(x).get("subAmtCr");
                            if (xBudgetName.equals(yBudgetName)) {
                                if (xPurchName == null && "T".equals(projectBillsSubs.getIsSur())) {
                                    budgetsDatas.get(x).put("subInvAmtCr", xSubInvAmtCr - ySubInvAmtCr);
                                    budgetsDatas.get(x).put("subAmtCr", xSubAmtCr - ySubAmtCr);
                                }
                                if (xPurchName != null) {
                                    if (xPurchName.equals(yPurchName) && Objects.equals(xContractAuditAmt, 0)) {
                                        if (Objects.equals(yContractAmt, 0)) {
                                            payCrShares.get(y).put("budgetAmt", budgetsDatas.get(x).get("budgetAmt"));
                                            budgetsDatas.add(x, payCrShares.get(y));
                                        } else {
                                            budgetsDatas.get(x).put("subInvAmtCr", xSubInvAmtCr + ySubInvAmtCr);
                                            budgetsDatas.get(x).put("subAmtCr", xSubAmtCr + ySubAmtCr);
                                        }
                                    } else {
                                        payCrShares.get(y).put("budgetAmt", budgetsDatas.get(x).get("budgetAmt"));
                                        budgetsDatas.add(x, payCrShares.get(y));
                                        break;
                                    }
                                } else {
                                    if ("T".equals(projectBillsSubs.getIsSur())) {
                                        budgetsDatas.add(x + 1, payCrShares.get(y));
                                        break;
                                    }
                                    budgetsDatas.get(x).put("purchName", payCrShares.get(y).get("purchName"));
                                    budgetsDatas.get(x).put("contractAuditAmt", yContractAuditAmt);
                                    budgetsDatas.get(x).put("subInvAmtCr", ySubInvAmtCr);
                                    budgetsDatas.get(x).put("subAmtCr", ySubAmtCr);
                                    break;
                                }
                            }
                        }
                    }
                }
                map.put("subBudgets", budgetsDatas);
            }
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> getProSummaryPage(Map<String, Object> map, SysUserDto sysUserDto) {
        Map<String, Object> objectMap = new HashMap<>();
        SysRole sysRole = subContractBillsService.selectRole(sysUserDto);
        map.put("user", sysUserDto);
        map.put("role", sysRole);
        try {
            int num = projectBillsSubsService.selectProSummaryTotal(map);
            if (num != 0) {
                int current = (int) map.get("current");
                int size = (int) map.get("size");
                if (current <= 1) {
                    current = 0;
                } else {
                    current = (current - 1) * size;
                }
                map.put("size", size);
                map.put("current", current);
                List<Map<String, Object>> mapList = projectBillsSubsService.selectProSummaryRecords(map);
                Page page = new Page();
                page.setRecords(mapList);
                page.setTotal(num);
                objectMap.put("page", page);
                return objectMap;
            }
        } catch (Exception e) {
            logger.error("操作异常：" + e.toString(), e);
        }
        return null;
    }

    @Override
    public Page<ProjectBillsSubsDto> purchaseSubPage(Page<ProjectBillsSubsDto> page, ProjectBillsSubsDto projectBillsSubsDto, SysUserDto sysUserDto) {
        Page pageDto = DataUtils.processingPage(page);
        Map<String, Object> map = new HashMap<>();
        SysRole sysRole = subContractBillsService.selectRole(sysUserDto);
        map.put("user", sysUserDto);
        map.put("role", sysRole);
        map.put("dto", projectBillsSubsDto);
        EntityWrapper<ProjectBillsSubs> subsEntityWrapper = new EntityWrapper<>();
        subsEntityWrapper.eq("IS_SUR", "F");
        int subContractBillsCount = projectBillsSubsService.selectPurchaseResultGoodsItemCount(map);
        if (subContractBillsCount != 0) {
            map.put("current", pageDto.getCurrent());
            map.put("size", pageDto.getSize());
            pageDto.setTotal(subContractBillsCount);
            pageDto.setRecords(projectBillsSubsService.selectPurchaseResultGoodsItem(map));
            return pageDto;
        }
        return null;
    }

    @Override
    public Page<ProjectBillsSubsDto> selectSubPage(Page<ProjectBillsSubsDto> page, ProjectBillsSubsDto projectBillsSubsDto, SysUserDto sysUserDto) {
        Page pageDto = DataUtils.processingPage(page);
        Map<String, Object> map = new HashMap<>();
        SysRole sysRole = subContractBillsService.selectRole(sysUserDto);
        map.put("user", sysUserDto);
        map.put("role", sysRole);
        map.put("dto", projectBillsSubsDto);
        int subContractBillsCount = projectBillsSubsService.selectPurchaseResultCount(map);
        if (subContractBillsCount != 0) {
            map.put("current", pageDto.getCurrent());
            map.put("size", pageDto.getSize());
            pageDto.setTotal(subContractBillsCount);
            List<Map<String, Object>> maps = projectBillsSubsService.selectPurchaseResult(map);
            for (Map<String, Object> inmap : maps) {
                Object projectSubNo = inmap.get("projectSubNo");
                Object branchId = inmap.get("branchId");
                if (null != projectSubNo && null != branchId) {
                    Integer qty = this.projectBillsSubsService.getQTY(projectSubNo, branchId);
                    Integer bicQTY = this.projectBillsSubsService.getBicQTY(projectSubNo, 6);
                    inmap.put("qty", qty);
                    inmap.put("bicQty", bicQTY);
                }
            }
            pageDto.setRecords(maps);
            return pageDto;
        }
        return null;
    }

    @Override
    public Map<String, Object> queryProjectBillsSubs(ProjectBillsSubsDto projectBillsSubsDto) {
        if (projectBillsSubsDto != null && projectBillsSubsDto.getId() != null) {
            Map<String, Object> map = new HashMap<>();
            ProjectBillsSubs projectBillsSubs = projectBillsSubsService.selectById(projectBillsSubsDto.getId());
            map.put("proSub", projectBillsSubs);
            EntityWrapper<ProjectBillsSubs> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "is_sur").eq("id", projectBillsSubsDto.getId());
            ProjectBillsSubs billsSubs = projectBillsSubsService.selectOne(entityWrapper);
            if ("F".equals(billsSubs.getIsSur())) {
                map.put("inv", payDrBillsItemsService.selectInvoiceBillsPrice(projectBillsSubsDto.getId()));
            } else {
                map.put("inv", payDrBillsItemsService.selectSubProjectAmt(projectBillsSubsDto.getId()));
            }
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> moneySettlementPage(Map<String, Object> params, SysUserDto sysUserDto) {
        /**
         * 未提出 选择条件 暂不添加选择条件
         */
        Map<String, Object> objectMap = new HashMap<>();
        SysRole sysRole = subContractBillsService.selectRole(sysUserDto);
        params.put("user", sysUserDto);
        params.put("role", sysRole);
        int num = projectBillsSubsService.selectMoneySettlementTotal(params);
        if (num != 0) {
            int current = (int) params.get("current");
            int size = (int) params.get("size");
            if (current <= 1) {
                current = 0;
            } else {
                current = (current - 1) * size;
            }
            params.put("size", size);
            params.put("current", current);
            List<Map<String, Object>> mapList = projectBillsSubsService.selectMoneySettlementRecords(params);
            Page page = new Page();
            page.setRecords(mapList);
            page.setTotal(num);
            objectMap.put("page", page);
            return objectMap;
        }
        return null;
    }

    @Override
    public Map<String, Object> queryClosingVal(Integer integer, SysUserDto sysUserDto) {
        if (integer != null) {
            Map<String, Object> map = new HashMap<>();
            Map<String, Object> objectMap = projectBillsSubsService.selectClsingVal(integer);
            List<ProjectBillsBudgets> budgetMap = projectBillsSubsService.selectClsingBudgets(integer);
            List<Map<String, Object>> auditList = auditItemsService.selectClsingAuditItems(integer, sysUserDto.getLoginContractorId());
            map.put("form", objectMap);
            map.put("budgets", budgetMap);
            map.put("audits", auditList);
            return map;
        }
        return null;
    }


    @Override
    public Map<String, Object> projectBalancePage(Map<String, Object> map, SysUserDto sysUserDto) {
        Map<String, Object> objectMap = new HashMap<>();
        SysRole sysRole = subContractBillsService.selectRole(sysUserDto);
        map.put("user", sysUserDto);
        map.put("role", sysRole);
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            if (map.get("startDate") != null && map.get("startDate") != "") {
                long startimes = (long) map.get("startDate");
                String startTime = sdf.format(new Date(startimes));
                map.put("startDateTime", startTime);
            }
            if (map.get("endDate") != null && map.get("endDate") != "") {
                long endtimes = (long) map.get("endDate");
                LocalDateTime localDateTime = LocalDateTime.ofInstant(Instant.ofEpochMilli(endtimes), ZoneId.systemDefault());
                LocalDateTime endOfDay = localDateTime.with(LocalTime.MAX);
                Date from = Date.from(endOfDay.atZone(ZoneId.systemDefault()).toInstant());
                String endTime = sdf.format(from);
                map.put("endDateTime", endTime);
            }
            int num = projectBillsSubsService.selectBalanceTotal(map);
            if (num != 0) {
                int current = (int) map.get("current");
                int size = (int) map.get("size");
                if (current <= 1) {
                    current = 0;
                } else {
                    current = (current - 1) * size;
                }
                map.put("size", size);
                map.put("current", current);
                List<Map<String, Object>> mapList = projectBillsSubsService.selectBalanceRecords(map);
                Page page = new Page();
                page.setRecords(mapList);
                page.setTotal(num);
                objectMap.put("page", page);
                return objectMap;
            }
        } catch (Exception e) {
            logger.error("操作异常：" + e.toString(), e);
        }
        return null;
    }

    @Override
    public Map<String, Object> queryPayInvoiceVal(Page page, ProjectBillsBudgetsDto projectBillsBudgetsDto, SysUserDto sysUserDto) {
        if (projectBillsBudgetsDto != null && projectBillsBudgetsDto.getBudgetId() != null) {
            Map<String, Object> map = new HashMap<>();
            map.put("proSub", projectBillsBudgetsDto);
            map.put("proBudget", projectBillsBudgetsDto);
            map.put("user", sysUserDto);
            int total = projectBillsSubsService.queryPayInvoiceTotal(map);
            if (total != 0) {
                Page pageDto = DataUtils.processingPage(page);
                map.put("current", pageDto.getCurrent());
                map.put("size", pageDto.getSize());
                List<ProjectBillsSubs> projectBillsSubs = projectBillsSubsService.queryPayInvoiceRecordsNew(
                        pageDto.getCurrent(),
                        pageDto.getSize(),
                        projectBillsBudgetsDto.getProjectSubName(),
                        projectBillsBudgetsDto.getNcProjectNo(),
                        projectBillsBudgetsDto.getProjectSubNo(),
                        sysUserDto.getLoginContractorId(),
                        projectBillsBudgetsDto.getBudgetId());
                pageDto.setTotal(total);
                pageDto.setRecords(projectBillsSubs);
                map.put("page", pageDto);
            }
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> getEngineeringPage(Page page, ProjectBillsSubsDto projectBillsSubsDto, SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        map.put("proSub", projectBillsSubsDto);
        map.put("user", sysUserDto);
        int total = projectBillsSubsService.selectEngineeringTotal(map);
        if (total != 0) {
            Page pageDto = DataUtils.processingPage(page);
            map.put("current", pageDto.getCurrent());
            map.put("size", pageDto.getSize());
            List<Map<String, Object>> mapList = projectBillsSubsService.selectEngineeringRecords(map);
            pageDto.setRecords(mapList);
            pageDto.setTotal(total);
            map.put("page", pageDto);
            return map;
        }
        return null;
    }

    @Override
    public List<Map<String, Object>> engineeringExportExcel(ProjectBillsSubsDto projectBillsSubsDto) {
        List<Map<String, Object>> mapList = projectBillsSubsService.selectEngineeringExportExcel(projectBillsSubsDto);
        int line = 0;
        for (Map<String, Object> mp : mapList) {
            line++;
            mp.put("serialNumber", line);
            int status = (int) mp.get("projectStatus");
            if (Objects.equals(status, 10)) {
                mp.put("projectStatusName", "未开工");
            } else if (Objects.equals(status, 20)) {
                mp.put("projectStatusName", "施工中");
            } else if (Objects.equals(status, 30)) {
                mp.put("projectStatusName", "已竣工");
            } else if (Objects.equals(status, 40)) {
                mp.put("projectStatusName", "已结算");
            } else if (Objects.equals(status, 50)) {
                mp.put("projectStatusName", "已结项");
            }
        }
        return mapList;
    }

    @Override
    public List<Map<String, Object>> subsistingExportExcel(ProjectBillsSubsDto projectBillsSubsDto, SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        map.put("proSub", projectBillsSubsDto);
        map.put("user", sysUserDto);
        List<Map<String, Object>> mapList = projectBillsSubsService.selectSubsistingExportExcel(map);
        int line = 0;
        for (Map<String, Object> mp : mapList) {
            line++;
            mp.put("serialNumber", line);
            int status = (int) mp.get("projectStatus");
            if (Objects.equals(status, 10)) {
                mp.put("projectStatusName", "未开工");
            } else if (Objects.equals(status, 20)) {
                mp.put("projectStatusName", "施工中");
            } else if (Objects.equals(status, 30)) {
                mp.put("projectStatusName", "已竣工");
            } else if (Objects.equals(status, 40)) {
                mp.put("projectStatusName", "已结算");
            } else if (Objects.equals(status, 50)) {
                mp.put("projectStatusName", "已结项");
            }
        }
        return mapList;
    }
}
