
package io.platform.projectSettlement.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;


import io.platform.projectSettlement.biz.entity.ProjectAnnex;
import io.platform.projectSettlement.biz.service.ProjectAnnexService;
import io.platform.projectSettlement.dto.ProjectAnnexDto;
import io.platform.projectSettlement.service.client.api.ProjectAnnexServiceClient;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class ProjectAnnexServiceClientImpl extends BaseServiceClient<ProjectAnnex, ProjectAnnexDto> implements ProjectAnnexServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private ProjectAnnexService projectAnnexService;

    @Override
    public ProjectAnnexDto queryObject(Long id) {
        ProjectAnnex projectAnnex = projectAnnexService.selectById(id);
        ProjectAnnexDto projectAnnexDto = new ProjectAnnexDto();
        BeanUtils.copyProperties(projectAnnex, projectAnnexDto);
        return projectAnnexDto;
    }

    @Override
    public List<ProjectAnnexDto> queryList(Map<String, Object> map) {
        List<ProjectAnnex> projectAnnexList = projectAnnexService.selectByMap(map);
        return convertList(projectAnnexList, ProjectAnnexDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<ProjectAnnex> ew = new EntityWrapper<>();
        ew.allEq(map);
        return projectAnnexService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(ProjectAnnexDto projectAnnexDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectAnnex projectAnnex = new ProjectAnnex();
            revert(projectAnnexDto, projectAnnex);
            boolean flag = projectAnnexService.insert(projectAnnex);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(ProjectAnnexDto projectAnnexDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            ProjectAnnex projectAnnex = new ProjectAnnex();
            revert(projectAnnexDto, projectAnnex);

            boolean flag = projectAnnexService.updateById(projectAnnex);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectAnnexService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = projectAnnexService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<ProjectAnnexDto> getPage(Page<ProjectAnnexDto> pageDto, ProjectAnnexDto projectAnnexDto) {
        Page<ProjectAnnex> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        ProjectAnnex projectAnnex = new ProjectAnnex();
        revert(projectAnnexDto, projectAnnex);
        EntityWrapper<ProjectAnnex> wrapper = new EntityWrapper<>();
        wrapper.setEntity(projectAnnex);
        page = projectAnnexService.selectPage(page, wrapper);
        List<ProjectAnnexDto> projectAnnexDtoList = convertList(page.getRecords(), ProjectAnnexDto.class);
        pageDto.setTotal(projectAnnexService.selectCount(wrapper));
        pageDto.setRecords(projectAnnexDtoList);
        return pageDto;
    }
}
