
package io.platform.sys.biz.service;

import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.baomidou.mybatisplus.service.impl.ServiceImpl;
import io.platform.base.common.exception.RRException;
import io.platform.base.common.utils.Constant;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.mapper.SysUserMapper;
import io.platform.sys.dto.SysUserDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Service("sysUserService")
public class SysUserService extends ServiceImpl<SysUserMapper, SysUser> {
    @Autowired
    private SysUserRoleService sysUserRoleService;
    @Autowired
    private SysRoleService sysRoleService;

    public Long queryId(SysUserDto user) {
        return baseMapper.queryId(user);
    }

    public List<String> queryAllPerms(Long userId) {
        return baseMapper.queryAllPerms(userId);
    }

    public List<Long> queryAllMenuId(Long userId) {
        return baseMapper.queryAllMenuId(userId);
    }

    public List<HashMap<String,String>> selectListPage(SysUserDto sysUserDto, SysUserDto userDto) {
        return baseMapper.selectListPage(sysUserDto, userDto);
    }

    public int selectListTotal(SysUserDto sysUserDto, SysUserDto userDto) {
        return baseMapper.selectListTotal(sysUserDto, userDto);
    }

    public SysUser queryByUserName(String username) {
        return baseMapper.queryByUserName(username);
    }


    @Transactional
    public void save(SysUser user) {
        user.setCreateTime(new Date());
        this.insert(user);

        //检查角色是否越权
        checkRole(user);

        //保存用户与角色关系
        sysUserRoleService.saveOrUpdate(user.getUserId(), user.getRoleIdList());
    }

    @Transactional
    public void update(SysUser user) {

        this.updateById(user);

        //检查角色是否越权
        checkRole(user);

        //保存用户与角色关系
        sysUserRoleService.saveOrUpdate(user.getUserId(), user.getRoleIdList());
    }

    public boolean updatePassword(Long userId, String password, String newPassword) {
        SysUser userEntity = new SysUser();
        userEntity.setPassword(newPassword);
        return this.update(userEntity,
                new EntityWrapper<SysUser>().eq("user_id", userId).eq("password", password));
    }

    /**
     * 检查角色是否越权
     */
    private void checkRole(SysUser user) {
        //  || user.getRoleIdList().size() == 0
        if (user.getRoleIdList() == null) {
            return;
        }
        //如果不是超级管理员，则需要判断用户的角色是否自己创建
        if (user.getCreateUserId() == Constant.SUPER_ADMIN) {
            return;
        }

        //查询用户创建的角色列表
        List<Long> roleIdList = sysRoleService.queryRoleIdList(user.getCreateUserId());

        //判断是否越权
/*        if (!roleIdList.containsAll(user.getRoleIdList())) {
            throw new RRException("新增用户所选角色，不是本人创建");
        }*/
    }

    /**
     * 模糊查询经理权限人员
     *
     * @param sysUserDto
     * @return
     */
    public List<SysUser> fuzzyQueryUser(SysUserDto sysUserDto) {
        return baseMapper.fuzzyQueryUser(sysUserDto);
    }

    public List<SysUser> selectProjectUser(Integer branchId) {
        return baseMapper.selectProjectUser(branchId);
    }

    public List<SysUser> selectProjectManagers(Map<String, Object> map) {
        return baseMapper.selectProjectManagers(map);
    }

    public int updateLoginContractorId(SysUserDto sysUserDto) {
        return baseMapper.updateLoginContractorId(sysUserDto);
    }

}
