
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.xiaoleilu.hutool.util.CollectionUtil;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysRole;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.entity.SysUserRole;
import io.platform.sys.biz.service.SysRoleMenuService;
import io.platform.sys.biz.service.SysRoleService;
import io.platform.sys.biz.service.SysUserRoleService;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysRoleDto;
import io.platform.sys.dto.SysUserDto;
import io.platform.sys.service.client.api.SysRoleServiceClient;
import io.platform.utils.DataUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = SysRoleServiceClient.class)
public class SysRoleServiceClientImpl extends BaseServiceClient<SysRole, SysRoleDto> implements SysRoleServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysRoleService sysRoleService;
    @Resource
    private SysRoleMenuService sysRoleMenuService;
    @Resource
    private SysUserService sysUserService;
    @Resource
    private SysUserRoleService sysUserRoleService;

    @Override
    public SysRoleDto queryObject(Long roleId) {
        SysRole sysRole = sysRoleService.selectById(roleId);

        SysRoleDto sysRoleDto = new SysRoleDto();
        BeanUtils.copyProperties(sysRole, sysRoleDto);
        //查询角色对应的菜单
        List<Long> menuIdList = sysRoleMenuService.queryMenuIdList(roleId);
        sysRoleDto.setMenuIdList(menuIdList);
        return sysRoleDto;
    }

    @Override
    public List<SysRoleDto> queryList(SysUserDto sysUserDto) {
/*        EntityWrapper<SysUserRole> sysUserRoleEntityWrapper = new EntityWrapper<>();
        sysUserRoleEntityWrapper.eq("user_id",sysUserDto.getUserId());
        sysUserRoleEntityWrapper.eq("role_id",1);
        SysUserRole sysUserRole = sysUserRoleService.selectOne(sysUserRoleEntityWrapper);*/
        Map<String, Object> map = new HashMap<>();
/*        if (sysUserDto.getLoginContractorId() != 1) { // 1 代表集团用户
            map.put("branch_id", sysUserDto.getLoginContractorId());
        }*/
        map.put("branch_id", sysUserDto.getLoginContractorId());
        List<SysRole> sysRoleList = sysRoleService.selectByMap(map);
        return convertList(sysRoleList, SysRoleDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<SysRole> ew = new EntityWrapper<>();
        ew.allEq(map);
        return sysRoleService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(SysRoleDto sysRoleDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysRole sysRole = new SysRole();
            revert(sysRoleDto, sysRole);
            sysRole.setMenuIdList(sysRoleDto.getMenuIdList());
            sysRoleService.save(sysRole);
            result.setSuccessMessage("创建成功");
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysRoleDto sysRoleDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysRole sysRole = sysRoleService.selectById(sysRoleDto.getRoleId());
            if (CollectionUtil.isNotEmpty(sysRoleDto.getMenuIdList())) {
                sysRole.setMenuIdList(sysRoleDto.getMenuIdList());
            }
            if (!StringUtils.isEmpty(sysRoleDto.getRoleName())) {
                sysRole.setRoleName(sysRoleDto.getRoleName());
            }
            if (!StringUtils.isEmpty(sysRoleDto.getRemark())) {
                sysRole.setRemark(sysRoleDto.getRemark());
            }
            if (!StringUtils.isEmpty(sysRoleDto.getDataAuthority())) {
                sysRole.setDataAuthority(sysRoleDto.getDataAuthority());
            }
            sysRoleService.update(sysRole);
            result.setSuccessMessage("更新成功");
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysRoleService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (ids.size() != 0) {
                for (Long lo : ids) {
                    EntityWrapper<SysUserRole> sysUserRoleEntityWrapper = new EntityWrapper<>();
                    sysUserRoleEntityWrapper.setSqlSelect("id").eq("role_id", lo);
                    List<SysUserRole> sysUserRoles = sysUserRoleService.selectList(sysUserRoleEntityWrapper);
                    if (sysUserRoles.size() != 0) {
                        result.addErrorMessage("角色管理已使用，不可删除");
                    }
                    boolean flag = sysRoleService.deleteById(lo);
                    if (!flag) {
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        result.addErrorMessage("批量删除失败。");
                    }
                }
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysRoleDto> getPage(Page pageDto, SysRoleDto sysRoleDto, SysUserDto userDto) {
        EntityWrapper<SysRole> sysRoleEntityWrapper = new EntityWrapper<>();
//        if (userDto.getLoginContractorId() != 1) {
            sysRoleEntityWrapper.eq("branch_id",userDto.getLoginContractorId());
//        }
        if (sysRoleDto.getRoleName() != null) {
            sysRoleEntityWrapper.like("role_name", "" + sysRoleDto.getRoleName() + "");
        }
        int number = sysRoleService.selectCount(sysRoleEntityWrapper);
        if (number != 0) {
            Page page = DataUtils.processingPage(pageDto);
            sysRoleEntityWrapper.last("LIMIT " + page.getCurrent() + "," + page.getSize());
            List<SysRole> sysRoles = sysRoleService.selectList(sysRoleEntityWrapper);
            page.setTotal(number);
            page.setRecords(sysRoles);
            return page;
        }
        return null;
    }
}
