
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysSmsLog;
import io.platform.sys.biz.service.SysSmsLogService;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysSmsLogDto;
import io.platform.sys.service.client.api.SysSmsLogServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysSmsLogServiceClientImpl extends BaseServiceClient<SysSmsLog,SysSmsLogDto> implements SysSmsLogServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysSmsLogService sysSmsLogService;
    @Resource
    private SysUserService sysUserService;

    @Override
    public SysSmsLogDto queryObject(Long id) {
        SysSmsLog sysSmsLog = sysSmsLogService.selectById(id);
        SysSmsLogDto sysSmsLogDto = new SysSmsLogDto();
        BeanUtils.copyProperties(sysSmsLog,sysSmsLogDto);
        return sysSmsLogDto;
    }

    @Override
    public List<SysSmsLogDto> queryList(Map<String, Object> map) {
        List<SysSmsLog> sysSmsLogList = sysSmsLogService.selectByMap(map);
        return convertList(sysSmsLogList, SysSmsLogDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<SysSmsLog> ew = new EntityWrapper<>();
        ew.allEq(map);
        return sysSmsLogService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(SysSmsLogDto sysSmsLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            //TODO 发送短信

            SysSmsLog sysSmsLog = new SysSmsLog();
            revert(sysSmsLogDto,sysSmsLog);
            boolean flag = sysSmsLogService.insert(sysSmsLog);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysSmsLogDto sysSmsLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysSmsLog sysSmsLog = new SysSmsLog();
            revert(sysSmsLogDto,sysSmsLog);

            boolean flag = sysSmsLogService.updateById(sysSmsLog);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysSmsLogService.deleteById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysSmsLogService.deleteBatchIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysSmsLogDto> getPage(Page<SysSmsLogDto> pageDto, SysSmsLogDto sysSmsLogDto) {
        Page<SysSmsLog> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        SysSmsLog sysSmsLog = new SysSmsLog();
        revert(sysSmsLogDto,sysSmsLog);
        EntityWrapper<SysSmsLog> wrapper = new EntityWrapper<>();
        wrapper.setEntity(sysSmsLog);
        page = sysSmsLogService.selectPage(page,wrapper);
        List<SysSmsLogDto> sysSmsLogDtoList = convertList(page.getRecords(), SysSmsLogDto.class);
//        if (!CollectionUtils.isEmpty(sysSmsLogDtoList)){
//            sysSmsLogDtoList.forEach(s->{
                  //暂时不需要发送人
//                SysUser sysUser = sysUserService.selectById(s.getUserId());
//            });
//        }
        pageDto.setTotal(sysSmsLogService.selectCount(wrapper));
        pageDto.setRecords(sysSmsLogDtoList);
        return pageDto;
    }
}
