
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.xiaoleilu.hutool.util.CollectionUtil;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.engineering.biz.entity.Bdepts;
import io.platform.engineering.biz.entity.Bempls;
import io.platform.engineering.biz.entity.BpriceModes;
import io.platform.engineering.biz.service.BdeptsService;
import io.platform.engineering.dto.BbranchsDto;
import io.platform.project.service.client.api.AttachFilesServiceClient;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.entity.SysUserRole;
import io.platform.sys.biz.service.SysUserRoleService;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysUserDto;
import io.platform.sys.dto.SysUserRoleDto;
import io.platform.sys.service.client.api.SysUserServiceClient;
import io.platform.utils.DataUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

import javax.annotation.Resource;
import java.util.*;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service(version = "1.0.0", interfaceClass = SysUserServiceClient.class)
public class SysUserServiceClientImpl extends BaseServiceClient<SysUser, SysUserDto> implements SysUserServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private BdeptsService bdeptsService;
    @Resource
    private SysUserService sysUserService;
    @Resource
    private SysUserRoleService sysUserRoleService;

    @Override
    public SysUserDto queryObject(Long id) {
        SysUser sysUser = sysUserService.selectById(id);
        SysUserDto sysUserDto = new SysUserDto();
        BeanUtils.copyProperties(sysUser, sysUserDto);
        return sysUserDto;
    }

    @Override
    public List<SysUserDto> queryList(Map<String, Object> map) {
        List<SysUser> sysUserList = sysUserService.selectByMap(map);
        return convertList(sysUserList, SysUserDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<SysUser> ew = new EntityWrapper<>();
        ew.allEq(map);
        return sysUserService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (!sysUserDto.getUsername().equals("admin")) {
                SysUser sysUser = new SysUser();
                revert(sysUserDto, sysUser);
                /*if (CollectionUtil.isNotEmpty(sysUserDto.getRoleIdList())) {
                    sysUser.setRoleIdList(sysUserDto.getRoleIdList());
                }
                boolean flag = sysUserService.insert(sysUser);
                Boolean isRole = true;
                if (sysUser.getRoleIdList() != null && !sysUser.getRoleIdList().isEmpty()) {
                    Long id = sysUserService.queryId(sysUserDto);
                    SysUserRole userRole = new SysUserRole();
                    userRole.setUserId(id);
                    for (Long attribute : sysUserDto.getRoleIdList()) {
                        userRole.setRoleId(attribute);
                    }
                    isRole = sysUserRoleService.insert(userRole);
                }*/
                EntityWrapper<SysUser> sysUserRoleEntityWrapper1 = new EntityWrapper<>();
                sysUserRoleEntityWrapper1.eq("username", sysUser.getUsername());
                List<SysUser> sysUserRole1 = sysUserService.selectList(sysUserRoleEntityWrapper1);
                if (sysUserRole1.size() > 0) {
                    result.addErrorMessage("更新错误： 用户名已存在");
                    return result;
                }
                boolean flag = sysUserService.insert(sysUser);
                Long id = sysUserService.queryId(sysUserDto);
                SysUserRole userRole = new SysUserRole();
                userRole.setUserId(id);
                userRole.setRoleId(sysUser.getRoleIdList().longValue());
                boolean isRole = sysUserRoleService.insert(userRole);
                if (!flag || !isRole) {
                    result.addErrorMessage("保存失败。");
                }
            } else {
                result.addErrorMessage("保存失败。无法使用此名称");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (!sysUserDto.getUsername().equals("admin")) {
                if (StringUtils.isNotBlank(sysUserDto.getPassword())) {
                    sysUserDto.setPassword(new Sha256Hash(sysUserDto.getPassword(), sysUserDto.getSalt()).toHex());
                }
                SysUser sysUser = sysUserService.selectById(sysUserDto.getUserId());
                revert(sysUserDto, sysUser);
/*                if (CollectionUtil.isNotEmpty(sysUserDto.getRoleIdList())) {
                    sysUser.setRoleIdList(sysUserDto.getRoleIdList());
                }*/
                EntityWrapper<SysUserRole> sysUserRoleEntityWrapper = new EntityWrapper<>();
                sysUserRoleEntityWrapper.eq("user_id", sysUser.getUserId());
                SysUserRole sysUserRole = sysUserRoleService.selectOne(sysUserRoleEntityWrapper);
                sysUserRole.setRoleId(sysUser.getRoleIdList().longValue());

                EntityWrapper<SysUser> sysUserRoleEntityWrapper1 = new EntityWrapper<>();
                sysUserRoleEntityWrapper1.eq("username", sysUser.getUsername());
                List<SysUser> sysUserRole1 = sysUserService.selectList(sysUserRoleEntityWrapper1);
                if (sysUserRole1.size() == 1) {
                    if (!(sysUserRole1.get(0).getUserId() + "").equals(sysUser.getUserId() + "")) {
                        result.addErrorMessage("更新错误： 用户名已存在");
                        return result;
                    }
                } else if (sysUserRole1.size() > 1) {
                    result.addErrorMessage("更新错误： 用户名已存在");
                    return result;
                }


                sysUserService.update(sysUser);
                sysUserRoleService.updateById(sysUserRole);
                result.setSuccessMessage("更新成功");
            } else {
                result.setSuccessMessage("无法使用此名称");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysUserService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Boolean isRole = true;
            for (Long attribute : ids) {
                isRole = sysUserRoleService.deleteByUserId(attribute);
            }
            boolean flag = sysUserService.deleteBatchIds(ids);
            if (!flag || !isRole) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysUserDto> getPage(Page<SysUserDto> page, SysUserDto sysUserDto, SysUserDto userDto) {
        Page pageDto = DataUtils.processingPage(page);
        List<HashMap<String, String>> sysUserDtoList;
/*        EntityWrapper<SysUserRole> sysUserRoleEntityWrapper = new EntityWrapper<>();
        sysUserRoleEntityWrapper.eq("user_id",userDto.getUserId());
        sysUserRoleEntityWrapper.eq("role_id",1);
        SysUserRole sysUserRole = sysUserRoleService.selectOne(sysUserRoleEntityWrapper);
        if (sysUserRole != null) {
            EntityWrapper<SysUser> sysUserEntityWrapper = new EntityWrapper<>();
            sysUserEntityWrapper.last("LIMIT "+pageDto.getCurrent() + "," + pageDto.getSize());
            sysUserDtoList = sysUserService.selectList(sysUserEntityWrapper);
        } else {
            EntityWrapper<SysUser> userEntityWrapper = new EntityWrapper<>();
            userEntityWrapper.eq("user_id", userDto.getUserId()).or().eq("create_user_id", userDto.getUserId()).last("LIMIT "+pageDto.getCurrent() + "," + pageDto.getSize());
            sysUserDtoList = sysUserService.selectList(userEntityWrapper);
        }*/
//        EntityWrapper<SysUser> userEntityWrapper = new EntityWrapper<>();
//        userEntityWrapper.eq("create_contractor_id", userDto.getLoginContractorId()).last("LIMIT "+pageDto.getCurrent() + "," + pageDto.getSize());
        int sum = sysUserService.selectListTotal(sysUserDto, userDto);
        userDto.setEmail("LIMIT " + pageDto.getCurrent() + "," + pageDto.getSize());
        sysUserDtoList = sysUserService.selectListPage(sysUserDto, userDto);
        pageDto.setTotal(sum);
        pageDto.setRecords(sysUserDtoList);
        return pageDto;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public SysUserDto selectByUserName(String username) {
        SysUser sysUser = sysUserService.queryByUserName(username);
        try {
            SysUserDto sysUse = new SysUserDto();
            sysUse.setUserId(sysUser.getUserId());
            sysUse.setLoginContractorId(sysUser.getContractorId());
            int upNum = sysUserService.updateLoginContractorId(sysUse);
            if (upNum <= 0) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                logger.error(" 初始化登录公司失败");
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 初始化登录公司异常：" + e.toString(), e);
        }

        SysUserDto sysUserDto = new SysUserDto();
        convert(sysUser, sysUserDto);
        return sysUserDto;
    }

    @Override
    public boolean updatePassword(Long userId, String password, String newPassword) {
        return sysUserService.updatePassword(userId, password, newPassword);
    }

    @Override
    public List<String> queryAllPerms(Long userId) {
        return sysUserService.queryAllPerms(userId);
    }

    @Override
    public List<Long> queryAllMenuId(Long userId) {
        return sysUserService.queryAllMenuId(userId);
    }

    @Override
    public Map<String, Object> fuzzyQueryUser(SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        List<SysUser> users = sysUserService.fuzzyQueryUser(sysUserDto);

        if (users.size() != 0) {
            map.put("user", users);
            List<Bdepts> bdeptsList = new ArrayList<>();
            EntityWrapper<Bdepts> entityWrapper = new EntityWrapper<>();
            entityWrapper.setSqlSelect("id", "dept_name");
            if (!Objects.equals(sysUserDto.getLoginContractorId(), 1)) {
                entityWrapper.eq("branch_id", sysUserDto.getLoginContractorId());
            }
            bdeptsList = bdeptsService.selectList(entityWrapper);
            if (bdeptsList.size() != 0) {
                map.put("depts", bdeptsList);
            }
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> selectUser(SysUserDto sysUserDto) {
        Map<String, Object> map = new HashMap<>();
        if (sysUserDto.getUserId() != null) {
            SysUser sysUser = sysUserService.selectById(sysUserDto.getUserId());
            if (sysUser != null) {
                map.put("user", sysUser);
                return map;
            }
        }
        EntityWrapper<SysUser> entityWrapper = new EntityWrapper<>();
        if (sysUserDto.getContractorId() != 1) {
            entityWrapper.eq("contractor_id", sysUserDto.getContractorId());
        }
        entityWrapper.orderBy("CONVERT ( actualname USING gbk ) asc");
        List<SysUser> sysUserList = sysUserService.selectList(entityWrapper);
        if (sysUserList.size() != 0) {
            map.put("users", sysUserList);
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> queryProjectManager(BbranchsDto bbranchsDto) {
        if (bbranchsDto != null && bbranchsDto.getId() != null) {
            Map<String, Object> map = new HashMap<>();
            map.put("branchId", bbranchsDto.getId());
            List<SysUser> sysUserList = sysUserService.selectProjectManagers(map);
            if (sysUserList.size() != 0) {
                map.put("users", sysUserList);
            }
            return map;
        }
        return null;
    }

    @Override
    public void updateloginConId(SysUserDto user) {
        SysUser sysUser = new SysUser();
        sysUser.setUserId(user.getUserId());
        sysUser.setLoginContractorId(user.getLoginContractorId());
        sysUserService.updateById(sysUser);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExecuteResult<String> saveBranch(SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (sysUserDto.getUserId() != null) {
                int num = sysUserService.updateLoginContractorId(sysUserDto);
                if (num <= 0) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    result.addErrorMessage("操作失败");
                    return result;
                }
            } else {
                result.addErrorMessage("未找到信息");
                return result;
            }
        } catch (Exception e) {
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            logger.error(" 修改登录公司失败：" + e.toString(), e);
            result.addErrorMessage("修改登录公司失败");
            return result;
        }
        return result;
    }
}
